import { __decorate, __param } from 'tslib';
import { Input, Component, NgModule, EventEmitter, Output, ChangeDetectionStrategy, Pipe, Inject, ViewChild, ElementRef, Renderer2, HostListener, Directive, Injectable, ComponentFactoryResolver, ViewContainerRef, ViewChildren, ChangeDetectorRef, Optional, SkipSelf, ViewEncapsulation } from '@angular/core';
import { CommonModule, DOCUMENT, PlatformLocation } from '@angular/common';
import { LocalDeviceDetectorService, AnchorService, CryptoService, DateFormatService, RichsnipetService, OptionsNgxOwCarouselService, LoadScrollService, LocalDeviceDetectorModule, FilterService, BuildInterfaceService, SocialNetworksService, SocialNetwork, SocialNetworkServiceModule, InstagramService } from 'dmmp-services';
import * as moment_ from 'moment';
import { PdfViewerModule } from 'ng2-pdf-viewer';
import { DomSanitizer, BrowserModule } from '@angular/platform-browser';
import { RouterModule, ActivatedRoute, Router } from '@angular/router';
import Player from '@vimeo/player';
import { YouTubePlayerModule } from '@angular/youtube-player';
import { NgbNavModule, NgbAccordionModule, NgbCollapseModule, NgbActiveModal, NgbModal, NgbModule } from '@ng-bootstrap/ng-bootstrap';
import { AgmCoreModule } from '@agm/core';
import { NgxJsonLdModule } from 'ngx-json-ld';
import { FormsModule, FormControl, FormGroupDirective, ReactiveFormsModule, Validators, FormBuilder } from '@angular/forms';
import { CarouselModule } from 'ngx-owl-carousel-o';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { InfiniteScrollModule } from 'ngx-infinite-scroll';
import { CookieService } from 'ngx-cookie-service';
import { from, Observable, EMPTY } from 'rxjs';
import { concatMap, scan, last, tap, debounceTime, distinctUntilChanged, filter, map } from 'rxjs/operators';
import { NgxCaptchaModule } from 'ngx-captcha';
import { DeviceDetectorService } from 'ngx-device-detector';
import { trigger, transition, query, style, stagger, animate } from '@angular/animations';
import { untilDestroyed, UntilDestroy } from '@ngneat/until-destroy';

let DescriptionComponent = class DescriptionComponent {
    constructor() { }
    ngOnInit() { }
};
__decorate([
    Input()
], DescriptionComponent.prototype, "data", void 0);
DescriptionComponent = __decorate([
    Component({
        selector: 'dmmp-description',
        template: "<p [innerHTML]=\"data\"></p>\r\n"
    })
], DescriptionComponent);

let DescriptionModule = class DescriptionModule {
};
DescriptionModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [DescriptionComponent],
        exports: [
            DescriptionComponent
        ]
    })
], DescriptionModule);

let ListComponent = class ListComponent {
    constructor() { }
    ngOnInit() { }
};
__decorate([
    Input()
], ListComponent.prototype, "data", void 0);
ListComponent = __decorate([
    Component({
        selector: 'dmmp-list',
        template: "<ul class=\"bullets\">\r\n  <li *ngFor=\"let dat of data\" [innerHTML]=\"dat.content\"></li>\r\n</ul>\r\n"
    })
], ListComponent);

let ListModule = class ListModule {
};
ListModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [ListComponent],
        exports: [
            ListComponent
        ]
    })
], ListModule);

let IconsTextComponent = class IconsTextComponent {
    constructor() { }
    ngOnInit() { }
};
__decorate([
    Input()
], IconsTextComponent.prototype, "data", void 0);
IconsTextComponent = __decorate([
    Component({
        selector: 'dmmp-icons-text',
        template: "<ng-container *ngFor=\"let dat of data; let i = index\">\r\n  <div *ngIf=\"i < 3\" class=\"row align-items-center no-gutters\">\r\n    <div class=\"col-3 col-sm-3 col-md-3 col-lg-3\">\r\n      <div class=\"box-image-icon\"\r\n           [ngClass]=\"dat.class ? dat.class : ''\"\r\n           [id]=\"dat.id_element ? dat.id_element : ''\">\r\n        <img\r\n          [src]=\"dat?.icon[0].styles.large ? dat?.icon[0].styles.large : ''\"\r\n          [alt]=\"dat?.icon[0].texts.alt ? dat?.icon[0].texts.alt : ''\"\r\n          [title]=\"dat?.icon[0].texts.title ? dat?.icon[0].texts.title : ''\"\r\n        />\r\n      </div>\r\n    </div>\r\n    <div class=\"col-9 col-sm-9 col-md-9 col-lg-9\">\r\n      <div class=\"content\">\r\n        <p [innerHTML]=\"dat?.text\"></p>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n\r\n"
    })
], IconsTextComponent);

let IconsTextModule = class IconsTextModule {
};
IconsTextModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [IconsTextComponent],
        exports: [
            IconsTextComponent
        ]
    })
], IconsTextModule);

let HeaderComponent = class HeaderComponent {
    constructor(localDeviceDetector) {
        this.localDeviceDetector = localDeviceDetector;
        this.anchorCustom = new EventEmitter();
        this.medias = [{ style: 'large', media: '(min-width:421px)' }];
    }
};
HeaderComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], HeaderComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], HeaderComponent.prototype, "data", void 0);
__decorate([
    Output()
], HeaderComponent.prototype, "anchorCustom", void 0);
__decorate([
    Input()
], HeaderComponent.prototype, "medias", void 0);
HeaderComponent = __decorate([
    Component({
        selector: 'dmmp-header',
        template: "<header\r\n  *ngIf=\"data?.visible\"\r\n  [id]=\"data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n  [ngClass]=\"data?.class || ''\"\r\n  [style.backgroundColor]=\"\r\n    data?.background_color?.color || ''\r\n  \"\r\n  [style.backgroundImage]=\"\r\n    data?.background_image?.length > 0\r\n      ? 'url(' + data?.background_image[0]?.styles?.large + ')'\r\n      : ''\r\n  \"\r\n  [style.opacity]=\"\r\n    data?.background_color['opacity'] || ''\r\n  \"\r\n  class=\"header\"\r\n>\r\n  <ng-container *ngIf=\"localDeviceDetector?.isDesktop(); else isMobile\">\r\n    <dmmp-desktop-menu\r\n      [data]=\"data?.content || ''\" [identifier]=\"identifier\" [medias]=\"medias\">\r\n    </dmmp-desktop-menu>\r\n  </ng-container>\r\n  <ng-template #isMobile>\r\n    <dmmp-mobile-menu-header\r\n      [data]=\"data?.content || ''\" [identifier]=\"identifier\" [medias]=\"medias\">\r\n    </dmmp-mobile-menu-header>\r\n  </ng-template>\r\n</header>\r\n"
    })
], HeaderComponent);

let MobileMenuComponent = class MobileMenuComponent {
    constructor(anchorService) {
        this.anchorService = anchorService;
        this.menuIsOpened = false;
    }
    closeAndOpenMenu() {
        this.menuIsOpened ? this.menuIsOpened = false : this.menuIsOpened = true;
    }
};
MobileMenuComponent.ctorParameters = () => [
    { type: AnchorService }
];
__decorate([
    Input()
], MobileMenuComponent.prototype, "data", void 0);
__decorate([
    Input()
], MobileMenuComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], MobileMenuComponent.prototype, "medias", void 0);
MobileMenuComponent = __decorate([
    Component({
        selector: 'dmmp-mobile-menu-header',
        template: "<ng-container *ngIf=\"data?.menu?.length > 0\">\r\n  <div class=\"sidebar-container\" *ngIf=\"menuIsOpened\">\r\n    <div class=\"sidebar-container__menu\">\r\n      <div class=\"container\">\r\n        <div class=\"row\">\r\n          <div class=\"col text-right\">\r\n            <div class=\"back-times\" *ngIf=\"menuIsOpened\">\r\n              <button type=\"button\" (click)=\"closeAndOpenMenu()\">\r\n                &times;\r\n              </button>\r\n            </div>\r\n          </div>\r\n        </div>\r\n        <div class=\"row\">\r\n          <dmmp-menu\r\n            [menu]=\"data?.menu || ''\"\r\n            (close)=\"closeAndOpenMenu()\"\r\n          ></dmmp-menu>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n\r\n<div class=\"container\">\r\n  <div class=\"row\">\r\n    <ng-container *ngIf=\"data?.menu?.length > 0\">\r\n      <div class=\"col-2 col-sm-auto\">\r\n        <dmmp-toggle-menu (clickAction)=\"closeAndOpenMenu()\">\r\n        </dmmp-toggle-menu>\r\n      </div>\r\n    </ng-container>\r\n    <div\r\n      [ngClass]=\"\r\n        data?.menu?.length === 0 && !data?.button ? 'col text-center' : 'col-auto'\r\n      \"\r\n      class=\"logo\"\r\n      *ngIf=\"data?.logo[0]\"\r\n    >\r\n      <a\r\n        [href]=\"data?.logo[0]?.link ? data?.logo[0]?.link : ''\"\r\n        (click)=\"anchorService.anchor($event, '#' + data?.logo[0]?.link)\"\r\n      >\r\n        <dmmp-image [images]=\"data?.logo[0]\" [medias]=\"medias\"></dmmp-image>\r\n      </a>\r\n    </div>\r\n\r\n    <div class=\"col-auto ml-auto\" *ngIf=\"data?.button\">\r\n      <div class=\"call-action text-right\">\r\n        <a\r\n          [href]=\"data?.button?.link || ''\"\r\n          (click)=\"anchorService.anchor($event, data?.button?.link)\"\r\n          [class]=\"data?.button?.class || ''\"\r\n          [id]=\"\r\n            data?.button?.id\r\n              ? identifier + '_' + data?.id_element + '_' + data?.button?.id\r\n              : 'button_header'\r\n          \"\r\n          >{{ data?.button?.label }}</a\r\n        >\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], MobileMenuComponent);

let ToggleMenuComponent = class ToggleMenuComponent {
    constructor() {
        this.page = new EventEmitter();
        this.clickAction = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Output()
], ToggleMenuComponent.prototype, "page", void 0);
__decorate([
    Output()
], ToggleMenuComponent.prototype, "clickAction", void 0);
ToggleMenuComponent = __decorate([
    Component({
        selector: 'dmmp-toggle-menu',
        template: "<div class=\"d-xl-none nav-menu\">\r\n  <button class=\"navbar-toggler pull-right\" type=\"button\" data-toggle=\"collapse\"\r\n    data-target=\"#navbarNavDropdown\" aria-controls=\"navbarNavDropdown\" aria-expanded=\"false\"\r\n    aria-label=\"Toggle navigation\" (click)=\"clickAction.emit()\">\r\n    <span class=\"sr-only\">Toggle navigation</span>\r\n    <span class=\"fas fa-bars\"></span>\r\n  </button>\r\n</div>\r\n"
    })
], ToggleMenuComponent);

let DesktopMenuComponent = class DesktopMenuComponent {
    constructor(anchorService) {
        this.anchorService = anchorService;
    }
};
DesktopMenuComponent.ctorParameters = () => [
    { type: AnchorService }
];
__decorate([
    Input()
], DesktopMenuComponent.prototype, "data", void 0);
__decorate([
    Input()
], DesktopMenuComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], DesktopMenuComponent.prototype, "medias", void 0);
DesktopMenuComponent = __decorate([
    Component({
        selector: 'dmmp-desktop-menu',
        template: "<div class=\"container\">\r\n  <div class=\"row no-gutters align-items-center\">\r\n    <div\r\n      class=\"col text-center\"\r\n      [ngClass]=\"\r\n          data?.menu?.length === 0 && !data?.button\r\n            ? 'col text-center'\r\n            : 'col-auto'\r\n        \"\r\n    >\r\n      <div class=\"logo\" *ngIf=\"data?.logo[0]\">\r\n        <a\r\n          [href]=\"\r\n              data?.logo[0]?.link || ''\r\n            \"\r\n          (click)=\"anchorService.anchor($event, '#' + data.logo[0].link)\"\r\n        >\r\n          <dmmp-image [images]=\"data?.logo[0]\" [medias]=\"medias\"></dmmp-image>\r\n        </a>\r\n      </div>\r\n    </div>\r\n    <ng-container *ngIf=\"data?.menu?.length > 0\">\r\n      <div class=\"col\">\r\n        <dmmp-menu [menu]=\"data?.menu || ''\"></dmmp-menu>\r\n      </div>\r\n    </ng-container>\r\n    <div class=\"col-auto ml-auto\" *ngIf=\"data?.button\">\r\n      <div class=\"call-action text-right\">\r\n        <a\r\n          [href]=\"data?.button?.link || ''\"\r\n          (click)=\"anchorService.anchor($event, data?.button?.link)\"\r\n          [class]=\"\r\n              data?.button?.class || ''\r\n            \"\r\n          [id]=\"\r\n              data?.button?.id\r\n                ? identifier +\r\n                  '_' +\r\n                  data?.id_element +\r\n                  '_' +\r\n                  data?.button.id\r\n                : 'button_header'\r\n            \"\r\n        >{{ data?.button?.label }}</a>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], DesktopMenuComponent);

let MenuComponent = class MenuComponent {
    constructor(anchorService) {
        this.anchorService = anchorService;
        this.close = new EventEmitter();
    }
};
MenuComponent.ctorParameters = () => [
    { type: AnchorService }
];
__decorate([
    Input()
], MenuComponent.prototype, "menu", void 0);
__decorate([
    Output()
], MenuComponent.prototype, "close", void 0);
MenuComponent = __decorate([
    Component({
        selector: 'dmmp-menu',
        template: "<div *ngIf=\"menu\" class=\"col menu\">\r\n  <ul class=\"main-menu\">\r\n    <ng-container\r\n      *ngFor=\"let menu of menu | slice: 0:3\"\r\n    >\r\n      <ng-container *ngIf=\"!menu?.parent\">\r\n        <li class=\"main-menu__item\" *ngIf=\"menu?.ancla; else simpleLink\">\r\n          <a\r\n            [href]=\"'#' + menu?.link\"\r\n            (click)=\"anchorService.anchor($event, '#' + menu?.link); close.emit($event)\"\r\n          >{{ menu?.label }}</a\r\n          >\r\n        </li>\r\n        <ng-template #simpleLink>\r\n          <li class=\"main-menu__item\">\r\n            <a [href]=\"menu?.link\">{{ menu?.label }}</a>\r\n          </li>\r\n        </ng-template>\r\n      </ng-container>\r\n    </ng-container>\r\n  </ul>\r\n</div>\r\n"
    })
], MenuComponent);

let CardGeneralResultComponent = class CardGeneralResultComponent {
    constructor() {
        this.image = [];
        this.medias = [{ style: 'large', media: '(min-width:421px)' }];
        this.redirectPage = new EventEmitter();
        this.arraryTypesLabels = [
            { label: 'PROGRAMA', identifier: 'programs' },
            { label: 'EVENTO', identifier: 'event' },
            { label: 'NOTICIA', identifier: 'news' },
            { label: 'BLOG', identifier: 'blog' },
        ];
    }
    ngOnInit() {
        this.getLabelTypes(this.type);
    }
    getLabelTypes(type) {
        let labelType = '';
        this.arraryTypesLabels.filter((item) => {
            if (item.identifier === this.type) {
                labelType = item.label;
            }
        });
        this.type = labelType;
    }
};
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "image", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "title", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "type", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "titleSize", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "description", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "descriptionSize", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "classDescription", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "classTitle", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "classImage", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "medias", void 0);
__decorate([
    Input()
], CardGeneralResultComponent.prototype, "path", void 0);
__decorate([
    Output()
], CardGeneralResultComponent.prototype, "redirectPage", void 0);
CardGeneralResultComponent = __decorate([
    Component({
        selector: 'dmmp-card-general-result',
        template: "<div class=\"card-general-result\">\r\n  <dmmp-path-link [path]=\"path ? path : ''\" (page)=\"redirectPage.emit()\">\r\n    <div class=\"box-content\">\r\n      <ng-container *ngIf=\"image?.length > 0\">\r\n        <div [ngClass]=\"classImage\" class=\"box-image\">\r\n          <dmmp-image [images]=\"image[0]\" [medias]=\"medias\"></dmmp-image>\r\n        </div>\r\n      </ng-container>\r\n      <div class=\"box-texts\">\r\n        <ng-container *ngIf=\"type\">\r\n          <div class=\"box-type\">\r\n            <p>{{ type }}</p>\r\n          </div>\r\n        </ng-container>\r\n        <ng-container *ngIf=\"title\">\r\n          <div class=\"box-title\">\r\n            <p [ngClass]=\"classTitle\" [innerHTML]=\"title | truncatetext: titleSize\"></p>\r\n          </div>\r\n        </ng-container>\r\n        <ng-container *ngIf=\"description\">\r\n          <div class=\"box-description\">\r\n            <div\r\n              [ngClass]=\"classDescription\"\r\n              [innerHTML]=\"description | truncatetext: descriptionSize\"\r\n            ></div>\r\n          </div>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </dmmp-path-link>\r\n</div>\r\n"
    })
], CardGeneralResultComponent);

let ButtonComponent = class ButtonComponent {
    constructor(cryptoService) {
        this.cryptoService = cryptoService;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.close = new EventEmitter();
        this.medias = [{ style: 'large', media: '(min-width:421px)' }];
        this.moment = moment_;
        this.idCryptoElement = 'buy';
    }
    ngOnInit() {
        this.cryptoJson = {
            id_course: this.programId,
            price: this.programPrice,
            date_purchase: '',
            expiration_days: this.programExpiration,
        };
        this.cryptoPayment();
    }
    anchor(event, data) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.anchorCustom.emit({ event: event, id: data });
        }
    }
    cryptoPayment() {
        if (this.data.id_element === this.idCryptoElement &&
            this.data.link &&
            this.data.link.length > 0) {
            this.cryptoJson.date_purchase = this.moment().format('X');
            const code = this.cryptoService.cryptoCode(this.cryptoJson, this.privateKey);
            this.data.link[0].link = `${this.urlPayment}/${this.programId}?token=${code}`;
        }
    }
};
ButtonComponent.ctorParameters = () => [
    { type: CryptoService }
];
__decorate([
    Input()
], ButtonComponent.prototype, "data", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "urlPayment", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "privateKey", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "programId", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "programPrice", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "programExpiration", void 0);
__decorate([
    Output()
], ButtonComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ButtonComponent.prototype, "page", void 0);
__decorate([
    Output()
], ButtonComponent.prototype, "close", void 0);
ButtonComponent = __decorate([
    Component({
        selector: 'dmmp-button',
        template: "<ng-container *ngIf=\"data?.link && data?.link?.length > 0\">\r\n  <a *ngIf=\" data.link[0].link.substring(0, 1) === '/' && !data.file; else dmmpButton\"\r\n     routerLink=\"{{ data.link[0].link ? data.link[0].link : '' }}\"\r\n     [ngClass]=\"data?.class ? data?.class : ''\"\r\n     [id]=\"data?.id_element ? data?.id_element : ''\"\r\n     (click)=\"page.emit(data.link[0].link ? data.link[0].link : '')\"\r\n     [rel]=\"data.nofollow ? 'ugc nofollow' : ''\"\r\n  >\r\n    <ng-container *ngTemplateOutlet=\"contentTpl\"></ng-container>\r\n  </a>\r\n  <ng-template #dmmpButton>\r\n    <a [href]=\" data.file ? data.file : data.link[0].link ? data.link[0].link : ''\"\r\n       [ngClass]=\"data.class ? data.class : ''\"\r\n       [id]=\"data.id_element === idCryptoElement ? data.id_element + '_' + programId : data.id_element\"\r\n       [target]=\"data.target ? data.target : ''\"\r\n       [rel]=\"data.nofollow ? 'ugc nofollow' : ''\"\r\n       (click)=\" data.id_element === idCryptoElement ? cryptoPayment() : anchor($event,data.file ? data.file : data.link[0].link ? data.link[0].link : '');\"\r\n    >\r\n      <ng-container *ngTemplateOutlet=\"contentTpl\"></ng-container>\r\n    </a>\r\n  </ng-template>\r\n</ng-container>\r\n<ng-template #contentTpl>\r\n  {{ data.link[0].name }}\r\n  <ng-container *ngIf=\"data?.icon ? (data?.icon?.length > 0 ? data?.icon[0]?.styles : false) : false\">\r\n    <dmmp-image\r\n      [images]=\"data.icon[0]\"\r\n      [medias]=\"medias\"\r\n      [defaultClass]=\"'btn-icons'\">\r\n    </dmmp-image>\r\n  </ng-container>\r\n</ng-template>\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], ButtonComponent);

let EmbedComponent = class EmbedComponent {
    constructor() { }
    ngOnInit() {
    }
};
__decorate([
    Input()
], EmbedComponent.prototype, "src", void 0);
__decorate([
    Input()
], EmbedComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], EmbedComponent.prototype, "type", void 0);
EmbedComponent = __decorate([
    Component({
        selector: 'dmmp-embed',
        template: "<ng-container *ngIf=\"src && type\">\r\n  <embed [src]=\"src | safe: type\" style=\"width: 100%;\" [class]=\"defaultClass ? defaultClass : ''\"\r\n    allowfullscreen />\r\n</ng-container>\r\n"
    })
], EmbedComponent);

let ContainerComponent = class ContainerComponent {
};
__decorate([
    Input()
], ContainerComponent.prototype, "data", void 0);
__decorate([
    Input()
], ContainerComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ContainerComponent.prototype, "defaultClass", void 0);
ContainerComponent = __decorate([
    Component({
        selector: 'dmmp-container',
        template: "<div *ngIf=\"data && data?.visible\" [id]=\" data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n  [style.backgroundImage]=\"(data?.background_image) && (data?.background_image).length > 0 ? 'url(' + (data?.background_image)[0].styles.large + ')' : ''\"\r\n  [style.backgroundColor]=\"data?.background_color && data?.background_color.color ? data?.background_color.color : ''\"\r\n  [style.opacity]=\"data.background_color && data.background_color.opacity ? data.background_color.opacity : ''\"\r\n  [ngClass]=\"[defaultClass ? defaultClass: '' , data.class ? data.class : '']\">\r\n  <ng-content></ng-content>\r\n</div>\r\n"
    })
], ContainerComponent);

let ImageComponent = class ImageComponent {
    constructor() {
        this.sources = { seo: { title: '', alt: '' }, images: [] };
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e;
        (_a = this.medias) === null || _a === void 0 ? void 0 : _a.forEach((item) => {
            var _a, _b, _c, _d;
            (_b = (_a = this.sources) === null || _a === void 0 ? void 0 : _a.images) === null || _b === void 0 ? void 0 : _b.push({
                url: (_c = this.images) === null || _c === void 0 ? void 0 : _c.styles[item.style],
                media: (_d = item) === null || _d === void 0 ? void 0 : _d.media,
            });
        });
        this.sources.seo = {
            title: (_c = (_b = this.images) === null || _b === void 0 ? void 0 : _b.texts) === null || _c === void 0 ? void 0 : _c.title,
            alt: (_e = (_d = this.images) === null || _d === void 0 ? void 0 : _d.texts) === null || _e === void 0 ? void 0 : _e.alt,
        };
    }
};
__decorate([
    Input()
], ImageComponent.prototype, "images", void 0);
__decorate([
    Input()
], ImageComponent.prototype, "medias", void 0);
__decorate([
    Input()
], ImageComponent.prototype, "defaultClass", void 0);
ImageComponent = __decorate([
    Component({
        selector: 'dmmp-image',
        template: "<picture *ngIf=\"sources?.images ? sources.images.length > 0 : false\">\r\n  <source *ngFor=\"let image of sources.images | slice:1 : sources.images.length\"\r\n          [media]=\"image.media\"\r\n          [srcset]=\"image.url\">\r\n  <img\r\n       [ngClass]=\"defaultClass ? defaultClass : ''\" [src]=\"sources.images[0].url\"\r\n       [alt]=\"sources.seo.alt\"\r\n       [title]=\"sources.seo.title\">\r\n</picture>\r\n\r\n"
    })
], ImageComponent);

let ImageLogoComponent = class ImageLogoComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], ImageLogoComponent.prototype, "data", void 0);
ImageLogoComponent = __decorate([
    Component({
        selector: 'dmmp-image-logo',
        template: "<img [src]=\"data[0].styles.large ? data[0].styles.large : ''\"\r\n     [alt]=\"data[0].texts.alt ? data[0].texts.alt : ''\"\r\n     [title]=\"data[0].texts.title ? data[0].texts.title : ''\">\r\n"
    })
], ImageLogoComponent);

let LinkComponent = class LinkComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.externalLink = new EventEmitter();
    }
    ngOnInit() {
    }
    ancla(event, data) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.anchorCustom.emit({ event: event, id: data });
        }
    }
};
__decorate([
    Input()
], LinkComponent.prototype, "data", void 0);
__decorate([
    Input()
], LinkComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], LinkComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], LinkComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], LinkComponent.prototype, "page", void 0);
__decorate([
    Output()
], LinkComponent.prototype, "externalLink", void 0);
LinkComponent = __decorate([
    Component({
        selector: 'dmmp-link',
        template: "<ng-container [ngSwitch]=\"data.link[0].link.substring(0, 1)\">\r\n  <ng-container *ngSwitchCase=\"'/'\">\r\n    <a (click)=\"page.emit(data.link[0].link ? data.link[0].link : '')\"\r\n      routerLink=\"{{ data.link[0].link ? data.link[0].link : ''}}\"\r\n      [ngClass]=\"[data.class ? data.class : '', defaultClass ? defaultClass : '']\"\r\n      [id]=\"data.id_element && identifier ? data.id_element + '_' + identifier : ''\"\r\n      [rel]=\"data.nofollow ? 'ugc nofollow' : ''\">\r\n      <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n    </a>\r\n  </ng-container>\r\n  <ng-container *ngSwitchCase=\"'#'\">\r\n    <a [target]=\"data.target ? data.target : ''\"\r\n      [ngClass]=\"[data.class ? data.class : '', defaultClass ? defaultClass : '']\"\r\n      [id]=\"data.id_element && identifier ? data.id_element + '_' + identifier : ''\"\r\n      (click)=\"ancla($event, data.link[0].link)\" [rel]=\"data.nofollow ? 'ugc nofollow' : ''\">\r\n      <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n    </a>\r\n  </ng-container>\r\n  <ng-container *ngSwitchDefault>\r\n    <a [href]=\"data.link[0].link ? data.link[0].link : ''\" [target]=\"data.target ? data.target : ''\"\r\n      [ngClass]=\"data.class ? data.class : ''\" [name]=\"data.link[0].name ? data.link[0].name : ''\"\r\n      [id]=\"data.id_element && identifier ? data.id_element + '_' + identifier : ''\"\r\n      [rel]=\"data.nofollow ? 'ugc nofollow' : ''\"\r\n      (click)=\"externalLink.emit(data.link[0].link ? data.link[0].link : '')\">\r\n      <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n    </a>\r\n  </ng-container>\r\n</ng-container>\r\n\r\n<ng-template #content>\r\n  <ng-content></ng-content>\r\n</ng-template>\r\n"
    })
], LinkComponent);

let PdfViewerComponent = class PdfViewerComponent {
    ngOnDestroy() {
        this.pdfSrc = '';
    }
};
__decorate([
    Input()
], PdfViewerComponent.prototype, "pdfSrc", void 0);
__decorate([
    Input()
], PdfViewerComponent.prototype, "defaultClass", void 0);
PdfViewerComponent = __decorate([
    Component({
        selector: 'dmmp-pdf-viewer',
        template: "<div *ngIf=\"pdfSrc\"\r\n  [ngClass]=\"defaultClass ? defaultClass : ''\">\r\n  <pdf-viewer [src]=\"pdfSrc\" [show-all]=\"true\" [original-size]=\"false\" [autoresize]=\"true\" [stick-to-page]=\"true\"\r\n    [show-borders]=\"true\"></pdf-viewer>\r\n</div>\r\n"
    })
], PdfViewerComponent);

let FilterProgramsPipe = class FilterProgramsPipe {
    transform(items, searchString) {
        if (!items) {
            return [];
        }
        if (!searchString || searchString === '') {
            return items;
        }
        return items.filter(item => {
            const categories = item.categories.toString();
            const filter = `${item.title} ${item.keywords} ${categories}`;
            return filter && filter.toLowerCase().includes(searchString.toLowerCase());
        });
    }
};
FilterProgramsPipe = __decorate([
    Pipe({
        name: 'FilterPrograms',
    })
], FilterProgramsPipe);

let EventsPipe = class EventsPipe {
    transform(items, searchString, currentPage, itemsPage, dateModelSearch) {
        if (!items) {
            return [];
        }
        if (!searchString || searchString === '' || !dateModelSearch) {
            return items;
        }
        return items.filter(item => {
            const tabs = item.campus.toString();
            return tabs.toLowerCase().includes(searchString.label.toLowerCase()) && item.date.start >= dateModelSearch.start
                && item.date.start <= dateModelSearch.end;
        }).slice(8 * (currentPage - 1), itemsPage * (currentPage));
    }
};
EventsPipe = __decorate([
    Pipe({
        name: 'Events',
    })
], EventsPipe);

let SafePipe = class SafePipe {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    transform(value, type) {
        switch (type) {
            case 'html':
                return this.sanitizer.bypassSecurityTrustHtml(value);
            case 'url':
                return this.sanitizer.bypassSecurityTrustUrl(value);
            case 'resourceUrl':
                return this.sanitizer.bypassSecurityTrustResourceUrl(value);
            default:
                throw new Error(`Invalid safe type specified: ${type}`);
        }
    }
};
SafePipe.ctorParameters = () => [
    { type: DomSanitizer }
];
SafePipe = __decorate([
    Pipe({
        name: 'safe',
    })
], SafePipe);

let ReplacePipe = class ReplacePipe {
    transform(value) {
        return value.toLowerCase().replace(/ /g, '_');
    }
};
ReplacePipe = __decorate([
    Pipe({ name: 'replace' })
], ReplacePipe);

let RandomPipe = class RandomPipe {
    transform(items, type) {
        if (!items) {
            return [];
        }
        if (type === 'rand') {
            let control = items.length;
            let tempItem;
            let index;
            // Mientras hay elementos en el array
            while (control > 0) {
                // Elige un índice aleatorio
                index = Math.floor(Math.random() * control);
                // Disminuye control en 1
                control--;
                // Cambia el último elemento con él
                tempItem = items[control];
                items[control] = items[index];
                items[index] = tempItem;
            }
            return items;
        }
        else {
            return items;
        }
    }
};
RandomPipe = __decorate([
    Pipe({
        name: 'RandomProgram',
    })
], RandomPipe);

let TruncateTextPipe = class TruncateTextPipe {
    transform(value, length) {
        const biggestWord = 50;
        const elipses = '...';
        if (typeof value === 'undefined') {
            return value;
        }
        if (value.length <= length) {
            return value;
        }
        // truncar a aproximadamente a la longitud correcta
        let truncatedText = value.slice(0, length + biggestWord);
        // ahora corta hasta la longitud correcta
        while (truncatedText.length > length - elipses.length) {
            const lastSpace = truncatedText.lastIndexOf(' ');
            if (lastSpace === -1) {
                break;
            }
            truncatedText = truncatedText.slice(0, lastSpace).replace(/[!,.?]$/, '');
        }
        return `${truncatedText}${elipses}`;
    }
};
TruncateTextPipe = __decorate([
    Pipe({
        name: 'truncatetext',
    })
], TruncateTextPipe);

let ColorOpacityPipe = class ColorOpacityPipe {
    transform(hexCode, opacity) {
        let hex;
        if (hexCode) {
            hex = hexCode.replace('#', '');
            if (hex.length === 3) {
                hex = hex[0] + hex[0] + hex[1] + hex[1] + hex[2] + hex[2];
            }
            const r = parseInt(hex.substring(0, 2), 16), g = parseInt(hex.substring(2, 4), 16), b = parseInt(hex.substring(4, 6), 16);
            return 'rgba(' + r + ',' + g + ',' + b + ',' + opacity + ')';
        }
    }
};
ColorOpacityPipe = __decorate([
    Pipe({ name: 'colorOpacity' })
], ColorOpacityPipe);

let BackgroundImagePipe = class BackgroundImagePipe {
    transform(images, dimensions) {
        if (images.length > 0) {
            return 'url(' + images[0].styles[dimensions] + ')';
        }
        else {
            return '';
        }
    }
};
BackgroundImagePipe = __decorate([
    Pipe({ name: 'backgroundImage' })
], BackgroundImagePipe);

let RemoveHtmlPipe = class RemoveHtmlPipe {
    transform(value) {
        return value.replace(/<(?:.|)*?>/gm, '');
    }
};
RemoveHtmlPipe = __decorate([
    Pipe({
        name: 'removeHtml'
    })
], RemoveHtmlPipe);

let DeleteCharactersFilePipe = class DeleteCharactersFilePipe {
    transform(value, quantity, mobile) {
        if (mobile) {
            return `${value.substring(0, quantity)}..${value.substring(value.lastIndexOf('.'), value.length)}`;
        }
        return value;
    }
};
DeleteCharactersFilePipe = __decorate([
    Pipe({
        name: 'deleteCharactersFile'
    })
], DeleteCharactersFilePipe);

let HighligthSearchText = class HighligthSearchText {
    transform(currentText, currentSearch) {
        const reg = new RegExp(currentSearch, 'gi');
        if (currentText.search(reg) !== -1 && currentSearch !== '') {
            return currentText.replace(reg, `<span class="highligthText">${currentSearch}</span>`);
        }
        else {
            return currentText;
        }
    }
};
HighligthSearchText = __decorate([
    Pipe({ name: 'highligthSearchText' })
], HighligthSearchText);

let ContentTypePipe = class ContentTypePipe {
    transform(value) {
        switch (value) {
            case 'event':
                return 'Evento';
            case 'news':
                return 'Noticias';
            case 'program':
                return 'Programa';
            case 'blog':
                return 'Identidad 21';
            case 'basic_page':
                return 'Institucional';
            default:
                return '';
        }
    }
};
ContentTypePipe = __decorate([
    Pipe({ name: 'contentType' })
], ContentTypePipe);

let PipesModule = class PipesModule {
};
PipesModule = __decorate([
    NgModule({
        imports: [],
        declarations: [
            FilterProgramsPipe,
            SafePipe,
            EventsPipe,
            ReplacePipe,
            RandomPipe,
            TruncateTextPipe,
            ColorOpacityPipe,
            BackgroundImagePipe,
            RemoveHtmlPipe,
            DeleteCharactersFilePipe,
            HighligthSearchText,
            ContentTypePipe
        ],
        exports: [
            FilterProgramsPipe,
            EventsPipe,
            SafePipe,
            ReplacePipe,
            RandomPipe,
            TruncateTextPipe,
            ColorOpacityPipe,
            BackgroundImagePipe,
            RemoveHtmlPipe,
            DeleteCharactersFilePipe,
            HighligthSearchText,
            ContentTypePipe
        ],
        providers: [],
    })
], PipesModule);

let ModalComponent = class ModalComponent {
    constructor() {
        this.openModal = false;
        this.showModal = new EventEmitter();
    }
    closeOutside(data) {
        if (data.target.id === 'modal_cover') {
            this.showModal.emit();
            this.openModal = false;
        }
    }
};
__decorate([
    Input()
], ModalComponent.prototype, "openModal", void 0);
__decorate([
    Input()
], ModalComponent.prototype, "locationVertical", void 0);
__decorate([
    Output()
], ModalComponent.prototype, "showModal", void 0);
ModalComponent = __decorate([
    Component({
        selector: 'dmmp-modal',
        template: "<div *ngIf=\"openModal\" class=\"modal-cover\" id=\"modal_cover\" (click)=\"closeOutside($event)\">\r\n  <div class=\"modal-dialog modal-lg \"\r\n  [ngClass]=\"locationVertical ? locationVertical : ''\">\r\n    <div class=\"modal-content\">\r\n      <div class=\"modal-header\">\r\n        <button type=\"button\" class=\"close\" (click)=\"showModal.emit(); openModal = false\">\r\n          <span aria-hidden=\"true\">\u00D7</span>\r\n        </button>\r\n      </div>\r\n      <div class=\"modal-body\">\r\n        <ng-content></ng-content>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
        styles: [".modal-cover{position:fixed;display:flex;top:0;left:0;background-color:rgba(0,0,0,.43);z-index:100;width:100%;height:100vh;justify-content:center}.modal-header{border-bottom:0 solid #dee2e6;padding:.5rem}.modal-header .close{padding:1rem 1.5rem;color:grey}.modal-header .close i:focus,.modal-header .close:focus{outline:0}.modal-content{z-index:101}.modal-dialog{position:fixed;display:flex;z-index:101;top:0;width:100%;margin:2.75rem auto}"]
    })
], ModalComponent);

let PaginatorComponent = class PaginatorComponent {
    constructor() {
        this.loop = false;
        this.newPageEmitter = new EventEmitter();
    }
    ngOnInit() {
    }
    nextPage() {
        if (this.loop && (this.totalPages < this.currentPage + 1)) {
            this.newPageEmitter.emit({ number: 1, direction: 'next' });
        }
        else {
            this.newPageEmitter.emit({ number: this.currentPage + 1, direction: 'next' });
        }
    }
    previousPage() {
        if (this.loop && (this.currentPage - 1) === 0) {
            this.newPageEmitter.emit({ number: this.totalPages, direction: 'prev' });
        }
        else {
            this.newPageEmitter.emit({ number: this.currentPage - 1, direction: 'prev' });
        }
    }
};
__decorate([
    Input()
], PaginatorComponent.prototype, "currentPage", void 0);
__decorate([
    Input()
], PaginatorComponent.prototype, "totalPages", void 0);
__decorate([
    Input()
], PaginatorComponent.prototype, "loop", void 0);
__decorate([
    Input()
], PaginatorComponent.prototype, "paginatorType", void 0);
__decorate([
    Output()
], PaginatorComponent.prototype, "newPageEmitter", void 0);
PaginatorComponent = __decorate([
    Component({
        selector: 'dmmp-paginator',
        template: "<div [ngSwitch]=\"paginatorType\">\r\n  <div *ngSwitchCase=\"1\">\r\n    <div class=\"col-12 col-sm-6 col-md-6 col-lg-12\">\r\n      <button class=\"previous\" (click)=\"previousPage()\" [disabled]=\"!loop ? currentPage === 1 : false\">\r\n        <i class=\"fas fa-chevron-left\"></i>\r\n      </button>\r\n      <span class=\"active\">{{currentPage}} / {{totalPages}}</span>\r\n      <button class=\"next\" (click)=\"nextPage()\" [disabled]=\"!loop ? currentPage === totalPages : false\">\r\n        <i class=\"fas fa-chevron-right\"></i>\r\n      </button>\r\n    </div>\r\n  </div>\r\n  <div *ngSwitchDefault>\r\n    <div class=\"col-12 col-sm-6 col-md-6 col-lg-12\">\r\n      <button class=\"previous\" (click)=\"previousPage()\" [disabled]=\"currentPage === 1\">\r\n        <i class=\"fas fa-chevron-left\"></i>\r\n      </button>\r\n      <span class=\"active\">{{currentPage}}</span>\r\n      <button class=\"next\" (click)=\"nextPage()\" [disabled]=\"currentPage === totalPages\">\r\n        <i class=\"fas fa-chevron-right\"></i>\r\n      </button>\r\n      <span class=\"total\">de {{totalPages}}</span>\r\n    </div>\r\n  </div>\r\n</div>\r\n\r\n"
    })
], PaginatorComponent);

let SimpleLinkComponent = class SimpleLinkComponent {
    constructor() {
        this.page = new EventEmitter();
    }
};
__decorate([
    Input()
], SimpleLinkComponent.prototype, "data", void 0);
__decorate([
    Input()
], SimpleLinkComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SimpleLinkComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], SimpleLinkComponent.prototype, "page", void 0);
SimpleLinkComponent = __decorate([
    Component({
        selector: 'dmmp-simple-link',
        template: "<a\r\n  *ngIf=\"data?.link[0]?.link?.substring(0, 1) === '/'; else urlLink\"\r\n  routerLink=\"{{ data.link[0].link ? data.link[0].link : '' }}\"\r\n  (click)=\"page.emit(data.link[0].link ? data.link[0].link : '')\"\r\n  [ngClass]=\"data.class ? data.class : ''\"\r\n  [name]=\"data.link[0].name ? data.link[0].name : ''\"\r\n  [id]=\"data.id_element && identifier ? data.id_element + '_' + identifier : ''\"\r\n>\r\n  <ng-container *ngTemplateOutlet=\"contentTpl\"></ng-container>\r\n</a>\r\n<ng-template #urlLink>\r\n  <a\r\n    [href]=\"data.link[0].link ? data.link[0].link : ''\"\r\n    [target]=\"data.target ? data.target : ''\"\r\n    [ngClass]=\"data.class ? data.class : ''\"\r\n    [name]=\"data.link[0].name ? data.link[0].name : ''\"\r\n    [id]=\"\r\n      data.id_element && identifier ? data.id_element + '_' + identifier : ''\r\n    \"\r\n    [rel]=\" data?.field_nofollow ? 'nofollow' : ''\"\r\n  >\r\n    <ng-container *ngTemplateOutlet=\"contentTpl\"></ng-container>\r\n  </a>\r\n</ng-template>\r\n<ng-template #contentTpl><ng-content></ng-content></ng-template>\r\n"
    })
], SimpleLinkComponent);

let WebsiteCardProgramComponent = class WebsiteCardProgramComponent {
    constructor() {
        this.page = new EventEmitter();
    }
    ngOnInit() {
        this.getNewProgram(this.program.created_at, this.program.flag);
    }
    getNewProgram(creationDate, flag) {
        if (flag != null) {
            this.labelFlag = flag.toString().replace('_', ' ');
            this.labelFlagCss = flag.toString().replace('_', '-');
        }
        else {
            const cmsDate = new Date(creationDate * 1000);
            const localDate = new Date();
            const utcCmsDate = Date.UTC(cmsDate.getFullYear(), cmsDate.getMonth(), cmsDate.getDate());
            const utcLocalDate = Date.UTC(localDate.getFullYear(), localDate.getMonth(), localDate.getDate());
            const diffDays = Math.floor((utcLocalDate - utcCmsDate) / (1000 * 60 * 60 * 24));
            if (diffDays <= parseInt(this.differenceDays, 0)) {
                this.labelFlag = 'new';
            }
        }
    }
};
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "program", void 0);
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "differenceDays", void 0);
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "urlPayment", void 0);
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "privateKey", void 0);
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "programId", void 0);
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "programPrice", void 0);
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "programExpiration", void 0);
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "labelCategory", void 0);
__decorate([
    Input()
], WebsiteCardProgramComponent.prototype, "labelPrice", void 0);
__decorate([
    Output()
], WebsiteCardProgramComponent.prototype, "page", void 0);
WebsiteCardProgramComponent = __decorate([
    Component({
        selector: 'dmmp-website-card-program',
        template: "<div class=\"card\">\r\n  <ng-container *ngIf=\"program?.recommended_image.length > 0\">\r\n    <div\r\n      *ngIf=\"labelFlag\"\r\n      class=\"box-portlets {{ program.flag ? labelFlagCss : 'new' }}\"\r\n    >\r\n      <div class=\"portlest\">\r\n        <p\r\n          [style.color]=\"\r\n            program.color_label_tag && program.color_label_tag.color\r\n              ? program.color_label_tag.color\r\n              : ''\r\n          \"\r\n        >\r\n          {{ program.text_tag ? program.text_tag : labelFlag }}\r\n        </p>\r\n      </div>\r\n    </div>\r\n    <div\r\n      class=\"box-image\"\r\n      *ngIf=\"program?.university?.length > 0\"\r\n      routerLink=\"{{ program.path }}\"\r\n      (click)=\"page.emit(program.path)\"\r\n    >\r\n      <dmmp-image\r\n        [images]=\"program.recommended_image[0]\"\r\n        [medias]=\"[\r\n          { style: '280x192', media: '(min-width:421px)' },\r\n          { style: '240x192', media: '(max-width:420px)' }\r\n        ]\"\r\n      ></dmmp-image>\r\n    </div>\r\n  </ng-container>\r\n  <div class=\"card-body\">\r\n    <div class=\"box-text\">\r\n      <div class=\"box-info\">\r\n        <p\r\n          *ngIf=\"program?.second_category?.length > 0\"\r\n          class=\"small-text color-gray-dark\"\r\n        >\r\n          {{ program.second_category[0] }}\r\n        </p>\r\n        <dmmp-website-card-title\r\n          [data]=\"program\"\r\n          [defaultClass]=\"'h4 color-purple-darkest'\"\r\n          (page)=\"page.emit($event)\"\r\n        >\r\n        </dmmp-website-card-title>\r\n      </div>\r\n      <div>\r\n        <p\r\n          *ngIf=\"program?.university?.length > 0\"\r\n          routerLink=\"{{ program.university[0].path }}\"\r\n          (click)=\"page.emit(program.university[0].path)\"\r\n          class=\"color-purple small-text\"\r\n        >\r\n          {{ labelCategory }} {{ program.university[0].title }}\r\n        </p>\r\n        <div\r\n          *ngIf=\"program?.description\"\r\n          class=\"p3 color-gray-dark card-text\"\r\n          [innerHTML]=\"program.description | truncatetext: 140\"\r\n        ></div>\r\n      </div>\r\n      <div class=\"box-duration\">\r\n        <p class=\"duration-calendar mb-0\" *ngIf=\"program.duration\">\r\n          {{ program.duration }}\r\n        </p>\r\n        <p class=\"frecuency-calendar mb-0\" *ngIf=\"program.frecuency\">\r\n          {{ program.frecuency }}\r\n        </p>\r\n      </div>\r\n      <div class=\"box-price\">\r\n        <p *ngIf=\"labelPrice\">\r\n          {{ labelPrice }}\r\n        </p>\r\n      </div>\r\n    </div>\r\n    <div class=\"button-info\">\r\n      <ng-container\r\n        *ngIf=\"\r\n          program?.recommended_buttons && program?.recommended_buttons?.length > 0\r\n        \"\r\n      >\r\n        <ng-container *ngFor=\"let button of program.recommended_buttons\">\r\n          <dmmp-button\r\n            [data]=\"button\"\r\n            [urlPayment]=\"urlPayment\"\r\n            [privateKey]=\"privateKey\"\r\n            [programId]=\"programId\"\r\n            [programPrice]=\"programPrice\"\r\n            [programExpiration]=\"programExpiration\"\r\n            (page)=\"page.emit($event)\"\r\n          >\r\n          </dmmp-button>\r\n        </ng-container>\r\n      </ng-container>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], WebsiteCardProgramComponent);

let WebsiteCardTitleComponent = class WebsiteCardTitleComponent {
    constructor() {
        this.page = new EventEmitter();
    }
};
__decorate([
    Input()
], WebsiteCardTitleComponent.prototype, "data", void 0);
__decorate([
    Output()
], WebsiteCardTitleComponent.prototype, "page", void 0);
__decorate([
    Input()
], WebsiteCardTitleComponent.prototype, "defaultClass", void 0);
WebsiteCardTitleComponent = __decorate([
    Component({
        selector: 'dmmp-website-card-title',
        template: "<ng-container>\r\n  <h3 class=\"title-card\" *ngIf=\"data?.path; else simpleTitle\" routerLink=\"{{ data.path }}\"\r\n    [ngClass]=\"data.card_title_class ? data.card_title_class : defaultClass\" (click)=\"page.emit(data.path)\">\r\n    {{ data.title }}\r\n  </h3>\r\n  <ng-template #simpleTitle>\r\n    <h3 class=\"title-card\" [ngClass]=\"data.card_title_class ? data.card_title_class : defaultClass\">\r\n      {{ data.title }}\r\n    </h3>\r\n  </ng-template>\r\n</ng-container>\r\n"
    })
], WebsiteCardTitleComponent);

let WebsiteCardArticleFeaturedComponent = class WebsiteCardArticleFeaturedComponent {
    constructor(dateFormat) {
        this.dateFormat = dateFormat;
        this.page = new EventEmitter();
    }
};
WebsiteCardArticleFeaturedComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], WebsiteCardArticleFeaturedComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteCardArticleFeaturedComponent.prototype, "type", void 0);
__decorate([
    Output()
], WebsiteCardArticleFeaturedComponent.prototype, "page", void 0);
__decorate([
    Input()
], WebsiteCardArticleFeaturedComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], WebsiteCardArticleFeaturedComponent.prototype, "classArticle", void 0);
WebsiteCardArticleFeaturedComponent = __decorate([
    Component({
        selector: 'dmmp-website-card-article-featured',
        template: "<div class=\"card card-article-featured\">\r\n  <div\r\n    class=\"card-header\"\r\n    *ngIf=\"data?.imagen.length > 0 && type !== 1\"\r\n    routerLink=\"{{ data.path ? data.path : '' }}\"\r\n    (click)=\"page.emit(data.path ? data.path : '')\"\r\n  >\r\n    <dmmp-image\r\n      [images]=\"data.imagen[0]\"\r\n      [medias]=\"[\r\n        { style: '280x192', media: '(min-width:421px)' },\r\n        { style: '272x200', media: '(max-width:420px)' }\r\n      ]\"\r\n    ></dmmp-image>\r\n  </div>\r\n  <div class=\"card-body\">\r\n    <div class=\"box-date\" *ngIf=\"data?.created_at\">\r\n      <p [ngClass]=\"classArticle.date ? classArticle.date : ''\">\r\n        {{\r\n          dateFormat.convertFromTimestampToDate(data?.created_at)\r\n            | date: 'longDate':'UTC'\r\n        }}\r\n      </p>\r\n    </div>\r\n    <div\r\n      class=\"box-title\"\r\n      *ngIf=\"data?.title && data?.path\"\r\n      routerLink=\"{{ data.path ? data.path : '' }}\"\r\n      (click)=\"page.emit(data.path ? data.path : '')\"\r\n    >\r\n      <h2 [ngClass]=\"classArticle.title ? classArticle.title : ''\">\r\n        {{ data.title }}\r\n      </h2>\r\n    </div>\r\n    <div class=\"box-description\" *ngIf=\"data.summary\">\r\n      <p [ngClass]=\"classArticle.summary ? classArticle.summary : ''\">\r\n        {{ data.summary | truncatetext: 130 }}\r\n      </p>\r\n    </div>\r\n    <div class=\"box-button button-content\">\r\n      <a\r\n        *ngIf=\"data?.path\"\r\n        routerLink=\"{{ data.path ? data.path : '' }}\"\r\n        [ngClass]=\"classArticle.buttonClass ? classArticle.buttonClass : ''\"\r\n        (click)=\"page.emit(data.path ? data.path : '')\"\r\n      >\r\n        {{ data.button_label ? data.button_label : '' }}</a\r\n      >\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], WebsiteCardArticleFeaturedComponent);

let WebsiteArticleBannerFeaturedComponent = class WebsiteArticleBannerFeaturedComponent {
    constructor(dateFormat) {
        this.dateFormat = dateFormat;
        this.quantityTitle = 90;
        this.page = new EventEmitter();
    }
};
WebsiteArticleBannerFeaturedComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], WebsiteArticleBannerFeaturedComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteArticleBannerFeaturedComponent.prototype, "type", void 0);
__decorate([
    Input()
], WebsiteArticleBannerFeaturedComponent.prototype, "quantityTitle", void 0);
__decorate([
    Input()
], WebsiteArticleBannerFeaturedComponent.prototype, "classArticle", void 0);
__decorate([
    Output()
], WebsiteArticleBannerFeaturedComponent.prototype, "page", void 0);
WebsiteArticleBannerFeaturedComponent = __decorate([
    Component({
        selector: 'dmmp-website-article-banner-featured',
        template: "<div\r\n  class=\"container main-banner-article\"\r\n>\r\n  <img *ngIf=\"data?.imagen ? data?.imagen?.length > 0 : false\"\r\n       [src]=\"data.imagen[0].styles && data.imagen[0].styles.large ? data.imagen[0].styles.large : ''\"\r\n       [alt]=\"data.imagen[0].texts && data.imagen[0].texts.alt ? data.imagen[0].texts.alt : ''\"\r\n       [title]=\"data.imagen[0].texts && data.imagen[0].texts.title ? data.imagen[0].texts.title : ''\"\r\n       class=\"img-absolute\"/>\r\n  <div class=\"row box-banner\" [id]=\"data?.identifier ? data?.identifier : ''\">\r\n    <div\r\n      class=\"col-md-6 col-12 main-description-article\"\r\n      [style.backgroundColor]=\"\r\n         data.background_color && data.background_color.color\r\n          ? data.opacity_first_box\r\n            ? (data.background_color?.color\r\n              | colorOpacity: data.opacity_first_box)\r\n            : data.background_color.color\r\n          : ''\r\n      \"\r\n    >\r\n      <div class=\"date-content\">\r\n        <p\r\n          *ngIf=\"data?.created_at\"\r\n          [class]=\"classArticle.date ? classArticle.date : ''\"\r\n        >\r\n          {{\r\n          dateFormat.convertFromTimestampToDate(data?.created_at)\r\n            | date: 'longDate':'UTC'\r\n          }}\r\n        </p>\r\n      </div>\r\n      <div\r\n        class=\"icon-content\"\r\n        *ngIf=\"data?.icon && data?.icon?.length > 0\"\r\n        [class]=\"data.icon_class ? data.icon_class : ''\"\r\n      >\r\n        <dmmp-image-logo [data]=\"data?.icon\"></dmmp-image-logo>\r\n      </div>\r\n      <div class=\"title-content\">\r\n        <h1\r\n          *ngIf=\"data?.title\"\r\n          [class]=\"classArticle.title ? classArticle.title : ''\"\r\n        >\r\n          {{data?.title | truncatetext: quantityTitle}}\r\n        </h1>\r\n      </div>\r\n      <ng-container *ngIf=\"type !== 'story'\">\r\n        <div class=\"summary-content\" *ngIf=\"data?.summary\">\r\n          <p [class]=\"classArticle.summary ? classArticle.summary : ''\">\r\n            {{ data?.summary }}\r\n          </p>\r\n        </div>\r\n        <div class=\"button-content\" *ngIf=\"data?.path\">\r\n          <div class=\"box-button button-content\">\r\n            <a\r\n              *ngIf=\"data?.path\"\r\n              routerLink=\"{{ data.path ? data.path : '' }}\"\r\n              [ngClass]=\"\r\n                classArticle.buttonClass ? classArticle.buttonClass : ''\r\n              \"\r\n              (click)=\"page.emit(data.path ? data.path : '')\"\r\n            >\r\n              {{ data.button_label ? data.button_label : '' }}</a\r\n            >\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"type === 'story'\">\r\n        <div\r\n          class=\"button-content\"\r\n          *ngIf=\"data?.categories && data?.categories?.length > 0\"\r\n        >\r\n          <a\r\n            [routerLink]=\"['/articles']\"\r\n            [queryParams]=\"{ category: data.categories }\"\r\n            (click)=\"page.emit('/articles?category=' + data.categories)\"\r\n            class=\"button-ghost white\"\r\n          >\r\n            {{ data.categories }}\r\n          </a>\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], WebsiteArticleBannerFeaturedComponent);

let H1Component = class H1Component {
    constructor() {
        this.arrayTypesLabels = ['programs', 'event', 'news', 'blog', 'campus'];
    }
    ngOnInit() {
        const hasTitle = this.layout.identifier !== null && this.arrayTypesLabels.some(type => type === this.layout.identifier);
        if (this.data.h1_filter === true) {
            this.text = this.data.name ? this.data.name : '';
        }
        else {
            if (this.layout !== undefined) {
                this.text =
                    this.layout.identifier === 'event' && hasTitle ?
                        this.layout.name : this.layout.title;
            }
            else {
                this.text = this.text !== null ? this.text : '';
            }
        }
    }
};
__decorate([
    Input()
], H1Component.prototype, "data", void 0);
__decorate([
    Input()
], H1Component.prototype, "identifier", void 0);
__decorate([
    Input()
], H1Component.prototype, "layout", void 0);
__decorate([
    Input()
], H1Component.prototype, "arrayTypesLabels", void 0);
H1Component = __decorate([
    Component({
        selector: 'dmmp-h1',
        template: "<dmmp-container\r\n  [data]=\"data\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'h1-component'\"\r\n>\r\n  <div class=\"container\">\r\n    <h1 *ngIf=\"text\" [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ text }}\r\n    </h1>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], H1Component);

let VideoPlayerComponent = class VideoPlayerComponent {
    constructor(_document) {
        this._document = _document;
    }
    ngAfterViewInit() {
        switch (this.type) {
            case 'youtube': {
                const tag = this._document.createElement('script');
                tag.src = 'https://www.youtube.com/iframe_api';
                this._document.body.appendChild(tag);
                break;
            }
            case 'vimeo': {
                this.player = new Player(this.playerContainer.nativeElement);
                break;
            }
        }
    }
    stopVideo() {
        var _a, _b;
        switch (this.type) {
            case 'youtube': {
                (_a = this.youtubePlayer) === null || _a === void 0 ? void 0 : _a.stopVideo();
                break;
            }
            case 'vimeo': {
                (_b = this.player) === null || _b === void 0 ? void 0 : _b.pause();
                break;
            }
        }
    }
};
VideoPlayerComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
__decorate([
    Input()
], VideoPlayerComponent.prototype, "type", void 0);
__decorate([
    Input()
], VideoPlayerComponent.prototype, "src", void 0);
__decorate([
    ViewChild('vimeoPlayer')
], VideoPlayerComponent.prototype, "playerContainer", void 0);
__decorate([
    ViewChild('youTubePlayer')
], VideoPlayerComponent.prototype, "youtubePlayer", void 0);
VideoPlayerComponent = __decorate([
    Component({
        selector: 'dmmp-video-player',
        template: "<div [ngSwitch]=\"type\" class=\"row row-content\">\r\n  <div *ngSwitchCase=\"'youtube'\" class=\"col-12 video-box\">\r\n    <youtube-player class=\"embed-responsive embed-responsive-16by9\"\r\n                    [videoId]=\"src.substr(src.indexOf('v=') + 2,src.length)\" #youTubePlayer></youtube-player>\r\n  </div>\r\n  <div *ngSwitchCase=\"'vimeo'\" class=\"col-12 video-box\">\r\n    <div class=\"embed-responsive embed-responsive-16by9\">\r\n      <iframe [src]=\"src  | safe: 'resourceUrl'\" frameborder=\"0\" class=\"embed-responsive-item\" #vimeoPlayer></iframe>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    }),
    __param(0, Inject(DOCUMENT))
], VideoPlayerComponent);

let BackToTopComponent = class BackToTopComponent {
    constructor() {
        this.medias = [{ style: 'large', media: '(min-width:421px)' }];
    }
    scrollTop() {
        document.body.scrollIntoView({
            behavior: 'smooth',
            block: 'start',
            inline: 'nearest',
        });
    }
};
__decorate([
    Input()
], BackToTopComponent.prototype, "image", void 0);
__decorate([
    Input()
], BackToTopComponent.prototype, "module", void 0);
__decorate([
    Input()
], BackToTopComponent.prototype, "identifier", void 0);
BackToTopComponent = __decorate([
    Component({
        selector: 'dmmp-back-to-top',
        template: "<ng-container *ngIf=\"module; else onlyImage\">\r\n  <div class=\"box-content\" (click)=\"scrollTop()\">\r\n    <dmmp-container\r\n      [defaultClass]=\"'back-to-top'\"\r\n      [data]=\"module\"\r\n      [identifier]=\"identifier\"\r\n    >\r\n      <ng-container *ngIf=\"module?.back_to_top_class; else isImage\">\r\n        <div class=\"box-icon\">\r\n          <i\r\n            [ngClass]=\"module.back_to_top_class ? module.back_to_top_class : ''\"\r\n          ></i>\r\n        </div>\r\n      </ng-container>\r\n      <ng-template #isImage>\r\n        <ng-container\r\n          *ngIf=\"\r\n            module?.back_to_top_image?.length > 0\r\n          \"\r\n        >\r\n          <div class=\"box-image\">\r\n            <dmmp-image\r\n              [images]=\"module.back_to_top_image[0]\"\r\n              [medias]=\"medias\"\r\n            >\r\n            </dmmp-image>\r\n          </div>\r\n        </ng-container>\r\n      </ng-template>\r\n    </dmmp-container>\r\n  </div>\r\n</ng-container>\r\n<ng-template #onlyImage>\r\n  <img\r\n    [src]=\"image[0].styles.large ? image[0].styles.large : ''\"\r\n    [alt]=\"image[0].texts.alt ? image[0].texts.alt : ''\"\r\n    [title]=\"image[0].texts.title ? image[0].texts.title : ''\"\r\n    (click)=\"scrollTop()\"\r\n  />\r\n</ng-template>\r\n",
        styles: ["i,img{cursor:pointer}"]
    })
], BackToTopComponent);

let LinkIconComponent = class LinkIconComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
    ancla(event) {
        this.anchorCustom.emit(event);
    }
};
__decorate([
    Input()
], LinkIconComponent.prototype, "data", void 0);
__decorate([
    Input()
], LinkIconComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], LinkIconComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], LinkIconComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], LinkIconComponent.prototype, "page", void 0);
LinkIconComponent = __decorate([
    Component({
        selector: 'dmmp-link-icon',
        template: "<div *ngIf=\"data?.link && data?.link?.length > 0\">\r\n  <dmmp-link [data]=\"data\" (anchorCustom)=\"ancla($event)\" (page)=\"page.emit($event)\" [identifier]=\"identifier\">\r\n    <span *ngIf=\"data?.link[0]?.name\">{{data.link[0].name}}</span>\r\n    <ng-container *ngIf=\"data?.icon; else bootstrapIcon\">\r\n      <img [src]=\"data.icon ? '../assets/images/' + data.icon : ''\" [ngClass]=\"data.class ? data.class : ''\" />\r\n    </ng-container>\r\n    <ng-template #bootstrapIcon>\r\n      <div [ngClass]=\"data.class ? data.class : ''\">\r\n        <i *ngIf=\"data?.custom_icon\" [class]=\"data.custom_icon\"></i>\r\n      </div>\r\n    </ng-template>\r\n  </dmmp-link>\r\n</div>\r\n"
    })
], LinkIconComponent);

let PathLinkComponent = class PathLinkComponent {
    constructor() {
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], PathLinkComponent.prototype, "path", void 0);
__decorate([
    Input()
], PathLinkComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], PathLinkComponent.prototype, "page", void 0);
PathLinkComponent = __decorate([
    Component({
        selector: 'dmmp-path-link',
        template: "<a (click)=\"page.emit(path ? path : '')\" routerLink=\"{{ path ? path : ''}}\"\r\n  [ngClass]=\"defaultClass ? defaultClass : ''\">\r\n  <ng-content></ng-content>\r\n</a>\r\n"
    })
], PathLinkComponent);

let BannerItemComponent = class BannerItemComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.medias = [
            { style: 'large', media: '(min-width:1301px)' },
            { style: 'max_1300x1300', media: '(max-width:1300x) AND (min-width: 651px)' },
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width: 326px)' },
            { style: 'max_325x325', media: '(max-width:325px)' },
        ];
    }
    ngOnInit() { }
    ancla(event, data) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.anchorCustom.emit(event);
        }
    }
};
__decorate([
    Input()
], BannerItemComponent.prototype, "rowItem", void 0);
__decorate([
    Output()
], BannerItemComponent.prototype, "page", void 0);
__decorate([
    Output()
], BannerItemComponent.prototype, "anchorCustom", void 0);
BannerItemComponent = __decorate([
    Component({
        selector: 'dmmp-banner-item',
        template: "<div *ngFor=\"let columnItem of rowItem.columns\"\r\n     [ngClass]=\"'col-12 ' + 'col-md-'+ columnItem?.number_columns + ' ' + columnItem?.class\" [id]=\"columnItem?.id\">\r\n\r\n     <ng-container *ngIf=\"columnItem?.in_related_content; else noReleated\"></ng-container>\r\n\r\n     <ng-template #noReleated>\r\n      <dmmp-banner-item-detail [data]=\"columnItem\"></dmmp-banner-item-detail>\r\n    </ng-template>\r\n</div>\r\n"
    })
], BannerItemComponent);

let TextComponent = class TextComponent {
    constructor() {
        this.class = 'summarized';
    }
    ngOnInit() { }
    changeQuantity() {
        this.class = '';
        this.buttonShow = false;
        this.quantityCharacters = this.textEnriched.length;
    }
};
__decorate([
    Input()
], TextComponent.prototype, "textEnriched", void 0);
__decorate([
    Input()
], TextComponent.prototype, "classTextEnriched", void 0);
__decorate([
    Input()
], TextComponent.prototype, "quantityCharacters", void 0);
__decorate([
    Input()
], TextComponent.prototype, "buttonShow", void 0);
__decorate([
    Input()
], TextComponent.prototype, "class", void 0);
TextComponent = __decorate([
    Component({
        selector: 'dmmp-shared-text',
        template: "<div class=\"text-html\">\r\n  <div\r\n    *ngIf=\"textEnriched\"\r\n    [ngClass]=\"[classTextEnriched ? classTextEnriched : '', class ? class : '']\"\r\n    [innerHTML]=\"textEnriched | truncatetext: quantityCharacters\"\r\n  ></div>\r\n  <div class=\"read-more color-green-dark text-center\" *ngIf=\"buttonShow\" (click)=\"changeQuantity()\">\r\n    Leer m\u00E1s\r\n  </div>\r\n</div>\r\n\r\n"
    })
], TextComponent);

let AccordionComponent = class AccordionComponent {
};
__decorate([
    Input()
], AccordionComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], AccordionComponent.prototype, "class", void 0);
__decorate([
    Input()
], AccordionComponent.prototype, "contentAccordion", void 0);
AccordionComponent = __decorate([
    Component({
        selector: 'dmmp-shared-accordion',
        template: "<div class=\"accordion-html\"\r\n  [ngClass]=\"class ? class : ''\">\r\n  <ngb-accordion\r\n    [closeOthers]=\"true\"\r\n    activeIds=\"accordion-course-0\"\r\n    [destroyOnHide]=\"false\"\r\n  >\r\n    <ng-container *ngFor=\"let data of contentAccordion; let i = index\">\r\n      <ngb-panel id=\"accordion-course-{{i}}\">\r\n        <ng-template ngbPanelTitle>\r\n          <div class=\"content-title\" *ngIf=\"data?.title\">\r\n            <h2\r\n              [ngClass]=\"data.class ? data.class : ''\">\r\n             {{data.title}}\r\n              <i class=\"fas fa-chevron-down\"></i>\r\n            </h2>\r\n          </div>\r\n        </ng-template>\r\n        <ng-template ngbPanelContent>\r\n          <div class=\"content-accordion\"\r\n               *ngIf=\"data?.text\"\r\n               [ngClass]=\"data.text_class ? data.text_class : ''\"\r\n               [innerHTML]=\"data.text\"></div>\r\n        </ng-template>\r\n      </ngb-panel>\r\n    </ng-container>\r\n  </ngb-accordion>\r\n\r\n</div>\r\n"
    })
], AccordionComponent);

let CardHorizontalImageLinkComponent = class CardHorizontalImageLinkComponent {
};
__decorate([
    Input()
], CardHorizontalImageLinkComponent.prototype, "image", void 0);
__decorate([
    Input()
], CardHorizontalImageLinkComponent.prototype, "text", void 0);
__decorate([
    Input()
], CardHorizontalImageLinkComponent.prototype, "link", void 0);
__decorate([
    Input()
], CardHorizontalImageLinkComponent.prototype, "identifier", void 0);
CardHorizontalImageLinkComponent = __decorate([
    Component({
        selector: 'dmmp-card-horizontal-image-link',
        template: "<div class=\"card-horizontal\">\r\n  <div class=\"box-card\">\r\n    <div class=\"row no-gutters\">\r\n      <div class=\"col-12 col-sm-5\" *ngIf=\"image && image?.length > 0\">\r\n        <div class=\"image\">\r\n          <dmmp-image-logo [data]=\"image\"></dmmp-image-logo>\r\n        </div>\r\n      </div>\r\n      <div class=\"col-12 col-sm-{{image && image?.length > 0 ? 7 : 12}}\">\r\n        <div class=\"content-text\">\r\n          <dmmp-simple-link\r\n            *ngIf=\"link\"\r\n            [data]=\"{link: link.link ? link.link : '',\r\n          class: link.class ? link.class : '', target: link.target ? link.target : ''}\"\r\n            [identifier]=\"identifier ? identifier : ''\">\r\n            {{link.link[0].name ? link.link[0].name : ''}}\r\n          </dmmp-simple-link>\r\n          <p\r\n            *ngIf=\"text?.text\"\r\n            [ngClass]=\"text.text_class ? text.text_class : ''\">{{text.text}}</p>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], CardHorizontalImageLinkComponent);

let CardEventComponent = class CardEventComponent {
    constructor(dateFormatService) {
        this.dateFormatService = dateFormatService;
        this.showImage = true;
        this.image = [];
        this.medias = [
            { style: 'max_650x650', media: '(min-width:351px)' },
            { style: 'file_entity_browser_thumbnail', media: '(max-width:350px) AND (min-width:326px)' },
            { style: 'max_325x325', media: '(max-width:325px)' },
        ];
        this.redirectPage = new EventEmitter();
        this.hoursText = 'hs.';
    }
    ngOnInit() {
        this.date = this.dateFormatService.convertFromTimestampToDate(this.date);
    }
};
CardEventComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], CardEventComponent.prototype, "showImage", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "category", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "title", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "image", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "date", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "description", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "descriptionSize", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "classDate", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "classHour", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "classDescription", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "classCategory", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "classTitle", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "classImage", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "medias", void 0);
__decorate([
    Input()
], CardEventComponent.prototype, "path", void 0);
__decorate([
    Output()
], CardEventComponent.prototype, "redirectPage", void 0);
CardEventComponent = __decorate([
    Component({
        selector: 'dmmp-card-event',
        template: "<div class=\"card-event\">\r\n  <dmmp-path-link [path]=\"path ? path : ''\" (page)=\"redirectPage.emit()\">\r\n    <div class=\"box-content\">\r\n      <ng-container *ngIf=\"showImage && image && image?.length > 0\">\r\n        <div [ngClass]=\"classImage\" class=\"box-image\">\r\n          <dmmp-image\r\n            [images]=\"image[0]\"\r\n            [medias]=\"medias\">\r\n          </dmmp-image>\r\n        </div>\r\n      </ng-container>\r\n      <div class=\"box-body\">\r\n        <ng-container *ngIf=\"date\">\r\n          <div [ngClass]=\"classDate\" class=\"box-date\">\r\n            <p class=\"month\">{{ date | date: 'LLL' }}</p>\r\n            <p class=\"day\">{{ date | date: 'dd' }}</p>\r\n          </div>\r\n        </ng-container>\r\n        <div class=\"box-text\">\r\n          <p [ngClass]=\"classCategory\" class=\"category\" *ngIf=\"category\">{{category}}</p>\r\n          <div [ngClass]=\"classTitle\" class=\"h3 title\" *ngIf=\"title\" [innerHTML]=\"title\"></div>\r\n          <div [ngClass]=\"classHour\" class=\"date\" *ngIf=\"date\">{{ date | date: 'shortTime': 'UTC' }} {{hoursText}}</div>\r\n          <div [ngClass]=\"classDescription\" class=\"description\" *ngIf=\"description\"\r\n               [innerHTML]=\"description | truncatetext: descriptionSize\"></div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </dmmp-path-link>\r\n</div>\r\n"
    })
], CardEventComponent);

let BannerNewComponent = class BannerNewComponent {
    constructor(dateFormat) {
        this.dateFormat = dateFormat;
        this.page = new EventEmitter();
        this.medias = [
            { style: 'large', media: '(min-width:1301px)' },
            { style: 'max_1300x1300', media: '(min-width:651px) AND (max-width:1300px)' },
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width:326px)' },
            { style: 'max_325x325', media: '(max-width:325px)' },
        ];
    }
    ngOnInit() {
        this.date = this.dateFormat.convertFromTimestampToDate(this.date);
    }
};
BannerNewComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], BannerNewComponent.prototype, "path", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "textLink", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "image", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "date", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "title", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "description", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "quantityDescription", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "backgroundColorBox", void 0);
__decorate([
    Input()
], BannerNewComponent.prototype, "opacityBox", void 0);
__decorate([
    Output()
], BannerNewComponent.prototype, "page", void 0);
BannerNewComponent = __decorate([
    Component({
        selector: 'dmmp-banner-new',
        template: "<div class=\"new-full-content\" [ngClass]=\"defaultClass ? defaultClass : ''\">\r\n  <dmmp-image *ngIf=\"image?.length > 0\" [images]=\"image[0]\" [medias]=\"medias\">\r\n  </dmmp-image>\r\n  <div class=\"content-info\" [style.backgroundColor]=\"backgroundColorBox ?\r\n    (opacityBox ? (backgroundColorBox | colorOpacity: opacityBox): backgroundColorBox): ''\">\r\n    <p class=\"date\" *ngIf=\"date\">\r\n      {{date | date : 'longDate': 'UTC' }}\r\n    </p>\r\n    <h2 *ngIf=\"title\">{{ title}}</h2>\r\n    <p class=\"description\" *ngIf=\"description\">\r\n      {{description | removeHtml | truncatetext: quantityDescription}}\r\n    </p>\r\n    <div class=\"content-btn\" *ngIf=\"path && textLink\">\r\n      <dmmp-path-link [path]=\"path\" (page)=\"page.emit($event)\">\r\n        {{textLink}}\r\n      </dmmp-path-link>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], BannerNewComponent);

let CardNewComponent = class CardNewComponent {
    constructor(dateFormat) {
        this.dateFormat = dateFormat;
        this.page = new EventEmitter();
        this.medias = [
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width:351px)' },
            { style: 'max_325x325', media: '(max-width:350px)' },
        ];
    }
    ngOnInit() {
        this.date = this.dateFormat.convertFromTimestampToDate(this.date);
    }
};
CardNewComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], CardNewComponent.prototype, "path", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "image", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "featured", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "categories", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "date", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "title", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "description", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "quantityDescription", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], CardNewComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], CardNewComponent.prototype, "page", void 0);
CardNewComponent = __decorate([
    Component({
        selector: 'dmmp-card-new',
        template: "<div class=\"card-box\" [ngClass]=\"defaultClass ? defaultClass : ''\">\r\n  <dmmp-path-link [path]=\"path ? path : ''\" (page)=\"page.emit($event)\">\r\n    <div class=\"box-card-new-content\">\r\n      <div class=\"image\">\r\n        <div *ngIf=\"featured && featured?.length > 0\"\r\n          [style.backgroundColor]=\"featured[0]?.featured_background.color ? featured[0]?.featured_background.color : ''\"\r\n          [ngClass]=\"[featured[0].featured_class ? featured[0].featured_class : '', 'portlest']\">\r\n          {{featured[0]?.title}}\r\n        </div>\r\n        <dmmp-image [images]=\"image[0]\" [medias]=\"medias\">\r\n        </dmmp-image>\r\n      </div>\r\n      <div class=\"content-info\">\r\n        <p class=\"category-box\" *ngIf=\"categories && categories?.length > 0\">\r\n          {{categories[0]}}\r\n        </p>\r\n        <div [outerHTML]=\"title\"></div>\r\n        <p class=\"date-box\" *ngIf=\"date\">\r\n          {{date | date : 'dd MMMM yyyy': 'UTC' }}\r\n        </p>\r\n        <p *ngIf=\"description\">\r\n          {{description | removeHtml | truncatetext: quantityDescription}}\r\n        </p>\r\n      </div>\r\n    </div>\r\n  </dmmp-path-link>\r\n</div>\r\n"
    })
], CardNewComponent);

let CardRelatedProgramComponent = class CardRelatedProgramComponent {
    constructor() {
        this.page = new EventEmitter();
        this.labelCard = { duration: 'Duración:', modality: 'Modalidad:' };
    }
};
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "flag", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "backgroundColorFlag", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "image", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "medias", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "category", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "title", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "titleClass", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "duration", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "modality", void 0);
__decorate([
    Input()
], CardRelatedProgramComponent.prototype, "button", void 0);
__decorate([
    Output()
], CardRelatedProgramComponent.prototype, "page", void 0);
CardRelatedProgramComponent = __decorate([
    Component({
        selector: 'dmmp-card-related-program',
        template: "<div class=\"card\">\r\n  <div *ngIf=\"flag\" class=\"box-portlets\">\r\n    <div class=\"portlest\" [style.backgroundColor]=\"backgroundColorFlag ? backgroundColorFlag : ''\">\r\n      <p>{{ flag }}</p>\r\n    </div>\r\n  </div>\r\n  <ng-container *ngIf=\"image && medias\">\r\n    <div class=\"box-image\">\r\n      <dmmp-image [images]=\"image\" [medias]=\"medias\"></dmmp-image>\r\n    </div>\r\n  </ng-container>\r\n  <div class=\"card-body\">\r\n    <div class=\"box-text\">\r\n      <div class=\"box-info\">\r\n        <p class=\"small-text color-gray-dark text-category\" *ngIf=\"category\">\r\n          {{ category }}\r\n        </p>\r\n        <ng-container *ngIf=\"title\">\r\n          <h3 [ngClass]=\"titleClass ? titleClass : ''\">\r\n            {{ title }}\r\n          </h3>\r\n        </ng-container>\r\n      </div>\r\n      <div class=\"box-duration\">\r\n        <p class=\"duration-calendar mb-0\" *ngIf=\"duration\">\r\n          <span> {{labelCard.duration}} </span>{{ duration }}\r\n        </p>\r\n      </div>\r\n      <div class=\"box-modality\">\r\n        <p class=\"duration-calendar mb-0\" *ngIf=\"modality\">\r\n          <span>{{labelCard.modality}} </span>{{ modality }}\r\n        </p>\r\n      </div>\r\n    </div>\r\n    <div class=\"button-info\">\r\n      <ng-container *ngIf=\"button\">\r\n        <dmmp-button\r\n          *ngFor=\"let button of button\"\r\n          [data]=\"button\"\r\n          (page)=\"page.emit($event)\"\r\n        >\r\n        </dmmp-button>\r\n      </ng-container>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], CardRelatedProgramComponent);

let RelatedContentComponent = class RelatedContentComponent {
    constructor(dateFormat) {
        this.dateFormat = dateFormat;
        this.page = new EventEmitter();
    }
    ngOnInit() {
        this.date = this.dateFormat.convertFromTimestampToDate(this.date);
    }
};
RelatedContentComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], RelatedContentComponent.prototype, "title", void 0);
__decorate([
    Input()
], RelatedContentComponent.prototype, "date", void 0);
__decorate([
    Input()
], RelatedContentComponent.prototype, "path", void 0);
__decorate([
    Input()
], RelatedContentComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], RelatedContentComponent.prototype, "page", void 0);
RelatedContentComponent = __decorate([
    Component({
        selector: 'dmmp-related-content',
        template: "<div [ngClass]=\"defaultClass ? defaultClass : ''\">\r\n  <dmmp-path-link\r\n    [path]=\"path ? path : ''\"\r\n    (page)=\"page.emit($event)\">\r\n    <ng-container *ngIf=\"title\">\r\n      <div class=\"box-title\">\r\n        <div [outerHTML]=\"title\"></div>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"date\">\r\n      <div class=\"box-date\">\r\n        <p class=\"date-box\" *ngIf=\"date\">\r\n          {{date | date : 'dd MMMM yyyy': 'UTC' }}\r\n        </p>\r\n      </div>\r\n    </ng-container>\r\n  </dmmp-path-link>\r\n</div>\r\n\r\n"
    })
], RelatedContentComponent);

let MapsComponent = class MapsComponent {
    constructor(env) {
        this.env = env;
        this.markerClickEmitter = new EventEmitter();
    }
    ngOnInit() {
    }
    markerClick(clickInfo) {
        this.markerClickEmitter.emit(clickInfo);
    }
};
MapsComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: ['ENV',] }] }
];
__decorate([
    Input()
], MapsComponent.prototype, "mapConfig", void 0);
__decorate([
    Input()
], MapsComponent.prototype, "marks", void 0);
__decorate([
    Input()
], MapsComponent.prototype, "type", void 0);
__decorate([
    Input()
], MapsComponent.prototype, "mapClass", void 0);
__decorate([
    Input()
], MapsComponent.prototype, "mode", void 0);
__decorate([
    Output()
], MapsComponent.prototype, "markerClickEmitter", void 0);
MapsComponent = __decorate([
    Component({
        selector: 'dmmp-maps',
        template: "<agm-map [latitude]=\"mapConfig.center.lat\" [longitude]=\"mapConfig.center.lng\" [zoom]=\"mapConfig.zoom\"\r\n         [ngClass]=\"mapClass ? mapClass : ''\" [styles]=\"mode === 'grey' ? env.style : []\">\r\n  <agm-marker [latitude]=\"currentMarkItem?.lat\" [longitude]=\"currentMarkItem?.lng\" *ngFor=\"let currentMarkItem of marks\"\r\n              [iconUrl]=\"{ url: currentMarkItem?.pinUrl, scaledSize: { width: 36, height: 47 }}\"\r\n              (markerClick)=\"markerClick(currentMarkItem)\" [openInfoWindow]=\"type === 'event-information' \">\r\n    <agm-info-window [isOpen]=\"false\">\r\n      <div [ngSwitch]=\"type\">\r\n        <div *ngSwitchCase=\"'event-information'\">\r\n          <p>{{currentMarkItem?.title}}</p>\r\n          <a *ngIf=\"currentMarkItem?.link?.length > 0\" [href]=\"currentMarkItem?.link[0].link\"\r\n             [target]=\"currentMarkItem?.target\">{{currentMarkItem?.link[0].name}}</a>\r\n        </div>\r\n      </div>\r\n    </agm-info-window>\r\n  </agm-marker>\r\n</agm-map>\r\n"
    }),
    __param(0, Inject('ENV'))
], MapsComponent);

let VideoGalleryComponent = class VideoGalleryComponent {
    constructor(dateFormat, richsnipetService, removeHtmlPipe) {
        this.dateFormat = dateFormat;
        this.richsnipetService = richsnipetService;
        this.removeHtmlPipe = removeHtmlPipe;
        this.videoSrc = null;
        this.videoType = null;
        this.page = new EventEmitter();
        this.schemaItemVideo = [];
    }
    ngOnInit() {
        this.date = this.dateFormat.convertFromTimestampToDate(this.date);
        this.selectCategories(this.categories.identifier);
        if (this.videoSrc) {
            this.schemaItemVideo = this.richsnipetService.setupJsonVideo(this.title ? this.removeHtmlPipe.transform(this.title) : '', this.description ? this.removeHtmlPipe.transform(this.description) : '', this.image && this.image.length > 0 && this.image.styles.large ? this.image.styles.large : '', this.date ? this.date : '', this.videoSrc ? this.videoSrc : '');
        }
    }
    selectCategories(identifier) {
        switch (identifier) {
            case 'news':
                this.categories = this.categories.topics && this.categories.topics.length > 0 ? this.categories.topics[0] : null;
                break;
            case 'blog':
                this.categories = this.categories.categories && this.categories.categories.length > 0 ? this.categories.categories[0] : null;
                break;
            case 'event':
                this.categories = this.categories.type && this.categories.type.length > 0 ? this.categories.type[0].label : null;
                break;
            default:
                break;
        }
    }
};
VideoGalleryComponent.ctorParameters = () => [
    { type: DateFormatService },
    { type: RichsnipetService },
    { type: RemoveHtmlPipe }
];
__decorate([
    Input()
], VideoGalleryComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "image", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "videoSrc", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "videoType", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "categories", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "medias", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "title", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "date", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "path", void 0);
__decorate([
    Input()
], VideoGalleryComponent.prototype, "description", void 0);
__decorate([
    Output()
], VideoGalleryComponent.prototype, "page", void 0);
VideoGalleryComponent = __decorate([
    Component({
        selector: 'dmmp-video-gallery',
        template: "<ngx-json-ld *ngIf=\"schemaItemVideo\" [json]=\"schemaItemVideo\"></ngx-json-ld>\r\n<ng-container *ngIf=\"videoSrc && videoType; else onlyImage\">\r\n  <div class=\"box-content-video\" [ngClass]=\"defaultClass ? defaultClass : ''\">\r\n    <div class=\"box-video\">\r\n      <dmmp-video-player\r\n        [src]=\"videoSrc\"\r\n        [type]=\"videoType\">\r\n      </dmmp-video-player>\r\n    </div>\r\n    <div class=\"box-text\">\r\n      <div class=\"box-category\" *ngIf=\"categories\">\r\n        <p class=\"category\">\r\n          {{categories}}\r\n        </p>\r\n      </div>\r\n      <dmmp-path-link [path]=\"path\" (page)=\"page.emit($event)\">\r\n        <div class=\"title\" *ngIf=\"title\">\r\n          <div [outerHTML]=\"title\"></div>\r\n        </div>\r\n      </dmmp-path-link>\r\n      <div class=\"box-date\" *ngIf=\"date\">\r\n        <p class=\"date\">\r\n          {{date | date : 'dd MMMM yyyy': 'UTC' }}\r\n        </p>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n<ng-template #onlyImage>\r\n  <div class=\"box-content-image\" [ngClass]=\"defaultClass ? defaultClass : ''\">\r\n    <div class=\"box-image\" *ngIf=\"image\">\r\n      <dmmp-image\r\n        [images]=\"image\"\r\n        [medias]=\"medias\">\r\n      </dmmp-image>\r\n    </div>\r\n    <div class=\"box-text\">\r\n      <div class=\"box-category\" *ngIf=\"categories\">\r\n        <p class=\"category\">\r\n          {{categories}}\r\n        </p>\r\n      </div>\r\n      <dmmp-path-link [path]=\"path\" (page)=\"page.emit($event)\">\r\n        <div class=\"title\" *ngIf=\"title\">\r\n          <div [outerHTML]=\"title\"></div>\r\n        </div>\r\n      </dmmp-path-link>\r\n      <div class=\"box-date\" *ngIf=\"date\">\r\n        <p class=\"date\">\r\n          {{date | date : 'dd MMMM yyyy': 'UTC' }}\r\n        </p>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n"
    })
], VideoGalleryComponent);

let BannerItemDetailComponent = class BannerItemDetailComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.truncateLength = 92;
        this.medias = [
            { style: 'large', media: '(min-width:1301px)' },
            { style: 'max_1300x1300', media: '(max-width:1300x) AND (min-width: 651px)' },
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width: 326px)' },
            { style: 'max_325x325', media: '(max-width:325px)' },
        ];
    }
    ngOnInit() {
    }
    ancla(event, data) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.anchorCustom.emit(event);
        }
    }
};
__decorate([
    Input()
], BannerItemDetailComponent.prototype, "data", void 0);
__decorate([
    Output()
], BannerItemDetailComponent.prototype, "page", void 0);
__decorate([
    Output()
], BannerItemDetailComponent.prototype, "anchorCustom", void 0);
__decorate([
    Input()
], BannerItemDetailComponent.prototype, "truncateLength", void 0);
BannerItemDetailComponent = __decorate([
    Component({
        selector: 'dmmp-banner-item-detail',
        template: "  <ng-container *ngIf=\"!data?.in_related_content; else relatedContent\">\r\n    <div *ngFor=\"let item of data.items\" [ngClass]=\"'item ' + item.identifier\" [id]=\"item?.id\">\r\n        <div *ngIf=\"item?.identifier?.toLowerCase() === 'button'\">\r\n          <dmmp-button [data]=\"item\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-button>\r\n        </div>\r\n        <div *ngIf=\"item.identifier.toLowerCase() === 'images_link'\">\r\n          <ng-container *ngIf=\"item?.link?.length > 0; else imgTem\">\r\n            <a [href]=\"item.link[0].link\" [target]=\"item.target\" [title]=\"item.link[0].name\"\r\n               (click)=\"ancla($event, item.link[0].link)\">\r\n              <dmmp-image *ngIf=\"item?.images?.length > 0\" [images]=\"item.images[0]\" [medias]=\"medias\"></dmmp-image>\r\n            </a>\r\n          </ng-container>\r\n          <ng-template #imgTem>\r\n            <dmmp-image *ngIf=\"item?.images?.length > 0\" [images]=\"item.images[0]\" [medias]=\"medias\"></dmmp-image>\r\n          </ng-template>\r\n        </div>\r\n        <div *ngIf=\"item?.identifier?.toLowerCase() === 'textos'\" class=\"box-texts\">\r\n          <div [ngClass]=\"item.class\" [innerHTML]=\"item.text\">\r\n          </div>\r\n        </div>\r\n        <div *ngIf=\"item?.identifier?.toLowerCase() === 'banner_video'\" class=\"box-video\">\r\n          <ng-container *ngIf=\"item?.video && item?.video?.length > 0\">\r\n            <dmmp-video-player [type]=\"item.video[0].type\" [src]=\"item.video[0].video[0].value\"></dmmp-video-player>\r\n          </ng-container>\r\n        </div>\r\n    </div>\r\n  </ng-container>\r\n\r\n  <ng-template #relatedContent>\r\n    <div>\r\n        <ng-container *ngFor=\"let item of data?.items\">\r\n          <ng-container *ngIf=\"item?.identifier?.toLowerCase() === 'images_link'\">\r\n            <ng-container *ngIf=\"item?.link?.length > 0; else imgTem\">\r\n              <a [href]=\"item?.link[0]?.link\" [target]=\"item?.target\" [title]=\"item?.link[0]?.name\"\r\n                  (click)=\"ancla($event, item?.link[0]?.link)\">\r\n                <dmmp-image  *ngIf=\"item?.images?.length > 0\"\r\n                  [class]=\"item?.class || ''\"\r\n                  [images]=\"item?.images[0]\"\r\n                  [medias]=\"medias\">\r\n                </dmmp-image>\r\n              </a>\r\n            </ng-container>\r\n            <ng-template #imgTem>\r\n              <dmmp-image *ngIf=\"item?.images?.length > 0\"\r\n                [class]=\"item?.class || ''\"\r\n                [images]=\"item?.images[0]\"\r\n                [medias]=\"medias\">\r\n              </dmmp-image>\r\n            </ng-template>\r\n          </ng-container>\r\n        </ng-container>\r\n\r\n        <div class=\"story-box\">\r\n          <ng-container *ngFor=\"let item of data?.items\">\r\n            <div class=\"event-button\" *ngIf=\"item?.identifier?.toLowerCase() === 'button'\">\r\n              <p>\r\n                <dmmp-button [data]=\"item\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-button>\r\n              </p>\r\n            </div>\r\n            <div *ngIf=\"item?.identifier?.toLowerCase() === 'textos'\" class=\"box-texts\">\r\n              <div [ngClass]=\"item?.class\" [innerHTML]=\"item?.text | truncatetext : truncateLength\">\r\n              </div>\r\n            </div>\r\n            <div *ngIf=\"item?.identifier?.toLowerCase() === 'banner_video'\" class=\"box-video\">\r\n              <ng-container *ngIf=\"item?.video && item?.video?.length > 0\">\r\n                <dmmp-video-player [type]=\"item?.video[0]?.type\" [src]=\"item?.video[0]?.video[0]?.value\"></dmmp-video-player>\r\n              </ng-container>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n  </ng-template>\r\n"
    })
], BannerItemDetailComponent);

let ShowItemOnUpScrollDirective = class ShowItemOnUpScrollDirective {
    constructor(el, renderer2) {
        this.el = el;
        this.renderer2 = renderer2;
        this.currentScrollPos = 0;
        this.prevScrollpos = 0;
    }
    showHideHeaderOnScroll(event) {
        this.currentScrollPos = window.pageYOffset;
        if (this.currentScrollPos > this.el.nativeElement.offsetHeight) {
            this.renderer2.removeClass(this.el.nativeElement, 'website-header--fixed');
            if (this.prevScrollpos > this.currentScrollPos) {
                this.renderer2.addClass(this.el.nativeElement, 'website-header--fixed');
                this.el.nativeElement.style.top = '0';
            }
            else {
                this.el.nativeElement.style.top = `-${this.el.nativeElement.offsetHeight}px`;
            }
            this.prevScrollpos = this.currentScrollPos;
        }
        else {
            this.renderer2.removeClass(this.el.nativeElement, 'website-header--fixed');
        }
    }
};
ShowItemOnUpScrollDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
__decorate([
    HostListener('window:scroll', ['$event'])
], ShowItemOnUpScrollDirective.prototype, "showHideHeaderOnScroll", null);
ShowItemOnUpScrollDirective = __decorate([
    Directive({
        selector: '[dmmpShowItemOnUpScroll]'
    })
], ShowItemOnUpScrollDirective);

let SharedModule = class SharedModule {
};
SharedModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            PipesModule,
            PdfViewerModule,
            RouterModule,
            YouTubePlayerModule,
            NgbNavModule,
            NgbAccordionModule,
            AgmCoreModule.forRoot({
                apiKey: 'AIzaSyAVHQjGmaK9pU0as9UVBuE_aKe_d10ZBvU',
            }),
            NgxJsonLdModule,
        ],
        declarations: [
            ContainerComponent,
            ImageComponent,
            PdfViewerComponent,
            EmbedComponent,
            ModalComponent,
            ButtonComponent,
            PaginatorComponent,
            ImageLogoComponent,
            LinkComponent,
            SimpleLinkComponent,
            WebsiteCardProgramComponent,
            WebsiteCardTitleComponent,
            WebsiteCardArticleFeaturedComponent,
            WebsiteArticleBannerFeaturedComponent,
            H1Component,
            VideoPlayerComponent,
            BackToTopComponent,
            LinkIconComponent,
            BannerItemComponent,
            LinkIconComponent,
            TextComponent,
            AccordionComponent,
            CardHorizontalImageLinkComponent,
            PathLinkComponent,
            MapsComponent,
            CardNewComponent,
            BannerNewComponent,
            RelatedContentComponent,
            CardEventComponent,
            CardRelatedProgramComponent,
            VideoGalleryComponent,
            CardGeneralResultComponent,
            BannerItemDetailComponent,
            ShowItemOnUpScrollDirective
        ],
        exports: [
            ContainerComponent,
            ImageComponent,
            PdfViewerComponent,
            EmbedComponent,
            ModalComponent,
            ButtonComponent,
            PaginatorComponent,
            ImageLogoComponent,
            LinkComponent,
            SimpleLinkComponent,
            WebsiteCardProgramComponent,
            WebsiteCardTitleComponent,
            WebsiteCardArticleFeaturedComponent,
            WebsiteArticleBannerFeaturedComponent,
            H1Component,
            VideoPlayerComponent,
            BackToTopComponent,
            LinkIconComponent,
            TextComponent,
            AccordionComponent,
            CardHorizontalImageLinkComponent,
            LinkIconComponent,
            BannerItemComponent,
            PathLinkComponent,
            MapsComponent,
            CardEventComponent,
            CardNewComponent,
            CardRelatedProgramComponent,
            BannerNewComponent,
            RelatedContentComponent,
            VideoGalleryComponent,
            CardGeneralResultComponent,
            BannerItemDetailComponent,
            ShowItemOnUpScrollDirective
        ],
        providers: [PipesModule],
    })
], SharedModule);

let HeaderModule = class HeaderModule {
};
HeaderModule = __decorate([
    NgModule({
        imports: [CommonModule, SharedModule],
        declarations: [HeaderComponent, MobileMenuComponent, ToggleMenuComponent, DesktopMenuComponent, MenuComponent],
        exports: [HeaderComponent],
        providers: [AnchorService, LocalDeviceDetectorService],
    })
], HeaderModule);

let WebsiteHeaderComponent = class WebsiteHeaderComponent {
    constructor(richsnipetService) {
        this.richsnipetService = richsnipetService;
        this.world_search = '';
        this.searching = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.classMenu = 'empty';
        this.showSearchContent = false;
        this.showSearchContentMenu = false;
    }
    ancla(event, data) {
        var _a;
        if (data.indexOf('#') === 0 && ((_a = data) === null || _a === void 0 ? void 0 : _a.length) > 1) {
            this.anchorCustom.emit({ event: event, id: data });
        }
    }
    open() {
        this.showSearchContent = false;
        if (this.classMenu === 'empty') {
            this.classMenu = 'show';
            this.showSearchContentMenu = true;
        }
        else {
            this.classMenu = 'empty';
            this.showSearchContentMenu = false;
        }
    }
    showSearch(placeholder, image) {
        this.classMenu = 'empty';
        this.showSearchContentMenu = false;
        this.showSearchContent = !this.showSearchContent;
        this.contentSearch = { placeholder: placeholder, image: image };
    }
    closeMenu() {
        this.classMenu = 'empty';
        this.showSearchContent = false;
        this.showSearchContentMenu = false;
    }
};
WebsiteHeaderComponent.ctorParameters = () => [
    { type: RichsnipetService }
];
__decorate([
    Input()
], WebsiteHeaderComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteHeaderComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteHeaderComponent.prototype, "menu", void 0);
__decorate([
    Input()
], WebsiteHeaderComponent.prototype, "world_search", void 0);
__decorate([
    Input()
], WebsiteHeaderComponent.prototype, "endPoint", void 0);
__decorate([
    Output()
], WebsiteHeaderComponent.prototype, "searching", void 0);
__decorate([
    Output()
], WebsiteHeaderComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], WebsiteHeaderComponent.prototype, "page", void 0);
WebsiteHeaderComponent = __decorate([
    Component({
        selector: 'dmmp-website-header',
        template: "<ngx-json-ld [json]=\"richsnipetService.setupJsonHeader()\"></ngx-json-ld>\r\n<ngx-json-ld  [json]=\"richsnipetService.setupJsonSearch(endPoint)\"></ngx-json-ld>\r\n<header class=\"website-header\">\r\n  <dmmp-container\r\n    [data]=\"data ? data : {}\"\r\n    [identifier]=\"identifier\">\r\n    <nav class=\"navbar navbar-expand-lg navbar-light\" *ngIf=\"data?.content?.row?.length > 0\">\r\n      <div class=\"container\">\r\n        <div\r\n          [ngClass]=\"data?.content?.row[0]?.class || ''\"\r\n          [id]=\"\r\n          data.content.row[0].id_element || ''\"\r\n          class=\"row row-content-header no-gutters align-items-center\"\r\n        >\r\n          <div class=\"col-auto d-lg-none\">\r\n            <button\r\n              [ngClass]=\"classMenu\"\r\n              class=\"navbar-toggler\"\r\n              type=\"button\"\r\n              data-toggle=\"collapse\"\r\n              data-target=\"#navbarNavDropdown\"\r\n              aria-controls=\"navbarNavDropdown\"\r\n              aria-expanded=\"false\"\r\n              aria-label=\"Toggle navigation\"\r\n              (click)=\"open()\"\r\n            >\r\n              <span></span>\r\n              <span></span>\r\n              <span></span>\r\n            </button>\r\n          </div>\r\n          <ng-container *ngIf=\"data?.content?.row[0]?.column?.length > 0\">\r\n            <div\r\n              *ngFor=\"let col of data?.content?.row[0]?.column\"\r\n              class=\"col-auto col-lg-{{ col?.number_columns || 'auto' }}\"\r\n              [ngClass]=\"col?.class || ''\"\r\n              [id]=\"col?.id_element || ''\"\r\n            >\r\n              <ng-container *ngIf=\"col?.items_column?.length > 0\">\r\n                <ng-container *ngFor=\"let info of col?.items_column\">\r\n                  <ng-container *ngIf=\"info?.identifier === 'images_link'\">\r\n                    <div\r\n                      class=\"content content-logo\"\r\n                      *ngIf=\"info?.link?.length > 0\"\r\n                    >\r\n                      <dmmp-simple-link [data]=\"info\" (page)=\"page.emit($event)\" [identifier]=\"identifier\">\r\n                        <dmmp-image-logo\r\n                          *ngIf=\"info?.image?.length > 0\"\r\n                          [data]=\"info?.image\"\r\n                        ></dmmp-image-logo>\r\n                      </dmmp-simple-link>\r\n                    </div>\r\n                  </ng-container>\r\n                  <ng-container *ngIf=\"info?.identifier === 'textos'\">\r\n                    <div\r\n                      class=\"content content-text\"\r\n                      *ngIf=\"info?.text\"\r\n                      [ngClass]=\"info?.class || ''\"\r\n                      [innerHTML]=\"info?.text\"></div>\r\n                  </ng-container>\r\n                  <ng-container *ngIf=\"info?.identifier === 'menu'\">\r\n                    <div class=\"content content-menu\">\r\n                      <div\r\n                        class=\"collapse navbar-collapse\"\r\n                        [ngClass]=\"classMenu\"\r\n                        [style.backgroundColor]=\"data?.background_color?.color || ''\"\r\n                      >\r\n                        <ul class=\"navbar-nav\" *ngIf=\"menu?.length > 0\">\r\n                          <li class=\"nav-item\" *ngFor=\"let men of menu\">\r\n                            <a class=\"nav-link\" (click)=\"page.emit(men.data.path)\"\r\n                               routerLink=\"{{men?.data?.path}}\">{{men?.data?.name}}</a>\r\n                          </li>\r\n                        </ul>\r\n                        <ul class=\"buttons-actions buttons-header-mobile\"\r\n                            *ngIf=\"data?.content?.row[0]?.column?.length > 0\">\r\n                          <ng-container\r\n                            *ngFor=\"let buttonTemp of data?.content?.row[0]?.column\"\r\n                          >\r\n                            <ng-container\r\n                              *ngFor=\"let typeButton of buttonTemp?.items_column\"\r\n                            >\r\n                              <li\r\n                                *ngIf=\"\r\n                          typeButton?.identifier === 'button' &&\r\n                          typeButton?.link?.length > 0\r\n                        \"\r\n                              >\r\n                                <dmmp-button\r\n                                  [data]=\"typeButton\"\r\n                                  [identifier]=\"identifier\"\r\n                                  (close)=\"closeMenu()\"\r\n                                ></dmmp-button>\r\n                              </li>\r\n                            </ng-container>\r\n                          </ng-container>\r\n                        </ul>\r\n                      </div>\r\n                    </div>\r\n                  </ng-container>\r\n                  <ng-container *ngIf=\"info?.identifier === 'search'\">\r\n                    <div\r\n                      class=\"content content-search\"\r\n                      *ngIf=\"info?.image?.length > 0\"\r\n                    >\r\n                      <div\r\n                        class=\"action\"\r\n                        (click)=\"showSearch(info?.placeholder, info?.image)\"\r\n                      >\r\n                        <dmmp-image-logo [data]=\"info?.image\"></dmmp-image-logo>\r\n                      </div>\r\n                    </div>\r\n                  </ng-container>\r\n                  <ng-container *ngIf=\"info?.identifier === 'button'\">\r\n                    <div\r\n                      class=\"content content-button buttons-header-desktop\"\r\n                      *ngIf=\"info?.link?.length > 0\"\r\n                    >\r\n                      <ul class=\"buttons-actions\">\r\n                        <li class=\"nav-item\">\r\n                          <dmmp-button\r\n                            [data]=\"info\"\r\n                            [identifier]=\"identifier\"\r\n                            (close)=\"closeMenu()\"\r\n                          ></dmmp-button>\r\n                        </li>\r\n                      </ul>\r\n                    </div>\r\n                  </ng-container>\r\n                </ng-container>\r\n              </ng-container>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n    </nav>\r\n    <div class=\"content-header-search\" *ngIf=\"showSearchContent\">\r\n      <div class=\"content-input\">\r\n        <div class=\"input-container\">\r\n          <input\r\n            type=\"text\"\r\n            name=\"search\"\r\n            [(ngModel)]=\"world_search\"\r\n            [placeholder]=\"contentSearch?.placeholder\"\r\n          />\r\n          <button (click)=\"searching.emit(world_search)\" [disabled]=\"world_search?.length < 3\">\r\n            <div\r\n              class=\"icon\"\r\n            >\r\n              <dmmp-image-logo [data]=\"contentSearch?.image\"></dmmp-image-logo>\r\n            </div>\r\n          </button>\r\n        </div>\r\n        <div class=\"close-search\" (click)=\"showSearchContent = false\">\r\n          <svg\r\n            xmlns=\"http://www.w3.org/2000/svg\"\r\n            width=\"16.242\"\r\n            height=\"16.242\"\r\n            viewBox=\"0 0 16.242 16.242\"\r\n          >\r\n            <defs>\r\n              <style>\r\n                .prefix__cls-1 {\r\n                  fill: none;\r\n                  stroke: #7754b1;\r\n                  stroke-linecap: round;\r\n                  stroke-width: 3px;\r\n                }\r\n              </style>\r\n            </defs>\r\n            <g id=\"prefix__close\" transform=\"translate(2.121 2.121)\">\r\n              <g id=\"prefix__Grupo_43\" data-name=\"Grupo 43\">\r\n                <g id=\"prefix__Grupo_43-2\" data-name=\"Grupo 43\">\r\n                  <path\r\n                    id=\"prefix__L\u00EDnea_1\"\r\n                    d=\"M0 0L11.771 11.947\"\r\n                    class=\"prefix__cls-1\"\r\n                    data-name=\"L\u00EDnea 1\"\r\n                    transform=\"translate(.229)\"\r\n                  />\r\n                  <path\r\n                    id=\"prefix__L\u00EDnea_5\"\r\n                    d=\"M0 12L11.649 0\"\r\n                    class=\"prefix__cls-1\"\r\n                    data-name=\"L\u00EDnea 5\"\r\n                  />\r\n                </g>\r\n              </g>\r\n            </g>\r\n          </svg>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </dmmp-container>\r\n</header>\r\n<div\r\n  (click)=\"showSearchContent = false\"\r\n  *ngIf=\"showSearchContent\"\r\n  class=\"overlay-black\"\r\n></div>\r\n<div\r\n  (click)=\"open()\"\r\n  *ngIf=\"showSearchContentMenu\"\r\n  class=\"overlay-black\"\r\n></div>\r\n"
    })
], WebsiteHeaderComponent);

let BreadcrumbComponent = class BreadcrumbComponent {
    constructor() {
        this.breadcrumbs = [{ label: 'Home', url: '' }];
        this.page = new EventEmitter();
    }
    ngOnInit() {
        this.makeBreadcrumb(this.breadcrumbElements);
    }
    ngOnChanges(changes) {
        this.makeBreadcrumb(this.breadcrumbElements);
    }
    makeBreadcrumb(breadcrumbElements) {
        var _a, _b, _c;
        this.breadcrumbs = [{ label: 'Home', url: '' }];
        (_a = breadcrumbElements) === null || _a === void 0 ? void 0 : _a.forEach((element) => {
            if (element.label && element.path) {
                this.breadcrumbs.push({
                    label: element.label,
                    url: element.path,
                });
            }
        });
        ((_b = this.breadcrumbs) === null || _b === void 0 ? void 0 : _b.length) > 1
            ? (this.showBreadcrumb = true)
            : (this.showBreadcrumb = false);
        (_c = this.breadcrumbs) === null || _c === void 0 ? void 0 : _c.find((element) => {
            var _a, _b, _c, _d;
            ((_b = (_a = element) === null || _a === void 0 ? void 0 : _a.url) === null || _b === void 0 ? void 0 : _b.includes('universities')) ? (this.isUniversity = true)
                : (this.isUniversity = false);
            ((_d = (_c = element) === null || _c === void 0 ? void 0 : _c.url) === null || _d === void 0 ? void 0 : _d.includes('articles')) ? (this.isUniversity = true)
                : (this.isUniversity = false);
        });
    }
};
__decorate([
    Input()
], BreadcrumbComponent.prototype, "data", void 0);
__decorate([
    Input()
], BreadcrumbComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], BreadcrumbComponent.prototype, "breadcrumbElements", void 0);
__decorate([
    Output()
], BreadcrumbComponent.prototype, "page", void 0);
BreadcrumbComponent = __decorate([
    Component({
        selector: 'dmmp-breadcrumb',
        template: "<dmmp-container [data]=\"data\" [identifier]=\"identifier\">\r\n  <div\r\n    [ngClass]=\"\r\n      isUniversity\r\n        ? 'box-breadcrumb'\r\n        : isArticles\r\n        ? 'box-breadcrumb-articles'\r\n        : ''\r\n    \"\r\n  >\r\n    <div *ngIf=\"showBreadcrumb\" class=\"container\">\r\n      <ol class=\"breadcrumb\" *ngIf=\"breadcrumbs?.length > 0\">\r\n        <li *ngFor=\"let breadcrumb of breadcrumbs; last as isLast\">\r\n          <a *ngIf=\"isLast; else isntLast\">\r\n            {{ breadcrumb?.label }}\r\n          </a>\r\n          <ng-template #isntLast>\r\n            <a\r\n              (click)=\"page.emit(breadcrumb?.url)\"\r\n              routerLink=\"{{ breadcrumb?.url }}\"\r\n            >\r\n              {{ breadcrumb?.label }}\r\n            </a>\r\n          </ng-template>\r\n        </li>\r\n      </ol>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n",
        styles: [".box-breadcrumb{background-color:transparent!important;position:absolute;width:100%}.box-breadcrumb .breadcrumb:after{width:100%;height:1px;content:\"\";display:block;background:rgba(255,255,255,.5);margin-top:1rem}.box-breadcrumb-articles{background-color:transparent!important}.box-breadcrumb-articles .breadcrumb:after{width:100%;height:1px;content:\"\";display:block;background:#1c0541;margin-top:1rem}.box-breadcrumb-articles .breadcrumb li a{color:#1c0541}.box-breadcrumb-articles .breadcrumb li a:hover{color:#7754b1}.box-breadcrumb-articles .breadcrumb li:after{color:#1c0541}.box-breadcrumb-articles .breadcrumb li:last-child a{color:#f57d03;font-weight:700}.breadcrumb{background:0 0;margin:0}.breadcrumb a{text-decoration:none}.breadcrumb a:hover{cursor:pointer}.breadcrumb li{list-style:none;float:left}.breadcrumb li:last-child{margin-right:10px}.breadcrumb li::after{content:\">\";margin-left:.5rem;margin-right:.5rem}.breadcrumb li:last-child::after{content:\"\"}"]
    })
], BreadcrumbComponent);

let BreadcrumbModule = class BreadcrumbModule {
};
BreadcrumbModule = __decorate([
    NgModule({
        declarations: [BreadcrumbComponent],
        exports: [BreadcrumbComponent],
        imports: [CommonModule, RouterModule, SharedModule],
    })
], BreadcrumbModule);

let WebsiteHeaderModule = class WebsiteHeaderModule {
};
WebsiteHeaderModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            SharedModule,
            RouterModule,
            BreadcrumbModule,
            FormsModule,
            NgxJsonLdModule,
        ],
        declarations: [WebsiteHeaderComponent],
        exports: [WebsiteHeaderComponent],
        providers: [AnchorService, RichsnipetService],
    })
], WebsiteHeaderModule);

let FooterComponent = class FooterComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
    }
    ancla(event, data) {
        var _a;
        if (data.indexOf('#') === 0 && ((_a = data) === null || _a === void 0 ? void 0 : _a.length) > 1) {
            this.anchorCustom.emit({ event: event, id: data });
        }
    }
};
__decorate([
    Input()
], FooterComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], FooterComponent.prototype, "data", void 0);
__decorate([
    Output()
], FooterComponent.prototype, "anchorCustom", void 0);
FooterComponent = __decorate([
    Component({
        selector: 'dmmp-footer',
        template: "<footer *ngIf=\"data && data?.visible\" [id]=\"data?.id_element ?  identifier + '_' + data?.id_element : 'header'\"\r\n        [ngClass]=\"data?.class || ''\"\r\n        [style.backgroundColor]=\"data?.background_color?.color || ''\"\r\n        [style.backgroundImage]=\"(data?.background_image)?.length > 0 ? 'url(' + (data?.background_image)[0]?.styles?.large + ')' : ''\"\r\n        class=\"footer\">\r\n  <div class=\"container\">\r\n    <div class=\"row no-gutters align-items-center\">\r\n      <ng-container *ngIf=\"data?.content?.length > 0\">\r\n        <div *ngFor=\"let footer of data?.content\"\r\n             class=\"col-12 {{footer?.number_columns ? 'col-md-'+ footer?.number_columns : 'col-md'}}\"\r\n             [ngClass]=\"data?.content?.length === 1 ? 'col text-center' : ''\">\r\n          <ng-container *ngIf=\"footer?.texts?.length > 0\">\r\n            <div class=\"footer-text\">\r\n              <div [innerHTML]=\"texts?.text\" *ngFor=\"let texts of footer?.texts\"></div>\r\n            </div>\r\n          </ng-container>\r\n          <ng-container *ngIf=\"footer?.images?.length > 0\">\r\n            <div class=\"box-image-footer\">\r\n              <ng-container *ngFor=\"let images of footer?.images\">\r\n                <a *ngIf=\"images?.link;else onlyImage\" [href]=\"images?.link\" [target]=\"images?.target\"\r\n                   (click)=\"ancla($event, images?.link)\">\r\n                  <img *ngIf=\"images?.styles && images?.styles?.large\" class=\"logo\"\r\n                       [ngClass]=\"images?.class || ''\" [src]=\"images?.styles?.large\"\r\n                       [alt]=\"images?.texts?.alt\" [title]=\"images?.texts?.title\"/>\r\n                </a>\r\n                <ng-template #onlyImage>\r\n                  <img *ngIf=\"images?.styles?.large\" class=\"logo\"\r\n                       [ngClass]=\"images?.class || ''\" [src]=\"images?.styles?.large\"\r\n                       [alt]=\"images?.texts?.alt\" [title]=\"images?.texts?.title\"/>\r\n                </ng-template>\r\n              </ng-container>\r\n            </div>\r\n          </ng-container>\r\n          <ng-container *ngIf=\"footer?.links?.items?.length > 0\">\r\n            <div [ngClass]=\"footer?.links?.parent_class_link || ''\">\r\n              <div *ngFor=\"let redes of footer?.links?.items\" [id]=\"redes?.id || ''\"\r\n                   [ngClass]=\"redes?.class || ''\">\r\n                <a [href]=\"redes?.link || ''\" [target]=\"redes?.target || ''\"\r\n                   (click)=\"ancla($event, redes?.link)\">\r\n                  <ng-container *ngIf=\"redes?.icon; else text\">\r\n                    <img [src]=\"redes?.icon ? '../assets/images/' + redes?.icon : ''\" [alt]=\"redes?.text || ''\"\r\n                         [title]=\"redes?.text || ''\"/>\r\n                  </ng-container>\r\n                  <ng-template #text>\r\n                    <p *ngIf=\"redes?.text\">{{redes?.text}}</p>\r\n                  </ng-template>\r\n                </a>\r\n              </div>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n  </div>\r\n</footer>\r\n"
    })
], FooterComponent);

let FooterModule = class FooterModule {
};
FooterModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [FooterComponent],
        exports: [
            FooterComponent
        ]
    })
], FooterModule);

let EventInformationComponent = class EventInformationComponent {
    constructor(localDeviceDetector, dateFormat) {
        this.localDeviceDetector = localDeviceDetector;
        this.dateFormat = dateFormat;
    }
    ngOnInit() {
        var _a, _b, _c, _d;
        this.startDate = this.dateFormat.convertFromTimestampToDate((_b = (_a = this.globalData) === null || _a === void 0 ? void 0 : _a.date) === null || _b === void 0 ? void 0 : _b.start);
        this.endDate = this.dateFormat.convertFromTimestampToDate((_d = (_c = this.globalData) === null || _c === void 0 ? void 0 : _c.date) === null || _d === void 0 ? void 0 : _d.end);
    }
};
EventInformationComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService },
    { type: DateFormatService }
];
__decorate([
    Input()
], EventInformationComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], EventInformationComponent.prototype, "globalData", void 0);
__decorate([
    Input()
], EventInformationComponent.prototype, "componentData", void 0);
EventInformationComponent = __decorate([
    Component({
        selector: 'dmmp-event-information',
        template: "<dmmp-container [data]=\"componentData\" [defaultClass]=\"'information-event-formulanding'\" [identifier]=\"identifier\">\r\n  <div class=\"container\" *ngIf=\"localDeviceDetector.isDesktop() || localDeviceDetector.isTablet()\">\r\n    <dmmp-desktop [startDate]=\"startDate\" [endDate]=\"endDate\" [localization]=\"globalData?.location\"\r\n      [items]=\"globalData?.items_order\" class=\"row\"></dmmp-desktop>\r\n  </div>\r\n  <div class=\"container\" *ngIf=\"localDeviceDetector.isMobile()\">\r\n    <dmmp-mobile [startDate]=\"startDate\" [endDate]=\"endDate\" [localization]=\"globalData?.location\"\r\n      [items]=\"globalData?.items_order\"></dmmp-mobile>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], EventInformationComponent);

let DesktopComponent = class DesktopComponent {
    constructor() {
        this.date = 'Fecha';
        this.hour = 'Hora';
        this.location = 'Lugar';
        this.items = [];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], DesktopComponent.prototype, "startDate", void 0);
__decorate([
    Input()
], DesktopComponent.prototype, "endDate", void 0);
__decorate([
    Input()
], DesktopComponent.prototype, "localization", void 0);
__decorate([
    Input()
], DesktopComponent.prototype, "items", void 0);
DesktopComponent = __decorate([
    Component({
        selector: 'dmmp-desktop',
        template: "<div *ngFor=\"let itemOrder of items\" class=\"col-md-4 col-12\">\r\n  <div *ngIf=\"itemOrder?.type === 'Fecha'\" [class]=\"itemOrder?.class + ' date-tab'\">\r\n    <div class=\"icon\">\r\n      <i class=\"far fa-calendar-alt\"></i>\r\n    </div>\r\n    <div class=\"info\">\r\n      <div class=\"title\" *ngIf=\"date\">{{date}}</div>\r\n      <div class=\"data\">\r\n        <ng-template *ngIf=\"startDate === endDate; else alternativeDateTemplate\">\r\n          {{startDate | date : 'fullDate': 'UTC'}}\r\n        </ng-template>\r\n        <ng-template #alternativeDateTemplate>\r\n          <div class=\"startDate\">{{startDate | date : 'fullDate': 'UTC'}} </div>\r\n          <div class=\"endDate\">al {{endDate | date : 'fullDate': 'UTC'}}</div>\r\n        </ng-template>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div *ngIf=\"itemOrder?.type === 'Hora'\" [class]=\"itemOrder?.class + ' hour-tab'\">\r\n    <div class=\"icon\">\r\n      <i class=\"far fa-clock\"></i>\r\n    </div>\r\n    <div class=\"info\">\r\n      <div class=\"title\" *ngIf=\"hour\">{{hour}}</div>\r\n      <div class=\"data\">\r\n        {{startDate | date : 'HH:mm': 'UTC'}} a {{endDate | date : 'HH:mm': 'UTC'}}\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div *ngIf=\"itemOrder?.type === 'Lugar'\" [class]=\"itemOrder?.class + ' place-tab'\">\r\n    <div class=\"icon\">\r\n      <i class=\"fas fa-map-marker-alt\"></i>\r\n    </div>\r\n    <div class=\"info\">\r\n      <div class=\"title\" *ngIf=\"location\">{{location}}</div>\r\n      <div class=\"data\" *ngIf=\"localization\">{{localization}}</div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], DesktopComponent);

let MobileComponent = class MobileComponent {
    constructor() {
        this.items = [];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], MobileComponent.prototype, "startDate", void 0);
__decorate([
    Input()
], MobileComponent.prototype, "endDate", void 0);
__decorate([
    Input()
], MobileComponent.prototype, "localization", void 0);
__decorate([
    Input()
], MobileComponent.prototype, "items", void 0);
MobileComponent = __decorate([
    Component({
        selector: 'dmmp-mobile',
        template: "<ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\">\r\n  <li [ngbNavItem]=\"i\" *ngFor=\"let itemOrder of items; let i = index\"\r\n      [class]=\"itemOrder?.class || ''\">\r\n    <ng-container *ngIf=\"itemOrder?.type?.toLocaleLowerCase() === 'fecha'\">\r\n      <a ngbNavLink>\r\n        <div class=\"icon\">\r\n          <i class=\"far fa-calendar-alt\"></i>\r\n        </div>\r\n        <div class=\"title\">Fecha</div>\r\n      </a>\r\n      <ng-template ngbNavContent>\r\n        <ng-template *ngIf=\"startDate === endDate; else alternativeDateTemplate\">\r\n          <div class=\"date-tab\">\r\n            {{startDate | date : 'fullDate': 'UTC'}}\r\n          </div>\r\n        </ng-template>\r\n        <ng-template #alternativeDateTemplate>\r\n          <div class=\"date-tab\">\r\n            <div class=\"startDate\">{{startDate | date : 'fullDate' : 'UTC'}} </div>\r\n            <div class=\"endDate\">al {{endDate | date : 'fullDate': 'UTC'}}</div>\r\n          </div>\r\n        </ng-template>\r\n      </ng-template>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"itemOrder?.type?.toLocaleLowerCase() === 'hora'\">\r\n      <a ngbNavLink>\r\n        <div class=\"icon\">\r\n          <i class=\"far fa-clock\"></i>\r\n        </div>\r\n        <div class=\"title\">Hora</div>\r\n      </a>\r\n      <ng-template ngbNavContent>\r\n        <div class=\"hour-tab\">\r\n          {{startDate | date : 'HH:mm' : 'UTC'}} a {{endDate | date : 'HH:mm' : 'UTC'}}\r\n        </div>\r\n      </ng-template>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"itemOrder?.type?.toLocaleLowerCase() === 'lugar'\">\r\n      <a ngbNavLink>\r\n        <div class=\"icon\">\r\n          <i class=\"fas fa-map-marker-alt\"></i>\r\n        </div>\r\n        <div class=\"title\">Lugar</div>\r\n      </a>\r\n      <ng-template ngbNavContent>\r\n        <div class=\"place-tab\">\r\n          {{localization}}\r\n        </div>\r\n      </ng-template>\r\n    </ng-container>\r\n  </li>\r\n</ul>\r\n<div [ngbNavOutlet]=\"nav\">\r\n</div>\r\n"
    })
], MobileComponent);

let EventInformationModule = class EventInformationModule {
};
EventInformationModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            NgbNavModule,
            SharedModule
        ],
        declarations: [EventInformationComponent, DesktopComponent, MobileComponent],
        exports: [
            EventInformationComponent
        ],
        providers: [
            DateFormatService,
            LocalDeviceDetectorService
        ]
    })
], EventInformationModule);

let ModalTemplateComponent = class ModalTemplateComponent {
    constructor() {
        this.isModalOpen = false;
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], ModalTemplateComponent.prototype, "itemsOrder", void 0);
ModalTemplateComponent = __decorate([
    Component({
        selector: 'dmmp-modal-template',
        template: "<dmmp-modal [openModal]=\"isModalOpen\" (showModal)=\"isModalOpen = $event\">\r\n  <div class=\"row\" *ngIf=\"this.temporalSelectedEvent\">\r\n    <div class=\"col-12 col-sm-6 col-md-4 col-lg-4\">\r\n      <div class=\"box-image\">\r\n        <img [src]=\"(temporalSelectedEvent?.image)[0].styles.large\"\r\n          [title]=\"(temporalSelectedEvent?.image)[0].texts.title\" [alt]=\"(temporalSelectedEvent?.image)[0].texts.alt\" />\r\n      </div>\r\n    </div>\r\n    <div class=\"col-12 col-sm-6 col-md-8 col-lg-8\">\r\n      <h5 class=\"event-title\">{{this.temporalSelectedEvent?.title}}</h5>\r\n      <p class=\"event-subtitle\">{{this.temporalSelectedEvent?.sub_title}}</p>\r\n      <ng-container *ngFor=\"let item of itemsOrder\">\r\n        <div class=\"row event-modal-hour\" *ngIf=\"item?.type?.toLocaleLowerCase() === 'hora'\">\r\n          <div class=\"icon col-auto\">\r\n            <i class=\"far fa-clock\"></i>\r\n          </div>\r\n          <div class=\"title col-auto\">Hora</div>\r\n          <div class=\"hour-tab col-6\">\r\n            {{this.selectedStartDate | date : 'HH:mm': 'UTC'}} a {{this.selectedEndDate | date : 'HH:mm': 'UTC'}}\r\n          </div>\r\n        </div>\r\n        <div class=\"row event-modal-date\" *ngIf=\"item?.type?.toLocaleLowerCase() === 'fecha'\">\r\n          <div class=\"icon col-auto\">\r\n            <i class=\"far fa-calendar-alt\"></i>\r\n          </div>\r\n          <div class=\"title col-auto\">Fecha</div>\r\n          <div class=\"date-tab col-6\">\r\n            {{this.selectedStartDate | date : 'fullDate': 'UTC'}}\r\n          </div>\r\n        </div>\r\n        <div class=\"row event-modal-place\" *ngIf=\"item?.type?.toLocaleLowerCase() === 'lugar'\">\r\n          <div class=\"icon col-auto\">\r\n            <i class=\"fas fa-map-marker-alt\"></i>\r\n          </div>\r\n          <div class=\"title col-auto\">Lugar</div>\r\n          <div class=\"date-tab col-6\">\r\n            {{this.temporalSelectedEvent?.location}}\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n      <div class=\"row event-modal-description\">\r\n        <div class=\"col-12\" [innerHTML]=\"this.temporalSelectedEvent?.description\">\r\n        </div>\r\n      </div>\r\n      <div class=\"row event-modal-price no-gutters\" *ngIf=\"this.temporalSelectedEvent?.price?.length > 0\"\r\n        [ngClass]=\"this.temporalSelectedEvent.price[0].class ? this.temporalSelectedEvent.price[0].class : ''\"\r\n        [id]=\"this.temporalSelectedEvent.price[0].id_element ? this.temporalSelectedEvent.price[0].id_element : ''\">\r\n        <div class=\"col-auto icon-price\">\r\n          <dmmp-image-logo [data]=\"this.temporalSelectedEvent.price[0].icon\"></dmmp-image-logo>\r\n        </div>\r\n        <div class=\"col description-price\">\r\n          <span [innerHTML]=\"this.temporalSelectedEvent.price[0].description\"></span>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-modal>\r\n"
    })
], ModalTemplateComponent);

let GeneralProgrammingComponent = class GeneralProgrammingComponent {
    constructor(dateFormatService, anchorService) {
        this.dateFormatService = dateFormatService;
        this.anchorService = anchorService;
        this.localModalComponent = new ModalTemplateComponent();
        this.itemsPage = 8;
        this.currentPage = 1;
        this.totalPages = 1;
    }
    ngOnInit() {
        if (this.dateOrderGroup && this.dateOrderGroup.length > 0) {
            this.selectModel = this.dateOrderGroup[0];
        }
        if (this.campusTabs && this.campusTabs.length > 0) {
            this.filterEvents(this.campusTabs[0]);
        }
    }
    filterEvents(tabIn) {
        this.currentPage = 1;
        this.totalPages = 1;
        this.searchModel = tabIn;
        this.totalPages = Math.max(Math.ceil(this.subEvents.filter(item => {
            const tabs = item.campus.toString();
            return tabs.toLowerCase().includes(this.searchModel.label.toLowerCase()) && item.date.start >= this.selectModel.start
                && item.date.start <= this.selectModel.end;
        }).length / this.itemsPage), 1);
    }
    newPageEvent(newPage) {
        var _a;
        if ((_a = this.programInformation) === null || _a === void 0 ? void 0 : _a.id_element) {
            this.anchorService.scrollToId('#' + this.programInformation.id_element);
        }
        else {
            this.anchorService.scrollToId('#Programación_general_eventos');
        }
        this.currentPage = newPage.number;
    }
    selectedEventNotification(event) {
        this.localModalComponent.selectedStartDate = this.dateFormatService.convertFromTimestampToDate(event.date.start);
        this.localModalComponent.selectedEndDate = this.dateFormatService.convertFromTimestampToDate(event.date.end);
        this.localModalComponent.temporalSelectedEvent = event;
        this.localModalComponent.isModalOpen = true;
    }
};
GeneralProgrammingComponent.ctorParameters = () => [
    { type: DateFormatService },
    { type: AnchorService }
];
__decorate([
    ViewChild(ModalTemplateComponent)
], GeneralProgrammingComponent.prototype, "localModalComponent", void 0);
__decorate([
    Input()
], GeneralProgrammingComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], GeneralProgrammingComponent.prototype, "campusTabs", void 0);
__decorate([
    Input()
], GeneralProgrammingComponent.prototype, "programInformation", void 0);
__decorate([
    Input()
], GeneralProgrammingComponent.prototype, "subEvents", void 0);
__decorate([
    Input()
], GeneralProgrammingComponent.prototype, "itemsOrder", void 0);
__decorate([
    Input()
], GeneralProgrammingComponent.prototype, "dateOrderGroup", void 0);
__decorate([
    Input()
], GeneralProgrammingComponent.prototype, "itemsPage", void 0);
GeneralProgrammingComponent = __decorate([
    Component({
        selector: 'dmmp-general-programming',
        template: "<div\r\n  [id]=\" programInformation?.id_element ? programInformation?.id_element : 'Programaci\u00F3n_general_eventos'\"\r\n  [style.backgroundImage]=\" (programInformation?.background_image).length > 0 ? 'url(' + (programInformation?.background_image)[0].styles.large + ')' : ''\"\r\n  [style.backgroundColor]=\" (programInformation?.background_color).length > 0 ? (programInformation?.background_color)[0].color : '#ffffff'\"\r\n  class=\"container general-event-scheduling\" [ngClass]=\"programInformation?.class\">\r\n  <h2 class=\"h2\">\r\n    {{this.programInformation.title}}\r\n  </h2>\r\n  <div class=\"tabs-content\">\r\n    <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\">\r\n      <li [ngbNavItem]=\"i + 1\" *ngFor=\"let itemTab of campusTabs; let i = index\">\r\n        <ng-container>\r\n          <a ngbNavLink class=\"\" href=\"#\" (click)=\"filterEvents(itemTab)\">\r\n            <h3 class=\"h3\">{{itemTab.label}}</h3>\r\n          </a>\r\n          <ng-template ngbNavContent>\r\n            <div class=\"row select-content\">\r\n              <div class=\"col-12 col-sm-12 col-md-4 col-lg-3\">\r\n                <select class=\"browser-default custom-select\" [(ngModel)]=\"selectModel\"\r\n                  (change)=\"filterEvents(itemTab)\">\r\n                  <option *ngFor=\"let dateItem of dateOrderGroup\" [ngValue]=\"dateItem\">\r\n                    {{dateItem.label}}\r\n                  </option>\r\n                </select>\r\n              </div>\r\n            </div>\r\n            <div class=\"row events-content\">\r\n              <ng-container *ngFor=\"\r\n                  let subEvent of subEvents\r\n                    | Events: searchModel: currentPage: itemsPage: selectModel\r\n                \">\r\n                <dmmp-sub-event class=\"col-12 col-sm-6 col-md-4 col-lg-3\" [subEvent]=\"subEvent\"\r\n                  [identifier]=\"identifier\" (eventEmitter)=\"selectedEventNotification($event)\">\r\n                </dmmp-sub-event>\r\n              </ng-container>\r\n            </div>\r\n            <dmmp-paginator class=\"row paginator\" [currentPage]=\"currentPage\" (newPageEmitter)=\"newPageEvent($event)\"\r\n              [totalPages]=\"totalPages\">\r\n            </dmmp-paginator>\r\n          </ng-template>\r\n        </ng-container>\r\n      </li>\r\n    </ul>\r\n    <div [ngbNavOutlet]=\"nav\">\r\n    </div>\r\n  </div>\r\n  <dmmp-modal-template [itemsOrder]=\"this.itemsOrder\"></dmmp-modal-template>\r\n</div>\r\n"
    })
], GeneralProgrammingComponent);

let SubEventComponent = class SubEventComponent {
    constructor() {
        this.eventEmitter = new EventEmitter();
        this.todayTimestamp = Math.floor(new Date().getTime() / 1000);
    }
    ngOnInit() {
    }
    showEvent(event) {
        this.eventEmitter.emit(event);
    }
};
__decorate([
    Input()
], SubEventComponent.prototype, "subEvent", void 0);
__decorate([
    Input()
], SubEventComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], SubEventComponent.prototype, "eventEmitter", void 0);
SubEventComponent = __decorate([
    Component({
        selector: 'dmmp-sub-event',
        template: "<div (click)=\"showEvent(subEvent)\" [ngClass]=\"subEvent.class ? subEvent.class + ' event-item' : 'event-item'\"\r\n  [id]=\" subEvent?.id_element ? identifier + '_' + subEvent?.id_element : 'sub_event'\">\r\n  <div *ngIf=\"subEvent?.date?.end >= todayTimestamp; else expiredTemplate\"\r\n    [style.backgroundImage]=\" (subEvent?.image).length > 0 ? 'url(' + (subEvent?.image)[0].styles.large + ')' : ''\">\r\n    <div class=\"box-text\">\r\n      <h4 class=\"h4\">{{subEvent.title}}</h4>\r\n      <span>{{subEvent.sub_title}}</span>\r\n    </div>\r\n  </div>\r\n  <ng-template #expiredTemplate>\r\n    <div class=\"expired\"\r\n      [style.backgroundImage]=\" (subEvent?.image).length > 0 ? 'url(' + (subEvent?.image)[0].styles.large + ')' : ''\">\r\n      <div class=\"overlay\">\r\n      </div>\r\n      <span class=\"label-expired\">Vencido</span>\r\n      <div class=\"box-text\">\r\n        <h4 class=\"h4\">{{subEvent.title}}</h4>\r\n        <span>{{subEvent.sub_title}}</span>\r\n      </div>\r\n    </div>\r\n  </ng-template>\r\n</div>\r\n"
    })
], SubEventComponent);

let GeneralProgrammingModule = class GeneralProgrammingModule {
};
GeneralProgrammingModule = __decorate([
    NgModule({
        declarations: [GeneralProgrammingComponent, SubEventComponent, ModalTemplateComponent],
        imports: [
            CommonModule,
            NgbNavModule,
            PipesModule,
            FormsModule,
            SharedModule
        ],
        exports: [GeneralProgrammingComponent]
    })
], GeneralProgrammingModule);

let ErrorPageComponent = class ErrorPageComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
};
__decorate([
    Input()
], ErrorPageComponent.prototype, "data", void 0);
__decorate([
    Output()
], ErrorPageComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ErrorPageComponent.prototype, "page", void 0);
ErrorPageComponent = __decorate([
    Component({
        selector: 'dmmp-error-page',
        template: "<section class=\"error-page\"\r\n         *ngIf=\"data?.length > 0\"\r\n         [ngClass]=\"data[0]?.class || ''\"\r\n         [id]=\"data[0]?.id_element || ''\"\r\n         [style.backgroundColor]=\"data[0]?.background_color?.color || ''\"\r\n         [style.opacity]=\"data[0]?.background_color?.opacity || ''\"\r\n         [style.backgroundImage]=\"data[0]?.background_image?.length > 0 ? 'url(' + data[0]?.background_image[0]?.styles?.large + ')' : ''\">\r\n  <div [className]=\"data[0]?.secure_zone ? data[0]?.secure_zone : ''\">\r\n    <div class=\"row\">\r\n      <div *ngFor=\"let dataCol of data[0]?.config_column_page; let e = index\" class=\"col-lg-{{dataCol?.number_columns}}\"\r\n           [ngClass]=\"dataCol?.class\">\r\n        <div class=\"container-fluid\">\r\n          <div class=\"row\" *ngIf=\"data?.length > 0\">\r\n            <ng-container *ngFor=\"let content of data; let i = index\">\r\n              <ng-container *ngIf=\"i > 0 && content?.component !== 'footer'\">\r\n                <ng-container *ngIf=\"content?.column_group == e + 1\">\r\n                  <!-- Image -->\r\n                  <ng-container *ngIf=\"content?.component === 'image'\">\r\n                    <div *ngIf=\"content?.image\"\r\n                         class=\"col-lg-{{content?.number_columns}} images\"\r\n                         [id]=\"content?.id_element || ''\"\r\n                         [ngClass]=\"content?.class || ''\">\r\n                      <div class=\"image\">\r\n                        <img [src]=\"content?.image[0]?.styles?.large || ''\"\r\n                             [alt]=\"content?.image[0]?.texts?.alt || ''\"\r\n                             [title]=\"content?.image[0]?.texts?.title || ''\"/>\r\n                      </div>\r\n                    </div>\r\n                  </ng-container>\r\n                  <!-- HTML -->\r\n                  <ng-container *ngIf=\"content?.component === 'html_text'\">\r\n                    <div *ngIf=\"content?.texts?.length > 0\"\r\n                         class=\"col-lg-{{content?.number_columns}} html\"\r\n                         [id]=\"content?.id_element || ''\"\r\n                         [ngClass]=\"content?.class || ''\">\r\n                      <div class=\"content\" *ngIf=\"content?.text?.length > 0\">\r\n                        <ng-container *ngFor=\"let text of content?.texts\">\r\n                          <div [innerHTML]=\"text.text\"></div>\r\n                        </ng-container>\r\n                      </div>\r\n                    </div>\r\n                  </ng-container>\r\n                  <!-- Button -->\r\n                  <ng-container *ngIf=\"content?.component === 'button'\">\r\n                    <div *ngIf=\"content?.link && content?.label\"\r\n                         class=\"col-lg-{{content?.number_columns}} button\">\r\n                      <a [href]=\"content?.link || ''\" [ngClass]=\"content?.class || ''\"\r\n                         [id]=\"content?.id_element || ''\">{{content?.label}}</a>\r\n                    </div>\r\n                  </ng-container>\r\n                </ng-container>\r\n              </ng-container>\r\n            </ng-container>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</section>\r\n<ng-container *ngFor=\"let content of data\">\r\n  <ng-container [ngSwitch]=\"content?.component\">\r\n    <dmmp-footer *ngSwitchCase=\"'footer'\" [data]=\"content || ''\"\r\n                 [identifier]=\"data[0]?.id_element || ''\"\r\n                 (anchorCustom)=\"anchorCustom.emit()\"></dmmp-footer>\r\n    <dmmp-footer-grid *ngSwitchCase=\"'footer_home'\" [module]=\"content || ''\"\r\n                      [identifier]=\"data[0]?.id_element || ''\" (anchorCustom)=\"anchorCustom.emit()\"\r\n                      (page)=\"page.emit()\"></dmmp-footer-grid>\r\n  </ng-container>\r\n</ng-container>\r\n"
    })
], ErrorPageComponent);

let FooterGridComponent = class FooterGridComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
        var _a, _b, _c;
        (_c = (_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.row) === null || _c === void 0 ? void 0 : _c.forEach(rowItem => {
            rowItem.column.isCollapse = false;
        });
    }
};
__decorate([
    Input()
], FooterGridComponent.prototype, "module", void 0);
__decorate([
    Input()
], FooterGridComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], FooterGridComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], FooterGridComponent.prototype, "page", void 0);
FooterGridComponent = __decorate([
    Component({
        selector: 'dmmp-footer-grid',
        template: "<dmmp-container [data]=\"module\" [identifier]=\"identifier\"\r\n                [defaultClass]=\"'footer-home bg-color-white z-index-4 position-relative'\"\r\n                *ngIf=\"module?.content?.row?.length > 0\">\r\n  <ng-container *ngFor=\"let rowItem of module?.content?.row\">\r\n    <div [ngClass]=\"rowItem?.class || ''\">\r\n      <div class=\"container\">\r\n        <div class=\"row content-footer-box\" [id]=\"rowItem?.id_element || ''\">\r\n          <div *ngFor=\"let columnItem of rowItem?.column; let i = index\"\r\n               [ngClass]=\"'col-12 ' + 'col-lg-'+ columnItem?.number_columns + ' wrapper-footer ' + columnItem?.class\"\r\n               [id]=\"columnItem?.id_element\">\r\n            <div *ngIf=\"columnItem?.link?.length > 0\">\r\n              <dmmp-collapse-item [columnItem]=\"columnItem\" [identifier]=\"identifier\" (page)=\"page.emit($event)\"\r\n                                  (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-collapse-item>\r\n            </div>\r\n            <div *ngFor=\"let item of columnItem?.items_column\" [id]=\"item?.identifier\" [ngClass]=\"'item box-text'\"\r\n                 [ngbCollapse]=\"columnItem?.isCollapse\">\r\n              <div *ngIf=\"item?.identifier?.toLowerCase() === 'button'\">\r\n                <dmmp-button [data]=\"item\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\">\r\n                </dmmp-button>\r\n              </div>\r\n              <div *ngIf=\"item?.identifier?.toLowerCase() === 'images_link'\">\r\n                <dmmp-image-link [item]=\"item\" (page)=\"page.emit($event)\"\r\n                                 (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-image-link>\r\n              </div>\r\n              <div *ngIf=\"item?.identifier?.toLowerCase() === 'link_icon'\">\r\n                <dmmp-link-icon [data]=\"item\" (page)=\"page.emit($event)\"\r\n                                (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-link-icon>\r\n              </div>\r\n              <div *ngIf=\"item?.identifier?.toLowerCase() === 'textos'\">\r\n                <div [ngClass]=\"item?.class || ''\" [innerHTML]=\"item?.text\">\r\n                </div>\r\n              </div>\r\n              <div *ngIf=\"item?.identifier?.toLowerCase() === 'content' && item?.content?.length > 0\">\r\n                <li class=\"nav-item\" [ngClass]=\"item?.class ? 'nav-item ' + item?.class : 'nav-item'\">\r\n                  <a id=\"{{item?.content[0]?.label | replace}}\" class=\"nav-link\" routerLink=\"{{item?.content[0]?.path}}\">\r\n                    {{item?.content[0]?.label}}\r\n                  </a>\r\n                </li>\r\n              </div>\r\n              <div *ngIf=\"item?.identifier?.toLowerCase() === 'categories' && item?.category?.length > 0\">\r\n                <li class=\"nav-item\" [ngClass]=\"item?.class ? 'nav-item ' + item?.class : 'nav-item'\">\r\n                  <a id=\"{{item?.category[0]?.label | replace}}\" class=\"nav-link\" routerLink=\"{{item?.category[0]?.path}}\">\r\n                    {{item?.category[0]?.label}}\r\n                  </a>\r\n                </li>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n</dmmp-container>\r\n"
    })
], FooterGridComponent);

let ImageLinkComponent = class ImageLinkComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.medias = [
            { style: 'large', media: '(min-width:260px)' }
        ];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], ImageLinkComponent.prototype, "item", void 0);
__decorate([
    Output()
], ImageLinkComponent.prototype, "page", void 0);
__decorate([
    Output()
], ImageLinkComponent.prototype, "anchorCustom", void 0);
__decorate([
    Input()
], ImageLinkComponent.prototype, "medias", void 0);
ImageLinkComponent = __decorate([
    Component({
        selector: 'dmmp-image-link',
        template: "<div *ngIf=\"item?.link?.length > 0; else imgTem\">\r\n  <dmmp-link *ngIf=\"item?.link[0]?.link !== '/backToTop'; else isbackToTop\" [data]=\"item\"\r\n             (anchorCustom)=\"anchorCustom.emit($event)\" (page)=\"page.emit($event)\" [identifier]=\"item?.identifier\">\r\n    <dmmp-image\r\n      [medias]=\"medias\"\r\n      *ngIf=\"item?.image?.length > 0\"\r\n      [images]=\"item?.image[0]\"></dmmp-image>\r\n  </dmmp-link>\r\n  <ng-template #isbackToTop>\r\n    <dmmp-back-to-top *ngIf=\"item?.image?.length > 0\" [image]=\"item?.image\"></dmmp-back-to-top>\r\n  </ng-template>\r\n</div>\r\n<ng-template #imgTem>\r\n  <dmmp-image [medias]=\"medias\"\r\n              *ngIf=\"item?.image?.length > 0\"\r\n              [images]=\"item?.image[0]\"></dmmp-image>\r\n</ng-template>\r\n"
    })
], ImageLinkComponent);

let CollapseItemComponent = class CollapseItemComponent {
    constructor(localDeviceDetector) {
        this.localDeviceDetector = localDeviceDetector;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
CollapseItemComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], CollapseItemComponent.prototype, "columnItem", void 0);
__decorate([
    Input()
], CollapseItemComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], CollapseItemComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], CollapseItemComponent.prototype, "page", void 0);
CollapseItemComponent = __decorate([
    Component({
        selector: 'dmmp-collapse-item',
        template: "<div class=\"row\">\r\n  <div class=\"col\">\r\n    <ul class=\"navbar-nav\">\r\n      <li class=\"nav-item\"\r\n        [ngClass]=\"columnItem?.title_column_class ? 'nav-item ' + columnItem?.title_column_class : 'nav-item'\">\r\n        <dmmp-link *ngIf=\"columnItem?.link?.length > 0\" [data]=\"columnItem\" [identifier]=\"identifier\"\r\n          class=\"nav-link nav-title\" [defaultClass]=\"columnItem?.title_column_class\"\r\n          (anchorCustom)=\"anchorCustom.emit($event)\" (page)=\"page.emit($event)\">\r\n          {{columnItem?.link[0]?.name}}\r\n        </dmmp-link>\r\n      </li>\r\n    </ul>\r\n  </div>\r\n  <div class=\"col-auto text-right\" (click)=\"columnItem.isCollapse = !columnItem.isCollapse\"\r\n    *ngIf=\"localDeviceDetector.isMobile()\">\r\n    <button type=\"button\" class=\"btn btn-outline\" align-left>\r\n      <i class=\"fas fa-chevron-up\" *ngIf=\"!columnItem?.isCollapse\"></i>\r\n      <i class=\"fas fa-chevron-down\" *ngIf=\"columnItem?.isCollapse\"></i>\r\n    </button>\r\n  </div>\r\n</div>\r\n"
    })
], CollapseItemComponent);

let FooterGridModule = class FooterGridModule {
};
FooterGridModule = __decorate([
    NgModule({
        declarations: [FooterGridComponent, ImageLinkComponent, CollapseItemComponent],
        imports: [
            CommonModule,
            SharedModule,
            RouterModule,
            NgbCollapseModule,
            PipesModule
        ],
        exports: [FooterGridComponent]
    })
], FooterGridModule);

let ErrorPageModule = class ErrorPageModule {
};
ErrorPageModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            DescriptionModule,
            FooterModule,
            FooterGridModule
        ],
        declarations: [ErrorPageComponent],
        exports: [
            ErrorPageComponent
        ]
    })
], ErrorPageModule);

let BenefitsCarouselComponent = class BenefitsCarouselComponent {
    constructor(options) {
        this.options = options;
    }
    ngOnInit() {
        this.configBenefits = this.options.configurationBenefits(this.data);
    }
};
BenefitsCarouselComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], BenefitsCarouselComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], BenefitsCarouselComponent.prototype, "data", void 0);
BenefitsCarouselComponent = __decorate([
    Component({
        selector: 'dmmp-benefits-carousel',
        template: "<div\r\n  *ngIf=\"data?.visible\"\r\n  [id]=\"data?.id_element ? identifier + '_' + data?.id_element : 'benefits'\"\r\n  [ngClass]=\"data?.class || 'benefits'\"\r\n  [style.backgroundColor]=\"data?.background_color?.color || ''\"\r\n  [style.opacity]=\"data?.background_color?.opacity || ''\"\r\n  class=\"benefits\"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\" [ngClass]=\"data?.title_class || ''\">\r\n      {{ data?.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"data?.content?.length > 0\">\r\n      <owl-carousel-o [options]=\"configBenefits\" class=\"row\">\r\n        <ng-container *ngFor=\"let slide of data?.content\">\r\n          <ng-template carouselSlide>\r\n            <div class=\"col benefit-col\">\r\n              <div class=\"slide\" [ngClass]=\"slide?.class || ''\">\r\n                <div class=\"benefit-img\">\r\n                  <img\r\n                    *ngIf=\"slide?.images?.length > 0\"\r\n                    [src]=\"slide?.images[0]?.styles?.large\"\r\n                    [alt]=\"slide?.images[0]?.texts?.alt\"\r\n                    [title]=\"slide?.images[0]?.texts?.title\"\r\n                  />\r\n                </div>\r\n                <h3\r\n                  *ngIf=\"slide?.sub_title\"\r\n                  [ngClass]=\"slide?.sub_title_class || ''\"\r\n                >\r\n                  {{ slide?.sub_title }}\r\n                </h3>\r\n                <div\r\n                  class=\"benefit-text\"\r\n                  [innerHTML]=\"slide?.description || ''\"\r\n                ></div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </owl-carousel-o>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n"
    })
], BenefitsCarouselComponent);

let TitleComponent = class TitleComponent {
};
__decorate([
    Input()
], TitleComponent.prototype, "title", void 0);
__decorate([
    Input()
], TitleComponent.prototype, "as_h1", void 0);
__decorate([
    Input()
], TitleComponent.prototype, "class", void 0);
TitleComponent = __decorate([
    Component({
        selector: 'dmmp-title',
        template: "<ng-container *ngIf=\"as_h1; else secondaryTitle\">\r\n  <h1 [ngClass]=\"class ? class : ''\">{{title}}</h1>\r\n</ng-container>\r\n<ng-template #secondaryTitle>\r\n  <h2 [ngClass]=\"class ? class : ''\">{{title}}</h2>\r\n</ng-template>\r\n"
    })
], TitleComponent);

let TitleModule = class TitleModule {
};
TitleModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [TitleComponent],
        exports: [
            TitleComponent
        ]
    })
], TitleModule);

let BenefitsCarouselModule = class BenefitsCarouselModule {
};
BenefitsCarouselModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CarouselModule,
            CommonModule,
            TitleModule
        ],
        declarations: [BenefitsCarouselComponent],
        exports: [
            BenefitsCarouselComponent
        ],
        providers: [
            OptionsNgxOwCarouselService
        ]
    })
], BenefitsCarouselModule);

let BannerComponent = class BannerComponent {
    constructor(options) {
        this.options = options;
        this.content = [];
    }
    ngOnInit() {
        var _a, _b;
        this.configCarousel = this.options.configurationBenefits(this.data);
        if ((_a = this.data) === null || _a === void 0 ? void 0 : _a.content) {
            this.content = Object.values((_b = this.data) === null || _b === void 0 ? void 0 : _b.content);
        }
    }
};
BannerComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], BannerComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], BannerComponent.prototype, "data", void 0);
BannerComponent = __decorate([
    Component({
        selector: 'dmmp-banner',
        template: "<div [id]=\" data?.id_element ? identifier + '_' + data?.id_element : 'banner'\"\r\n     [style.backgroundImage]=\" (data?.background_image)?.length > 0 ? 'url(' + (data?.background_image)[0]?.styles?.large + ')' : ''\"\r\n     [style.backgroundColor]=\" data?.background_color?.color || '#ffffff'\"\r\n     class=\"banner\"\r\n     [ngClass]=\"data?.class\">\r\n  <ng-container *ngIf=\"content.length > 0\">\r\n    <ng-container *ngIf=\"content?.length > 1; else simpleBanner\">\r\n      <owl-carousel-o [options]=\"configCarousel\">\r\n        <ng-container *ngFor=\"let carouselBanner of content\">\r\n          <ng-template carouselSlide>\r\n            <div class=\"slide\">\r\n              <img [src]=\"carouselBanner?.images[0]?.styles?.large\"\r\n                   [alt]=\"carouselBanner?.images[0].texts?.alt\"\r\n                   [title]=\"carouselBanner?.images[0]?.texts?.title\"\r\n                   class=\"img-banner\"/>\r\n              <div class=\"txt-banner\" [innerHTML]=\"carouselBanner?.description || ''\"></div>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </owl-carousel-o>\r\n    </ng-container>\r\n    <ng-template #simpleBanner>\r\n      <div class=\"item-slide\">\r\n        <img [src]=\"content[0]?.images[0]?.styles?.large\"\r\n             [alt]=\"content[0]?.images[0]?.texts?.alt\"\r\n             [title]=\"content[0]?.images[0]?.texts?.title\"\r\n             class=\"img-banner\"/>\r\n        <div class=\"txt-banner\" [innerHTML]=\"content[0]?.description || ''\"></div>\r\n      </div>\r\n    </ng-template>\r\n  </ng-container>\r\n</div>\r\n"
    })
], BannerComponent);

let BannerModule = class BannerModule {
};
BannerModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CarouselModule,
            CommonModule
        ],
        declarations: [BannerComponent],
        exports: [
            BannerComponent
        ],
        providers: [OptionsNgxOwCarouselService]
    })
], BannerModule);

let BannerFullComponent = class BannerFullComponent {
    constructor(options) {
        this.options = options;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.bannerHeight = 'banner-height-changed';
    }
    ngOnInit() {
        this.configCarousel = this.options.configurationBenefits(this.data);
        this.hasImageOrVideo();
    }
    hasImageOrVideo() {
        var _a, _b, _c, _d;
        if (((_b = (_a = this.data) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.length) > 0) {
            (_d = (_c = this.data) === null || _c === void 0 ? void 0 : _c.content) === null || _d === void 0 ? void 0 : _d.filter(element => {
                var _a, _b;
                (_b = (_a = element) === null || _a === void 0 ? void 0 : _a.row) === null || _b === void 0 ? void 0 : _b.find(rowElement => {
                    var _a, _b;
                    (_b = (_a = rowElement) === null || _a === void 0 ? void 0 : _a.columns) === null || _b === void 0 ? void 0 : _b.find(columnElement => {
                        var _a, _b;
                        (_b = (_a = columnElement) === null || _a === void 0 ? void 0 : _a.items) === null || _b === void 0 ? void 0 : _b.find(itemElement => {
                            var _a, _b;
                            if (((_a = itemElement) === null || _a === void 0 ? void 0 : _a.identifier) === 'banner_video' || ((_b = itemElement) === null || _b === void 0 ? void 0 : _b.identifier) === 'images_link') {
                                this.bannerHeight = '';
                            }
                        });
                    });
                });
            });
        }
    }
};
BannerFullComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], BannerFullComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], BannerFullComponent.prototype, "data", void 0);
__decorate([
    Output()
], BannerFullComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], BannerFullComponent.prototype, "page", void 0);
BannerFullComponent = __decorate([
    Component({
        selector: 'dmmp-banner-full',
        template: "<div [id]=\" data?.id_element ? identifier + '_' + data?.id_element : 'banner'\" class=\"banner\" [ngClass]=\"[data?.class || '', bannerHeight]\"\r\n  [style.backgroundColor]=\"data?.background_color?.color || ''\"\r\n  [style.backgroundImage]=\" (data?.background_image)?.length > 0 ? 'url(' + (data?.background_image)[0]?.styles?.large + ')' : ''\">\r\n  <ng-container *ngIf=\"data?.content?.length > 0\">\r\n    <ng-container *ngIf=\"data?.content?.length > 1; else simpleBanner\">\r\n      <owl-carousel-o [options]=\"configCarousel\">\r\n        <ng-container *ngFor=\"let carouselBanner of data?.content\">\r\n          <ng-template carouselSlide>\r\n            <div class=\"bg-banner\"\r\n              [style.backgroundColor]=\"carouselBanner?.background_color?.color || ''\"\r\n              [style.backgroundImage]=\"carouselBanner?.background_image?.length > 0 ? 'url(' + (carouselBanner?.background_image)[0]?.styles?.large + ')' : ''\">\r\n              <div [ngClass]=\"['item ', carouselBanner?.class || 'container']\">\r\n                <div *ngFor=\"let rowItem of carouselBanner?.row\" [ngClass]=\"rowItem?.class ? 'row ' + rowItem.class : ''\"\r\n                    [id]=\"rowItem?.id || ''\">\r\n                  <dmmp-banner-item [rowItem]=\"rowItem\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-banner-item>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </owl-carousel-o>\r\n    </ng-container>\r\n    <ng-template #simpleBanner>\r\n      <div class=\"bg-banner\"\r\n        [style.backgroundColor]=\"data?.content[0]?.background_color?.color || ''\"\r\n        [style.backgroundImage]=\"data?.content[0]?.background_image?.length > 0 ? 'url(' + (data?.content[0]?.background_image)[0]?.styles?.large + ')' : ''\">\r\n        <div [ngClass]=\"['item ', data?.content[0]?.class || 'container']\">\r\n          <div *ngFor=\"let rowItem of data?.content[0]?.row\" [ngClass]=\"['row', rowItem?.class || '']\" [id]=\"rowItem?.id\">\r\n            <dmmp-banner-item [rowItem]=\"rowItem\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-banner-item>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </ng-template>\r\n  </ng-container>\r\n</div>\r\n"
    })
], BannerFullComponent);

let BannerFullModule = class BannerFullModule {
};
BannerFullModule = __decorate([
    NgModule({
        declarations: [BannerFullComponent],
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CarouselModule,
            CommonModule,
            SharedModule
        ],
        exports: [BannerFullComponent],
        providers: [OptionsNgxOwCarouselService]
    })
], BannerFullModule);

let FloatObjectService = class FloatObjectService {
    constructor() {
    }
    selectPosition(position) {
        let positionElement;
        switch (position) {
            case 'right_up':
                positionElement = { top: '15px' };
                break;
            case 'right_middle':
                positionElement = { top: '50%' };
                break;
            case 'right_down':
                positionElement = { bottom: '15px' };
                break;
            default:
                positionElement = { bottom: '20px' };
        }
        return positionElement;
    }
};
FloatObjectService = __decorate([
    Injectable()
], FloatObjectService);

let FloatObjectComponent = class FloatObjectComponent {
    constructor(floatService) {
        this.floatService = floatService;
    }
    ngOnInit() {
        var _a, _b;
        if (this.data.content.position) {
            this.positionElement = this.floatService.selectPosition((_b = (_a = this.data) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.position);
        }
    }
};
FloatObjectComponent.ctorParameters = () => [
    { type: FloatObjectService }
];
__decorate([
    Input()
], FloatObjectComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], FloatObjectComponent.prototype, "data", void 0);
FloatObjectComponent = __decorate([
    Component({
        selector: 'dmmp-float-object',
        template: "<div class=\"float-container\"\r\n     *ngIf=\"data?.visible\"\r\n     [id]=\"data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n     [style.backgroundColor]=\"data?.background_color?.color || ''\"\r\n     [style.backgroundImage]=\"(data?.background_image)?.length > 0  ? 'url(' +(data?.background_image)[0]?.styles?.large +')':''\"\r\n     [ngClass]=\"data?.class || ''\"\r\n     [ngStyle]=\"positionElement\"\r\n>\r\n  <ng-container *ngIf=\"data?.content\">\r\n    <div *ngIf=\"data?.content?.icon?.length > 0\">\r\n      <a *ngIf=\"data?.content?.icon[0]?.link; else onlyImage\" [href]=\"data?.content?.icon[0]?.link\"\r\n         [target]=\"'_blank'\">\r\n        <ng-container *ngIf=\"data?.content.icon[0]?.icon === null; else onlyIconSvg\">\r\n          <img\r\n            [src]=\"data?.content?.icon[0]?.styles?.large\"\r\n            [alt]=\"data?.content?.icon[0]?.texts?.alt\"\r\n            [title]=\"data?.content?.icon[0]?.texts?.title\">\r\n          <span *ngIf=\"data?.content?.tooltip\"\r\n                class=\"tooltiptext\">{{data?.content?.tooltip}}</span>\r\n        </ng-container>\r\n        <ng-template #onlyIconSvg>\r\n          <img [src]=\"'../assets/images/' + data?.content?.icon[0]?.icon\" alt=\"\">\r\n          <span *ngIf=\"data?.content?.tooltip\"\r\n                class=\"tooltiptext\">{{data?.content?.tooltip}}</span>\r\n        </ng-template>\r\n      </a>\r\n      <ng-template #onlyImage>\r\n        <ng-container *ngIf=\"data?.content?.icon[0]?.icon === null; else onlyIconSvg\">\r\n          <img\r\n            [src]=\"data?.content?.icon[0]?.styles?.large\"\r\n            [alt]=\"data?.content?.icon[0]?.texts?.alt\"\r\n            [title]=\"data?.content?.icon[0]?.texts?.title\">\r\n          <span *ngIf=\"data?.content?.tooltip\"\r\n                class=\"tooltiptext\">{{data?.content?.tooltip}}</span>\r\n        </ng-container>\r\n        <ng-template #onlyIconSvg>\r\n          <img [src]=\"'../assets/images/' + data?.content?.icon[0]?.icon\" alt=\"\">\r\n          <span *ngIf=\"data?.content?.tooltip\"\r\n                class=\"tooltiptext\">{{data?.content?.tooltip}}</span>\r\n        </ng-template>\r\n      </ng-template>\r\n    </div>\r\n  </ng-container>\r\n</div>\r\n",
        styles: [".float-container{position:fixed;right:15px;z-index:999;cursor:pointer}.float-container img{width:50px;height:50px}.tooltiptext{visibility:hidden;width:120px;background-color:#000;color:#fff;text-align:center;border-radius:6px;padding:5px 0;position:absolute;z-index:1;bottom:5px;right:110%;transition:.3s}.tooltiptext::after{content:\"\";position:absolute;top:50%;left:100%;margin-top:-5px;border-width:5px;border-style:solid;border-color:transparent transparent transparent #000}.float-container:hover .tooltiptext{visibility:visible}"]
    })
], FloatObjectComponent);

let FloatObjectModule = class FloatObjectModule {
};
FloatObjectModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
        ],
        declarations: [FloatObjectComponent],
        exports: [
            FloatObjectComponent,
        ],
        providers: [
            FloatObjectService
        ]
    })
], FloatObjectModule);

let ThanksYouPageComponent = class ThanksYouPageComponent {
};
__decorate([
    Input()
], ThanksYouPageComponent.prototype, "data", void 0);
__decorate([
    Input()
], ThanksYouPageComponent.prototype, "name", void 0);
ThanksYouPageComponent = __decorate([
    Component({
        selector: 'dmmp-thanks-you-page',
        template: "<section class=\"thank-you-page\"\r\n         *ngIf=\"data\"\r\n         [ngClass]=\"data[0]?.class ? data[0]?.class : ''\"\r\n         [id]=\"data[0]?.id_element ? data[0]?.id_element:''\"\r\n         [style.backgroundColor]=\"data[0]?.background_color.color ? data[0]?.background_color.color : ''\"\r\n         [style.opacity]=\"data[0]?.background_color.opacity ? data[0]?.background_color.opacity : ''\"\r\n         [style.backgroundImage]=\"data[0]?.background_image.length > 0 ? 'url(' + data[0]?.background_image[0].styles.large + ')' : ''\">\r\n  <div [className]=\"data[0]?.secure_zone ? data[0]?.secure_zone : ''\">\r\n    <div class=\"row\">\r\n      <div *ngFor=\"let dataCol of data[0]?.config_column_page; let e = index\" class=\"col-lg-{{dataCol.number_columns}}\"\r\n           [ngClass]=\"dataCol?.class\">\r\n        <div class=\"container-fluid\">\r\n          <div class=\"row\">\r\n            <ng-container *ngFor=\"let content of data; let i = index\">\r\n              <ng-container *ngIf=\"i > 0 && content.component !== 'footer'\">\r\n                <ng-container *ngIf=\"content.column_group == e+1\">\r\n                  <!-- Image -->\r\n                  <ng-container *ngIf=\"content?.component === 'image'\">\r\n                    <div class=\"col-lg-{{content.number_columns}} images\"\r\n                         [id]=\"content.id_element ? content.id_element : ''\"\r\n                         [ngClass]=\"content.class ? content.class : ''\" *ngIf=\"content?.image\">\r\n                      <div class=\"image\">\r\n                        <img [src]=\"content.image[0].styles.large ? content.image[0].styles.large:''\"\r\n                             [alt]=\"content.image[0].texts.alt ? content?.image[0].texts.alt:''\"\r\n                             [title]=\"content.image[0].texts.title ? content.image[0].texts.title : ''\"/>\r\n                      </div>\r\n                    </div>\r\n                  </ng-container>\r\n                  <!-- HTML -->\r\n                  <ng-container *ngIf=\"content?.component === 'html_text'\">\r\n                    <div class=\"col-lg-{{content.number_columns}} html\"\r\n                         [id]=\"content.id_element ? content.id_element : ''\"\r\n                         [ngClass]=\"content.class ? content.class : ''\" *ngIf=\"content?.texts?.length > 0\">\r\n                      <div class=\"content\">\r\n                        <ng-container *ngFor=\"let text of content?.texts\">\r\n                          <div *ngIf=\"text?.text !== '$name$'; else showName\" [innerHTML]=\"text.text\"></div>\r\n                          <ng-template #showName>\r\n                            <div *ngIf=\"name\">\r\n                              <p class=\"name-dynamic\">{{name}}</p>\r\n                            </div>\r\n                          </ng-template>\r\n                        </ng-container>\r\n                      </div>\r\n                    </div>\r\n                  </ng-container>\r\n                  <!-- Button -->\r\n                  <ng-container *ngIf=\"content?.component === 'button'\">\r\n                    <div class=\"col-lg-{{content.number_columns}} button\" *ngIf=\"content?.link && content?.label\">\r\n                      <a [href]=\"content.link ? content.link : ''\" [ngClass]=\"content.class ? content.class : ''\"\r\n                         [id]=\"content.id_element ? content.id_element : ''\">{{content.label}}</a>\r\n                    </div>\r\n                  </ng-container>\r\n                  <!-- Icon -->\r\n                  <ng-container *ngIf=\"content?.component === 'icon'\">\r\n                    <div class=\"col-lg-{{content.number_columns}}\"\r\n                         [id]=\"content.id_element ? content.id_element : ''\"\r\n                         [ngClass]=\"content.class ? content.class : ''\" *ngIf=\"content?.image?.length > 0\">\r\n                      <div class=\"image\">\r\n                        <img [src]=\"content?.image[0].styles.large ? content?.image[0].styles.large:''\"\r\n                             [alt]=\"content?.image[0]?.texts.alt ? content?.image[0]?.texts.alt:''\"\r\n                             [title]=\"content?.image[0]?.texts.title ? content?.image[0]?.texts.title : ''\"/>\r\n                      </div>\r\n                    </div>\r\n                  </ng-container>\r\n                  <!-- Icons -->\r\n                  <ng-container *ngIf=\"content?.component === 'icons'\">\r\n                    <div class=\"col-lg-{{content.number_columns}}\"\r\n                         [id]=\"content.id_element ? content.id_element : ''\"\r\n                         [ngClass]=\"content.class ? content.class : ''\">\r\n                      <ng-container *ngIf=\"content?.icons?.length > 0\">\r\n                        <ng-container *ngFor=\"let icons of content.icons\">\r\n                          <div [id]=\"icons.id ? icons.id : ''\"\r\n                               [ngClass]=\"icons.class\">\r\n                            <a *ngIf=\"icons?.link\" [href]=\"icons.link\" [target]=\"icons.target\">\r\n                              <img *ngIf=\"icons.styles\"\r\n                                   [src]=\"icons?.styles.large ? icons?.styles.large:''\"\r\n                                   [alt]=\"icons?.texts.alt ? icons?.texts.alt:''\"\r\n                                   [title]=\"icons?.texts.title ? icons?.texts.title : ''\"\r\n                              />\r\n                            </a>\r\n                          </div>\r\n                        </ng-container>\r\n                      </ng-container>\r\n                    </div>\r\n                  </ng-container>\r\n                </ng-container>\r\n              </ng-container>\r\n            </ng-container>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</section>\r\n<ng-container *ngFor=\"let content of data\">\r\n  <dmmp-footer *ngIf=\"content.component === 'footer'\"\r\n               [data]=\"content ? content:''\"></dmmp-footer>\r\n</ng-container>\r\n\r\n"
    })
], ThanksYouPageComponent);

let ThanksYouPageModule = class ThanksYouPageModule {
};
ThanksYouPageModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            DescriptionModule,
            FooterModule
        ],
        declarations: [ThanksYouPageComponent],
        exports: [
            ThanksYouPageComponent
        ]
    })
], ThanksYouPageModule);

let FourBenefitsComponent = class FourBenefitsComponent {
    ngOnInit() {
    }
};
__decorate([
    Input()
], FourBenefitsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], FourBenefitsComponent.prototype, "data", void 0);
FourBenefitsComponent = __decorate([
    Component({
        selector: 'dmmp-four-benefits',
        template: "<div\r\n  *ngIf=\"data?.visible\"\r\n  [id]=\"data.id_element ? identifier + '_' + data.id_element : 'benefits'\"\r\n  [ngClass]=\"data?.class || 'benefits'\"\r\n  [style.backgroundColor]=\"\r\n    data?.background_color?.color || ''\r\n  \"\r\n  [style.opacity]=\"\r\n    data?.background_color?.opacity || ''\r\n  \"\r\n  [style.backgroundImage]=\"\r\n    data?.background_image?.length > 0\r\n      ? 'url(' + data?.background_image[0]?.styles?.large + ')'\r\n      : ''\r\n  \"\r\n  class=\"four-benefits\"\r\n>\r\n  <div class=\"container\">\r\n    <div *ngIf=\"data?.name\">\r\n      <h2 *ngIf=\"data?.name\" [ngClass]=\"data?.title_class || ''\">\r\n        {{ data?.name }}\r\n      </h2>\r\n    </div>\r\n    <div *ngIf=\"data?.texts?.length > 0\">\r\n      <ng-container *ngFor=\"let texts of data?.texts\">\r\n        <div [innerHTML]=\"texts?.text\" [ngClass]=\"texts?.class\"></div>\r\n      </ng-container>\r\n    </div>\r\n    <div class=\"row\" *ngIf=\"data?.content?.length > 0\">\r\n      <ng-container *ngFor=\"let benefit of data?.content\">\r\n        <div\r\n          class=\"col-12 col-md-6 benefits-items\"\r\n          *ngIf=\"benefit?.images?.length > 0\"\r\n          [ngClass]=\"benefit?.class || ''\"\r\n        >\r\n          <div class=\"benefit-img\">\r\n            <img\r\n              [src]=\"benefit?.images[0]?.styles?.large\"\r\n              [alt]=\"benefit?.images[0]?.texts?.alt\"\r\n              [title]=\"benefit?.images[0]?.texts?.title\"\r\n            />\r\n          </div>\r\n          <div\r\n            class=\"benefit-text\"\r\n            [innerHTML]=\"benefit?.description || ''\"\r\n          ></div>\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], FourBenefitsComponent);

let FourBenefitsModule = class FourBenefitsModule {
};
FourBenefitsModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TitleModule
        ],
        declarations: [FourBenefitsComponent],
        exports: [FourBenefitsComponent]
    })
], FourBenefitsModule);

let SvgIconsComponent = class SvgIconsComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
SvgIconsComponent = __decorate([
    Component({
        selector: 'dmmp-svg-icons',
        template: "<svg xmlns=\"http://www.w3.org/2000/svg\">\r\n  <symbol id=\"icon-dmmp-pencil\" viewBox=\"0 0 512 512\">\r\n    <path\r\n      d=\"m140 439l26-26-67-67-26 26 0 30 37 0 0 37z m150-265c0-4-2-7-7-7-1 0-3 1-4 2l-155 155c-2 2-2 3-2 5 0 4 2 6 6 6 2 0 4 0 5-2l155-154c1-2 2-3 2-5z m-16-55l119 119-238 237-118 0 0-118z m195 27c0 10-3 19-10 26l-48 47-118-118 47-48c7-7 15-10 26-10 10 0 18 3 26 10l67 67c7 8 10 16 10 26z\"\r\n    />\r\n  </symbol>\r\n\r\n  <symbol id=\"icon-dmmp-guia\" viewBox=\"0 0 15 12\">\r\n    <svg\r\n      version=\"1.1\"\r\n      id=\"Layer_1\"\r\n      xmlns=\"http://www.w3.org/2000/svg\"\r\n      xmlns:xlink=\"http://www.w3.org/1999/xlink\"\r\n      x=\"0px\"\r\n      y=\"0px\"\r\n      viewBox=\"0 0 44 75\"\r\n      style=\"enable-background:new 0 0 44 75;\"\r\n      xml:space=\"preserve\"\r\n    >\r\n      <g>\r\n        <g>\r\n          <path\r\n            d=\"M3.8,57.3h36.4c1,0,1.8-0.8,1.8-1.8V4.5c0-1-0.8-1.8-1.8-1.8H12c0,0,0,0-0.1,0c-0.1,0-0.2,0-0.2,0c0,0-0.1,0-0.1,0\r\n\t\t\tc-0.1,0-0.2,0.1-0.3,0.2l-9.1,9.1v0c-0.1,0.1-0.1,0.2-0.2,0.3c0,0,0,0.1,0,0.1c0,0.1,0,0.2,0,0.2c0,0,0,0,0,0.1v42.7\r\n\t\t\tC2,56.5,2.8,57.3,3.8,57.3z M11.1,5.8v6h-6L11.1,5.8z M3.8,13.6H12c0.5,0,0.9-0.4,0.9-0.9V4.5h27.3v50.9H3.8V13.6z\"\r\n          />\r\n          <path\r\n            d=\"M8.4,18.2h16.4c0.5,0,0.9-0.4,0.9-0.9c0-0.5-0.4-0.9-0.9-0.9H8.4c-0.5,0-0.9,0.4-0.9,0.9C7.5,17.8,7.9,18.2,8.4,18.2z\"\r\n          />\r\n          <path\r\n            d=\"M35.6,21.8H8.4c-0.5,0-0.9,0.4-0.9,0.9s0.4,0.9,0.9,0.9h27.3c0.5,0,0.9-0.4,0.9-0.9S36.1,21.8,35.6,21.8z\"\r\n          />\r\n          <path\r\n            d=\"M35.6,27.3H8.4c-0.5,0-0.9,0.4-0.9,0.9s0.4,0.9,0.9,0.9h27.3c0.5,0,0.9-0.4,0.9-0.9S36.1,27.3,35.6,27.3z\"\r\n          />\r\n          <path\r\n            d=\"M35.6,32.7H8.4c-0.5,0-0.9,0.4-0.9,0.9c0,0.5,0.4,0.9,0.9,0.9h27.3c0.5,0,0.9-0.4,0.9-0.9C36.5,33.1,36.1,32.7,35.6,32.7z\r\n\t\t\t\"\r\n          />\r\n          <path\r\n            d=\"M35.6,38.2H8.4c-0.5,0-0.9,0.4-0.9,0.9S7.9,40,8.4,40h27.3c0.5,0,0.9-0.4,0.9-0.9S36.1,38.2,35.6,38.2z\"\r\n          />\r\n          <path\r\n            d=\"M35.6,43.6H8.4c-0.5,0-0.9,0.4-0.9,0.9s0.4,0.9,0.9,0.9h27.3c0.5,0,0.9-0.4,0.9-0.9S36.1,43.6,35.6,43.6z\"\r\n          />\r\n          <path\r\n            d=\"M33.8,49.1h-2.7c-0.5,0-0.9,0.4-0.9,0.9c0,0.5,0.4,0.9,0.9,0.9h2.7c0.5,0,0.9-0.4,0.9-0.9C34.7,49.5,34.3,49.1,33.8,49.1z\r\n\t\t\t\"\r\n          />\r\n          <path\r\n            d=\"M27.5,49.1H13.8c-0.5,0-0.9,0.4-0.9,0.9c0,0.5,0.4,0.9,0.9,0.9h13.6c0.5,0,0.9-0.4,0.9-0.9C28.4,49.5,28,49.1,27.5,49.1z\"\r\n          />\r\n          <path\r\n            d=\"M10.2,49.1H8.4c-0.5,0-0.9,0.4-0.9,0.9c0,0.5,0.4,0.9,0.9,0.9h1.8c0.5,0,0.9-0.4,0.9-0.9C11.1,49.5,10.7,49.1,10.2,49.1z\"\r\n          />\r\n        </g>\r\n      </g>\r\n    </svg>\r\n  </symbol>\r\n</svg>\r\n"
    })
], SvgIconsComponent);

let SvgIconsModule = class SvgIconsModule {
};
SvgIconsModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [SvgIconsComponent],
        exports: [
            SvgIconsComponent
        ]
    })
], SvgIconsModule);

let DetailProgramDescBulletsComponent = class DetailProgramDescBulletsComponent {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.active = 0;
    }
    ngOnInit() { }
    transform(url) {
        return this.sanitizer.bypassSecurityTrustResourceUrl(url);
    }
};
DetailProgramDescBulletsComponent.ctorParameters = () => [
    { type: DomSanitizer }
];
__decorate([
    Input()
], DetailProgramDescBulletsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], DetailProgramDescBulletsComponent.prototype, "data", void 0);
DetailProgramDescBulletsComponent = __decorate([
    Component({
        selector: 'dmmp-detail-program-desc-bullets',
        template: "<section class=\"detail-program detail-program-desc-bullets\" *ngIf=\"data?.visible\"\r\n         [ngClass]=\"data.class ? data.class : ''\" [id]=\"data?.id_element ?  identifier + '_' + data?.id_element : ''\"\r\n         [style.backgroundColor]=\"data?.background_color ? data?.background_color.color : ''\"\r\n         [style.backgroundImage]=\"(data?.background_image).length > 0 ? 'url(' + (data?.background_image)[0].styles.large + ')' : ''\"\r\n         [style.opacity]=\"data?.background_color['opacity'] ? data?.background_color['opacity']:''\">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts ? data?.texts?.length > 0 : false\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"tabs\" *ngIf=\"data?.content?.length > 0\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n          <li *ngFor=\"let arr of data.content[0].details | slice:0:4; let u = index\" [ngbNavItem]=\"u\">\r\n            <a ngbNavLink>{{ arr?.tab_name }}</a>\r\n            <ng-template ngbNavContent>\r\n              <ng-container *ngIf=\"arr?.file; else contentN\">\r\n                <div class=\"content\">\r\n                  <h3>{{ arr.title }}</h3>\r\n                  <div class=\"iframe\" *ngIf=\"arr?.file\">\r\n                    <dmmp-pdf-viewer [pdfSrc]=\"arr?.file\" [defaultClass]=\"'modal-embed'\"></dmmp-pdf-viewer>\r\n                  </div>\r\n                  <ng-container *ngIf=\"arr?.button?.length > 0\">\r\n                    <div class=\"row\">\r\n                      <ng-container *ngFor=\"let button of arr?.button\">\r\n                        <dmmp-button [data]=\"button\"></dmmp-button>\r\n                      </ng-container>\r\n                    </div>\r\n                  </ng-container>\r\n                </div>\r\n              </ng-container>\r\n              <ng-template #contentN>\r\n                <div class=\"row\" [ngClass]=\"arr.class ? arr.class : ''\" [id]=\"arr.id_element ? arr.id_element : ''\">\r\n                  <div class=\"col-12 col-sm-6 col-md-6 col-lg-6\">\r\n                    <div class=\"box-image\" *ngIf=\"arr?.image?.length > 0\">\r\n                      <img [src]=\"arr?.image[0].styles.large ? arr?.image[0].styles.large : ''\"\r\n                           [alt]=\"arr?.image[0].texts.alt ? arr?.image[0].texts.alt : ''\"\r\n                           [title]=\"arr?.image[0].texts.title ? arr?.image[0].texts.title : ''\"/>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"col-12 col-sm-6 col-md-6 col-lg-6\">\r\n                    <div class=\"content\">\r\n                      <h3 *ngIf=\"arr?.title\">{{ arr.title }}</h3>\r\n                      <ng-container *ngIf=\"u === 0\">\r\n                        <div class=\"star-class\"\r\n                             *ngIf=\"data?.content[0]?.start_date?.length > 0\"\r\n                             [ngClass]=\"data.content[0].start_date[0].class ? data.content[0].start_date[0].class : ''\">\r\n                          <div>Inicio de clases: <span [innerHTML]=\"data.content[0].start_date[0].text\"></span></div>\r\n                        </div>\r\n                        <div class=\"duration-content\" *ngIf=\"data?.content[0]?.duration\"\r\n                             [ngClass]=\"data.content[0].duration_class ? data.content[0].duration_class : ''\">\r\n                          <p>Duraci\u00F3n: {{data.content[0].duration}}</p>\r\n                        </div>\r\n                      </ng-container>\r\n                      <ng-container *ngIf=\"arr?.options\">\r\n                        <dmmp-icons-text [data]=\"arr.options\"></dmmp-icons-text>\r\n                      </ng-container>\r\n                      <ng-container *ngIf=\"arr?.text\">\r\n                        <dmmp-description [data]=\"arr.text\"></dmmp-description>\r\n                      </ng-container>\r\n                      <ng-container *ngIf=\"arr?.button?.length > 0\">\r\n                        <div class=\"row\">\r\n                          <div class=\"col-12 col-sm-12 col-md-12 col-lg-12\">\r\n                            <div class=\"content content-button\">\r\n                              <ng-container *ngFor=\"let btn of arr.button\">\r\n                                <dmmp-button [data]=\"btn\"></dmmp-button>\r\n                              </ng-container>\r\n                            </div>\r\n                          </div>\r\n                        </div>\r\n                      </ng-container>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </ng-template>\r\n            </ng-template>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n      <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], DetailProgramDescBulletsComponent);

let ModalProgramDescBulletsComponent = class ModalProgramDescBulletsComponent {
    constructor(activeModal, sanitizer) {
        this.activeModal = activeModal;
        this.sanitizer = sanitizer;
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
    }
    transform(url) {
        return this.sanitizer.bypassSecurityTrustResourceUrl(url);
    }
    anchor(event, data, categories) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.categoriesOut.emit(categories);
            event.preventDefault();
            this.activeModal.close('Close click');
            setTimeout(() => {
                this.anchorCustom.emit({ event: event, id: data });
            }, 100);
        }
    }
};
ModalProgramDescBulletsComponent.ctorParameters = () => [
    { type: NgbActiveModal },
    { type: DomSanitizer }
];
__decorate([
    Input()
], ModalProgramDescBulletsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ModalProgramDescBulletsComponent.prototype, "data", void 0);
__decorate([
    Output()
], ModalProgramDescBulletsComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], ModalProgramDescBulletsComponent.prototype, "anchorCustom", void 0);
ModalProgramDescBulletsComponent = __decorate([
    Component({
        selector: 'dmmp-modal-program-desc-bullets',
        template: "<div class=\"modal-detail-program modal-program-desc-bullets\" [id]=\"identifier ? identifier + '_' + 'modal' : ''\">\r\n  <div class=\"modal-header-content\">\r\n    <div class=\"info-header-content\">\r\n      <h2 class=\"modal-title h2\" *ngIf=\"data?.title\" [innerHTML]=\"data.title\"></h2>\r\n      <div class=\"row\">\r\n        <div class=\"col-12 col-md\" *ngIf=\"data?.start_date?.length > 0\">\r\n          <div class=\"start-class-content\" [ngClass]=\"data.start_date[0].class ? data.start_date[0].class : ''\">\r\n            <p>Inicio de clases: </p>\r\n            <div class=\"date\" [innerHTML]=\"data.start_date[0].text\"></div>\r\n          </div>\r\n        </div>\r\n        <div class=\"col-12 col-md\" *ngIf=\"data?.duration\">\r\n          <div class=\"duration-modal\" [ngClass]=\"data.duration_class ? data.duration_class : ''\">\r\n            <p>Duraci\u00F3n: {{data.duration}}</p>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <button type=\"button\" class=\"close\" aria-label=\"Close\" (click)=\"activeModal.close('Close click')\">\r\n      <span aria-hidden=\"true\">\r\n        <i class=\"fas fa-times\"></i>\r\n      </span>\r\n    </button>\r\n  </div>\r\n  <div class=\"modal-body\" *ngIf=\"data?.additional_information\">\r\n    <div class=\"tabs-content\">\r\n      <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n        <li *ngFor=\"\r\n            let detailProgram of data?.additional_information;\r\n            let i = index\r\n          \" [ngbNavItem]=\"i\">\r\n          <a ngbNavLink>{{ detailProgram?.tab_name }}</a>\r\n          <ng-template ngbNavContent>\r\n            <div class=\"content-tab\" [ngClass]=\"detailProgram.class ? detailProgram.class : ''\"\r\n              [id]=\"detailProgram?.id_element ? identifier + '_' + detailProgram?.id_element : ''\">\r\n              <div class=\"row\">\r\n                <ng-container *ngIf=\"detailProgram?.options; else content\">\r\n                  <div class=\"col-12\">\r\n                    <div class=\"subtitle-content-modal\">\r\n                      <h3 *ngIf=\"detailProgram?.title\">\r\n                        {{ detailProgram?.title }}\r\n                      </h3>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"col-12 col-sm-6 col-md-4 col-lg-4\" *ngFor=\"let option of detailProgram?.options\">\r\n                    <div class=\"content\" [ngClass]=\"option?.class ? option?.class : ''\"\r\n                      [id]=\"option?.id_element ? option?.id_element : ''\">\r\n                      <div class=\"image\" *ngIf=\"option?.icon\">\r\n                        <img [src]=\"\r\n                            option?.icon[0].styles.large\r\n                              ? option?.icon[0].styles.large\r\n                              : ''\r\n                          \" [alt]=\"\r\n                            option?.icon[0].texts.alt ? option?.icon[0].texts.alt : ''\r\n                          \" [title]=\"\r\n                            option?.icon[0].texts.title\r\n                              ? option?.icon[0].texts.title\r\n                              : ''\r\n                          \" />\r\n                      </div>\r\n                      <div class=\"text\" *ngIf=\"option?.text\" [innerHTML]=\"option.text\"></div>\r\n                    </div>\r\n                  </div>\r\n                </ng-container>\r\n                <ng-template #content>\r\n                  <div class=\"col-12\">\r\n                    <div class=\"content content-embed\">\r\n                      <div class=\"subtitle-content-modal\">\r\n                        <h3 *ngIf=\"detailProgram?.title\">\r\n                          {{ detailProgram?.title }}\r\n                        </h3>\r\n                      </div>\r\n                      <ng-container *ngIf=\"detailProgram?.file; else contentText\">\r\n                        <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                        <div class=\"iframe\" *ngIf=\"detailProgram?.file\">\r\n                          <dmmp-pdf-viewer [pdfSrc]=\"detailProgram?.file\" [defaultClass]=\"'modal-embed'\"></dmmp-pdf-viewer>\r\n                        </div>\r\n                      </ng-container>\r\n                      <ng-template #contentText>\r\n                        <div class=\"content-row\">\r\n                          <div class=\"row\">\r\n                            <div class=\"col-12 col-md-3\"\r\n                              *ngIf=\"detailProgram?.image?.length > 0\">\r\n                              <div class=\"image\">\r\n                                <img class=\"btn-icons\"\r\n                                  [src]=\"detailProgram?.image[0].styles.large ?  detailProgram?.image[0].styles.large : ''\"\r\n                                  [alt]=\" detailProgram?.image[0].texts.alt ? detailProgram?.image[0].texts.alt : ''\"\r\n                                  [title]=\"detailProgram?.image[0].texts.title ? detailProgram?.image[0].texts.title : ''\" />\r\n                              </div>\r\n                            </div>\r\n                            <div\r\n                              class=\"col-12 {{detailProgram?.image && detailProgram?.image.length > 0 ? 'col-md-9' : 'col-md-12'}}\">\r\n                              <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                            </div>\r\n                          </div>\r\n                        </div>\r\n                      </ng-template>\r\n                    </div>\r\n                  </div>\r\n                </ng-template>\r\n                <div class=\"col-12 col-sm-12 col-md-12 col-lg-12\"\r\n                *ngIf=\"detailProgram?.button?.length > 0\">\r\n                  <div class=\"content content-button\">\r\n                    <ng-container *ngFor=\"let button of detailProgram?.button\">\r\n                      <a [id]=\"button?.id_element ? button?.id_element : ''\"\r\n                        [ngClass]=\"button?.class ? button?.class : ''\" [href]=\"\r\n                          button?.file\r\n                            ? button?.file\r\n                            : button.link[0].link\r\n                            ? button.link[0].link\r\n                            : ''\r\n                        \" [target]=\"button?.file ? '_blank' : ''\" (click)=\"\r\n                          anchor(\r\n                            $event,\r\n                            button?.file\r\n                              ? button?.file\r\n                              : button.link[0].link\r\n                              ? button.link[0].link\r\n                              : '',\r\n                              data.categories\r\n                          )\r\n                        \">\r\n                        {{ button.link[0].name }}\r\n                        <ng-container *ngIf=\"button?.icon?.length>0\">\r\n                          <img class=\"btn-icons\"\r\n                            [src]=\" button?.icon[0].styles.large ?  button?.icon[0].styles.large : ''\"\r\n                            [alt]=\" button?.icon[0].texts.alt ?  button.icon[0].texts.alt : ''\"\r\n                            [title]=\" button?.icon[0].texts.title ?  button.icon[0].texts.title : ''\" />\r\n                        </ng-container>\r\n\r\n                      </a>\r\n                    </ng-container>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </li>\r\n      </ul>\r\n    </div>\r\n    <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n  </div>\r\n  <div class=\"modal-footer\">\r\n    <button type=\"button\" class=\"btn btn-outline-dark\" (click)=\"activeModal.close('Close click')\">\r\n      Close\r\n    </button>\r\n  </div>\r\n</div>\r\n"
    })
], ModalProgramDescBulletsComponent);

let SearchProgramsDescBulletsComponent = class SearchProgramsDescBulletsComponent {
    constructor(modalService) {
        this.modalService = modalService;
        this.textNoFound = 'No se encontraron resultados';
        this.textAll = 'Todos';
        this.categories = [];
        this.categoryOut = new EventEmitter();
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.status = true;
        this.notEmptyPost = true;
        this.statusInit = 8;
    }
    ngOnInit() {
    }
    click(category) {
        this.categoryOut.emit(category);
    }
    sendData(data, identifier) {
        this.status = false;
        const modalRef = this.modalService.open(ModalProgramDescBulletsComponent, { size: 'lg' });
        modalRef.componentInstance.data = data;
        modalRef.componentInstance.identifier = identifier;
        modalRef.componentInstance.categoriesOut.subscribe(($e) => {
            this.categoriesOut.emit($e);
        });
        modalRef.componentInstance.anchorCustom.subscribe(($e) => {
            this.anchorCustom.emit($e);
        });
    }
    onScroll() {
        if (this.notEmptyPost) {
            this.statusInit += 8;
        }
    }
};
SearchProgramsDescBulletsComponent.ctorParameters = () => [
    { type: NgbModal }
];
__decorate([
    Input()
], SearchProgramsDescBulletsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SearchProgramsDescBulletsComponent.prototype, "data", void 0);
__decorate([
    Input()
], SearchProgramsDescBulletsComponent.prototype, "filterPrograms", void 0);
__decorate([
    Input()
], SearchProgramsDescBulletsComponent.prototype, "textNoFound", void 0);
__decorate([
    Input()
], SearchProgramsDescBulletsComponent.prototype, "textAll", void 0);
__decorate([
    Input()
], SearchProgramsDescBulletsComponent.prototype, "categories", void 0);
__decorate([
    Output()
], SearchProgramsDescBulletsComponent.prototype, "categoryOut", void 0);
__decorate([
    Output()
], SearchProgramsDescBulletsComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], SearchProgramsDescBulletsComponent.prototype, "anchorCustom", void 0);
SearchProgramsDescBulletsComponent = __decorate([
    Component({
        selector: 'dmmp-search-programs-desc-bullets',
        template: "<section\r\n  class=\"programs search-programs-desc-bullets\"\r\n  *ngIf=\"data?.visible\"\r\n  [ngClass]=\"data.class ? data.class : ''\"\r\n  [id]=\"data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n  [style.backgroundColor]=\"\r\n    data?.background_color ? data?.background_color.color : ''\r\n  \"\r\n  [style.backgroundImage]=\"\r\n    (data?.background_image) && (data?.background_image).length > 0\r\n      ? 'url(' + (data?.background_image)[0].styles.large + ')'\r\n      : ''\r\n  \"\r\n  [style.opacity]=\"\r\n    (data?.background_color)['opacity']\r\n      ? (data?.background_color)['opacity']\r\n      : ''\r\n  \"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data.texts ? data.texts.length > 0 : false\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"container-search\" *ngIf=\"data?.search\">\r\n      <div class=\"search\">\r\n        <div class=\"content-input\">\r\n          <input\r\n            [placeholder]=\"data.search.placeholder\"\r\n            class=\"search-input\"\r\n            [ngClass]=\"data.search.class ? data.search.class : ''\"\r\n            [id]=\"data.search.id_element ? data.search.id_element : ''\"\r\n            type=\"text\"\r\n            placeholder=\"\"\r\n            [(ngModel)]=\"searchModel\"\r\n          />\r\n          <div class=\"icon\">\r\n            <img\r\n              [src]=\"\r\n                (data?.search.image)[0].styles.large\r\n                  ? (data?.search.image)[0].styles.large\r\n                  : ''\r\n              \"\r\n              [alt]=\"(data?.search.image)[0].texts.alt\"\r\n              [title]=\"(data?.search.image)[0].texts.title\"\r\n            />\r\n          </div>\r\n        </div>\r\n        <ul class=\"result-search\" *ngIf=\"searchModel\">\r\n          <div class=\"close\">\r\n            <span (click)=\"searchModel= ''\">x</span>\r\n          </div>\r\n          <ng-container\r\n            *ngIf=\"\r\n              (filterPrograms | FilterPrograms: searchModel)?.length >\r\n                0;\r\n              else noResul\r\n            \">\r\n            <li\r\n              *ngFor=\"\r\n                let content of filterPrograms\r\n                  | FilterPrograms: searchModel\r\n              \"\r\n              (click)=\"sendData(content, identifier + '_' + data?.id_element)\"\r\n            >\r\n              <span\r\n                [innerHTML]=\"content.title\"\r\n              ></span>\r\n            </li>\r\n          </ng-container>\r\n          <ng-template #noResul>\r\n            <div>\r\n              {{textNoFound}}\r\n            </div>\r\n          </ng-template>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n    <div class=\"tabs\" *ngIf=\"filterPrograms\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\" *ngIf=\"categories && categories.length > 0\">\r\n          <li [ngbNavItem]=\"0\">\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click('')\">{{textAll}}</a>\r\n          </li>\r\n          <li\r\n            *ngFor=\"\r\n              let tabs of categories;\r\n              let i = index\r\n            \"\r\n            [ngbNavItem]=\"i + 1\"\r\n          >\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click(tabs.term)\">{{\r\n              tabs?.label\r\n              }}</a>\r\n          </li>\r\n        </ul>\r\n        <div\r\n          class=\"tab-content\"\r\n          infiniteScroll\r\n          [infiniteScrollDistance]=\"2\"\r\n          [infiniteScrollThrottle]=\"50\"\r\n          (scrolled)=\"onScroll()\"\r\n        >\r\n          <div class=\"row justify-content-center\">\r\n            <ng-container\r\n              *ngIf=\"\r\n                (filterPrograms | FilterPrograms: searchModel)?.length >\r\n                  0;\r\n                else noFound\r\n              \"\r\n            >\r\n              <ng-container\r\n                *ngFor=\"\r\n                  let content of filterPrograms | RandomProgram: data.order\r\n                    | FilterPrograms: searchModel;\r\n                  let init = index\r\n                \"\r\n              >\r\n                <div\r\n                  *ngIf=\"init < statusInit\"\r\n                  class=\"col-12 col-sm-6 col-md-4\"\r\n                >\r\n                  <div class=\"content-flex\">\r\n                    <div class=\"image\" *ngIf=\"content?.image?.length > 0\">\r\n                      <img\r\n                        [src]=\"\r\n                          content?.image[0].styles.large\r\n                            ? content?.image[0].styles.large\r\n                            : ''\r\n                        \"\r\n                        [alt]=\"\r\n                          content?.image[0].texts.alt\r\n                            ? content?.image[0].texts.alt\r\n                            : ''\r\n                        \"\r\n                        [title]=\"\r\n                          content?.image[0].texts.title\r\n                            ? content?.image[0].texts.title\r\n                            : ''\r\n                        \"\r\n                      />\r\n                    </div>\r\n                    <div class=\"box-description\">\r\n                      <h3\r\n                        class=\"h4\"\r\n                        *ngIf=\"content?.title\"\r\n                        [innerHTML]=\"content.title\"\r\n                      ></h3>\r\n                    </div>\r\n                    <div class=\"button-container\" *ngIf=\"content?.button?.length > 0\"\r\n                         [ngClass]=\"content.button[0].class ? content.button[0].class : ''\">\r\n                      <button *ngIf=\"content?.button[0]?.link[0]?.name || content?.button[0]?.icon?.length > 0\"\r\n                              [id]=\"\r\n                          content.button[0].id_element && data?.id_element\r\n                            ? identifier +\r\n                              '_' +\r\n                              data.id_element +\r\n                              '_' +\r\n                              content.button[0].id_element\r\n                            : ''\r\n                        \"\r\n                              (click)=\"\r\n                          sendData(content, identifier + '_' + data?.id_element)\r\n                        \"\r\n                      >\r\n                        <ng-container *ngIf=\"content?.button[0]?.link[0]?.name\">{{\r\n                          content.button[0].link[0].name\r\n                          }}</ng-container>\r\n                        <ng-container *ngIf=\" content?.button[0]?.icon?.length > 0\">\r\n                          <img class=\"btn-icons\"\r\n                               [src]=\"\r\n                              content?.button[0].icon[0].styles.large\r\n                                ? content?.button[0].icon[0].styles.large\r\n                                : ''\r\n                            \"\r\n                          />\r\n                        </ng-container>\r\n                      </button>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </ng-container>\r\n            </ng-container>\r\n            <ng-template #noFound>\r\n              <div class=\"no-found-content\">\r\n                {{textNoFound}}\r\n              </div>\r\n            </ng-template>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], SearchProgramsDescBulletsComponent);

let ProgramDescBulletsModule = class ProgramDescBulletsModule {
};
ProgramDescBulletsModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            IconsTextModule,
            DescriptionModule,
            NgbNavModule,
            PipesModule,
            FormsModule,
            InfiniteScrollModule,
            SharedModule
        ],
        declarations: [
            DetailProgramDescBulletsComponent,
            ModalProgramDescBulletsComponent,
            SearchProgramsDescBulletsComponent
        ],
        exports: [
            DetailProgramDescBulletsComponent,
            ModalProgramDescBulletsComponent,
            SearchProgramsDescBulletsComponent
        ],
        providers: []
    })
], ProgramDescBulletsModule);

let DetailProgramDescGraficaComponent = class DetailProgramDescGraficaComponent {
    constructor() {
        this.active = 0;
    }
    ngOnInit() { }
};
__decorate([
    Input()
], DetailProgramDescGraficaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], DetailProgramDescGraficaComponent.prototype, "data", void 0);
DetailProgramDescGraficaComponent = __decorate([
    Component({
        selector: 'dmmp-detail-program-desc-grafica',
        template: "<section class=\"detail-program detail-program-desc-grafica\" *ngIf=\"data?.visible\"\r\n         [ngClass]=\"data.class ? data.class : ''\"\r\n         [id]=\"data?.id_element ?  identifier + '_' + data?.id_element : ''\"\r\n         [style.backgroundColor]=\"data?.background_color ? data?.background_color.color : ''\"\r\n         [style.backgroundImage]=\"(data?.background_image).length > 0 ? 'url(' + (data?.background_image)[0].styles.large + ')' : ''\"\r\n         [style.opacity]=\"data?.background_color['opacity'] ? data?.background_color['opacity']:''\"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"tabs\" *ngIf=\"data?.content?.length > 0\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n          <li *ngFor=\"let arr of data.content[0].details | slice:0:4; let u = index\" [ngbNavItem]=\"u\">\r\n            <a ngbNavLink>{{ arr?.tab_name }}</a>\r\n            <ng-template ngbNavContent>\r\n              <div class=\"row\"\r\n                   [ngClass]=\"arr.class ? arr.class : ''\"\r\n                   [id]=\"arr.id_element ? arr.id_element : ''\">\r\n                <div class=\"col-12 col-sm-6 col-md-6 col-lg-6\">\r\n                  <div class=\"box-image\" *ngIf=\"arr?.image?.length > 0\">\r\n                    <img\r\n                      [src]=\"arr?.image[0].styles.large ? arr?.image[0].styles.large : ''\"\r\n                      [alt]=\"arr?.image[0].texts.alt ? arr?.image[0].texts.alt : ''\"\r\n                      [title]=\"arr?.image[0].texts.title ? arr?.image[0].texts.title : ''\"\r\n                    />\r\n                  </div>\r\n                </div>\r\n                <div class=\"col-12 col-sm-6 col-md-6 col-lg-6\">\r\n                  <div class=\"content\">\r\n                    <h3>{{ arr.title }}</h3>\r\n                    <ng-container *ngIf=\"arr?.options\">\r\n                      <dmmp-icons-text [data]=\"arr.options\"></dmmp-icons-text>\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"arr?.text\">\r\n                      <dmmp-description\r\n                        [data]=\"arr.text\"\r\n                      ></dmmp-description>\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"arr?.button?.length > 0\">\r\n                      <div class=\"row\">\r\n                        <ng-container *ngFor=\"let button of arr?.button\">\r\n                          <dmmp-button [data]=\"button\"></dmmp-button>\r\n                        </ng-container>\r\n                      </div>\r\n                    </ng-container>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </ng-template>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n      <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], DetailProgramDescGraficaComponent);

let ModalProgramDescGraficaComponent = class ModalProgramDescGraficaComponent {
    constructor(activeModal, sanitizer) {
        this.activeModal = activeModal;
        this.sanitizer = sanitizer;
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
    }
    transform(url) {
        return this.sanitizer.bypassSecurityTrustResourceUrl(url);
    }
    anchor(event, data, categories) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.categoriesOut.emit(categories);
            event.preventDefault();
            this.activeModal.close('Close click');
            setTimeout(() => {
                this.anchorCustom.emit({ event: event, id: data });
            }, 100);
        }
    }
};
ModalProgramDescGraficaComponent.ctorParameters = () => [
    { type: NgbActiveModal },
    { type: DomSanitizer }
];
__decorate([
    Input()
], ModalProgramDescGraficaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ModalProgramDescGraficaComponent.prototype, "data", void 0);
__decorate([
    Output()
], ModalProgramDescGraficaComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], ModalProgramDescGraficaComponent.prototype, "anchorCustom", void 0);
ModalProgramDescGraficaComponent = __decorate([
    Component({
        selector: 'dmmp-modal-program-desc-grafica',
        template: "<div class=\"modal-detail-program modal-program-desc-grafica\" [id]=\"identifier ? identifier + '_' + 'modal' : ''\">\r\n  <div class=\"modal-header-content\">\r\n    <div class=\"info-header-content\">\r\n      <h2 class=\"modal-title h2\" *ngIf=\"data?.title\" [innerHTML]=\"data.title\"></h2>\r\n      <ul class=\"categories-program\" *ngIf=\"data?.categories?.length > 0\">\r\n        <li *ngFor=\"let cate of data.categories | slice:0:3\">\r\n          {{ cate }}\r\n        </li>\r\n      </ul>\r\n      <div *ngIf=\"data?.duration\" class=\"duration-modal\"\r\n           [ngClass]=\"data.duration_class ? data.duration_class : ''\">\r\n        <p>Duraci\u00F3n: {{data.duration}}</p>\r\n      </div>\r\n    </div>\r\n    <button\r\n      type=\"button\"\r\n      class=\"close\"\r\n      aria-label=\"Close\"\r\n      (click)=\"activeModal.close('Close click')\"\r\n    >\r\n      <span aria-hidden=\"true\">\r\n        <i class=\"fas fa-times\"></i>\r\n      </span>\r\n    </button>\r\n  </div>\r\n  <div class=\"modal-body\" *ngIf=\"data?.additional_information\">\r\n    <div class=\"tabs-content\">\r\n      <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n        <li\r\n          *ngFor=\"\r\n            let detailProgram of data?.additional_information;\r\n            let i = index\r\n          \"\r\n          [ngbNavItem]=\"i\"\r\n        >\r\n          <a ngbNavLink>{{ detailProgram?.tab_name }}</a>\r\n          <ng-template ngbNavContent>\r\n            <div class=\"content-tab\"\r\n                 [ngClass]=\"detailProgram.class ? detailProgram.class : ''\"\r\n                 [id]=\"detailProgram?.id_element ? identifier + '_' + detailProgram?.id_element : ''\">\r\n              <div class=\"row\">\r\n                <ng-container *ngIf=\"detailProgram?.options; else content\">\r\n                  <div class=\"col-12\">\r\n                    <div class=\"subtitle-content-modal\">\r\n                      <h3 *ngIf=\"detailProgram?.title\">\r\n                        {{ detailProgram?.title }}\r\n                      </h3>\r\n                    </div>\r\n                  </div>\r\n                  <div\r\n                    class=\"col-12 col-sm-6 col-md-4 col-lg-4\"\r\n                    *ngFor=\"let option of detailProgram?.options\"\r\n                  >\r\n                    <div\r\n                      class=\"content\"\r\n                      [ngClass]=\"option?.class ? option?.class : ''\"\r\n                      [id]=\"option?.id_element ? option?.id_element : ''\"\r\n                    >\r\n                      <div class=\"image\" *ngIf=\"option?.icon\">\r\n                        <img\r\n                          [src]=\"\r\n                            option?.icon[0].styles.large\r\n                              ? option?.icon[0].styles.large\r\n                              : ''\r\n                          \"\r\n                          [alt]=\"\r\n                            option?.icon[0].texts.alt ? option?.icon[0].texts.alt : ''\r\n                          \"\r\n                          [title]=\"\r\n                            option?.icon[0].texts.title\r\n                              ? option?.icon[0].texts.title\r\n                              : ''\r\n                          \"\r\n                        />\r\n                      </div>\r\n                      <div\r\n                        class=\"text\"\r\n                        *ngIf=\"option?.text\"\r\n                        [innerHTML]=\"option.text\"\r\n                      ></div>\r\n                    </div>\r\n                  </div>\r\n                </ng-container>\r\n                <ng-template #content>\r\n                  <div class=\"col-12\">\r\n                    <div class=\"content content-embed\">\r\n                      <div class=\"subtitle-content-modal\">\r\n                        <h3 *ngIf=\"detailProgram?.title\">\r\n                          {{ detailProgram?.title }}\r\n                        </h3>\r\n                      </div>\r\n                      <ng-container *ngIf=\"detailProgram?.file; else contentText\">\r\n                        <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                        <div class=\"iframe\" *ngIf=\"detailProgram?.file\">\r\n                          <dmmp-pdf-viewer [pdfSrc]=\"detailProgram?.file\"\r\n                                           [defaultClass]=\"'modal-embed'\"></dmmp-pdf-viewer>\r\n                        </div>\r\n                      </ng-container>\r\n                      <ng-template #contentText>\r\n                        <div class=\"content-row\">\r\n                          <div class=\"row\">\r\n                            <div class=\"col-12 col-md-3\"\r\n                                 *ngIf=\"detailProgram?.image?.length > 0\">\r\n                              <div class=\"image\">\r\n                                <img\r\n                                  class=\"btn-icons\"\r\n                                  [src]=\"detailProgram?.image[0].styles.large ?  detailProgram?.image[0].styles.large : ''\"\r\n                                  [alt]=\" detailProgram?.image[0].texts.alt ? detailProgram?.image[0].texts.alt : ''\"\r\n                                  [title]=\"detailProgram?.image[0].texts.title ? detailProgram?.image[0].texts.title : ''\"\r\n                                />\r\n                              </div>\r\n                            </div>\r\n                            <div\r\n                              class=\"col-12 {{detailProgram?.image && detailProgram?.image.length > 0 ? 'col-md-9' : 'col-md-12'}}\">\r\n                              <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                            </div>\r\n                          </div>\r\n                        </div>\r\n                      </ng-template>\r\n                    </div>\r\n                  </div>\r\n                </ng-template>\r\n                <div\r\n                  class=\"col-12 col-sm-12 col-md-12 col-lg-12\"\r\n                  *ngIf=\"detailProgram?.button?.length > 0\">\r\n                  <div class=\"content content-button\">\r\n                    <ng-container *ngFor=\"let button of detailProgram?.button\">\r\n                      <a\r\n                        [id]=\"button?.id_element ? button?.id_element : ''\"\r\n                        [ngClass]=\"button?.class ? button?.class : ''\"\r\n                        [href]=\"\r\n                          button?.file\r\n                            ? button?.file\r\n                            : button.link[0].link\r\n                            ? button.link[0].link\r\n                            : ''\r\n                        \"\r\n                        [target]=\"button?.file ? '_blank' : ''\"\r\n                        (click)=\"\r\n                          anchor(\r\n                            $event,\r\n                            button?.file\r\n                              ? button?.file\r\n                              : button.link[0].link\r\n                              ? button.link[0].link\r\n                              : '',\r\n                              data.categories\r\n                          )\r\n                        \"\r\n                      >\r\n                        {{ button.link[0].name }}\r\n                        <ng-container *ngIf=\"button?.icon?.length>0\">\r\n                          <img\r\n                            class=\"btn-icons\"\r\n                            [src]=\" button?.icon[0].styles.large ?  button?.icon[0].styles.large : ''\"\r\n                            [alt]=\" button?.icon[0].texts.alt ?  button.icon[0].texts.alt : ''\"\r\n                            [title]=\" button?.icon[0].texts.title ?  button.icon[0].texts.title : ''\"\r\n                          />\r\n                        </ng-container>\r\n\r\n                      </a>\r\n                    </ng-container>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </li>\r\n      </ul>\r\n    </div>\r\n    <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n  </div>\r\n  <div class=\"modal-footer\">\r\n    <button\r\n      type=\"button\"\r\n      class=\"btn btn-outline-dark\"\r\n      (click)=\"activeModal.close('Close click')\"\r\n    >\r\n      Close\r\n    </button>\r\n  </div>\r\n</div>\r\n"
    })
], ModalProgramDescGraficaComponent);

let SearchProgramsDescGraficaComponent = class SearchProgramsDescGraficaComponent {
    constructor(modalService) {
        this.modalService = modalService;
        this.categories = [];
        this.textNoFound = 'No se encontraron resultados';
        this.textAll = 'Todos';
        this.categoryOut = new EventEmitter();
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.status = true;
        this.notEmptyPost = true;
        this.statusInit = 8;
    }
    ngOnInit() {
    }
    click(category) {
        this.categoryOut.emit(category);
    }
    sendData(data, identifier) {
        this.status = false;
        const modalRef = this.modalService.open(ModalProgramDescGraficaComponent, { size: 'lg' });
        modalRef.componentInstance.data = data;
        modalRef.componentInstance.identifier = identifier;
        modalRef.componentInstance.categoriesOut.subscribe(($e) => {
            this.categoriesOut.emit($e);
        });
        modalRef.componentInstance.anchorCustom.subscribe(($e) => {
            this.anchorCustom.emit($e);
        });
    }
    onScroll() {
        if (this.notEmptyPost) {
            this.statusInit += 8;
        }
    }
};
SearchProgramsDescGraficaComponent.ctorParameters = () => [
    { type: NgbModal }
];
__decorate([
    Input()
], SearchProgramsDescGraficaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SearchProgramsDescGraficaComponent.prototype, "data", void 0);
__decorate([
    Input()
], SearchProgramsDescGraficaComponent.prototype, "filterPrograms", void 0);
__decorate([
    Input()
], SearchProgramsDescGraficaComponent.prototype, "categories", void 0);
__decorate([
    Input()
], SearchProgramsDescGraficaComponent.prototype, "textNoFound", void 0);
__decorate([
    Input()
], SearchProgramsDescGraficaComponent.prototype, "textAll", void 0);
__decorate([
    Output()
], SearchProgramsDescGraficaComponent.prototype, "categoryOut", void 0);
__decorate([
    Output()
], SearchProgramsDescGraficaComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], SearchProgramsDescGraficaComponent.prototype, "anchorCustom", void 0);
SearchProgramsDescGraficaComponent = __decorate([
    Component({
        selector: 'dmmp-search-programs-desc-grafica',
        template: "<section\r\n  class=\"programs search-programs-desc-grafica\"\r\n  *ngIf=\"data?.visible\"\r\n  [ngClass]=\"data.class ? data.class : ''\"\r\n  [id]=\"data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n  [style.backgroundColor]=\"\r\n    data?.background_color ? data?.background_color.color : ''\r\n  \"\r\n  [style.backgroundImage]=\"\r\n    (data?.background_image) && (data?.background_image).length > 0\r\n      ? 'url(' + (data?.background_image)[0].styles.large + ')'\r\n      : ''\r\n  \"\r\n  [style.opacity]=\"\r\n    (data?.background_color)['opacity']\r\n      ? (data?.background_color)['opacity']\r\n      : ''\r\n  \"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"container-search\" *ngIf=\"data?.search\">\r\n      <div class=\"search\">\r\n        <div class=\"content-input\">\r\n          <input\r\n            [placeholder]=\"data.search.placeholder\"\r\n            class=\"search-input\"\r\n            [ngClass]=\"data.search.class ? data.search.class : ''\"\r\n            [id]=\"data.search.id_element ? data.search.id_element : ''\"\r\n            type=\"text\"\r\n            placeholder=\"\"\r\n            [(ngModel)]=\"searchModel\"\r\n          />\r\n          <div class=\"icon\" *ngIf=\" data?.search?.image?.length > 0\">\r\n            <img\r\n              [src]=\"\r\n                (data?.search.image)[0].styles.large\r\n                  ? (data?.search.image)[0].styles.large\r\n                  : ''\r\n              \"\r\n              [alt]=\"(data?.search.image)[0].texts.alt\"\r\n              [title]=\"(data?.search.image)[0].texts.title\"\r\n            />\r\n          </div>\r\n        </div>\r\n        <ul class=\"result-search\" *ngIf=\"searchModel\">\r\n          <div class=\"close\">\r\n            <span (click)=\"searchModel= ''\">x</span>\r\n          </div>\r\n          <ng-container\r\n            *ngIf=\"\r\n              (filterPrograms | FilterPrograms: searchModel)?.length >\r\n                0;\r\n              else noResul\r\n            \">\r\n            <li\r\n              *ngFor=\"\r\n                let content of filterPrograms\r\n                  | FilterPrograms: searchModel\r\n              \"\r\n              (click)=\"sendData(content, identifier + '_' + data?.id_element)\"\r\n            >\r\n              <span [id]=\"'search_'+ content.title | replace\"\r\n                    [innerHTML]=\"content.title\"\r\n              ></span>\r\n            </li>\r\n          </ng-container>\r\n          <ng-template #noResul>\r\n            <div>\r\n             {{textNoFound}}\r\n            </div>\r\n          </ng-template>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n    <div class=\"tabs\" *ngIf=\"filterPrograms\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\">\r\n          <li [ngbNavItem]=\"0\">\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click('')\">{{textAll}}</a>\r\n          </li>\r\n          <li\r\n            *ngFor=\"\r\n              let tabs of categories;\r\n              let i = index\r\n            \"\r\n            [ngbNavItem]=\"i + 1\"\r\n          >\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click(tabs.term)\">{{\r\n              tabs?.label\r\n              }}</a>\r\n          </li>\r\n        </ul>\r\n        <div\r\n          class=\"tab-content\"\r\n          infiniteScroll\r\n          [infiniteScrollDistance]=\"2\"\r\n          [infiniteScrollThrottle]=\"50\"\r\n          (scrolled)=\"onScroll()\"\r\n        >\r\n          <div class=\"row\">\r\n            <ng-container\r\n              *ngIf=\"\r\n                (filterPrograms | FilterPrograms: searchModel)?.length >\r\n                  0;\r\n                else noFound\r\n              \"\r\n            >\r\n              <ng-container\r\n                *ngFor=\"\r\n                  let content of filterPrograms | RandomProgram : data.order\r\n                    | FilterPrograms: searchModel;\r\n                  let init = index\r\n                \"\r\n              >\r\n                <div\r\n                  *ngIf=\"init < statusInit\"\r\n                  class=\"col-12 col-sm-6 col-md-4 col-lg-3\"\r\n                  style=\"margin-bottom: 40px;\"\r\n                >\r\n                  <div class=\"content-flex\" [id]=\"content.title ? (content.title | replace) : ''\"\r\n                       (click)=\"sendData(content, identifier + '_' + data?.id_element)\">\r\n                    <div class=\"image\">\r\n                      <div class=\"label-image\" *ngIf=\"content?.label_image\">\r\n                        {{content.label_image}}\r\n                      </div>\r\n                      <img\r\n                        *ngIf=\"content?.image?.length > 0\"\r\n                        [src]=\"\r\n                          content?.image[0].styles.large\r\n                            ? content?.image[0].styles.large\r\n                            : ''\r\n                        \"\r\n                        [alt]=\"\r\n                          content?.image[0].texts.alt\r\n                            ? content?.image[0].texts.alt\r\n                            : ''\r\n                        \"\r\n                        [title]=\"\r\n                          content?.image[0].texts.title\r\n                            ? content?.image[0].texts.title\r\n                            : ''\r\n                        \"\r\n                      />\r\n                    </div>\r\n                    <div class=\"box-description\">\r\n                      <h3\r\n                        class=\"h4\"\r\n                        *ngIf=\"content.title\"\r\n                        [innerHTML]=\"content.title\"\r\n                      ></h3>\r\n                      <div class=\"duration\" *ngIf=\"content?.duration\"\r\n                           [ngClass]=\"content.duration_class ? content.duration_class : ''\">\r\n                        <p>{{content.duration}}</p>\r\n                      </div>\r\n                      <div class=\"snies-content\" *ngIf=\" content?.snies?.length > 0\"\r\n                           [ngClass]=\"content.snies[0].class ? content.snies[0].class : ''\"\r\n                           [innerHTML]=\"content.snies[0].text\"></div>\r\n                      <ul *ngIf=\"content.categories.length > 0\">\r\n                        <li *ngFor=\"let cate of content.categories | slice:0:3\">\r\n                          {{ cate }}\r\n                        </li>\r\n                      </ul>\r\n                    </div>\r\n                    <div class=\"button-container\" *ngIf=\"content?.button?.length > 0\"\r\n                         [ngClass]=\"content.button[0].class ? content.button[0].class : ''\">\r\n                      <button *ngIf=\"content.button[0].link[0].name || content?.button[0].icon.length > 0\"\r\n                              [id]=\"\r\n                          content.button[0].id_element && data?.id_element\r\n                            ? identifier +\r\n                              '_' +\r\n                              data.id_element +\r\n                              '_' +\r\n                              content.button[0].id_element\r\n                            : ''\r\n                        \">\r\n                        <ng-container *ngIf=\"content?.button[0]?.link[0]?.name\">{{\r\n                          content.button[0].link[0].name\r\n                          }}</ng-container>\r\n                        <ng-container *ngIf=\"content?.button[0]?.icon?.length > 0\">\r\n                          <img class=\"btn-icons\"\r\n                               [src]=\"\r\n                              content?.button[0].icon[0].styles.large\r\n                                ? content?.button[0].icon[0].styles.large\r\n                                : ''\r\n                            \"\r\n                          />\r\n                        </ng-container>\r\n                      </button>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </ng-container>\r\n            </ng-container>\r\n            <ng-template #noFound>\r\n              <div class=\"no-found-content\">\r\n               {{textNoFound}}\r\n              </div>\r\n            </ng-template>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], SearchProgramsDescGraficaComponent);

let ProgramDescGraficaModule = class ProgramDescGraficaModule {
};
ProgramDescGraficaModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            IconsTextModule,
            DescriptionModule,
            NgbNavModule,
            PipesModule,
            FormsModule,
            InfiniteScrollModule,
            SharedModule
        ],
        declarations: [
            DetailProgramDescGraficaComponent,
            ModalProgramDescGraficaComponent,
            SearchProgramsDescGraficaComponent
        ],
        exports: [
            DetailProgramDescGraficaComponent,
            ModalProgramDescGraficaComponent,
            SearchProgramsDescGraficaComponent
        ],
        providers: []
    })
], ProgramDescGraficaModule);

let DetailProgramDescMixtaComponent = class DetailProgramDescMixtaComponent {
    constructor() {
        this.active = 0;
        this.duration = 'Duración estimada:';
        this.price = 'Valor del semestre:';
    }
};
__decorate([
    Input()
], DetailProgramDescMixtaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], DetailProgramDescMixtaComponent.prototype, "data", void 0);
DetailProgramDescMixtaComponent = __decorate([
    Component({
        selector: 'dmmp-detail-program-desc-mixta',
        template: "<section class=\"detail-program detail-program-desc-mixta\" *ngIf=\"data?.visible\"\r\n         [ngClass]=\"data.class ? data.class : ''\"\r\n         [id]=\"data?.id_element ?  identifier + '_' + data?.id_element : ''\"\r\n         [style.backgroundColor]=\"data?.background_color ? data?.background_color.color : ''\"\r\n         [style.backgroundImage]=\"(data?.background_image).length > 0 ? 'url(' + (data?.background_image)[0].styles.large + ')' : ''\"\r\n         [style.opacity]=\"data?.background_color['opacity'] ? data?.background_color['opacity']:''\"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"tabs\" *ngIf=\"data?.content?.length > 0\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n          <li *ngFor=\"let arr of data.content[0].details | slice:0:4; let u = index\" [ngbNavItem]=\"u\">\r\n            <a ngbNavLink>{{ arr?.tab_name }}</a>\r\n            <ng-template ngbNavContent>\r\n              <div class=\"container\">\r\n                <div class=\"row\"\r\n                     [ngClass]=\"arr.class ? arr.class : ''\"\r\n                     [id]=\"arr.id_element ? arr.id_element : ''\">\r\n                  <div class=\"col-12 col-sm-6 col-md-6 col-lg-6\">\r\n                    <div class=\"content\">\r\n                      <h3>{{ arr.title }}</h3>\r\n                      <ng-container *ngIf=\"arr?.options\">\r\n                        <dmmp-icons-text [data]=\"arr.options\"></dmmp-icons-text>\r\n                      </ng-container>\r\n                      <ng-container *ngIf=\"arr?.text\">\r\n                        <dmmp-description\r\n                          [data]=\"arr.text\"\r\n                        ></dmmp-description>\r\n                      </ng-container>\r\n                      <ng-container *ngIf=\"arr?.button?.length > 0\">\r\n                        <div class=\"row\">\r\n                          <ng-container *ngFor=\"let button of arr?.button\">\r\n                            <div class=\"col\">\r\n                              <dmmp-button [data]=\"button\"></dmmp-button>\r\n                            </div>\r\n                          </ng-container>\r\n                        </div>\r\n                      </ng-container>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"col-12 col-sm-6 col-md-6 col-lg-6\">\r\n                    <div class=\"information\">\r\n                      <div class=\"row content-info\">\r\n                        <div class=\"col-12 col-md-6\"\r\n                             *ngIf=\"data?.content[0]?.credits?.length > 0\">\r\n                          <div class=\"content item-1\"\r\n                               [ngClass]=\"data.content[0].credits[0].class ? data.content[0].credits[0].class : ''\">\r\n                            <span>Cr\u00E9ditos:</span>\r\n                            <p [innerHTML]=\"data.content[0].credits[0].text\"></p>\r\n                          </div>\r\n                        </div>\r\n                        <div class=\"col-12 col-md-6\" *ngIf=\"data?.content[0]?.duration\">\r\n                          <div class=\"content item-2\"\r\n                               [ngClass]=\"data.content[0].duration_class ? data.content[0].duration_class : ''\">\r\n                            <span>{{duration}}</span>\r\n                            <p>{{data.content[0].duration}}</p>\r\n                          </div>\r\n                        </div>\r\n                        <div class=\"col-12 col-md-6\" *ngIf=\" data?.content[0]?.price?.length > 0\">\r\n                          <div class=\"content item-3\"\r\n                               [ngClass]=\"data.content[0].price[0].class ? data.content[0].price[0].class : ''\">\r\n                            <span>{{price}}</span>\r\n                            <p [innerHTML]=\"data.content[0].price[0].text\"></p>\r\n                          </div>\r\n                        </div>\r\n                        <div class=\"col-12 col-md-6\" *ngIf=\"data?.content[0]?.snies?.length > 0\"\r\n                             [ngClass]=\"data.content[0].snies[0].class ? data.content[0].snies[0].class : ''\">\r\n                          <div class=\"content item-4\">\r\n                            <span>SNIES:</span>\r\n                            <p [innerHTML]=\"data.content[0].snies[0].text\"></p>\r\n                          </div>\r\n                        </div>\r\n                      </div>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </ng-template>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n      <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], DetailProgramDescMixtaComponent);

let ModalProgramDescMixtaComponent = class ModalProgramDescMixtaComponent {
    constructor(activeModal, sanitizer) {
        this.activeModal = activeModal;
        this.sanitizer = sanitizer;
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
    }
    transform(url) {
        return this.sanitizer.bypassSecurityTrustResourceUrl(url);
    }
    anchor(event, data, categories) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.categoriesOut.emit(categories);
            event.preventDefault();
            this.activeModal.close('Close click');
            setTimeout(() => {
                this.anchorCustom.emit({ event: event, id: data });
            }, 100);
        }
    }
};
ModalProgramDescMixtaComponent.ctorParameters = () => [
    { type: NgbActiveModal },
    { type: DomSanitizer }
];
__decorate([
    Input()
], ModalProgramDescMixtaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ModalProgramDescMixtaComponent.prototype, "data", void 0);
__decorate([
    Input()
], ModalProgramDescMixtaComponent.prototype, "snies", void 0);
__decorate([
    Input()
], ModalProgramDescMixtaComponent.prototype, "credit", void 0);
__decorate([
    Input()
], ModalProgramDescMixtaComponent.prototype, "duration", void 0);
__decorate([
    Output()
], ModalProgramDescMixtaComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], ModalProgramDescMixtaComponent.prototype, "anchorCustom", void 0);
ModalProgramDescMixtaComponent = __decorate([
    Component({
        selector: 'dmmp-modal-program-desc-mixta',
        template: "<div class=\"modal-detail-program modal-program-desc-mixta\" [id]=\"identifier ? identifier + '_' + 'modal' : ''\">\r\n  <div class=\"modal-header-content\"\r\n       [style.backgroundImage]=\"\r\n    (data?.banner_image).length > 0\r\n      ? 'url(' + (data?.banner_image)[0].styles.large + ')'\r\n      : ''\r\n  \"\r\n  >\r\n    <div class=\"info-header-content\">\r\n      <h2 class=\"modal-title h2\" *ngIf=\"data?.title\" [innerHTML]=\"data.title\"></h2>\r\n      <div class=\"snies-content color-blue\"\r\n           *ngIf=\"data.snies && data.snies.length > 0\"\r\n           [ngClass]=\"data.snies[0].class ? data.snies[0].class : ''\">\r\n        <strong>{{snies}} </strong>\r\n        <div [outerHTML]=\"data.snies[0].text\"></div>\r\n      </div>\r\n      <div class=\"credits-content\" *ngIf=\"data?.credits?.length > 0\"\r\n           [ngClass]=\"data.credits[0].class ? data.credits[0].class : ''\">\r\n        <p>{{credit}}</p>\r\n        <div [innerHTML]=\"data.credits[0].text\"></div>\r\n      </div>\r\n      <div *ngIf=\"data?.duration\" class=\"duration-modal\"\r\n           [ngClass]=\"data.duration_class ? data.duration_class : ''\">\r\n        <p>{{duration}}</p>\r\n        <div>{{data.duration}}</div>\r\n      </div>\r\n    </div>\r\n    <button\r\n      type=\"button\"\r\n      class=\"close\"\r\n      aria-label=\"Close\"\r\n      (click)=\"activeModal.close('Close click')\"\r\n    >\r\n      <span aria-hidden=\"true\">\r\n        <i class=\"fas fa-times\"></i>\r\n      </span>\r\n    </button>\r\n  </div>\r\n  <div class=\"modal-body\" *ngIf=\"data?.additional_information\">\r\n    <div class=\"tabs-content\">\r\n      <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n        <li\r\n          *ngFor=\"\r\n            let detailProgram of data?.additional_information;\r\n            let i = index\r\n          \"\r\n          [ngbNavItem]=\"i\"\r\n        >\r\n          <a ngbNavLink>{{ detailProgram?.tab_name }}</a>\r\n          <ng-template ngbNavContent>\r\n            <div class=\"content-tab\"\r\n                 [ngClass]=\"detailProgram.class ? detailProgram.class : ''\"\r\n                 [id]=\"detailProgram?.id_element ? identifier + '_' + detailProgram?.id_element : ''\"\r\n            >\r\n              <div class=\"row\">\r\n                <ng-container *ngIf=\"detailProgram?.options; else content\">\r\n                  <div class=\"col-12\">\r\n                    <div class=\"subtitle-content-modal\">\r\n                      <h3 *ngIf=\"detailProgram?.title\">\r\n                        {{ detailProgram?.title }}\r\n                      </h3>\r\n                    </div>\r\n                  </div>\r\n                  <div\r\n                    class=\"col-12 col-sm-6 col-md-4 col-lg-4\"\r\n                    *ngFor=\"let option of detailProgram?.options\"\r\n                  >\r\n                    <div\r\n                      class=\"content\"\r\n                      [ngClass]=\"option?.class ? option?.class : ''\"\r\n                      [id]=\"option?.id_element ? option?.id_element : ''\"\r\n                    >\r\n                      <div class=\"image\" *ngIf=\"option?.icon\">\r\n                        <img\r\n                          [src]=\"\r\n                            option?.icon[0].styles.large\r\n                              ? option?.icon[0].styles.large\r\n                              : ''\r\n                          \"\r\n                          [alt]=\"\r\n                            option?.icon[0].texts.alt ? option?.icon[0].texts.alt : ''\r\n                          \"\r\n                          [title]=\"\r\n                            option?.icon[0].texts.title\r\n                              ? option?.icon[0].texts.title\r\n                              : ''\r\n                          \"\r\n                        />\r\n                      </div>\r\n                      <div\r\n                        class=\"text\"\r\n                        *ngIf=\"option?.text\"\r\n                        [innerHTML]=\"option.text\"\r\n                      ></div>\r\n                    </div>\r\n                  </div>\r\n                </ng-container>\r\n                <ng-template #content>\r\n                  <div class=\"col-12\">\r\n                    <div class=\"content content-embed\">\r\n                      <div class=\"subtitle-content-modal\">\r\n                        <h3 class=\"\" *ngIf=\"detailProgram?.title\">\r\n                          {{ detailProgram?.title }}\r\n                        </h3>\r\n                      </div>\r\n                      <ng-container *ngIf=\"detailProgram?.file; else contentText\">\r\n                        <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                        <div class=\"iframe\" *ngIf=\"detailProgram?.file\">\r\n                          <dmmp-pdf-viewer [pdfSrc]=\"detailProgram?.file\"\r\n                                           [defaultClass]=\"'modal-embed'\"></dmmp-pdf-viewer>\r\n                        </div>\r\n                      </ng-container>\r\n                      <ng-template #contentText>\r\n                        <div class=\"content-row\">\r\n                          <div class=\"row\">\r\n                            <div class=\"col-12 col-md-3\"\r\n                                 *ngIf=\"detailProgram?.image?.length > 0\">\r\n                              <div class=\"image\">\r\n                                <img\r\n                                  class=\"btn-icons\"\r\n                                  [src]=\"detailProgram?.image[0].styles.large ?  detailProgram?.image[0].styles.large : ''\"\r\n                                  [alt]=\" detailProgram?.image[0].texts.alt ? detailProgram?.image[0].texts.alt : ''\"\r\n                                  [title]=\"detailProgram?.image[0].texts.title ? detailProgram?.image[0].texts.title : ''\"\r\n                                />\r\n                              </div>\r\n                            </div>\r\n                            <div\r\n                              class=\"col-12 {{detailProgram?.image && detailProgram?.image.length > 0 ? 'col-md-9' : 'col-md-12'}}\">\r\n                              <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                            </div>\r\n                          </div>\r\n                        </div>\r\n                      </ng-template>\r\n                    </div>\r\n                  </div>\r\n                </ng-template>\r\n                <div\r\n                  class=\"col-12 col-sm-12 col-md-12 col-lg-12\"\r\n                  *ngIf=\"detailProgram?.button?.length > 0\">\r\n                  <div class=\"content content-button\">\r\n                    <ng-container *ngFor=\"let button of detailProgram?.button\">\r\n                      <a\r\n                        [id]=\"button?.id_element ? button?.id_element : ''\"\r\n                        [ngClass]=\"button?.class ? button?.class : ''\"\r\n                        [href]=\"\r\n                          button?.file\r\n                            ? button?.file\r\n                            : button.link[0].link\r\n                            ? button.link[0].link\r\n                            : ''\r\n                        \"\r\n                        [target]=\"button?.file ? '_blank' : ''\"\r\n                        (click)=\"\r\n                          anchor(\r\n                            $event,\r\n                            button?.file\r\n                              ? button?.file\r\n                              : button.link[0].link\r\n                              ? button.link[0].link\r\n                              : '',\r\n                              data.categories\r\n                          )\r\n                        \"\r\n                      >\r\n                        {{ button.link[0].name }}\r\n                        <ng-container *ngIf=\"button?.icon?.length>0\">\r\n                          <img\r\n                            class=\"btn-icons\"\r\n                            [src]=\" button?.icon[0].styles.large ?  button?.icon[0].styles.large : ''\"\r\n                            [alt]=\" button?.icon[0].texts.alt ?  button.icon[0].texts.alt : ''\"\r\n                            [title]=\" button?.icon[0].texts.title ?  button.icon[0].texts.title : ''\"\r\n                          />\r\n                        </ng-container>\r\n\r\n                      </a>\r\n                    </ng-container>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </li>\r\n      </ul>\r\n    </div>\r\n    <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n  </div>\r\n  <div class=\"modal-footer\">\r\n    <button\r\n      type=\"button\"\r\n      class=\"btn btn-outline-dark\"\r\n      (click)=\"activeModal.close('Close click')\"\r\n    >\r\n      Close\r\n    </button>\r\n  </div>\r\n</div>\r\n"
    })
], ModalProgramDescMixtaComponent);

let SearchProgramsDescMixtaComponent = class SearchProgramsDescMixtaComponent {
    constructor(modalService) {
        this.modalService = modalService;
        this.categories = [];
        this.textNoFound = 'No se encontraron resultados';
        this.textAll = 'Todos';
        this.snies = 'SNIES:';
        this.credit = 'CRÉDITOS';
        this.duration = 'DURACIÓN ESTIMADA';
        this.categoryOut = new EventEmitter();
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.status = true;
        this.notEmptyPost = true;
        this.statusInit = 8;
    }
    ngOnInit() {
    }
    click(category) {
        this.categoryOut.emit(category);
    }
    sendData(data, identifier) {
        this.status = false;
        const modalRef = this.modalService.open(ModalProgramDescMixtaComponent, { size: 'lg' });
        modalRef.componentInstance.data = data;
        modalRef.componentInstance.identifier = identifier;
        modalRef.componentInstance.snies = this.snies;
        modalRef.componentInstance.credit = this.credit;
        modalRef.componentInstance.duration = this.duration;
        modalRef.componentInstance.categoriesOut.subscribe(($e) => {
            this.categoriesOut.emit($e);
        });
        modalRef.componentInstance.anchorCustom.subscribe(($e) => {
            this.anchorCustom.emit($e);
        });
    }
    onScroll() {
        if (this.notEmptyPost) {
            this.statusInit += 8;
        }
    }
};
SearchProgramsDescMixtaComponent.ctorParameters = () => [
    { type: NgbModal }
];
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "data", void 0);
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "filterPrograms", void 0);
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "categories", void 0);
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "textNoFound", void 0);
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "textAll", void 0);
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "snies", void 0);
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "credit", void 0);
__decorate([
    Input()
], SearchProgramsDescMixtaComponent.prototype, "duration", void 0);
__decorate([
    Output()
], SearchProgramsDescMixtaComponent.prototype, "categoryOut", void 0);
__decorate([
    Output()
], SearchProgramsDescMixtaComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], SearchProgramsDescMixtaComponent.prototype, "anchorCustom", void 0);
SearchProgramsDescMixtaComponent = __decorate([
    Component({
        selector: 'dmmp-search-programs-desc-mixta',
        template: "<section\r\n  class=\"programs search-programs-desc-mixta\"\r\n  *ngIf=\"data?.visible\"\r\n  [ngClass]=\"data.class ? data.class : ''\"\r\n  [id]=\"data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n  [style.backgroundColor]=\"\r\n    data?.background_color ? data?.background_color.color : ''\r\n  \"\r\n  [style.backgroundImage]=\"\r\n    (data?.background_image) && (data?.background_image).length > 0\r\n      ? 'url(' + (data?.background_image)[0].styles.large + ')'\r\n      : ''\r\n  \"\r\n  [style.opacity]=\"\r\n    (data?.background_color)['opacity']\r\n      ? (data?.background_color)['opacity']\r\n      : ''\r\n  \"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"container-search\" *ngIf=\"data?.search\">\r\n      <div class=\"search\">\r\n        <div class=\"content-input\">\r\n          <input\r\n            [placeholder]=\"data.search.placeholder\"\r\n            class=\"search-input\"\r\n            [ngClass]=\"data.search.class ? data.search.class : ''\"\r\n            [id]=\"data.search.id_element ? data.search.id_element : ''\"\r\n            type=\"text\"\r\n            placeholder=\"\"\r\n            [(ngModel)]=\"searchModel\"\r\n          />\r\n          <div class=\"icon\" *ngIf=\"data?.search?.image?.length > 0\">\r\n            <img\r\n              [src]=\"\r\n                (data?.search.image)[0].styles.large\r\n                  ? (data?.search.image)[0].styles.large\r\n                  : ''\r\n              \"\r\n              [alt]=\"(data?.search.image)[0].texts.alt\"\r\n              [title]=\"(data?.search.image)[0].texts.title\"\r\n            />\r\n          </div>\r\n        </div>\r\n        <ul class=\"result-search\" *ngIf=\"searchModel\">\r\n          <div class=\"close\">\r\n            <span (click)=\"searchModel= ''\">x</span>\r\n          </div>\r\n          <ng-container\r\n            *ngIf=\"\r\n              (filterPrograms | FilterPrograms: searchModel).length >\r\n                0;\r\n              else noResul\r\n            \">\r\n            <li\r\n              *ngFor=\"\r\n                let content of filterPrograms\r\n                  | FilterPrograms: searchModel\r\n              \"\r\n              (click)=\"sendData(content, identifier + '_' + data?.id_element)\"\r\n            >\r\n              <span\r\n                [innerHTML]=\"content.title\"\r\n              ></span>\r\n            </li>\r\n          </ng-container>\r\n          <ng-template #noResul>\r\n            <div>\r\n              {{textNoFound}}\r\n            </div>\r\n          </ng-template>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n    <div class=\"tabs\" *ngIf=\"filterPrograms\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\">\r\n          <li [ngbNavItem]=\"0\">\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click('')\">{{textAll}}</a>\r\n          </li>\r\n          <li\r\n            *ngFor=\"\r\n              let tabs of categories;\r\n              let i = index\r\n            \"\r\n            [ngbNavItem]=\"i + 1\"\r\n          >\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click(tabs.term)\">{{\r\n              tabs?.label\r\n              }}</a>\r\n          </li>\r\n        </ul>\r\n        <div\r\n          class=\"tab-content\"\r\n          infiniteScroll\r\n          [infiniteScrollDistance]=\"2\"\r\n          [infiniteScrollThrottle]=\"50\"\r\n          (scrolled)=\"onScroll()\"\r\n        >\r\n          <div class=\"container\">\r\n            <div class=\"row\">\r\n              <ng-container\r\n                *ngIf=\"\r\n                (filterPrograms | FilterPrograms: searchModel)?.length >\r\n                  0;\r\n                else noFound\r\n              \"\r\n              >\r\n                <ng-container\r\n                  *ngFor=\"\r\n                  let content of filterPrograms | RandomProgram : data.order\r\n                    | FilterPrograms: searchModel;\r\n                  let init = index\r\n                \"\r\n                >\r\n                  <div\r\n                    *ngIf=\"init < statusInit\"\r\n                    class=\"col-12 col-sm-6 col-md-4 col-lg-3\"\r\n                    style=\"margin-bottom: 40px;\"\r\n                  >\r\n                    <div class=\"content-flex\">\r\n                      <div class=\"image\" *ngIf=\"content?.image?.length > 0\">\r\n                        <img\r\n                          [src]=\"\r\n                          content?.image[0].styles.large\r\n                            ? content?.image[0].styles.large\r\n                            : ''\r\n                        \"\r\n                          [alt]=\"\r\n                          content?.image[0].texts.alt\r\n                            ? content?.image[0].texts.alt\r\n                            : ''\r\n                        \"\r\n                          [title]=\"\r\n                          content?.image[0].texts.title\r\n                            ? content?.image[0].texts.title\r\n                            : ''\r\n                        \"\r\n                        />\r\n                      </div>\r\n                      <div class=\"box-description\">\r\n                        <h3\r\n                          class=\"h4\"\r\n                          *ngIf=\"content?.title\"\r\n                          [innerHTML]=\"content.title\"\r\n                        ></h3>\r\n                        <div class=\"snies-content\"\r\n                             *ngIf=\"content?.snies?.length > 0\"\r\n                             [ngClass]=\"content.snies[0].class ? content.snies[0].class : ''\">\r\n                          <strong>{{snies}} </strong>\r\n                          <div [outerHTML]=\"content.snies[0].text\"></div>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"button-container\" *ngIf=\"content?.button?.length > 0\"\r\n                           [ngClass]=\"content.button[0].class ? content.button[0].class : ''\">\r\n                        <button *ngIf=\"content?.button[0]?.link[0]?.name || content?.button[0]?.icon?.length > 0\"\r\n                                [id]=\"\r\n                          content.button[0].id_element && data?.id_element\r\n                            ? identifier +\r\n                              '_' +\r\n                              data.id_element +\r\n                              '_' +\r\n                              content.button[0].id_element\r\n                            : ''\r\n                        \"\r\n                                (click)=\"\r\n                          sendData(content, identifier + '_' + data?.id_element)\r\n                        \"\r\n                        >\r\n                          <ng-container *ngIf=\"content?.button[0]?.link[0]?.name\">{{\r\n                            content.button[0].link[0].name\r\n                            }}</ng-container>\r\n                          <ng-container *ngIf=\"content?.button[0]?.icon?.length > 0\">\r\n                            <img class=\"btn-icons\"\r\n                                 [src]=\"\r\n                              content?.button[0].icon[0].styles.large\r\n                                ? content?.button[0].icon[0].styles.large\r\n                                : ''\r\n                            \"\r\n                            />\r\n                          </ng-container>\r\n                        </button>\r\n                      </div>\r\n                    </div>\r\n                  </div>\r\n                </ng-container>\r\n              </ng-container>\r\n              <ng-template #noFound>\r\n                <div class=\"no-found-content\">\r\n                  {{textNoFound}}\r\n                </div>\r\n              </ng-template>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], SearchProgramsDescMixtaComponent);

let ProgramDescMixtaModule = class ProgramDescMixtaModule {
};
ProgramDescMixtaModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            IconsTextModule,
            DescriptionModule,
            NgbNavModule,
            PipesModule,
            FormsModule,
            InfiniteScrollModule,
            SharedModule
        ],
        declarations: [
            DetailProgramDescMixtaComponent,
            ModalProgramDescMixtaComponent,
            SearchProgramsDescMixtaComponent
        ],
        exports: [
            DetailProgramDescMixtaComponent,
            ModalProgramDescMixtaComponent,
            SearchProgramsDescMixtaComponent
        ],
        providers: []
    })
], ProgramDescMixtaModule);

let DetailProgramDescSimplificadaComponent = class DetailProgramDescSimplificadaComponent {
    constructor() {
        this.active = 0;
    }
    ngOnInit() { }
};
__decorate([
    Input()
], DetailProgramDescSimplificadaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], DetailProgramDescSimplificadaComponent.prototype, "data", void 0);
DetailProgramDescSimplificadaComponent = __decorate([
    Component({
        selector: 'dmmp-detail-program-desc-simplificada',
        template: "<section class=\"detail-program detail-program-desc-simplificada\" *ngIf=\"data?.visible\"\r\n         [ngClass]=\"data.class ? data.class : ''\"\r\n         [id]=\"data?.id_element ?  identifier + '_' + data?.id_element : ''\"\r\n         [style.backgroundColor]=\"data?.background_color ? data?.background_color.color : ''\"\r\n         [style.backgroundImage]=\"(data?.background_image).length > 0 ? 'url(' + (data?.background_image)[0].styles.large + ')' : ''\"\r\n         [style.opacity]=\"data?.background_color['opacity'] ? data?.background_color['opacity']:''\"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"incription\" *ngIf=\"data?.content[0]?.label_image\">\r\n      {{data.content[0].label_image}}\r\n    </div>\r\n    <div class=\"tabs\" *ngIf=\"data?.content?.length > 0\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n          <li *ngFor=\"let arr of data.content[0].details | slice:0:4; let u = index\" [ngbNavItem]=\"u\">\r\n            <a ngbNavLink>{{ arr?.tab_name }}</a>\r\n            <ng-template ngbNavContent>\r\n              <div class=\"row\"\r\n                   [ngClass]=\"arr.class ? arr.class : ''\"\r\n                   [id]=\"arr.id_element ? arr.id_element : ''\">\r\n                <div class=\"col-12 col-sm-8 col-md-8 col-lg-8\">\r\n                  <div class=\"content\">\r\n                    <h3>{{ arr.title }}</h3>\r\n                    <ng-container *ngIf=\"arr?.options\">\r\n                      <dmmp-icons-text [data]=\"arr.options\"></dmmp-icons-text>\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"arr?.text\">\r\n                      <dmmp-description\r\n                        [data]=\"arr.text\"\r\n                      ></dmmp-description>\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\" arr?.button?.length > 0\">\r\n                      <div class=\"row\">\r\n                        <ng-container *ngFor=\"let button of arr?.button\">\r\n                          <dmmp-button [data]=\"button\"></dmmp-button>\r\n                        </ng-container>\r\n                      </div>\r\n                    </ng-container>\r\n                  </div>\r\n                </div>\r\n                <div class=\"col-12 col-sm-4 col-md-4 col-lg-4\">\r\n                  <div class=\"box-image\" *ngIf=\"arr?.image?.length > 0\">\r\n                    <img\r\n                      [src]=\"arr?.image[0].styles.large ? arr?.image[0].styles.large : ''\"\r\n                      [alt]=\"arr?.image[0].texts.alt ? arr?.image[0].texts.alt : ''\"\r\n                      [title]=\"arr?.image[0].texts.title ? arr?.image[0].texts.title : ''\"\r\n                    />\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </ng-template>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n      <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], DetailProgramDescSimplificadaComponent);

let ModalProgramDescSimplificadaComponent = class ModalProgramDescSimplificadaComponent {
    constructor(activeModal, sanitizer) {
        this.activeModal = activeModal;
        this.sanitizer = sanitizer;
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
    }
    transform(url) {
        return this.sanitizer.bypassSecurityTrustResourceUrl(url);
    }
    anchor(event, data, categories) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.categoriesOut.emit(categories);
            event.preventDefault();
            this.activeModal.close('Close click');
            setTimeout(() => {
                this.anchorCustom.emit({ event: event, id: data });
            }, 100);
        }
    }
};
ModalProgramDescSimplificadaComponent.ctorParameters = () => [
    { type: NgbActiveModal },
    { type: DomSanitizer }
];
__decorate([
    Input()
], ModalProgramDescSimplificadaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ModalProgramDescSimplificadaComponent.prototype, "data", void 0);
__decorate([
    Output()
], ModalProgramDescSimplificadaComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], ModalProgramDescSimplificadaComponent.prototype, "anchorCustom", void 0);
ModalProgramDescSimplificadaComponent = __decorate([
    Component({
        selector: 'dmmp-modal-program-desc-simplificada',
        template: "<div class=\"modal-detail-program modal-program-desc-simplificada\" [id]=\"identifier ? identifier + '_' + 'modal' : ''\">\r\n  <div class=\"modal-header-content\">\r\n    <div class=\"info-header-content\">\r\n      <h2 class=\"modal-title h2\" *ngIf=\"data?.title\" [innerHTML]=\"data.title\"></h2>\r\n      <div class=\"start-class-content\" *ngIf=\"data.start_date && data.start_date.length > 0\"\r\n           [ngClass]=\"data.start_date[0].class ? data.start_date[0].class : ''\">\r\n        <p>Inicios de clase: </p>\r\n        <div class=\"date\" [innerHTML]=\"data.start_date[0].text\"></div>\r\n      </div>\r\n    </div>\r\n    <button\r\n      type=\"button\"\r\n      class=\"close\"\r\n      aria-label=\"Close\"\r\n      (click)=\"activeModal.close('Close click')\"\r\n    >\r\n      <span aria-hidden=\"true\">\r\n        <i class=\"fas fa-times\"></i>\r\n      </span>\r\n    </button>\r\n  </div>\r\n  <div class=\"modal-body\" *ngIf=\"data?.additional_information\">\r\n    <div class=\"tabs-content\">\r\n      <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n        <li\r\n          *ngFor=\"\r\n            let detailProgram of data?.additional_information;\r\n            let i = index\r\n          \"\r\n          [ngbNavItem]=\"i\"\r\n        >\r\n          <a ngbNavLink>{{ detailProgram?.tab_name }}</a>\r\n          <ng-template ngbNavContent>\r\n            <div class=\"content-tab\"\r\n                 [ngClass]=\"detailProgram.class ? detailProgram.class : ''\"\r\n                 [id]=\"detailProgram?.id_element ? identifier + '_' + detailProgram?.id_element : ''\">\r\n              <div class=\"row\">\r\n                <ng-container *ngIf=\"detailProgram?.options; else content\">\r\n                  <div class=\"col-12\">\r\n                    <div class=\"subtitle-content-modal\">\r\n                      <h3 *ngIf=\"detailProgram?.title\">\r\n                        {{ detailProgram?.title }}\r\n                      </h3>\r\n                    </div>\r\n                  </div>\r\n                  <div\r\n                    class=\"col-12 col-sm-6 col-md-4 col-lg-4\"\r\n                    *ngFor=\"let option of detailProgram?.options\"\r\n                  >\r\n                    <div\r\n                      class=\"content\"\r\n                      [ngClass]=\"option?.class ? option?.class : ''\"\r\n                      [id]=\"option?.id_element ? option?.id_element : ''\"\r\n                    >\r\n                      <div class=\"image\" *ngIf=\"option?.icon?.length > 0\">\r\n                        <img\r\n                          [src]=\"\r\n                            option?.icon[0].styles.large\r\n                              ? option?.icon[0].styles.large\r\n                              : ''\r\n                          \"\r\n                          [alt]=\"\r\n                            option?.icon[0].texts.alt ? option?.icon[0].texts.alt : ''\r\n                          \"\r\n                          [title]=\"\r\n                            option?.icon[0].texts.title\r\n                              ? option?.icon[0].texts.title\r\n                              : ''\r\n                          \"\r\n                        />\r\n                      </div>\r\n                      <div\r\n                        class=\"text\"\r\n                        *ngIf=\"option?.text\"\r\n                        [innerHTML]=\"option.text\"\r\n                      ></div>\r\n                    </div>\r\n                  </div>\r\n                </ng-container>\r\n                <ng-template #content>\r\n                  <div class=\"col-12\">\r\n                    <div class=\"content content-embed\">\r\n                      <div class=\"subtitle-content-modal\">\r\n                        <h3 *ngIf=\"detailProgram?.title\">\r\n                          {{ detailProgram?.title }}\r\n                        </h3>\r\n                      </div>\r\n                      <ng-container *ngIf=\"detailProgram?.file; else contentText\">\r\n                        <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                        <div class=\"iframe\" *ngIf=\"detailProgram?.file\">\r\n                          <dmmp-pdf-viewer [pdfSrc]=\"detailProgram?.file\" [defaultClass]=\"'modal-embed'\"></dmmp-pdf-viewer>\r\n                        </div>\r\n                      </ng-container>\r\n                      <ng-template #contentText>\r\n                        <div class=\"content-row\">\r\n                          <div class=\"row\">\r\n                            <div class=\"col-12 col-md-3\" *ngIf=\"detailProgram?.image?.length > 0\">\r\n                              <div class=\"image\">\r\n                                <img\r\n                                  class=\"btn-icons\"\r\n                                  [src]=\"detailProgram?.image[0].styles.large ?  detailProgram?.image[0].styles.large : ''\"\r\n                                  [alt]=\" detailProgram?.image[0].texts.alt ? detailProgram?.image[0].texts.alt : ''\"\r\n                                  [title]=\"detailProgram?.image[0].texts.title ? detailProgram?.image[0].texts.title : ''\"\r\n                                />\r\n                              </div>\r\n                            </div>\r\n                            <div class=\"col-12 {{detailProgram?.image && detailProgram?.image.length > 0 ? 'col-md-9' : 'col-md-12'}}\">\r\n                              <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                            </div>\r\n                          </div>\r\n                        </div>\r\n                      </ng-template>\r\n                    </div>\r\n                  </div>\r\n                </ng-template>\r\n                <div\r\n                  class=\"col-12 col-sm-12 col-md-12 col-lg-12\"\r\n                  *ngIf=\"detailProgram?.button?.length > 0\">\r\n                  <div class=\"content content-button\">\r\n                    <ng-container *ngFor=\"let button of detailProgram?.button\">\r\n                      <a\r\n                        [id]=\"button?.id_element ? button?.id_element : ''\"\r\n                        [ngClass]=\"button?.class ? button?.class : ''\"\r\n                        [href]=\"\r\n                          button?.file\r\n                            ? button?.file\r\n                            : button.link[0].link\r\n                            ? button.link[0].link\r\n                            : ''\r\n                        \"\r\n                        [target]=\"button?.file ? '_blank' : ''\"\r\n                        (click)=\"\r\n                          anchor(\r\n                            $event,\r\n                            button?.file\r\n                              ? button?.file\r\n                              : button.link[0].link\r\n                              ? button.link[0].link\r\n                              : '',\r\n                              data.categories\r\n                          )\r\n                        \"\r\n                      >\r\n                        {{ button.link[0].name }}\r\n                        <ng-container *ngIf=\"button?.icon?.length>0\">\r\n                          <img\r\n                            class=\"btn-icons\"\r\n                            [src]=\" button?.icon[0].styles.large ?  button?.icon[0].styles.large : ''\"\r\n                            [alt]=\" button?.icon[0].texts.alt ?  button.icon[0].texts.alt : ''\"\r\n                            [title]=\" button?.icon[0].texts.title ?  button.icon[0].texts.title : ''\"\r\n                          />\r\n                        </ng-container>\r\n\r\n                      </a>\r\n                    </ng-container>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </li>\r\n      </ul>\r\n    </div>\r\n    <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n  </div>\r\n  <div class=\"modal-footer\">\r\n    <button\r\n      type=\"button\"\r\n      class=\"btn btn-outline-dark\"\r\n      (click)=\"activeModal.close('Close click')\"\r\n    >\r\n      Close\r\n    </button>\r\n  </div>\r\n</div>\r\n"
    })
], ModalProgramDescSimplificadaComponent);

let SearchProgramsDescSimplificadaComponent = class SearchProgramsDescSimplificadaComponent {
    constructor(modalService) {
        this.modalService = modalService;
        this.categories = [];
        this.textNoFound = 'No se encontraron resultados';
        this.textAll = 'Todos';
        this.categoryOut = new EventEmitter();
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.status = true;
        this.notEmptyPost = true;
        this.statusInit = 8;
    }
    ngOnInit() {
    }
    click(category) {
        this.categoryOut.emit(category);
    }
    sendData(data, identifier) {
        this.status = false;
        const modalRef = this.modalService.open(ModalProgramDescSimplificadaComponent, { size: 'lg' });
        modalRef.componentInstance.data = data;
        modalRef.componentInstance.identifier = identifier;
        modalRef.componentInstance.categoriesOut.subscribe(($e) => {
            this.categoriesOut.emit($e);
        });
        modalRef.componentInstance.anchorCustom.subscribe(($e) => {
            this.anchorCustom.emit($e);
        });
    }
    onScroll() {
        if (this.notEmptyPost) {
            this.statusInit += 8;
        }
    }
};
SearchProgramsDescSimplificadaComponent.ctorParameters = () => [
    { type: NgbModal }
];
__decorate([
    Input()
], SearchProgramsDescSimplificadaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SearchProgramsDescSimplificadaComponent.prototype, "data", void 0);
__decorate([
    Input()
], SearchProgramsDescSimplificadaComponent.prototype, "filterPrograms", void 0);
__decorate([
    Input()
], SearchProgramsDescSimplificadaComponent.prototype, "categories", void 0);
__decorate([
    Input()
], SearchProgramsDescSimplificadaComponent.prototype, "textNoFound", void 0);
__decorate([
    Input()
], SearchProgramsDescSimplificadaComponent.prototype, "textAll", void 0);
__decorate([
    Output()
], SearchProgramsDescSimplificadaComponent.prototype, "categoryOut", void 0);
__decorate([
    Output()
], SearchProgramsDescSimplificadaComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], SearchProgramsDescSimplificadaComponent.prototype, "anchorCustom", void 0);
SearchProgramsDescSimplificadaComponent = __decorate([
    Component({
        selector: 'dmmp-search-programs-desc-simplificada',
        template: "<section\r\n  class=\"programs search-programs-desc-simplificada\"\r\n  *ngIf=\"data?.visible\"\r\n  [ngClass]=\"data.class ? data.class : ''\"\r\n  [id]=\"data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n  [style.backgroundColor]=\"\r\n    data?.background_color ? data?.background_color.color : ''\r\n  \"\r\n  [style.backgroundImage]=\"\r\n    (data?.background_image) && (data?.background_image).length > 0\r\n      ? 'url(' + (data?.background_image)[0].styles.large + ')'\r\n      : ''\r\n  \"\r\n  [style.opacity]=\"\r\n    (data?.background_color)['opacity']\r\n      ? (data?.background_color)['opacity']\r\n      : ''\r\n  \"\r\n>\r\n  <div class=\"container p-0\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\" data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"container-search\" *ngIf=\"data?.search\">\r\n      <div class=\"search\">\r\n        <div class=\"content-input\">\r\n          <input\r\n            [placeholder]=\"data.search.placeholder\"\r\n            class=\"search-input\"\r\n            [ngClass]=\"data.search.class ? data.search.class : ''\"\r\n            [id]=\"data.search.id_element ? data.search.id_element : ''\"\r\n            type=\"text\"\r\n            placeholder=\"\"\r\n            [(ngModel)]=\"searchModel\"\r\n          />\r\n          <div class=\"icon\" *ngIf=\"data?.search?.image?.length > 0\">\r\n            <img\r\n              [src]=\"\r\n                (data?.search.image)[0].styles.large\r\n                  ? (data?.search.image)[0].styles.large\r\n                  : ''\r\n              \"\r\n              [alt]=\"(data?.search.image)[0].texts.alt\"\r\n              [title]=\"(data?.search.image)[0].texts.title\"\r\n            />\r\n          </div>\r\n        </div>\r\n        <ul class=\"result-search\" *ngIf=\"searchModel\">\r\n          <div class=\"close\">\r\n            <span (click)=\"searchModel= ''\">x</span>\r\n          </div>\r\n          <ng-container\r\n            *ngIf=\"\r\n              (filterPrograms | FilterPrograms: searchModel)?.length >\r\n                0;\r\n              else noResul\r\n            \">\r\n            <li\r\n              *ngFor=\"\r\n                let content of filterPrograms\r\n                  | FilterPrograms: searchModel\r\n              \"\r\n              (click)=\"sendData(content, identifier + '_' + data?.id_element)\"\r\n            >\r\n              <span\r\n                [innerHTML]=\"content.title\"\r\n              ></span>\r\n            </li>\r\n          </ng-container>\r\n          <ng-template #noResul>\r\n            <div>\r\n              {{textNoFound}}\r\n            </div>\r\n          </ng-template>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n    <div class=\"container tabs\" *ngIf=\"filterPrograms\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\">\r\n          <li [ngbNavItem]=\"0\">\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click('')\">{{textAll}}</a>\r\n          </li>\r\n          <li\r\n            *ngFor=\"\r\n              let tabs of categories;\r\n              let i = index\r\n            \"\r\n            [ngbNavItem]=\"i + 1\"\r\n          >\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click(tabs.term)\">{{\r\n              tabs?.label\r\n              }}</a>\r\n          </li>\r\n        </ul>\r\n        <div\r\n          class=\"tab-content\"\r\n          infiniteScroll\r\n          [infiniteScrollDistance]=\"2\"\r\n          [infiniteScrollThrottle]=\"50\"\r\n          (scrolled)=\"onScroll()\"\r\n        >\r\n          <div class=\"row\">\r\n            <ng-container\r\n              *ngIf=\"\r\n                (filterPrograms | FilterPrograms: searchModel)?.length >\r\n                  0;\r\n                else noFound\r\n              \"\r\n            >\r\n              <ng-container\r\n                *ngFor=\"\r\n                  let content of filterPrograms | RandomProgram : data.order\r\n                    | FilterPrograms: searchModel;\r\n                  let init = index\r\n                \"\r\n              >\r\n                <div\r\n                  *ngIf=\"init < statusInit\"\r\n                  class=\"col-12 col-sm-6 col-md-4 col-lg-3\"\r\n                  style=\"margin-bottom: 40px;\"\r\n                >\r\n                  <div class=\"content-flex\">\r\n                    <div class=\"image\" *ngIf=\"content?.image?.length > 0\">\r\n                      <img\r\n                        [src]=\"\r\n                          content?.image[0].styles.large\r\n                            ? content?.image[0].styles.large\r\n                            : ''\r\n                        \"\r\n                        [alt]=\"\r\n                          content?.image[0].texts.alt\r\n                            ? content?.image[0].texts.alt\r\n                            : ''\r\n                        \"\r\n                        [title]=\"\r\n                          content?.image[0].texts.title\r\n                            ? content?.image[0].texts.title\r\n                            : ''\r\n                        \"\r\n                      />\r\n                    </div>\r\n                    <div class=\"box-description\">\r\n                      <h3\r\n                        class=\"p6\"\r\n                        *ngIf=\"content?.title\"\r\n                        [innerHTML]=\"content.title\"\r\n                      ></h3>\r\n                    </div>\r\n                    <div class=\"button-container\"\r\n                         *ngIf=\"content?.button?.length > 0\"\r\n                         [ngClass]=\"content.button[0].class ? content.button[0].class : ''\">\r\n                      <button\r\n                        *ngIf=\"content?.button[0]?.link[0]?.name || content?.button[0]?.icon?.length > 0\"\r\n                        [id]=\"content.button[0].id_element && data?.id_element ? identifier + '_' + data.id_element + '_' + content.button[0].id_element : ''\"\r\n                        (click)=\"sendData(content, identifier + '_' + data?.id_element)\">\r\n                        <ng-container *ngIf=\"content?.button[0]?.link[0]?.name\">{{\r\n                          content.button[0].link[0].name\r\n                          }}</ng-container>\r\n                        <ng-container *ngIf=\"content?.button[0]?.icon?.length > 0\">\r\n                          <img class=\"btn-icons\"\r\n                               [src]=\"\r\n                              content?.button[0].icon[0].styles.large\r\n                                ? content?.button[0].icon[0].styles.large\r\n                                : ''\r\n                            \"\r\n                          />\r\n                        </ng-container>\r\n                      </button>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </ng-container>\r\n            </ng-container>\r\n            <ng-template #noFound>\r\n              <div class=\"no-found-content\">\r\n                {{textNoFound}}\r\n              </div>\r\n            </ng-template>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], SearchProgramsDescSimplificadaComponent);

let ProgramDescSimplificadaModule = class ProgramDescSimplificadaModule {
};
ProgramDescSimplificadaModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            IconsTextModule,
            DescriptionModule,
            NgbNavModule,
            PipesModule,
            FormsModule,
            InfiniteScrollModule,
            SharedModule
        ],
        declarations: [
            DetailProgramDescSimplificadaComponent,
            ModalProgramDescSimplificadaComponent,
            SearchProgramsDescSimplificadaComponent
        ],
        exports: [
            DetailProgramDescSimplificadaComponent,
            ModalProgramDescSimplificadaComponent,
            SearchProgramsDescSimplificadaComponent
        ],
        providers: []
    })
], ProgramDescSimplificadaModule);

let DetailProgramDescTablaComponent = class DetailProgramDescTablaComponent {
    constructor() {
        this.active = 0;
    }
    ngOnInit() { }
};
__decorate([
    Input()
], DetailProgramDescTablaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], DetailProgramDescTablaComponent.prototype, "data", void 0);
DetailProgramDescTablaComponent = __decorate([
    Component({
        selector: 'dmmp-detail-program-desc-tabla',
        template: "<section class=\"detail-program detail-program-desc-tabla\" *ngIf=\"data?.visible\"\r\n         [ngClass]=\"data.class ? data.class : ''\"\r\n         [id]=\"data?.id_element ?  identifier + '_' + data?.id_element : ''\"\r\n         [style.backgroundColor]=\"data?.background_color ? data?.background_color.color : ''\"\r\n         [style.backgroundImage]=\"(data?.background_image).length > 0 ? 'url(' + (data?.background_image)[0].styles.large + ')' : ''\"\r\n         [style.opacity]=\"data?.background_color['opacity'] ? data?.background_color['opacity']:''\"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"tabs\" *ngIf=\" data?.content?.length > 0\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n          <li *ngFor=\"let arr of data.content[0].details | slice:0:4; let u = index\" [ngbNavItem]=\"u\">\r\n            <a ngbNavLink *ngIf=\"arr?.tab_name\">{{ arr?.tab_name }}</a>\r\n            <ng-template ngbNavContent>\r\n              <div class=\"row\"\r\n                   [ngClass]=\"arr.class ? arr.class : ''\"\r\n                   [id]=\"arr.id_element ? arr.id_element : ''\">\r\n                <div class=\"col-12 col-sm-6 col-md-6 col-lg-6\">\r\n                  <div class=\"content\">\r\n                    <h3>{{ arr.title }}</h3>\r\n                    <ng-container *ngIf=\"arr?.options\">\r\n                      <dmmp-icons-text [data]=\"arr.options\"></dmmp-icons-text>\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"arr?.text\">\r\n                      <dmmp-description\r\n                        [data]=\"arr.text\"\r\n                      ></dmmp-description>\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"arr?.button?.length > 0\">\r\n                      <div class=\"row row-buttons\">\r\n                        <ng-container *ngFor=\"let button of arr?.button\">\r\n                          <dmmp-button [data]=\"button\"></dmmp-button>\r\n                        </ng-container>\r\n                      </div>\r\n                    </ng-container>\r\n                  </div>\r\n                </div>\r\n                <div class=\"col-12 col-sm-6 col-md-6 col-lg-6\">\r\n                  <div class=\"content data-sheet\">\r\n                    <h3>Ficha t\u00E9cnica</h3>\r\n                    <div class=\"row no-gutters\">\r\n                      <div class=\"col-12 col-md-6\" *ngIf=\"data?.content[0]?.snies?.length > 0\">\r\n                        <div class=\"content-text\">\r\n                          <div class=\"subtitle-text\"><strong>Resoluci\u00F3n Ministerial:</strong></div>\r\n                          <div class=\"value-content\">\r\n                            <div class=\"snies-content\"\r\n                                 [ngClass]=\"data.content[0].snies[0].class ? data.content[0].snies[0].class : ''\"\r\n                                 [innerHTML]=\"data.content[0].snies[0].text\"></div>\r\n                          </div>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"col-12 col-md-6\" *ngIf=\"data.content[0]?.program_type\">\r\n                        <div class=\"content-text\">\r\n                          <div class=\"subtitle-text\"><strong>Tipo de Programa:</strong></div>\r\n                          <div class=\"value-content\">{{data.content[0].program_type}}</div>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"col-12 col-md-6\"\r\n                           *ngIf=\"data?.content[0]?.certification?.length > 0\">\r\n                        <div class=\"content-text\">\r\n                          <div class=\"subtitle-text\"><strong>T\u00EDtulo:</strong></div>\r\n                          <div class=\"value-content\">\r\n                            <div class=\"title-content\"\r\n                                 [ngClass]=\"data.content[0].certification[0].class ? data.content[0].certification[0].class : ''\"\r\n                                 [innerHTML]=\"data.content[0].certification[0].text\"></div>\r\n                          </div>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"col-12 col-md-6\"\r\n                           *ngIf=\"data?.content[0]?.certification_double?.length > 0\">\r\n                        <div class=\"content-text\">\r\n                          <div class=\"subtitle-text\"><strong>Doble titulaci\u00F3n posible:</strong></div>\r\n                          <div class=\"value-content\">\r\n                            <div class=\"title-content\"\r\n                                 [ngClass]=\"data.content[0].certification_double[0].class ? data.content[0].certification_double[0].class : ''\"\r\n                                 [innerHTML]=\"data.content[0].certification_double[0].text\"></div>\r\n                          </div>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"col-12 col-md-6\"\r\n                           *ngIf=\"data?.content[0]?.certification_complementary?.length > 0\">\r\n                        <div class=\"content-text\">\r\n                          <div class=\"subtitle-text\"><strong>T\u00EDtulo complementario:</strong></div>\r\n                          <div class=\"value-content\">\r\n                            <div class=\"title-content\"\r\n                                 [ngClass]=\"data.content[0].certification_complementary[0].class ? data.content[0].certification_complementary[0].class : ''\"\r\n                                 [innerHTML]=\"data.content[0].certification_complementary[0].text\"></div>\r\n                          </div>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"col-12 col-md-6\"\r\n                           *ngIf=\"data?.content[0]?.certification_middle?.length > 0\">\r\n                        <div class=\"content-text\">\r\n                          <div class=\"subtitle-text\"><strong>T\u00EDtulo intermedio (3 a\u00F1os):</strong></div>\r\n                          <div class=\"value-content\">\r\n                            <div class=\"title-content\"\r\n                                 [ngClass]=\"data.content[0].certification_middle[0].class ? data.content[0].certification_middle[0].class : ''\"\r\n                                 [innerHTML]=\"data.content[0].certification_middle[0].text\"></div>\r\n                          </div>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"col-12 col-md-6\" *ngIf=\"data?.content[0]?.duration\">\r\n                        <div class=\"content-text\">\r\n                          <div class=\"subtitle-text\"><strong>Duraci\u00F3n:</strong></div>\r\n                          <div class=\"value-content\">\r\n                            <div class=\"duration\"\r\n                                 [ngClass]=\"data.content[0].duration_class ? data.content[0].duration_class : ''\">\r\n                              <p>{{data.content[0].duration}}</p>\r\n                            </div>\r\n                          </div>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"col-12 col-md-6\" *ngIf=\"data?.content[0]?.modality?.length > 0\">\r\n                        <div class=\"content-text\">\r\n                          <div class=\"subtitle-text\"><strong>Modalidad:</strong></div>\r\n                          <div class=\"value-content\"><ng-container *ngFor=\"let modality of data.content[0].modality; let i = index\">\r\n                            {{modality}}{{ (i + 1) < data.content[0].modality.length ? ', ' : '.'}}\r\n                          </ng-container></div>\r\n                        </div>\r\n                      </div>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </ng-template>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n      <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], DetailProgramDescTablaComponent);

let ModalProgramDescTablaComponent = class ModalProgramDescTablaComponent {
    constructor(activeModal, sanitizer) {
        this.activeModal = activeModal;
        this.sanitizer = sanitizer;
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
    }
    transform(url) {
        return this.sanitizer.bypassSecurityTrustResourceUrl(url);
    }
    anchor(event, data, categories) {
        if (data.indexOf('#') === 0 && data.length > 1) {
            this.categoriesOut.emit(categories);
            event.preventDefault();
            this.activeModal.close('Close click');
            setTimeout(() => {
                this.anchorCustom.emit({ event: event, id: data });
            }, 100);
        }
    }
};
ModalProgramDescTablaComponent.ctorParameters = () => [
    { type: NgbActiveModal },
    { type: DomSanitizer }
];
__decorate([
    Input()
], ModalProgramDescTablaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ModalProgramDescTablaComponent.prototype, "data", void 0);
__decorate([
    Output()
], ModalProgramDescTablaComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], ModalProgramDescTablaComponent.prototype, "anchorCustom", void 0);
ModalProgramDescTablaComponent = __decorate([
    Component({
        selector: 'dmmp-modal-program-desc-tabla',
        template: "<div class=\"modal-detail-program modal-program-desc-tabla\" [id]=\"identifier ? identifier + '_' + 'modal' : ''\">\r\n  <div class=\"modal-header-content\"\r\n       [style.backgroundImage]=\"\r\n    (data?.banner_image).length > 0\r\n      ? 'url(' + (data?.banner_image)[0].styles.large + ')'\r\n      : ''\r\n  \">\r\n    <div class=\"info-header-content\">\r\n      <h2 class=\"modal-title h2\" *ngIf=\"data?.title\" [innerHTML]=\"data.title\"></h2>\r\n      <div class=\"content-category\">\r\n        <div class=\"duration\" *ngIf=\"data.duration\"\r\n             [ngClass]=\"data.duration_class ? data.duration_class : ''\">\r\n          <p>{{data.duration}}</p>\r\n        </div>\r\n        <ul *ngIf=\"data?.categories?.length > 0\">\r\n          <li *ngFor=\"let cate of data.categories | slice:0:3\">\r\n            {{ cate }}\r\n          </li>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n    <button\r\n      type=\"button\"\r\n      class=\"close\"\r\n      aria-label=\"Close\"\r\n      (click)=\"activeModal.close('Close click')\"\r\n    >\r\n      <span aria-hidden=\"true\">\r\n        <i class=\"fas fa-times\"></i>\r\n      </span>\r\n    </button>\r\n  </div>\r\n  <div class=\"modal-body\" *ngIf=\"data?.additional_information\">\r\n    <div class=\"tabs-content\">\r\n      <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n        <li\r\n          *ngFor=\"\r\n            let detailProgram of data?.additional_information;\r\n            let i = index\r\n          \"\r\n          [ngbNavItem]=\"i\"\r\n        >\r\n          <a ngbNavLink>{{ detailProgram?.tab_name }}</a>\r\n          <ng-template ngbNavContent>\r\n            <div class=\"content-tab\"\r\n                 [ngClass]=\"detailProgram.class ? detailProgram.class : ''\"\r\n                 [id]=\"detailProgram?.id_element ? identifier + '_' + detailProgram?.id_element : ''\">\r\n              <div class=\"row\">\r\n                <ng-container *ngIf=\"detailProgram?.options && detailProgram?.identifier === 'text_icon'; else content\">\r\n                  <div class=\"col-12\">\r\n                   <div class=\"subtitle-content-modal\">\r\n                     <h3 *ngIf=\"detailProgram?.title\">\r\n                       {{ detailProgram?.title }}\r\n                     </h3>\r\n                   </div>\r\n                  </div>\r\n                  <div\r\n                    class=\"col-12 col-sm-6 col-md-4 col-lg-4\"\r\n                    *ngFor=\"let option of detailProgram?.options\"\r\n                  >\r\n                    <div\r\n                      class=\"content\"\r\n                      [ngClass]=\"option?.class ? option?.class : ''\"\r\n                      [id]=\"option?.id_element ? option?.id_element : ''\"\r\n                    >\r\n                      <div class=\"image\" *ngIf=\"option?.icon\">\r\n                        <img\r\n                          [src]=\"\r\n                            option?.icon[0].styles.large\r\n                              ? option?.icon[0].styles.large\r\n                              : ''\r\n                          \"\r\n                          [alt]=\"\r\n                            option?.icon[0].texts.alt ? option?.icon[0].texts.alt : ''\r\n                          \"\r\n                          [title]=\"\r\n                            option?.icon[0].texts.title\r\n                              ? option?.icon[0].texts.title\r\n                              : ''\r\n                          \"\r\n                        />\r\n                      </div>\r\n                      <div\r\n                        class=\"text\"\r\n                        *ngIf=\"option?.text\"\r\n                        [innerHTML]=\"option.text\"\r\n                      ></div>\r\n                    </div>\r\n                  </div>\r\n                </ng-container>\r\n                <ng-template #content>\r\n                  <div class=\"col-12\">\r\n                    <div class=\"content content-embed\">\r\n                      <div class=\"subtitle-content-modal\">\r\n                        <h3 *ngIf=\"detailProgram?.title\">\r\n                          {{ detailProgram?.title }}\r\n                        </h3>\r\n                      </div>\r\n                      <ng-container *ngIf=\"(detailProgram?.file || detailProgram?.table); else contentText\">\r\n                        <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                        <div class=\"content-table-technique\" *ngIf=\"detailProgram?.table\">\r\n                          <div class=\"content data-sheet\">\r\n                            <div class=\"row no-gutters\">\r\n                              <div class=\"col-12 col-md-6\" *ngIf=\"data?.snies?.length > 0\">\r\n                                <div class=\"content-text\">\r\n                                  <div class=\"subtitle-text\"><strong>Resoluci\u00F3n Ministerial:</strong></div>\r\n                                  <div class=\"value-content\">\r\n                                    <div class=\"snies-content\"\r\n                                         [ngClass]=\"data.snies[0].class ? data.snies[0].class : ''\"\r\n                                         [innerHTML]=\"data.snies[0].text\"></div>\r\n                                  </div>\r\n                                </div>\r\n                              </div>\r\n                              <div class=\"col-12 col-md-6\" *ngIf=\"data?.program_type\">\r\n                                <div class=\"content-text\">\r\n                                  <div class=\"subtitle-text\"><strong>Tipo de Programa:</strong></div>\r\n                                  <div class=\"value-content\">{{data.program_type}}</div>\r\n                                </div>\r\n                              </div>\r\n                              <div class=\"col-12 col-md-6\"\r\n                                   *ngIf=\"data?.certification?.length > 0\">\r\n                                <div class=\"content-text\">\r\n                                  <div class=\"subtitle-text\"><strong>T\u00EDtulo:</strong></div>\r\n                                  <div class=\"value-content\">\r\n                                    <div class=\"title-content\"\r\n                                         [ngClass]=\"data.certification[0].class ? data.certification[0].class : ''\"\r\n                                         [innerHTML]=\"data.certification[0].text\"></div>\r\n                                  </div>\r\n                                </div>\r\n                              </div>\r\n                              <div class=\"col-12 col-md-6\"\r\n                                   *ngIf=\"data?.certification_double?.length > 0\">\r\n                                <div class=\"content-text\">\r\n                                  <div class=\"subtitle-text\"><strong>Doble titulaci\u00F3n posible:</strong></div>\r\n                                  <div class=\"value-content\">\r\n                                    <div class=\"title-content\"\r\n                                         [ngClass]=\"data.certification_double[0].class ? data.certification_double[0].class : ''\"\r\n                                         [innerHTML]=\"data.certification_double[0].text\"></div>\r\n                                  </div>\r\n                                </div>\r\n                              </div>\r\n                              <div class=\"col-12 col-md-6\"\r\n                                   *ngIf=\"data?.certification_complementary?.length > 0\">\r\n                                <div class=\"content-text\">\r\n                                  <div class=\"subtitle-text\"><strong>T\u00EDtulo complementario:</strong></div>\r\n                                  <div class=\"value-content\">\r\n                                    <div class=\"title-content\"\r\n                                         [ngClass]=\"data.certification_complementary[0].class ? data.certification_complementary[0].class : ''\"\r\n                                         [innerHTML]=\"data.certification_complementary[0].text\"></div>\r\n                                  </div>\r\n                                </div>\r\n                              </div>\r\n                              <div class=\"col-12 col-md-6\"\r\n                                   *ngIf=\"data?.certification_middle?.length > 0\">\r\n                                <div class=\"content-text\">\r\n                                  <div class=\"subtitle-text\"><strong>T\u00EDtulo intermedio (3 a\u00F1os):</strong></div>\r\n                                  <div class=\"value-content\">\r\n                                    <div class=\"title-content\"\r\n                                         [ngClass]=\"data.certification_middle[0].class ? data.certification_middle[0].class : ''\"\r\n                                         [innerHTML]=\"data.certification_middle[0].text\"></div>\r\n                                  </div>\r\n                                </div>\r\n                              </div>\r\n                              <div class=\"col-12 col-md-6\" *ngIf=\"data?.duration\">\r\n                                <div class=\"content-text\">\r\n                                  <div class=\"subtitle-text\"><strong>Duraci\u00F3n:</strong></div>\r\n                                  <div class=\"value-content\">\r\n                                    <div class=\"duration\"\r\n                                         [ngClass]=\"data.duration_class ? data.duration_class : ''\">\r\n                                      <p>{{data.duration}}</p>\r\n                                    </div>\r\n                                  </div>\r\n                                </div>\r\n                              </div>\r\n                              <div class=\"col-12 col-md-6\" *ngIf=\"data?.modality?.length > 0\">\r\n                                <div class=\"content-text\">\r\n                                  <div class=\"subtitle-text\"><strong>Modalidad:</strong></div>\r\n                                  <div class=\"value-content\"><ng-container *ngFor=\"let modality of data.modality; let i = index\">\r\n                                    {{modality}}{{ (i + 1) < data.modality.length ? ', ' : '.'}}\r\n                                  </ng-container></div>\r\n                                </div>\r\n                              </div>\r\n                            </div>\r\n                          </div>\r\n                        </div>\r\n                        <div class=\"iframe\" *ngIf=\"detailProgram?.file\">\r\n                          <dmmp-pdf-viewer [pdfSrc]=\"detailProgram?.file\" [defaultClass]=\"'modal-embed'\"></dmmp-pdf-viewer>\r\n                        </div>\r\n                      </ng-container>\r\n                      <ng-template #contentText>\r\n                        <div class=\"content-row\">\r\n                          <div class=\"row\">\r\n                            <div class=\"col-12 col-md-3\" *ngIf=\"detailProgram?.image?.length > 0\">\r\n                              <div class=\"image\">\r\n                                <img\r\n                                  class=\"btn-icons\"\r\n                                  [src]=\"detailProgram?.image[0].styles.large ?  detailProgram?.image[0].styles.large : ''\"\r\n                                  [alt]=\" detailProgram?.image[0].texts.alt ? detailProgram?.image[0].texts.alt : ''\"\r\n                                  [title]=\"detailProgram?.image[0].texts.title ? detailProgram?.image[0].texts.title : ''\"\r\n                                />\r\n                              </div>\r\n                            </div>\r\n                            <div class=\"col-12 {{detailProgram?.image && detailProgram?.image.length > 0 ? 'col-md-9' : 'col-md-12'}}\">\r\n                              <p class=\"description\" *ngIf=\"detailProgram?.text\" [innerHTML]=\"detailProgram?.text\"></p>\r\n                            </div>\r\n                          </div>\r\n                        </div>\r\n                      </ng-template>\r\n                    </div>\r\n                  </div>\r\n                </ng-template>\r\n                <div\r\n                  class=\"col-12 col-sm-12 col-md-12 col-lg-12\"\r\n                  *ngIf=\"detailProgram?.button?.length > 0\">\r\n                  <div class=\"content content-button\">\r\n                    <ng-container *ngFor=\"let button of detailProgram?.button\">\r\n                      <a\r\n                        [id]=\"button?.id_element ? button?.id_element : ''\"\r\n                        [ngClass]=\"button?.class ? button?.class : ''\"\r\n                        [href]=\"\r\n                          button?.file\r\n                            ? button?.file\r\n                            : button.link[0].link\r\n                            ? button.link[0].link\r\n                            : ''\r\n                        \"\r\n                        [target]=\"button?.file ? '_blank' : ''\"\r\n                        (click)=\"\r\n                          anchor(\r\n                            $event,\r\n                            button?.file\r\n                              ? button?.file\r\n                              : button.link[0].link\r\n                              ? button.link[0].link\r\n                              : '',\r\n                              data.categories\r\n                          )\r\n                        \"\r\n                      >\r\n                        {{ button.link[0].name }}\r\n                        <ng-container *ngIf=\"button?.icon?.length>0\">\r\n                          <img\r\n                            class=\"btn-icons\"\r\n                            [src]=\" button?.icon[0].styles.large ?  button?.icon[0].styles.large : ''\"\r\n                            [alt]=\" button?.icon[0].texts.alt ?  button.icon[0].texts.alt : ''\"\r\n                            [title]=\" button?.icon[0].texts.title ?  button.icon[0].texts.title : ''\"\r\n                          />\r\n                        </ng-container>\r\n\r\n                      </a>\r\n                    </ng-container>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </li>\r\n      </ul>\r\n    </div>\r\n    <div [ngbNavOutlet]=\"nav\" class=\"\"></div>\r\n  </div>\r\n  <div class=\"modal-footer\">\r\n    <button\r\n      type=\"button\"\r\n      class=\"btn btn-outline-dark\"\r\n      (click)=\"activeModal.close('Close click')\"\r\n    >\r\n      Close\r\n    </button>\r\n  </div>\r\n</div>\r\n"
    })
], ModalProgramDescTablaComponent);

let SearchProgramsDescTablaComponent = class SearchProgramsDescTablaComponent {
    constructor(modalService) {
        this.modalService = modalService;
        this.categories = [];
        this.textNoFound = 'No se encontraron resultados';
        this.textAll = 'Todos';
        this.categoryOut = new EventEmitter();
        this.categoriesOut = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.status = true;
        this.notEmptyPost = true;
        this.statusInit = 8;
    }
    ngOnInit() {
    }
    click(category) {
        this.categoryOut.emit(category);
    }
    sendData(data, identifier) {
        this.status = false;
        const modalRef = this.modalService.open(ModalProgramDescTablaComponent, { size: 'lg' });
        modalRef.componentInstance.data = data;
        modalRef.componentInstance.identifier = identifier;
        modalRef.componentInstance.categoriesOut.subscribe(($e) => {
            this.categoriesOut.emit($e);
        });
        modalRef.componentInstance.anchorCustom.subscribe(($e) => {
            this.anchorCustom.emit($e);
        });
    }
    onScroll() {
        if (this.notEmptyPost) {
            this.statusInit += 8;
        }
    }
};
SearchProgramsDescTablaComponent.ctorParameters = () => [
    { type: NgbModal }
];
__decorate([
    Input()
], SearchProgramsDescTablaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SearchProgramsDescTablaComponent.prototype, "data", void 0);
__decorate([
    Input()
], SearchProgramsDescTablaComponent.prototype, "filterPrograms", void 0);
__decorate([
    Input()
], SearchProgramsDescTablaComponent.prototype, "categories", void 0);
__decorate([
    Input()
], SearchProgramsDescTablaComponent.prototype, "textNoFound", void 0);
__decorate([
    Input()
], SearchProgramsDescTablaComponent.prototype, "textAll", void 0);
__decorate([
    Output()
], SearchProgramsDescTablaComponent.prototype, "categoryOut", void 0);
__decorate([
    Output()
], SearchProgramsDescTablaComponent.prototype, "categoriesOut", void 0);
__decorate([
    Output()
], SearchProgramsDescTablaComponent.prototype, "anchorCustom", void 0);
SearchProgramsDescTablaComponent = __decorate([
    Component({
        selector: 'dmmp-search-programs-desc-tabla',
        template: "<section\r\n  class=\"programs search-programs-desc-tabla\"\r\n  *ngIf=\"data?.visible\"\r\n  [ngClass]=\"data.class ? data.class : ''\"\r\n  [id]=\"data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n  [style.backgroundColor]=\"\r\n    data?.background_color ? data?.background_color.color : ''\r\n  \"\r\n  [style.backgroundImage]=\"\r\n    (data?.background_image) && (data?.background_image).length > 0\r\n      ? 'url(' + (data?.background_image)[0].styles.large + ')'\r\n      : ''\r\n  \"\r\n  [style.opacity]=\"\r\n    (data?.background_color)['opacity']\r\n      ? (data?.background_color)['opacity']\r\n      : ''\r\n  \"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n      {{ data.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"container-search\" *ngIf=\"data?.search\">\r\n      <div class=\"search\">\r\n        <div class=\"content-input\">\r\n          <input\r\n            [placeholder]=\"data.search.placeholder\"\r\n            class=\"search-input\"\r\n            [ngClass]=\"data.search.class ? data.search.class : ''\"\r\n            [id]=\"data.search.id_element ? data.search.id_element : ''\"\r\n            type=\"text\"\r\n            placeholder=\"\"\r\n            [(ngModel)]=\"searchModel\"\r\n          />\r\n          <div class=\"icon\">\r\n            <img\r\n              [src]=\"\r\n                (data?.search.image)[0].styles.large\r\n                  ? (data?.search.image)[0].styles.large\r\n                  : ''\r\n              \"\r\n              [alt]=\"(data?.search.image)[0].texts.alt\"\r\n              [title]=\"(data?.search.image)[0].texts.title\"\r\n            />\r\n          </div>\r\n        </div>\r\n        <ul class=\"result-search\" *ngIf=\"searchModel\">\r\n          <div class=\"close\">\r\n            <span (click)=\"searchModel= ''\">x</span>\r\n          </div>\r\n          <ng-container\r\n            *ngIf=\"\r\n              (filterPrograms | FilterPrograms: searchModel).length >\r\n                0;\r\n              else noResul\r\n            \">\r\n            <li\r\n              *ngFor=\"\r\n                let content of filterPrograms\r\n                  | FilterPrograms: searchModel\r\n              \"\r\n              (click)=\"sendData(content, identifier + '_' + data?.id_element)\"\r\n            >\r\n              <span\r\n                [innerHTML]=\"content.title\"\r\n              ></span>\r\n            </li>\r\n          </ng-container>\r\n          <ng-template #noResul>\r\n            <div>\r\n              {{textNoFound}}\r\n            </div>\r\n          </ng-template>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n    <div class=\"tabs\" *ngIf=\"filterPrograms\">\r\n      <div class=\"tabs-content\">\r\n        <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\">\r\n          <li [ngbNavItem]=\"0\">\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click('')\"> {{textAll}}</a>\r\n          </li>\r\n          <li\r\n            *ngFor=\"\r\n              let tabs of categories;\r\n              let i = index\r\n            \"\r\n            [ngbNavItem]=\"i + 1\"\r\n          >\r\n            <a ngbNavLink class=\"\" href=\"#\" (click)=\"click(tabs.term)\">{{\r\n              tabs?.label\r\n              }}</a>\r\n          </li>\r\n        </ul>\r\n        <div\r\n          class=\"tab-content\"\r\n          infiniteScroll\r\n          [infiniteScrollDistance]=\"2\"\r\n          [infiniteScrollThrottle]=\"50\"\r\n          (scrolled)=\"onScroll()\"\r\n        >\r\n          <div class=\"row\">\r\n            <ng-container\r\n              *ngIf=\"\r\n                (filterPrograms | FilterPrograms: searchModel).length >\r\n                  0;\r\n                else noFound\r\n              \"\r\n            >\r\n              <ng-container\r\n                *ngFor=\"\r\n                  let content of filterPrograms | RandomProgram : data.order\r\n                    | FilterPrograms: searchModel;\r\n                  let init = index\r\n                \"\r\n              >\r\n                <div\r\n                  *ngIf=\"init < statusInit\"\r\n                  class=\"col-12 col-sm-6 col-md-4 col-lg-3\"\r\n                  style=\"margin-bottom: 40px;\"\r\n                >\r\n                  <div class=\"content-flex\">\r\n                    <div class=\"image\" *ngIf=\"content?.image?.length > 0\">\r\n                      <img\r\n                        [src]=\"\r\n                          content?.image[0].styles.large\r\n                            ? content?.image[0].styles.large\r\n                            : ''\r\n                        \"\r\n                        [alt]=\"\r\n                          content?.image[0].texts.alt\r\n                            ? content?.image[0].texts.alt\r\n                            : ''\r\n                        \"\r\n                        [title]=\"\r\n                          content?.image[0].texts.title\r\n                            ? content?.image[0].texts.title\r\n                            : ''\r\n                        \"\r\n                      />\r\n                    </div>\r\n                    <div class=\"box-description\">\r\n                      <h3\r\n                        class=\"h4\"\r\n                        *ngIf=\"content.title\"\r\n                        [innerHTML]=\"content.title\"\r\n                      ></h3>\r\n                      <div class=\"duration\" *ngIf=\"content?.duration\"\r\n                           [ngClass]=\"content.duration_class ? content.duration_class : ''\">\r\n                        <p>{{content.duration}}</p>\r\n                      </div>\r\n                      <ul *ngIf=\"content?.categories?.length > 0\">\r\n                        <li *ngFor=\"let cate of content.categories | slice:0:3\">\r\n                          {{ cate }}\r\n                        </li>\r\n                      </ul>\r\n                    </div>\r\n                    <div class=\"button-container\" *ngIf=\"content?.button?.length > 0\"\r\n                         [ngClass]=\"content.button[0].class ? content.button[0].class : ''\">\r\n                      <button *ngIf=\"content.button[0].link[0].name || content?.button[0].icon.length > 0\"\r\n                              [id]=\"\r\n                          content.button[0].id_element && data?.id_element\r\n                            ? identifier +\r\n                              '_' +\r\n                              data.id_element +\r\n                              '_' +\r\n                              content.button[0].id_element\r\n                            : ''\r\n                        \"\r\n                              (click)=\"\r\n                          sendData(content, identifier + '_' + data?.id_element)\r\n                        \"\r\n                      >\r\n                        <ng-container *ngIf=\"content?.button[0]?.link[0]?.name\">{{\r\n                          content.button[0].link[0].name\r\n                          }}</ng-container>\r\n                        <ng-container *ngIf=\"content?.button[0]?.icon?.length > 0\">\r\n                          <img class=\"btn-icons\"\r\n                               [src]=\"\r\n                              content?.button[0].icon[0].styles.large\r\n                                ? content?.button[0].icon[0].styles.large\r\n                                : ''\r\n                            \"\r\n                          />\r\n                        </ng-container>\r\n                      </button>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </ng-container>\r\n            </ng-container>\r\n            <ng-template #noFound>\r\n              <div class=\"no-found-content\">\r\n                {{textNoFound}}\r\n              </div>\r\n            </ng-template>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</section>\r\n"
    })
], SearchProgramsDescTablaComponent);

let ProgramDescTablaModule = class ProgramDescTablaModule {
};
ProgramDescTablaModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            IconsTextModule,
            DescriptionModule,
            NgbNavModule,
            PipesModule,
            FormsModule,
            InfiniteScrollModule,
            SharedModule
        ],
        declarations: [
            DetailProgramDescTablaComponent,
            ModalProgramDescTablaComponent,
            SearchProgramsDescTablaComponent
        ],
        exports: [
            DetailProgramDescTablaComponent,
            ModalProgramDescTablaComponent,
            SearchProgramsDescTablaComponent
        ],
        providers: []
    })
], ProgramDescTablaModule);

let FeaturesCarouselComponent = class FeaturesCarouselComponent {
    constructor(options) {
        this.options = options;
    }
    ngOnInit() {
        this.configBenefits = this.data ? this.options.configurationBenefits(this.data) : '';
    }
};
FeaturesCarouselComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], FeaturesCarouselComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], FeaturesCarouselComponent.prototype, "data", void 0);
FeaturesCarouselComponent = __decorate([
    Component({
        selector: 'dmmp-features-carousel',
        template: "<div\r\n  *ngIf=\"data?.visible\"\r\n  [id]=\"data?.id_element ?  identifier + '_' + data?.id_element : 'features'\"\r\n  [ngClass]=\" data?.class || 'features'\"\r\n  [style.backgroundColor]=\"data?.background_color?.color || ''\"\r\n  [style.opacity]=\"data?.background_color?.opacity || ''\"\r\n  [style.backgroundImage]=\"\r\n    (data?.background_image)?.length > 0\r\n      ? 'url(' + (data?.background_image)[0]?.styles?.large + ')'\r\n      : ''\r\n  \"\r\n  class=\"features-landing\"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data?.title_class || ''\">\r\n      {{ data?.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"data?.content?.length > 0\">\r\n      <owl-carousel-o [options]=\"configBenefits\" class=\"row\">\r\n        <ng-container *ngFor=\"let slide of data?.content\">\r\n          <ng-template carouselSlide>\r\n            <div class=\"col features-col\">\r\n              <div class=\"content-features\">\r\n                <p class=\"title-features\" *ngIf=\"slide?.title\" [ngClass]=\"slide?.title_class || ''\">\r\n                  {{slide?.title}}\r\n                </p>\r\n                <h3 *ngIf=\"slide?.sub_title\" [ngClass]=\"slide?.sub_title_class || ''\">\r\n                  {{slide?.sub_title}}\r\n                </h3>\r\n                <div class=\"description-features\" *ngIf=\"slide?.description\"\r\n                     [ngClass]=\"slide?.description_class || ''\"\r\n                     [innerHTML]=\"slide?.description\"></div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </owl-carousel-o>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n"
    })
], FeaturesCarouselComponent);

let FeaturesCarouselModule = class FeaturesCarouselModule {
};
FeaturesCarouselModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CarouselModule,
            CommonModule,
            TitleModule
        ],
        declarations: [FeaturesCarouselComponent],
        exports: [
            FeaturesCarouselComponent
        ],
        providers: [
            OptionsNgxOwCarouselService
        ]
    })
], FeaturesCarouselModule);

let ImagesEventCarouselComponent = class ImagesEventCarouselComponent {
    constructor(options) {
        this.options = options;
    }
    ngOnInit() {
        this.configBenefits = this.options.configurationBenefits(this.data);
    }
};
ImagesEventCarouselComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], ImagesEventCarouselComponent.prototype, "data", void 0);
__decorate([
    Input()
], ImagesEventCarouselComponent.prototype, "identifier", void 0);
ImagesEventCarouselComponent = __decorate([
    Component({
        selector: 'dmmp-images-event-carousel',
        template: "<div *ngIf=\"data?.visible\"\r\n     [id]=\" data.id_element ? identifier + '_' + data.id_element : 'carrousel_images_landing_event'\"\r\n     [style.backgroundImage]=\" (data.background_image).length > 0 ? 'url(' + (data.background_image)[0].styles.large + ')' : ''\"\r\n     [style.backgroundColor]=\" data.background_color.color ? data.background_color.color : '#ffffff'\"\r\n     class=\"carrousel-images-landing-event\" [ngClass]=\"data?.class\">\r\n  <div class=\"container\">\r\n    <div class=\"row\" *ngIf=\"data?.texts?.length > 0\">\r\n      <div class=\"col text-center\">\r\n        <!--<dmmp-title [title]=\"data.name\" [as_h1]=\"data.as_h1\" [class]=\"'h2'\"></dmmp-title>-->\r\n        <div [innerHTML]=\"data.texts[0].text\" [ngClass]=\"data.texts[0].class\"></div>\r\n      </div>\r\n    </div>\r\n    <ng-container *ngIf=\"data?.content?.items_carrusel?.length > 0\">\r\n      <owl-carousel-o [options]=\"configBenefits\" class=\"row\">\r\n        <ng-container *ngFor=\"let slide of data.content.items_carrusel\">\r\n          <ng-template carouselSlide>\r\n            <div class=\"col image-event-col\">\r\n              <div class=\"slide\">\r\n                <div class=\"image-event-img\">\r\n                  <img *ngIf=\"slide?.image\"\r\n                       [src]=\"slide.image[0].styles.large\"\r\n                       [alt]=\"slide.image[0].texts.alt\"\r\n                       [title]=\"slide.image[0].texts.title\"/>\r\n                </div>\r\n                <div class=\"image-event-text\" [innerHTML]=\"slide.title ? slide.title : ''\"></div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </owl-carousel-o>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n"
    })
], ImagesEventCarouselComponent);

let ImagesEventCarouselModule = class ImagesEventCarouselModule {
};
ImagesEventCarouselModule = __decorate([
    NgModule({
        declarations: [ImagesEventCarouselComponent],
        imports: [
            CommonModule,
            BrowserAnimationsModule,
            BrowserModule,
            CarouselModule,
            CommonModule,
        ],
        exports: [ImagesEventCarouselComponent],
    })
], ImagesEventCarouselModule);

let BenefitsFiguresComponent = class BenefitsFiguresComponent {
    constructor() {
        this.medias = [
            { style: 'thumbnail', media: '(min-width: 250px)' }
        ];
    }
};
__decorate([
    Input()
], BenefitsFiguresComponent.prototype, "data", void 0);
__decorate([
    Input()
], BenefitsFiguresComponent.prototype, "identifier", void 0);
BenefitsFiguresComponent = __decorate([
    Component({
        selector: 'dmmp-benefits-figures',
        template: "<dmmp-container\r\n  [data]=\"data\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'benefits-figures'\"\r\n>\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"data?.name\"\r\n        [ngClass]=\"data?.title_class || ''\">\r\n      {{ data?.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"data?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of data?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <ng-container\r\n      *ngIf=\"data?.benefits_figures?.length > 0\"\r\n    >\r\n      <div class=\"row row-figures\">\r\n        <div class=\"col-12 col-md\" *ngFor=\"let figures of data?.benefits_figures\">\r\n          <div class=\"box-content-figures\">\r\n            <ng-container *ngIf=\"figures?.image?.length > 0\">\r\n              <div class=\"box-figures\">\r\n                <dmmp-image\r\n                  [images]=\"figures?.image[0]\" [medias]=\"medias\" [defaultClass]=\"'image-figure'\">\r\n                </dmmp-image>\r\n              </div>\r\n            </ng-container>\r\n            <ng-container *ngIf=\"figures?.cifra\">\r\n              <div class=\"box-cifra\">\r\n                <p class=\"h1\" [ngClass]=\"figures?.class || ''\">\r\n                  {{ figures?.cifra }}\r\n                </p>\r\n              </div>\r\n            </ng-container>\r\n          </div>\r\n          <div class=\"box-description-figures h4\" [ngClass]=\"figures?.class || ''\">\r\n            <ng-container *ngIf=\"figures?.text\">\r\n              <div [outerHTML]=\"figures?.text\"></div>\r\n            </ng-container>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"data?.content?.length > 0\">\r\n      <div class=\"row\">\r\n        <div class=\"col-12 col-md\" *ngFor=\"let benefits of data?.content\"\r\n             [ngClass]=\"benefits?.class || ''\">\r\n          <div class=\"box-image\" *ngIf=\"benefits?.images?.length > 0\">\r\n            <dmmp-image\r\n              [images]=\"benefits?.images[0]\" [medias]=\"medias\">\r\n            </dmmp-image>\r\n          </div>\r\n          <div class=\"box-text\">\r\n            <ng-container *ngIf=\"benefits?.sub_title\">\r\n              <div class=\"box-sub-title\">\r\n                <h3 [ngClass]=\"benefits?.sub_title_class || ''\">{{benefits?.sub_title}}</h3>\r\n              </div>\r\n            </ng-container>\r\n            <div\r\n              class=\"box-description\"\r\n              *ngIf=\"benefits?.description\"\r\n              [innerHTML]=\"benefits?.description\"\r\n            ></div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n      <div class=\"row content-button\" *ngIf=\"data?.see_more?.length > 0\">\r\n        <dmmp-button [data]=\"data?.see_more[0]\"></dmmp-button>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], BenefitsFiguresComponent);

let BenefitsFiguresModule = class BenefitsFiguresModule {
};
BenefitsFiguresModule = __decorate([
    NgModule({
        declarations: [BenefitsFiguresComponent],
        exports: [BenefitsFiguresComponent],
        imports: [CommonModule, SharedModule],
    })
], BenefitsFiguresModule);

let TestimonyStoriesComponent = class TestimonyStoriesComponent {
};
__decorate([
    Input()
], TestimonyStoriesComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], TestimonyStoriesComponent.prototype, "data", void 0);
__decorate([
    Input()
], TestimonyStoriesComponent.prototype, "detailLayout", void 0);
TestimonyStoriesComponent = __decorate([
    Component({
        selector: 'dmmp-testimony-stories',
        template: "<dmmp-container\r\n  [data]=\"data\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'testimony-stories container-fluid'\"\r\n>\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <div\r\n        [ngClass]=\"\r\n          detailLayout.columns_content\r\n            ? 'col-' + detailLayout.columns_content\r\n            : 'col-12'\r\n        \"\r\n      >\r\n        <h2\r\n          *ngIf=\"data?.name\"\r\n          [ngClass]=\"data.title_class ? data.title_class : ''\"\r\n        >\r\n          {{ data.name }}\r\n        </h2>\r\n      </div>\r\n    </div>\r\n    <ng-container\r\n      *ngIf=\"\r\n        (data?.content && data?.content?.length > 0) ||\r\n        (detailLayout?.testimonials && detailLayout?.testimonials?.length > 0)\r\n      \"\r\n    >\r\n      <dmmp-testimony\r\n        [data]=\"data\"\r\n        [detailLayout]=\"detailLayout\"\r\n      ></dmmp-testimony>\r\n    </ng-container>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], TestimonyStoriesComponent);

let TestimonyComponent = class TestimonyComponent {
    constructor() {
        this.medias = [
            { style: 'large', media: '(min-width:1301px)' },
            { style: 'max_1300x1300', media: '(min-width:651px) AND (max-width:1300px)' },
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width:326px)' },
            { style: 'max_325x325', media: '(max-width:325px)' },
        ];
    }
    ngOnInit() {
        this.data.content && this.data.content.length > 0
            ? (this.testimonials = this.data.content)
            : (this.testimonials = this.detailLayout.testimonials);
    }
};
__decorate([
    Input()
], TestimonyComponent.prototype, "data", void 0);
__decorate([
    Input()
], TestimonyComponent.prototype, "detailLayout", void 0);
TestimonyComponent = __decorate([
    Component({
        selector: 'dmmp-testimony',
        template: "<ng-container *ngIf=\"data?.vertical_view; else normalTestimony\">\r\n  <div class=\"row testimony-content testimony-vertical\">\r\n    <div\r\n      class=\"col-12\"\r\n      [ngClass]=\"\r\n        detailLayout?.columns_content\r\n          ? 'col-md-' + detailLayout?.columns_content\r\n          : 'col-md-12'\r\n      \"\r\n      *ngFor=\"let testimony of testimonials\"\r\n    >\r\n      <div [class]=\"testimony?.class\" *ngIf=\"testimony\" class=\"row\">\r\n        <div\r\n          class=\"author-image col-auto\"\r\n          *ngIf=\"testimony?.author_image?.length > 0\"\r\n        >\r\n          <dmmp-image\r\n            [images]=\"testimony?.author_image[0]?.image[0]\"\r\n            [medias]=\"medias\">\r\n          </dmmp-image>\r\n\r\n        </div>\r\n        <div class=\"author-testimony col-12 col-md-8\">\r\n          <p class=\"p1\">{{ testimony.title }}</p>\r\n          <div\r\n            *ngIf=\"testimony?.author?.length > 0\"\r\n            [innerHTML]=\"testimony?.author[0]?.text\"\r\n            [id]=\"testimony?.author[0]?.identifier\"\r\n            [class]=\"testimony?.author[0]?.class\"\r\n          ></div>\r\n          <div\r\n            *ngIf=\"testimony?.profession?.length > 0\"\r\n            [innerHTML]=\"testimony?.profession[0]?.text\"\r\n            [id]=\"testimony?.profession[0]?.identifier\"\r\n            [class]=\"testimony?.profession[0]?.class\"\r\n          ></div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n<ng-template #normalTestimony>\r\n  <div class=\"row testimony-content\">\r\n    <div\r\n      class=\"col-12 col-xs-12 col-md-4 col-lg-4\"\r\n      *ngFor=\"let testimony of testimonials\"\r\n    >\r\n      <div [class]=\"testimony?.class\" *ngIf=\"testimony\" class=\"row\">\r\n        <div\r\n          class=\"author-image col-4\"\r\n          *ngIf=\"testimony?.author_image?.length > 0\"\r\n        >\r\n          <dmmp-image\r\n            [images]=\"testimony?.author_image[0]?.image[0]\"\r\n            [medias]=\"medias\">\r\n          </dmmp-image>\r\n        </div>\r\n        <div class=\"author-testimony col-8\">\r\n          <p class=\"p1\">{{ testimony.title }}</p>\r\n          <div class=\"author-info\">\r\n            <div class=\"name\"\r\n              *ngIf=\"testimony?.author?.length > 0\"\r\n              [innerHTML]=\"testimony?.author[0]?.text\"\r\n              [id]=\"testimony?.author[0]?.identifier\"\r\n              [class]=\"testimony?.author[0]?.class\"\r\n            ></div>\r\n            <div class=\"profession\"\r\n              *ngIf=\"testimony?.profession?.length > 0\"\r\n              [innerHTML]=\"testimony?.profession[0]?.text\"\r\n              [id]=\"testimony?.profession[0]?.identifier\"\r\n              [class]=\"testimony?.profession[0]?.class\"\r\n            ></div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n"
    })
], TestimonyComponent);

let TestimonyStoriesModule = class TestimonyStoriesModule {
};
TestimonyStoriesModule = __decorate([
    NgModule({
        declarations: [TestimonyStoriesComponent, TestimonyComponent],
        imports: [CommonModule, SharedModule],
        exports: [TestimonyStoriesComponent],
    })
], TestimonyStoriesModule);

let ButtonComponent$1 = class ButtonComponent {
    constructor() {
        this.submitValidation = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], ButtonComponent$1.prototype, "field", void 0);
__decorate([
    Input()
], ButtonComponent$1.prototype, "identifier", void 0);
__decorate([
    Input()
], ButtonComponent$1.prototype, "loading", void 0);
__decorate([
    Input()
], ButtonComponent$1.prototype, "form", void 0);
__decorate([
    Input()
], ButtonComponent$1.prototype, "group", void 0);
__decorate([
    Output()
], ButtonComponent$1.prototype, "submitValidation", void 0);
ButtonComponent$1 = __decorate([
    Component({
        selector: 'dmmp-form-button',
        template: "<ng-container [formGroup]=\"group\">\r\n  <button\r\n    [type]=\"field?.name === 'combinate' ? 'button' : field?.name\"\r\n    [ngClass]=\"field?.class || ''\"\r\n    [id]=\"identifier + '_' + field?.idHtml\"\r\n    (click)=\"field.name === 'button' || field.name === 'combinate' ? submitValidation.emit({status: true, field: field?.name}) : ''\"\r\n    [disabled]=\"field?.name === 'submit' || field?.name === 'combinate' ? loading : false\"\r\n  >\r\n    {{ field.label }}\r\n    <img\r\n      *ngIf=\"loading\"\r\n      class=\"btn-icons\"\r\n      [src]=\"\r\n          form?.image?.length > 0 &&\r\n          form?.image[0]?.styles?.large\r\n            ? form?.image[0]?.styles?.large\r\n            : '../../../../assets/images/spinner-search.svg'\r\n        \"\r\n      [ngClass]=\"form?.class || ''\"\r\n      [alt]=\"\r\n          form?.image?.length > 0 &&\r\n          form?.image[0]?.texts?.alt\r\n            ? form?.image[0]?.texts?.alt\r\n            : ''\r\n        \"\r\n      [title]=\"\r\n          form?.image.length > 0 &&\r\n          form?.image[0]?.texts?.title\r\n            ? form?.image[0]?.texts?.title\r\n            : ''\r\n        \"\r\n    />\r\n  </button>\r\n</ng-container>\r\n"
    })
], ButtonComponent$1);

let CheckboxComponent = class CheckboxComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], CheckboxComponent.prototype, "field", void 0);
__decorate([
    Input()
], CheckboxComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], CheckboxComponent.prototype, "terms", void 0);
__decorate([
    Input()
], CheckboxComponent.prototype, "group", void 0);
CheckboxComponent = __decorate([
    Component({
        selector: 'dmmp-form-checkbox',
        template: "<ng-container [formGroup]=\"group\">\r\n  <div\r\n    class=\"custom-control custom-checkbox box-input\"\r\n    [ngClass]=\"\r\n      group.get(field?.name).valid\r\n        ? 'valid'\r\n        : group.get(field?.name).touched\r\n        ? 'invalid'\r\n        : ''\r\n    \"\r\n  >\r\n    <input\r\n      class=\"custom-control-input\"\r\n      type=\"checkbox\"\r\n      [formControlName]=\"field?.name || ''\"\r\n      [ngClass]=\"field?.class || ''\"\r\n      [id]=\"identifier + '_' + field?.idHtml\"\r\n      [value]=\"null\"\r\n    />\r\n    <label class=\"custom-control-label\" [id]=\"field?.idHtml + '_label_accepted'\"\r\n           [for]=\"identifier + '_' + field?.idHtml\"\r\n           [ngClass]=\"field?.class || ''\">\r\n        <span (click)=\"terms ? (openModal = true) : ''\">{{\r\n          field?.label\r\n          }}</span>\r\n    </label>\r\n\r\n    <ng-container>\r\n      <div\r\n        class=\"error-field\"\r\n        *ngIf=\"\r\n          group.get(field?.name).invalid &&\r\n          (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n        \"\r\n      >\r\n        {{ field?.validations?.message }}\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</ng-container>\r\n<dmmp-modal\r\n  [openModal]=\"openModal\"\r\n  [locationVertical]=\"'modal-dialog-scrollable'\"\r\n  (showModal)=\"openModal = $event\">\r\n  <dmmp-pdf-viewer\r\n    [pdfSrc]=\"terms\"\r\n    [defaultClass]=\"'modal-embed'\"\r\n  ></dmmp-pdf-viewer>\r\n</dmmp-modal>\r\n"
    })
], CheckboxComponent);

let SurveyComponent = class SurveyComponent {
    constructor() {
        this.changeModel = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], SurveyComponent.prototype, "survey", void 0);
__decorate([
    Output()
], SurveyComponent.prototype, "changeModel", void 0);
SurveyComponent = __decorate([
    Component({
        selector: 'dmmp-form-survey',
        template: "<!-- Encuesta -->\r\n<ng-container *ngIf=\"survey?.question && survey?.options.length > 0\">\r\n  <div class=\"survey\">\r\n    <label class=\"label-form\">{{ survey?.question }}</label>\r\n    <div class=\"row box-radios\">\r\n      <div class=\"col\" *ngFor=\"let options of survey?.options; let i = index\">\r\n        <input\r\n          type=\"radio\"\r\n          (change)=\"changeModel.emit($event)\"\r\n          name=\"survey\"\r\n          [id]=\"'survey_' + i\"\r\n          [value]=\"options?.value\"\r\n        />\r\n        <label [htmlFor]=\"'survey_' + i\">{{ options?.label }}</label>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n"
    })
], SurveyComponent);

let TextLinkComponent = class TextLinkComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], TextLinkComponent.prototype, "textLink", void 0);
TextLinkComponent = __decorate([
    Component({
        selector: 'dmmp-form-text-link',
        template: "<div class=\"content-copy-link\" *ngIf=\"textLink\">\r\n  <div class=\"content-box\" [ngClass]=\"textLink?.class || ''\">\r\n    <div\r\n      class=\"description\"\r\n      [innerHTML]=\"textLink?.text || ''\"\r\n    ></div>\r\n    <a\r\n      *ngIf=\"textLink?.label\"\r\n      [href]=\"textLink?.link || ''\"\r\n      target=\"_blank\"\r\n    >\r\n      {{ textLink?.label }}\r\n    </a>\r\n  </div>\r\n</div>\r\n"
    })
], TextLinkComponent);

let InputComponent = class InputComponent {
    constructor() {
        this.changeValueInput = new EventEmitter();
    }
    ngOnInit() {
    }
    ngOnChanges(changes) {
        var _a;
        if (this.fieldData) {
            this.group.get((_a = this.field) === null || _a === void 0 ? void 0 : _a.name).setValue(this.fieldData);
        }
    }
    filterInput(event) {
        return event.keyCode !== 69;
    }
};
__decorate([
    Input()
], InputComponent.prototype, "field", void 0);
__decorate([
    Input()
], InputComponent.prototype, "fieldData", void 0);
__decorate([
    Input()
], InputComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], InputComponent.prototype, "group", void 0);
__decorate([
    Output()
], InputComponent.prototype, "changeValueInput", void 0);
InputComponent = __decorate([
    Component({
        selector: 'dmmp-form-input',
        template: "<ng-container [formGroup]=\"group\">\r\n  <div\r\n    class=\"box-input\"\r\n    [ngClass]=\"\r\n      group.get(field?.name).valid\r\n        ? 'valid'\r\n        : group.get(field?.name).touched\r\n        ? 'invalid'\r\n        : ''\r\n    \"\r\n  >\r\n    <label *ngIf=\"field?.label\" class=\"label-form\">{{ field?.label }}</label>\r\n   <div class=\"input-content\">\r\n     <div *ngIf=\"field?.prefix_label && showLabelPrefix\" class=\"prefix-label\">{{field?.prefix_label}}<span></span></div>\r\n     <input\r\n       class=\"input-custom\"\r\n       [type]=\"field?.inputType\"\r\n       [formControlName]=\" field?.name || ''\"\r\n       [placeholder]=\"field?.placeholder || ''\"\r\n       (keydown)=\"field?.inputType === 'number' ? filterInput($event) : null\"\r\n       [ngClass]=\"[field?.class || '', field?.prefix_label ? 'input-prefix' : '']\"\r\n       [id]=\"identifier + '_' + field?.idHtml\"\r\n       (keyup)=\"changeValueInput.emit(field?.name)\"\r\n       (focusin)=\"showLabelPrefix = true\"\r\n       (focusout)=\"showLabelPrefix = false\"\r\n     />\r\n   </div>\r\n    <ng-container>\r\n      <div\r\n        class=\"error-field\"\r\n        *ngIf=\"\r\n          group.get(field?.name).invalid &&\r\n          (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n        \"\r\n      >\r\n        {{ field?.validations?.message }}\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</ng-container>\r\n"
    })
], InputComponent);

let SelectComponent = class SelectComponent {
    constructor() {
        this.changeSelect = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], SelectComponent.prototype, "field", void 0);
__decorate([
    Input()
], SelectComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SelectComponent.prototype, "group", void 0);
__decorate([
    Input()
], SelectComponent.prototype, "fieldData", void 0);
__decorate([
    Input()
], SelectComponent.prototype, "formSelects", void 0);
__decorate([
    Input()
], SelectComponent.prototype, "formSelectFilter", void 0);
__decorate([
    Output()
], SelectComponent.prototype, "changeSelect", void 0);
SelectComponent = __decorate([
    Component({
        selector: 'dmmp-form-select',
        template: "<ng-container [formGroup]=\"group\">\r\n  <div class=\"box-input\">\r\n    <label *ngIf=\"field?.label\" class=\"label-form\">{{ field?.label }}</label>\r\n    <ng-container>\r\n      <div\r\n        class=\"box-select\"\r\n        [ngClass]=\"\r\n          group.get(field?.name).valid\r\n            ? 'valid'\r\n            : group.get(field?.name).touched\r\n            ? 'invalid'\r\n            : ''\r\n        \"\r\n      >\r\n        <select\r\n          *ngIf=\"field.data\"\r\n          [formControlName]=\"field?.name || ''\"\r\n          (change)=\"changeSelect.emit({value: $event, field: field})\"\r\n          [ngClass]=\"field?.class || ''\"\r\n          [id]=\"identifier + '_' + field?.idHtml\"\r\n          class=\"select-custom\"\r\n        >\r\n          <option [ngValue]=\"null\" disabled hidden>{{\r\n            field?.placeholder\r\n            }}</option>\r\n          <ng-container\r\n            *ngIf=\"\r\n              field?.data?.length === 1 && !field?.data[0]?.identifier;\r\n              else dependence\r\n            \"\r\n          >\r\n            <option\r\n              *ngFor=\"let item of field?.data[0]?.options\"\r\n              [value]=\"\r\n                field.name === 'programTypes'\r\n                  ? item?.code + '|' + item?.opportunityType\r\n                  : field?.name === 'modality'\r\n                  ? item?.code\r\n                  : field?.name === 'campus'\r\n                  ? item?.code === '0'\r\n                    ? 'cero'\r\n                    : item?.code\r\n                  : field?.name === 'program'\r\n                  ? item?.code + '|' + item?.sublist\r\n                  : (item | json)\r\n              \"\r\n            >\r\n              {{ item?.name }}\r\n            </option>\r\n          </ng-container>\r\n          <ng-template #dependence>\r\n            <ng-container *ngFor=\"let opt of field?.data\">\r\n              <ng-container\r\n                *ngFor=\"let sl of formSelects\"\r\n              >\r\n                <ng-container *ngIf=\"opt?.identifier === sl?.identifier\">\r\n                  <ng-container *ngIf=\"field?.name === 'program'; else other\">\r\n                    <ng-container *ngFor=\"let item of opt?.options\">\r\n                      <option\r\n                        *ngIf=\"\r\n                          item?.filter === formSelectFilter\r\n                        \"\r\n                        [value]=\"item?.code + '|' + item?.sublist\"\r\n                      >\r\n                        {{ item?.name }}</option\r\n                      >\r\n                    </ng-container>\r\n                  </ng-container>\r\n                  <ng-template #other>\r\n                    <option\r\n                      *ngFor=\"let item of opt?.options\"\r\n                      [value]=\"\r\n                        field?.name === 'programTypes'\r\n                          ? item?.code + '|' + item?.opportunityType\r\n                          : field?.name === 'modality'\r\n                          ? item?.code\r\n                          : field?.name === 'campus'\r\n                          ? item?.code === '0'\r\n                            ? 'cero'\r\n                            : item?.code\r\n                          : field?.name === 'program'\r\n                          ? item?.code + '|' + item?.sublist\r\n                          : (item | json)\r\n                      \"\r\n                    >\r\n                      {{ item?.name }}\r\n                    </option>\r\n                  </ng-template>\r\n                </ng-container>\r\n              </ng-container>\r\n            </ng-container>\r\n          </ng-template>\r\n        </select>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container>\r\n      <div\r\n        class=\"error-field\"\r\n        *ngIf=\"\r\n          group.get(field?.name).invalid &&\r\n          (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n        \"\r\n      >\r\n        {{ field?.validations?.message }}\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</ng-container>\r\n"
    })
], SelectComponent);

let RadioComponent = class RadioComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], RadioComponent.prototype, "field", void 0);
__decorate([
    Input()
], RadioComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], RadioComponent.prototype, "group", void 0);
RadioComponent = __decorate([
    Component({
        selector: 'dmmp-form-radio',
        template: "<ng-container [formGroup]=\"group\">\r\n  <div\r\n    class=\"box-input\"\r\n    [ngClass]=\"\r\n      group.get(field?.name).valid\r\n        ? 'valid'\r\n        : group.get(field?.name).touched\r\n        ? 'invalid'\r\n        : ''\r\n    \"\r\n  >\r\n    <label [ngClass]=\"field.class || ''\">{{ field?.label }}</label>\r\n    <ng-container *ngIf=\"field?.values?.length > 0\">\r\n      <ng-container *ngFor=\"let radio of field?.values\">\r\n        <div class=\"custom-control custom-radio\">\r\n          <input\r\n            type=\"radio\"\r\n            class=\"custom-control-input\"\r\n            name=\"{{ field?.name }}\"\r\n            [id]=\"identifier + '_' + field?.idHtml + '_' + radio\"\r\n            [value]=\"radio\"\r\n            [formControlName]=\"field?.name || ''\"\r\n            [ngClass]=\"field?.class || ''\"\r\n          />\r\n          <label\r\n            class=\"custom-control-label\"\r\n            [for]=\"identifier + '_' + field?.idHtml + '_' + radio\"\r\n            >{{ radio }}</label\r\n          >\r\n        </div>\r\n      </ng-container>\r\n    </ng-container>\r\n  </div>\r\n  <ng-container>\r\n    <div\r\n      class=\"error-field\"\r\n      *ngIf=\"\r\n        group.get(field?.name).invalid &&\r\n        (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n      \"\r\n    >\r\n      {{ field?.validations?.message }}\r\n    </div>\r\n  </ng-container>\r\n</ng-container>\r\n"
    })
], RadioComponent);

let EventsComponent = class EventsComponent {
    constructor(parent) {
        this.parent = parent;
        this.dateAct = Math.round(new Date().getTime() / 1000);
        this.textInfo = ' Elige las actividades a las que quieres asistir';
        this.formParent = parent.form;
    }
    ngOnInit() {
    }
    ngOnChanges() {
    }
    onCheckboxChange(e, SubEvent) {
        const checkArray = this.form.get('checkSubEvent');
        if (e.target.checked) {
            checkArray.push(new FormControl(SubEvent));
            this.formParent.setControl('events', checkArray);
        }
        else {
            checkArray.controls.forEach((item, index) => {
                if (item.value === SubEvent) {
                    checkArray.removeAt(index);
                    return;
                }
            });
        }
    }
};
EventsComponent.ctorParameters = () => [
    { type: FormGroupDirective }
];
__decorate([
    Input()
], EventsComponent.prototype, "field", void 0);
__decorate([
    Input()
], EventsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], EventsComponent.prototype, "form", void 0);
__decorate([
    Input()
], EventsComponent.prototype, "dateFilter", void 0);
__decorate([
    Input()
], EventsComponent.prototype, "subEventsInput", void 0);
__decorate([
    Input()
], EventsComponent.prototype, "invalidEvents", void 0);
__decorate([
    Input()
], EventsComponent.prototype, "textInfo", void 0);
EventsComponent = __decorate([
    Component({
        selector: 'dmmp-form-events',
        template: "<div\r\n  class=\"sub-events-form\"\r\n  [ngClass]=\"field?.class || ''\"\r\n  [id]=\"field?.idHtml ? identifier + '_' + field?.idHtml : ''\"\r\n>\r\n  <ng-container\r\n    [formGroup]=\"form\"\r\n  >\r\n    <div class=\"content-full\">\r\n      <h3 *ngIf=\"field?.label\" class=\"h3 label-form-event\">\r\n        {{ field?.label }}\r\n      </h3>\r\n      <ngb-accordion\r\n        [closeOthers]=\"true\"\r\n        activeIds=\"static-0\"\r\n        [destroyOnHide]=\"false\"\r\n      >\r\n        <ngb-panel\r\n          *ngFor=\"let eventGene of dateFilter; let i = index\"\r\n          id=\"static-{{ i }}\"\r\n        >\r\n          <ng-template ngbPanelTitle>\r\n            <div class=\"content\">\r\n              <div class=\"col-title\">\r\n                <h4 class=\"p2\">\r\n                  {{ eventGene?.label }}\r\n                </h4>\r\n                <p class=\"small-text\" *ngIf=\"textInfo\">\r\n                 {{textInfo}}\r\n                </p>\r\n              </div>\r\n              <div class=\"col-title\">\r\n                <div class=\"icono\">\r\n                  <img src=\"assets/images/arrow-acor.svg\" />\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n          <ng-template ngbPanelContent>\r\n            <ng-container *ngIf=\"subEventsInput\">\r\n              <div\r\n                class=\"input-container\"\r\n                *ngFor=\"\r\n                  let event of subEventsInput | Event: eventGene;\r\n                  let u = index\r\n                \"\r\n              >\r\n                <ng-container\r\n                  *ngIf=\"event?.date?.start > dateAct; else expiredEvent\"\r\n                >\r\n                  <div class=\"custom-control custom-checkbox\">\r\n                    <input\r\n                      class=\"custom-control-input\"\r\n                      id=\"check-{{ i }}-{{ u }}\"\r\n                      type=\"checkbox\"\r\n                      (change)=\"onCheckboxChange($event, event)\"\r\n                    />\r\n                    <label\r\n                      class=\"custom-control-label\"\r\n                      for=\"check-{{ i }}-{{ u }}\"\r\n                    >\r\n                      <span class=\"p2\"\r\n                      ><strong>{{ event?.title }}</strong\r\n                      >. {{ event?.date?.showStar | date: 'HH:mm':'UTC' }} h.\r\n                        Sede {{ event?.campus }}. Campus</span\r\n                      >\r\n                    </label>\r\n                  </div>\r\n                </ng-container>\r\n                <ng-template #expiredEvent>\r\n                  <span\r\n                  ><strong>{{ event?.title }}</strong\r\n                  >. {{ event?.date?.showStar | date: 'HH:mm':'UTC' }} h. Sede\r\n                    {{ event?.campus }}. Campus</span\r\n                  >\r\n                </ng-template>\r\n              </div>\r\n            </ng-container>\r\n          </ng-template>\r\n        </ngb-panel>\r\n      </ngb-accordion>\r\n      <ng-container>\r\n        <div class=\"error-field\" *ngIf=\"invalidEvents\">\r\n          {{ field?.validations?.message }}\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n  </ng-container>\r\n</div>\r\n"
    })
], EventsComponent);

let EventPipe = class EventPipe {
    transform(items, dateModelSearch) {
        if (!items) {
            return [];
        }
        if (!dateModelSearch) {
            return items;
        }
        return items.filter(item => {
            return (item.date.start >= dateModelSearch.start &&
                item.date.start <= dateModelSearch.end);
        });
    }
};
EventPipe = __decorate([
    Pipe({
        name: 'Event',
    })
], EventPipe);

let InputInsideValidationsComponent = class InputInsideValidationsComponent {
    constructor() {
        this.changeValueInput = new EventEmitter();
    }
    ngOnInit() {
    }
    ngOnChanges(changes) {
        var _a;
        if (this.fieldData) {
            this.group.get((_a = this.field) === null || _a === void 0 ? void 0 : _a.name).setValue(this.fieldData);
        }
    }
    filterInput(event) {
        return event.keyCode !== 69;
    }
};
__decorate([
    Input()
], InputInsideValidationsComponent.prototype, "field", void 0);
__decorate([
    Input()
], InputInsideValidationsComponent.prototype, "fieldData", void 0);
__decorate([
    Input()
], InputInsideValidationsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], InputInsideValidationsComponent.prototype, "spinnerInput", void 0);
__decorate([
    Input()
], InputInsideValidationsComponent.prototype, "group", void 0);
__decorate([
    Output()
], InputInsideValidationsComponent.prototype, "changeValueInput", void 0);
InputInsideValidationsComponent = __decorate([
    Component({
        selector: 'dmmp-form-input-inside-validations',
        template: "<ng-container [formGroup]=\"group\">\r\n  <div\r\n    class=\"box-input\"\r\n    [ngClass]=\"\r\n      group.get(field?.name).valid\r\n        ? 'valid'\r\n        : group.get(field?.name).touched\r\n        ? 'invalid'\r\n        : ''\r\n    \"\r\n  >\r\n    <label *ngIf=\"field?.label\" class=\"label-form\">{{ field?.label }}</label>\r\n    <div class=\"input-content\">\r\n      <div *ngIf=\"field?.prefix_label && showLabelPrefix\" class=\"prefix-label\">{{field?.prefix_label}}<span></span>\r\n      </div>\r\n      <input\r\n        class=\"input-custom\"\r\n        [type]=\"field?.inputType\"\r\n        [formControlName]=\"field.name || ''\"\r\n        [placeholder]=\"\r\n        group.get(field?.name).invalid && (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n          ? (field?.validations?.message || '')\r\n          : (field?.placeholder || '')\r\n      \"\r\n        (keydown)=\"field?.inputType === 'number' ? filterInput($event) : null\"\r\n        [ngClass]=\"[\r\n          group.get(field?.name).invalid && (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n          ? 'error-field ' + (field?.class || '')\r\n          : (field?.class || ''),\r\n           field?.prefix_label ? 'input-prefix' : '']\"\r\n        [id]=\"identifier + '_' + field?.idHtml\"\r\n        (keyup)=\"changeValueInput.emit(field?.name)\"\r\n        (focusin)=\"showLabelPrefix = true\"\r\n        (focusout)=\"showLabelPrefix = false\"\r\n      />\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n"
    })
], InputInsideValidationsComponent);

let SelectInsideValidationsComponent = class SelectInsideValidationsComponent {
    constructor() {
        this.changeSelect = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], SelectInsideValidationsComponent.prototype, "field", void 0);
__decorate([
    Input()
], SelectInsideValidationsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SelectInsideValidationsComponent.prototype, "group", void 0);
__decorate([
    Input()
], SelectInsideValidationsComponent.prototype, "fieldData", void 0);
__decorate([
    Input()
], SelectInsideValidationsComponent.prototype, "formSelects", void 0);
__decorate([
    Input()
], SelectInsideValidationsComponent.prototype, "formSelectFilter", void 0);
__decorate([
    Output()
], SelectInsideValidationsComponent.prototype, "changeSelect", void 0);
SelectInsideValidationsComponent = __decorate([
    Component({
        selector: 'dmmp-form-select-inside-validations',
        template: "<ng-container [formGroup]=\"group\">\r\n  <div class=\"box-input\">\r\n    <label *ngIf=\"field?.label\" class=\"label-form\">{{ field?.label }}</label>\r\n    <ng-container>\r\n      <div\r\n        class=\"box-select\"\r\n        [ngClass]=\"\r\n          group.get(field?.name).valid ? 'valid' : (group.get(field?.name).touched\r\n            ? 'invalid'\r\n            : '')\r\n        \"\r\n      >\r\n        <select\r\n          [formControlName]=\"field?.name || ''\"\r\n          (change)=\"changeSelect.emit({value: $event, field: field})\"\r\n          [ngClass]=\"\r\n            group.get(field?.name).invalid &&\r\n            (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n              ? 'error-field ' + (field?.class || '')\r\n              : (field?.class || '')\r\n          \"\r\n          [id]=\"identifier + '_' + field?.idHtml\"\r\n          class=\"select-custom\"\r\n        >\r\n          <option [ngValue]=\"null\" disabled hidden>{{\r\n            field?.placeholder || ''\r\n            }}</option>\r\n          <ng-container\r\n            *ngIf=\"\r\n              field?.data?.length === 1 && !field?.data[0]?.identifier;\r\n              else dependence\r\n            \"\r\n          >\r\n            <option\r\n              *ngFor=\"let item of field?.data[0]?.options\"\r\n              [value]=\"\r\n                field?.name === 'programTypes'\r\n                  ? item?.code + '|' + item?.opportunityType\r\n                  : field?.name === 'modality'\r\n                  ? item?.code\r\n                  : field?.name === 'campus'\r\n                  ? item?.code === '0'\r\n                    ? 'cero'\r\n                    : item?.code\r\n                  : field?.name === 'program'\r\n                  ? item?.code + '|' + item?.sublist\r\n                  : (item | json)\r\n              \"\r\n            >\r\n              {{ item?.name }}\r\n            </option>\r\n          </ng-container>\r\n          <ng-template #dependence>\r\n            <ng-container *ngFor=\"let opt of field?.data\">\r\n              <ng-container\r\n                *ngFor=\"let sl of formSelects\"\r\n              >\r\n                <ng-container *ngIf=\"opt?.identifier === sl?.identifier\">\r\n                  <ng-container *ngIf=\"field?.name === 'program'; else other\">\r\n                    <ng-container *ngFor=\"let item of opt?.options\">\r\n                      <option\r\n                        *ngIf=\"\r\n                          item?.filter === formSelectFilter\r\n                        \"\r\n                        [value]=\"item?.code + '|' + item?.sublist\"\r\n                      >\r\n                        {{ item?.name }}</option\r\n                      >\r\n                    </ng-container>\r\n                  </ng-container>\r\n                  <ng-template #other>\r\n                    <option\r\n                      *ngFor=\"let item of opt?.options\"\r\n                      [value]=\"\r\n                        field?.name === 'programTypes'\r\n                          ? item?.code + '|' + item?.opportunityType\r\n                          : field?.name === 'modality'\r\n                          ? item?.code\r\n                          : field?.name === 'campus'\r\n                          ? item?.code === '0'\r\n                            ? 'cero'\r\n                            : item?.code\r\n                          : field?.name === 'program'\r\n                          ? item?.code + '|' + item?.sublist\r\n                          : (item | json)\r\n                      \"\r\n                    >\r\n                      {{ item?.name }}\r\n                    </option>\r\n                  </ng-template>\r\n                </ng-container>\r\n              </ng-container>\r\n            </ng-container>\r\n          </ng-template>\r\n        </select>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</ng-container>\r\n"
    })
], SelectInsideValidationsComponent);

let StepNumberComponent = class StepNumberComponent {
    constructor() {
        this.stepPrev = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], StepNumberComponent.prototype, "stepActive", void 0);
__decorate([
    Input()
], StepNumberComponent.prototype, "fieldSteps", void 0);
__decorate([
    Output()
], StepNumberComponent.prototype, "stepPrev", void 0);
StepNumberComponent = __decorate([
    Component({
        selector: 'dmmp-form-step-number',
        template: "<!-- Step Number -->\r\n<div class=\"steps-bullets\">\r\n  <div class=\"row no-gutters\">\r\n    <div class=\"col-auto btn-arrow btn-arrow-left\">\r\n      <button\r\n        type=\"button\"\r\n        [disabled]=\"stepActive === 1\"\r\n        (click)=\"stepPrev.emit()\"\r\n      >\r\n        <\r\n      </button>\r\n    </div>\r\n    <div class=\"col-auto\">\r\n      <div class=\"step-bullets-number\">\r\n        {{ stepActive }}/{{ fieldSteps }}\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], StepNumberComponent);

let StepDetailsComponent = class StepDetailsComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], StepDetailsComponent.prototype, "stepsDetails", void 0);
__decorate([
    Input()
], StepDetailsComponent.prototype, "stepActive", void 0);
StepDetailsComponent = __decorate([
    Component({
        selector: 'dmmp-form-step-details',
        template: "<div\r\n  class=\"steps-details\"\r\n  *ngIf=\"stepsDetails?.length > 0\">\r\n  <p class=\"step-title\">\r\n    {{ stepsDetails[stepActive - 1]?.title }}\r\n  </p>\r\n  <div class=\"row-step\">\r\n    <div\r\n      class=\"steps-item\"\r\n      *ngFor=\"let step_detail of stepsDetails; let u = index\"\r\n      [ngClass]=\"[u + 1 === stepActive ? 'step-current' : '', u + 1 <= stepActive ? 'active' : '']\"\r\n    >\r\n      <div\r\n        *ngIf=\"step_detail?.label\"\r\n        class=\"content-step\"\r\n        [ngClass]=\"step_detail?.class || ''\"\r\n      >\r\n        <div class=\"number\">{{ u + 1 }}</div>\r\n        <p>{{ step_detail?.label }}</p>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <p class=\"step-description\">\r\n    {{ stepsDetails[stepActive - 1]?.description }}\r\n  </p>\r\n</div>\r\n"
    })
], StepDetailsComponent);

let TextAreaComponent = class TextAreaComponent {
    constructor() {
        this.changeValueInput = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], TextAreaComponent.prototype, "field", void 0);
__decorate([
    Input()
], TextAreaComponent.prototype, "fieldData", void 0);
__decorate([
    Input()
], TextAreaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], TextAreaComponent.prototype, "group", void 0);
__decorate([
    Output()
], TextAreaComponent.prototype, "changeValueInput", void 0);
TextAreaComponent = __decorate([
    Component({
        selector: 'dmmp-form-text-area',
        template: "<ng-container [formGroup]=\"group\">\r\n  <div\r\n    class=\"box-text-area\"\r\n    [ngClass]=\"\r\n      group.get(field?.name).valid\r\n        ? 'valid'\r\n        : group.get(field?.name).touched\r\n        ? 'invalid'\r\n        : ''\r\n    \"\r\n  >\r\n    <label *ngIf=\"field?.label\" class=\"label-form\">{{ field?.label }}</label>\r\n    <textarea\r\n      class=\"input-custom\"\r\n      [formControlName]=\"field?.name || ''\"\r\n      [placeholder]=\"field?.placeholder || ''\"\r\n      [ngClass]=\"field?.class || ''\"\r\n      [id]=\"identifier + '_' + field?.idHtml\">\r\n    </textarea>\r\n    <ng-container>\r\n      <div\r\n        class=\"error-field\"\r\n        *ngIf=\"\r\n          group.get(field?.name).invalid &&\r\n          (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n        \"\r\n      >\r\n        {{ field?.validations?.message }}\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</ng-container>\r\n"
    })
], TextAreaComponent);

let CaptchaComponent = class CaptchaComponent {
    constructor() {
    }
    ngOnInit() {
    }
    updateValidation() {
        setTimeout(() => {
            this.captchaElem.resetCaptcha();
        }, 800);
    }
};
__decorate([
    Input()
], CaptchaComponent.prototype, "field", void 0);
__decorate([
    Input()
], CaptchaComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], CaptchaComponent.prototype, "keyCaptcha", void 0);
__decorate([
    Input()
], CaptchaComponent.prototype, "group", void 0);
__decorate([
    ViewChild('captchaElem')
], CaptchaComponent.prototype, "captchaElem", void 0);
CaptchaComponent = __decorate([
    Component({
        selector: 'dmmp-form-captcha',
        template: "<ng-container\r\n  [formGroup]=\"group\">\r\n  <div class=\"captcha\"\r\n       [ngClass]=\"field.class || ''\">\r\n    <label *ngIf=\"field?.label\" class=\"label\">{{ field?.label }}</label>\r\n    <ngx-recaptcha2 #captchaElem\r\n                    [siteKey]=\"keyCaptcha\"\r\n                    [useGlobalDomain]=\"true\"\r\n                    (load)=\"updateValidation()\"\r\n                    [formControlName]=\"field?.name || ''\">\r\n    </ngx-recaptcha2>\r\n    <ng-container>\r\n      <div\r\n        class=\"error-field\"\r\n        *ngIf=\"\r\n          group.get(field?.name).invalid &&\r\n          (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n        \">\r\n        {{ field?.validations?.message }}\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</ng-container>\r\n\r\n"
    })
], CaptchaComponent);

let FileComponent = class FileComponent {
    constructor() {
        this.sizeFilePermitted = 10485760;
        this.numberFilesPermitted = 3;
        this.arrayFilesRedux = new EventEmitter();
        this.arrayFilesAllRedux = new EventEmitter();
        this.changeFile = new EventEmitter();
        this.accept = '';
        this.classDisabled = '';
        this.arrayFiles = [];
        this.arrayFilesEnd = [];
    }
    ngOnChanges(changes) {
        var _a, _b, _c, _d, _e, _f;
        if ((_b = (_a = changes) === null || _a === void 0 ? void 0 : _a.arrayFilesReduxTemp) === null || _b === void 0 ? void 0 : _b.currentValue) {
            this.addArrayObjectEnd((_d = (_c = changes) === null || _c === void 0 ? void 0 : _c.arrayFilesReduxTemp) === null || _d === void 0 ? void 0 : _d.currentValue);
            this.arrayFiles = (_f = (_e = changes) === null || _e === void 0 ? void 0 : _e.arrayFilesReduxTemp) === null || _f === void 0 ? void 0 : _f.currentValue;
        }
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        if (((_b = (_a = this.field) === null || _a === void 0 ? void 0 : _a.validations) === null || _b === void 0 ? void 0 : _b.regularExpressions) && ((_e = (_d = (_c = this.field) === null || _c === void 0 ? void 0 : _c.validations) === null || _d === void 0 ? void 0 : _d.regularExpressions) === null || _e === void 0 ? void 0 : _e.length) > 0) {
            (_h = (_g = (_f = this.field) === null || _f === void 0 ? void 0 : _f.validations) === null || _g === void 0 ? void 0 : _g.regularExpressions) === null || _h === void 0 ? void 0 : _h.forEach(res => {
                var _a;
                this.accept = `${this.accept}, ${(_a = res) === null || _a === void 0 ? void 0 : _a.expression}`;
            });
        }
    }
    reset(event) {
        event.target.value = '';
    }
    onFilesChanged(event) {
        var _a, _b, _c;
        const files = (_b = (_a = event) === null || _a === void 0 ? void 0 : _a.target) === null || _b === void 0 ? void 0 : _b.files;
        if (((_c = files) === null || _c === void 0 ? void 0 : _c.length) > 0) {
            from(files)
                .pipe(concatMap((file) => this.obsReaderFile(file)), scan((acc, value) => [...acc, value], []), last(), tap(it => {
                var _a;
                this.arrayFiles = (_a = this.arrayFiles) === null || _a === void 0 ? void 0 : _a.filter((arrayFiles, index, array) => index ===
                    array.findIndex(arrayFilesRepeat => { var _a, _b; return ((_a = arrayFilesRepeat) === null || _a === void 0 ? void 0 : _a.name) === ((_b = arrayFiles) === null || _b === void 0 ? void 0 : _b.name); }));
                this.arrayFilesAllRedux.emit(this.arrayFiles);
            })).subscribe();
        }
    }
    obsReaderFile(file) {
        return new Observable(obs => {
            const reader = new FileReader();
            reader.onload = (e) => {
                var _a, _b, _c;
                this.arrayFiles.push({
                    name: (_a = file) === null || _a === void 0 ? void 0 : _a.name,
                    type: (_b = file) === null || _b === void 0 ? void 0 : _b.type,
                    size: (_c = file) === null || _c === void 0 ? void 0 : _c.size,
                    documentBody: btoa(e.target.result),
                });
                obs.next(btoa(e.target.result));
                obs.complete();
            };
            reader.readAsBinaryString(file);
        });
    }
    addArrayObjectEnd(files) {
        var _a, _b, _c, _d;
        this.arrayFilesEnd = [];
        if (((_a = files) === null || _a === void 0 ? void 0 : _a.length) > 0) {
            for (const file of files) {
                if (file.size <= this.sizeFilePermitted) {
                    (_d = (_c = (_b = this.field) === null || _b === void 0 ? void 0 : _b.validations) === null || _c === void 0 ? void 0 : _c.regularExpressions) === null || _d === void 0 ? void 0 : _d.forEach(exp => {
                        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
                        if (((_a = file) === null || _a === void 0 ? void 0 : _a.type) === ((_b = exp) === null || _b === void 0 ? void 0 : _b.expression)) {
                            if (((_c = this.arrayFilesEnd) === null || _c === void 0 ? void 0 : _c.length) <= this.numberFilesPermitted) {
                                this.arrayFilesEnd.push({
                                    subject: 'Annotation Case',
                                    noteText: 'Annotation Text Case',
                                    fileName: (_d = file) === null || _d === void 0 ? void 0 : _d.name,
                                    mimeType: (_e = file) === null || _e === void 0 ? void 0 : _e.name,
                                    documentBody: (_f = file) === null || _f === void 0 ? void 0 : _f.documentBody,
                                });
                                if (((_g = this.arrayFilesEnd) === null || _g === void 0 ? void 0 : _g.length) === this.numberFilesPermitted) {
                                    this.group.get((_h = this.field) === null || _h === void 0 ? void 0 : _h.name).disable();
                                    this.classDisabled = 'disable';
                                }
                                else {
                                    this.group.get((_j = this.field) === null || _j === void 0 ? void 0 : _j.name).enable();
                                    this.classDisabled = '';
                                }
                            }
                            this.arrayFilesRedux.emit(this.arrayFilesEnd);
                        }
                    });
                }
            }
        }
        else {
            this.arrayFilesRedux.emit([]);
        }
    }
};
__decorate([
    Input()
], FileComponent.prototype, "field", void 0);
__decorate([
    Input()
], FileComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], FileComponent.prototype, "arrayFilesReduxTemp", void 0);
__decorate([
    Input()
], FileComponent.prototype, "group", void 0);
__decorate([
    Input()
], FileComponent.prototype, "sizeFilePermitted", void 0);
__decorate([
    Input()
], FileComponent.prototype, "numberFilesPermitted", void 0);
__decorate([
    Output()
], FileComponent.prototype, "arrayFilesRedux", void 0);
__decorate([
    Output()
], FileComponent.prototype, "arrayFilesAllRedux", void 0);
__decorate([
    Output()
], FileComponent.prototype, "changeFile", void 0);
FileComponent = __decorate([
    Component({
        selector: 'dmmp-form-file',
        template: "<ng-container [formGroup]=\"group\">\r\n  <div\r\n    class=\"box-file\"\r\n    [ngClass]=\"\r\n      group.get(field?.name).valid\r\n        ? 'valid'\r\n        : group.get(field?.name).touched\r\n        ? 'invalid'\r\n        : ''\r\n    \"\r\n  >\r\n    <label\r\n      class=\"box-file__label button-border\"\r\n      [ngClass]=\"[field?.class || '', classDisabled]\">\r\n      <input\r\n        class=\"box-file__input\"\r\n        [type]=\"field?.type\"\r\n        [formControlName]=\"field?.name || ''\"\r\n        [id]=\"identifier + '_' + field?.idHtml\"\r\n        [accept]=\"accept || ''\"\r\n        (click)=\"reset($event)\"\r\n        (change)=\"onFilesChanged($event)\"\r\n      />\r\n      {{field?.placeholder}}\r\n    </label>\r\n    <p *ngIf=\"field?.label\" class=\"box-file__help\" [innerHTML]=\"field?.label\"></p>\r\n    <ng-container>\r\n      <div\r\n        class=\"error-field\"\r\n        *ngIf=\"\r\n          group.get(field?.name).invalid &&\r\n          (group.get(field?.name).dirty || group.get(field?.name).touched)\r\n        \"\r\n      >\r\n        {{ field?.validations?.message }}\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n  <dmmp-form-file-list\r\n    [arrayFiles]=\"arrayFilesReduxTemp ? arrayFilesReduxTemp : []\"\r\n    [sizeFilePermitted]=\"sizeFilePermitted\"\r\n    [accept]=\"accept ? accept : ''\"\r\n    (deleteFileOut)=\"addArrayObjectEnd($event)\">\r\n  </dmmp-form-file-list>\r\n</ng-container>\r\n"
    })
], FileComponent);

let FileListComponent = class FileListComponent {
    constructor(localDeviceDetectorService) {
        this.localDeviceDetectorService = localDeviceDetectorService;
        this.deleteFileOut = new EventEmitter();
        this.labelButton = 'Eliminar';
        this.textFormatInvalid = 'Formato y/o peso no admitido, este archivo no será cargado';
    }
    deleteFile(position) {
        this.arrayFiles.splice(position, 1);
        this.deleteFileOut.emit(this.arrayFiles);
    }
};
FileListComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], FileListComponent.prototype, "arrayFiles", void 0);
__decorate([
    Input()
], FileListComponent.prototype, "accept", void 0);
__decorate([
    Input()
], FileListComponent.prototype, "sizeFilePermitted", void 0);
__decorate([
    Output()
], FileListComponent.prototype, "deleteFileOut", void 0);
FileListComponent = __decorate([
    Component({
        selector: 'dmmp-form-file-list',
        template: "<div class=\"content-files\" *ngIf=\"arrayFiles?.length > 0\">\r\n  <ng-container *ngFor=\"let file of arrayFiles; index as index\">\r\n    <ng-container *ngIf=\"accept.includes(file?.type)  && file?.size <= sizeFilePermitted; else invalidFile\">\r\n      <div class=\"row file-valid\">\r\n        <div class=\"col-8 col-md-10\">\r\n          <p class=\"file-name\" *ngIf=\"file?.name\">{{ file?.name | deleteCharactersFile: 15 : localDeviceDetectorService.isMobile() }}</p>\r\n        </div>\r\n        <div class=\"col-auto text-center\">\r\n          <a\r\n            (click)=\"deleteFile(index)\"\r\n            class=\"button-border transparent delete\"\r\n          >\r\n            {{ labelButton }}\r\n          </a>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n    <ng-template #invalidFile>\r\n      <div class=\"row file-invalid\">\r\n        <div class=\"col-9 col-md-10\">\r\n          <p class=\"file-name file-invalid__icon\" *ngIf=\"file?.name\">{{ file.name | deleteCharactersFile: 15 : localDeviceDetectorService.isMobile() }}</p>\r\n          <p class=\"file-invalid__alert\">{{ textFormatInvalid }}</p>\r\n        </div>\r\n        <div class=\"col-auto text-center\">\r\n          <a (click)=\"deleteFile(index)\" class=\"file-invalid__button\">\r\n            <i class=\"fas fa-times\"></i>\r\n          </a>\r\n        </div>\r\n      </div>\r\n    </ng-template>\r\n  </ng-container>\r\n</div>\r\n"
    })
], FileListComponent);

let FormModule = class FormModule {
};
FormModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            RouterModule,
            FormsModule,
            ReactiveFormsModule,
            NgbAccordionModule,
            NgbNavModule,
            SharedModule,
            NgxCaptchaModule,
            PipesModule
        ],
        declarations: [
            ButtonComponent$1,
            CheckboxComponent,
            SurveyComponent,
            TextLinkComponent,
            InputComponent,
            TextAreaComponent,
            InputInsideValidationsComponent,
            SelectComponent,
            SelectInsideValidationsComponent,
            RadioComponent,
            EventsComponent,
            StepNumberComponent,
            StepDetailsComponent,
            EventPipe,
            CaptchaComponent,
            FileComponent,
            FileListComponent
        ],
        exports: [
            ButtonComponent$1,
            CheckboxComponent,
            SurveyComponent,
            TextLinkComponent,
            InputComponent,
            TextAreaComponent,
            InputInsideValidationsComponent,
            SelectComponent,
            SelectInsideValidationsComponent,
            RadioComponent,
            EventsComponent,
            StepNumberComponent,
            StepDetailsComponent,
            CaptchaComponent,
            FileComponent,
            FileListComponent
        ],
        providers: [
            CookieService
        ]
    })
], FormModule);

let FaqSectionComponent = class FaqSectionComponent {
    constructor(richsnipetService) {
        this.richsnipetService = richsnipetService;
    }
    ngOnInit() {
        var _a, _b;
        this.schema = this.richsnipetService.setupJsonFaq((_b = (_a = this.data) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.faqs);
    }
};
FaqSectionComponent.ctorParameters = () => [
    { type: RichsnipetService }
];
__decorate([
    Input()
], FaqSectionComponent.prototype, "data", void 0);
__decorate([
    Input()
], FaqSectionComponent.prototype, "layout", void 0);
__decorate([
    Input()
], FaqSectionComponent.prototype, "identifier", void 0);
FaqSectionComponent = __decorate([
    Component({
        selector: 'dmmp-faq-section',
        template: "<ngx-json-ld [json]=\"schema\"></ngx-json-ld>\r\n<dmmp-container [data]=\"data\" [identifier]=\"identifier\"\r\n  [defaultClass]=\"'container-fluid faq-section'\">\r\n  <div class=\"container faq-box\">\r\n    <div class=\"row\">\r\n      <div class=\"col-lg-{{layout?.columns_content || 12 }}\"\r\n      [ngClass]=\"layout?.columns_content ? (layout?.columns_content > 8 ? 'bg-color-white z-index-4 position-relative': '') : ''\">\r\n        <div class=\"row\">\r\n          <div class=\"col\">\r\n            <h2 class=\"h2\">{{ data?.name }}</h2>\r\n          </div>\r\n        </div>\r\n        <div *ngFor=\"let faqItem of data?.content?.faqs\" class=\"faq-item container-fluid\">\r\n          <div class=\"row\" [ngClass]=\"!faqItem?.isCollapse ? 'active' : ''\"\r\n            (click)=\"faqItem.isCollapse = !faqItem.isCollapse\">\r\n            <div class=\"col\">\r\n              <h3 class=\"white\" *ngIf=\"faqItem?.title\">{{ faqItem?.title }}</h3>\r\n            </div>\r\n            <div class=\"col-auto text-right\">\r\n              <button type=\"button\" class=\"btn btn-outline\" align-left>\r\n                <i class=\"fas fa-chevron-up\" *ngIf=\"!faqItem?.isCollapse\"></i>\r\n                <i class=\"fas fa-chevron-down\" *ngIf=\"faqItem?.isCollapse\"></i>\r\n              </button>\r\n            </div>\r\n          </div>\r\n          <div class=\"row\">\r\n            <div class=\"col-lg-12\" id=\"collapseExample\" [ngbCollapse]=\"faqItem?.isCollapse\">\r\n              <p [innerHTML]=\"faqItem?.description\"></p>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], FaqSectionComponent);

let FaqSectionModule = class FaqSectionModule {
};
FaqSectionModule = __decorate([
    NgModule({
        declarations: [FaqSectionComponent],
        imports: [CommonModule, NgbModule, SharedModule, NgxJsonLdModule],
        exports: [FaqSectionComponent],
        providers: [RichsnipetService],
    })
], FaqSectionModule);

let InformationCardsComponent = class InformationCardsComponent {
    constructor(localDeviceDetector) {
        this.localDeviceDetector = localDeviceDetector;
        this.page = new EventEmitter();
    }
};
InformationCardsComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], InformationCardsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], InformationCardsComponent.prototype, "data", void 0);
__decorate([
    Input()
], InformationCardsComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], InformationCardsComponent.prototype, "itemByRow", void 0);
__decorate([
    Output()
], InformationCardsComponent.prototype, "page", void 0);
InformationCardsComponent = __decorate([
    Component({
        selector: 'dmmp-information-cards',
        template: "<div [id]=\" data?.id_element ? identifier + '_' + data?.id_element : 'information_cards'\"\r\n  class=\"information_cards container-fluid\" [ngClass]=\"data?.class\"\r\n  [style.backgroundColor]=\" data?.background_color.color ? data?.background_color.color : ''\"\r\n  [style.backgroundImage]=\" (data?.background_image).length > 0 ? 'url(' + (data?.background_image)[0].styles.large + ')' : ''\"\r\n  *ngIf=\"this.data\">\r\n  <div class=\"container\" *ngIf=\"this.localDeviceDetector?.isDesktop() || this.localDeviceDetector.isTablet()\">\r\n    <dmmp-desktop [itemByRow]=\"itemByRow\" [data]=\"this.data\" (page)=\"page.emit($event)\"></dmmp-desktop>\r\n  </div>\r\n  <div class=\"container\" *ngIf=\"this.localDeviceDetector?.isMobile()\">\r\n    <dmmp-mobile [itemByRow]=\"itemByRow\" [data]=\"this.data\" (page)=\"page.emit($event)\"></dmmp-mobile>\r\n  </div>\r\n</div>\r\n"
    })
], InformationCardsComponent);

let CardComponent = class CardComponent {
    constructor() {
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], CardComponent.prototype, "infoCard", void 0);
__decorate([
    Output()
], CardComponent.prototype, "page", void 0);
CardComponent = __decorate([
    Component({
        selector: 'dmmp-card',
        template: "<div class=\"card\" [ngClass]=\"infoCard.card_class ? infoCard.card_class : ''\">\r\n  <div class=\"logo-content\" [style.backgroundColor]=\"infoCard.background_color?.color\"\r\n    *ngIf=\"infoCard?.logo?.length > 0\">\r\n    <img [src]=\"infoCard.logo[0].styles.large\" [title]=\"infoCard.logo[0].texts.title\" [alt]=\"infoCard.logo[0].texts.alt\"\r\n      [class]=\"infoCard.image_class\" />\r\n  </div>\r\n  <div class=\"info\">\r\n    <div class=\"box-info\">\r\n      <dmmp-website-card-title [data]=\"infoCard\" (page)=\"page.emit($event)\"></dmmp-website-card-title>\r\n      <p [ngClass]=\"infoCard.description_class ? infoCard.description_class : ''\" [innerHTML]=\"infoCard.description | truncatetext: 140\">\r\n      </p>\r\n    </div>\r\n    <div class=\"button-info\">\r\n      <ng-container *ngIf=\"infoCard?.card_button?.length\">\r\n        <dmmp-button [data]=\"infoCard.card_button[0]\" (page)=\"page.emit($event)\"></dmmp-button>\r\n      </ng-container>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], CardComponent);

let MobileComponent$1 = class MobileComponent {
    constructor(loadScroll) {
        this.loadScroll = loadScroll;
        this.cards = [];
        this.page = new EventEmitter();
    }
    ngOnInit() {
        this.scrollEvent();
    }
    scrollEvent() {
        this.loadScroll.loadScroll(this.data.content, this.itemByRow, this.cards);
    }
};
MobileComponent$1.ctorParameters = () => [
    { type: LoadScrollService }
];
__decorate([
    Input()
], MobileComponent$1.prototype, "data", void 0);
__decorate([
    Input()
], MobileComponent$1.prototype, "itemByRow", void 0);
__decorate([
    Output()
], MobileComponent$1.prototype, "page", void 0);
MobileComponent$1 = __decorate([
    Component({
        selector: 'dmmp-mobile',
        template: "<div class=\"row main-panel-info-cards\" (scroll)=\"scrollEvent()\">\r\n  <dmmp-card class=\"col-12 col-sm-12 col-md-4 col-lg-3 box-card\" *ngFor=\"let card of cards\" [infoCard]=\"card\"\r\n    (page)=\"page.emit($event)\">\r\n  </dmmp-card>\r\n</div>\r\n",
        styles: [""]
    })
], MobileComponent$1);

let DesktopComponent$1 = class DesktopComponent {
    constructor(loadScroll) {
        this.loadScroll = loadScroll;
        this.cards = [];
        this.page = new EventEmitter();
    }
    ngOnInit() {
        this.scrollEvent();
    }
    scrollEvent() {
        this.loadScroll.loadScroll(this.data.content, this.itemByRow, this.cards);
    }
};
DesktopComponent$1.ctorParameters = () => [
    { type: LoadScrollService }
];
__decorate([
    Input()
], DesktopComponent$1.prototype, "data", void 0);
__decorate([
    Input()
], DesktopComponent$1.prototype, "itemByRow", void 0);
__decorate([
    Output()
], DesktopComponent$1.prototype, "page", void 0);
DesktopComponent$1 = __decorate([
    Component({
        selector: 'dmmp-desktop',
        template: "<div infiniteScroll [infiniteScrollDistance]=\"2\" [infiniteScrollThrottle]=\"50\" [fromRoot]=\"true\"\r\n     (scrolled)=\"scrollEvent()\">\r\n  <div class=\"row\">\r\n    <dmmp-card class=\"col-12 col-sm-12 col-md-4 col-lg-3 box-card\" *ngFor=\"let card of cards\" [infoCard]=\"card\" (page)=\"page.emit($event)\">\r\n    </dmmp-card>\r\n  </div>\r\n</div>\r\n"
    })
], DesktopComponent$1);

let InformationCardsModule = class InformationCardsModule {
};
InformationCardsModule = __decorate([
    NgModule({
        declarations: [
            InformationCardsComponent,
            CardComponent,
            MobileComponent$1,
            DesktopComponent$1,
        ],
        imports: [CommonModule, SharedModule, InfiniteScrollModule, PipesModule],
        exports: [InformationCardsComponent],
        providers: [LoadScrollService],
    })
], InformationCardsModule);

let WebsiteFooterComponent = class WebsiteFooterComponent {
    constructor(localDeviceDetector) {
        this.localDeviceDetector = localDeviceDetector;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
        var _a, _b;
        (_b = (_a = this.menus) === null || _a === void 0 ? void 0 : _a.sistemap) === null || _b === void 0 ? void 0 : _b.forEach(menu => {
            menu.isCollapse = true;
        });
    }
    ancla(event) {
        this.anchorCustom.emit(event);
    }
    anclaValidate(event, data) {
        var _a, _b;
        if (((_a = data) === null || _a === void 0 ? void 0 : _a.indexOf('#')) === 0 && ((_b = data) === null || _b === void 0 ? void 0 : _b.length) > 1) {
            this.anchorCustom.emit({ event: event, id: data });
        }
    }
};
WebsiteFooterComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], WebsiteFooterComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteFooterComponent.prototype, "data", void 0);
__decorate([
    Output()
], WebsiteFooterComponent.prototype, "anchorCustom", void 0);
__decorate([
    Input()
], WebsiteFooterComponent.prototype, "menus", void 0);
__decorate([
    Output()
], WebsiteFooterComponent.prototype, "page", void 0);
WebsiteFooterComponent = __decorate([
    Component({
        selector: 'dmmp-website-footer',
        template: "<dmmp-container [data]=\"data\" [identifier]=\"data?.id_element ? identifier + '_' + data?.id_element : ''\"\r\n                [defaultClass]=\"'footer-home bg-color-white z-index-4 position-relative'\">\r\n  <div class=\"bg-footer\" [style.backgroundColor]=\" data?.background_color?.color || ''\"\r\n       [style.backgroundImage]=\"data?.background_image?.length > 0 ? 'url(' + data?.background_image[0]?.styles?.large + ')' : ''\">\r\n    <ng-container *ngFor=\"let rowItem of data?.content?.row\">\r\n      <div class=\"row-container\" [ngClass]=\"rowItem?.class || ''\"\r\n           [id]=\"rowItem?.id_element || ''\">\r\n        <div class=\"container\">\r\n          <div class=\"row\">\r\n            <div *ngFor=\"let columnItem of rowItem?.column; let i = index\"\r\n                 [ngClass]=\"'col-12 ' + 'col-md-'+ columnItem?.number_columns + ' ' + columnItem?.class\"\r\n                 [id]=\"columnItem?.id_element\">\r\n              <div *ngFor=\"let item of columnItem?.items_column\" [ngClass]=\"'item ' + item?.identifier\">\r\n                <div *ngIf=\"item?.identifier.toLowerCase() === 'button'\">\r\n                  <div *ngIf=\"item?.icon_image?.length === 0; else linkTem\">\r\n                    <dmmp-link [data]=\"item\" (anchorCustom)=\"ancla($event)\" [identifier]=\"identifier\">\r\n                      {{item?.link[0]?.name}}\r\n                    </dmmp-link>\r\n                  </div>\r\n                  <ng-template #linkTem>\r\n                    <ng-template *ngIf=\"item?.link?.length > 0; else iconTemplate\">\r\n                      <dmmp-link [data]=\"item\" (anchorCustom)=\"ancla($event)\" [identifier]=\"identifier\">\r\n                        <dmmp-image-logo [data]=\"item?.icon_image\"></dmmp-image-logo>\r\n                      </dmmp-link>\r\n                    </ng-template>\r\n                    <ng-template #iconTemplate>\r\n                      <dmmp-image-logo [data]=\"item?.icon_image\"></dmmp-image-logo>\r\n                    </ng-template>\r\n                  </ng-template>\r\n                </div>\r\n                <div *ngIf=\"item.identifier.toLowerCase() === 'images_link'\">\r\n                  <div *ngIf=\"item?.link?.length > 0; else imgTem\">\r\n                    <dmmp-link *ngIf=\"item?.link[0]?.link !== '/backToTop'; else isbackToTop\"\r\n                    [data]=\"item\" (anchorCustom)=\"ancla($event)\" [identifier]=\"identifier\">\r\n                      <dmmp-image-logo [data]=\"item?.image\"></dmmp-image-logo>\r\n                    </dmmp-link>\r\n                    <ng-template #isbackToTop>\r\n                      <dmmp-back-to-top [image]=\"item?.image\"></dmmp-back-to-top>\r\n                    </ng-template>\r\n                  </div>\r\n                  <ng-template #imgTem>\r\n                    <dmmp-image-logo [data]=\"item?.image\"></dmmp-image-logo>\r\n                  </ng-template>\r\n                </div>\r\n                <div *ngIf=\"item?.identifier?.toLowerCase() === 'link_icon'\">\r\n                  <div *ngIf=\"item?.link?.length > 0; else iconTemplate\">\r\n                    <dmmp-link [data]=\"item\" (anchorCustom)=\"ancla($event)\" [identifier]=\"identifier\">\r\n                      <ng-container *ngIf=\"item?.icon; else textLink\">\r\n                        <img [src]=\"item?.icon ? '../assets/images/' + item?.icon : ''\"/>\r\n                      </ng-container>\r\n                      <ng-template #textLink>\r\n                        <div *ngIf=\"item?.link[0]?.name\" [innerHTML]=\"item?.link[0]?.name\"></div>\r\n                      </ng-template>\r\n                    </dmmp-link>\r\n                  </div>\r\n                  <ng-template #iconTemplate>\r\n                    <img [src]=\"item?.icon ? '../assets/images/' + item?.icon : ''\"\r\n                         [class]=\"item?.class ? item?.class : ''\"/>\r\n                  </ng-template>\r\n                </div>\r\n                <div *ngIf=\"item?.identifier?.toLowerCase() === 'menu'\">\r\n                  <div *ngIf=\"item?.menu?.toLowerCase() === 'copyright'; else sitemap\"\r\n                       [ngClass]=\"item?.class || ''\">\r\n                    <ul class=\"navbar-nav\">\r\n                      <li class=\"nav-item\" [ngClass]=\"item?.items_class ? 'nav-item ' + item?.items_class : 'nav-item'\"\r\n                          *ngFor=\"let subMenu of this.menus?.copyright\">\r\n                        <a class=\"nav-link\" routerLink=\"{{subMenu?.data?.path}}\" (click)=\"page.emit(subMenu?.data?.path)\">\r\n                          {{subMenu?.data?.name}}\r\n                        </a>\r\n                      </li>\r\n                    </ul>\r\n                  </div>\r\n                  <ng-template #sitemap>\r\n                    <div *ngIf=\"this.localDeviceDetector.isDesktop() || this.localDeviceDetector.isTablet()\">\r\n                      <dmmp-desktop-sitemap-menu [item]=\"item\" [index]=\"i\" [menus]=\"menus\"\r\n                                                 (page)=\"page.emit($event)\"></dmmp-desktop-sitemap-menu>\r\n                    </div>\r\n                    <div *ngIf=\"this.localDeviceDetector.isMobile()\">\r\n                      <dmmp-mobile-sitemap-menu [item]=\"item\" [index]=\"i\" [menus]=\"menus\"\r\n                                                (page)=\"page.emit($event)\"></dmmp-mobile-sitemap-menu>\r\n                    </div>\r\n                  </ng-template>\r\n                </div>\r\n                <div *ngIf=\"item.identifier.toLowerCase() === 'textos'\">\r\n                  <div [ngClass]=\"item?.class || ''\" [innerHTML]=\"item?.text\">\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteFooterComponent);

let DesktopSitemapMenuComponent = class DesktopSitemapMenuComponent {
    constructor() {
        this.page = new EventEmitter();
    }
};
__decorate([
    Input()
], DesktopSitemapMenuComponent.prototype, "item", void 0);
__decorate([
    Input()
], DesktopSitemapMenuComponent.prototype, "menus", void 0);
__decorate([
    Input()
], DesktopSitemapMenuComponent.prototype, "index", void 0);
__decorate([
    Output()
], DesktopSitemapMenuComponent.prototype, "page", void 0);
DesktopSitemapMenuComponent = __decorate([
    Component({
        selector: 'dmmp-desktop-sitemap-menu',
        template: "<div [ngClass]=\"item.class ? item.class + ' wrapper-sitemap': 'wrapper-sitemap'\" *ngIf=\"menus?.sitemap?.length > 0\">\r\n  <ul class=\"navbar-nav\" *ngFor=\"let menu of menus?.sitemap\">\r\n    <li class=\"nav-item\" [ngClass]=\"item?.items_class ? 'nav-item ' + item?.items_class : 'nav-item'\">\r\n      <a class=\"nav-link nav-title\" routerLink=\"{{menu?.data?.path}}\"\r\n        (click)=\"page.emit(menu?.data?.path)\">\r\n        {{menu?.data?.name}}\r\n      </a>\r\n    </li>\r\n    <li class=\"nav-item\" [ngClass]=\"item?.items_class ? 'nav-item ' + item?.items_class : 'nav-item'\"\r\n      *ngFor=\"let subMenu of menu?.children\">\r\n      <a id=\"{{subMenu?.data?.name | replace}}\" class=\"nav-link\" routerLink=\"{{subMenu?.data?.path}}\" (click)=\"page.emit(subMenu?.data?.path)\">\r\n        {{subMenu?.data?.name}}\r\n      </a>\r\n    </li>\r\n  </ul>\r\n</div>\r\n"
    })
], DesktopSitemapMenuComponent);

let MobileSitemapMenuComponent = class MobileSitemapMenuComponent {
    constructor() {
        this.page = new EventEmitter();
    }
};
__decorate([
    Input()
], MobileSitemapMenuComponent.prototype, "item", void 0);
__decorate([
    Input()
], MobileSitemapMenuComponent.prototype, "menus", void 0);
__decorate([
    Input()
], MobileSitemapMenuComponent.prototype, "index", void 0);
__decorate([
    Output()
], MobileSitemapMenuComponent.prototype, "page", void 0);
MobileSitemapMenuComponent = __decorate([
    Component({
        selector: 'dmmp-mobile-sitemap-menu',
        template: "<div *ngIf=\"menus?.sitemap?.length > 0\">\r\n  <div *ngFor=\"let menu of menus?.sitemap\">\r\n    <div class=\"row\">\r\n      <div class=\"col\">\r\n        <ul class=\"navbar-nav\">\r\n          <li class=\"nav-item\" [ngClass]=\"item.items_class ? 'nav-item ' + item.items_class : 'nav-item'\">\r\n            <a class=\"nav-link nav-title\" routerLink=\"{{menu?.data?.path}}\"\r\n               (click)=\"page.emit(menu?.data?.path)\">\r\n              {{menu?.data?.name}}\r\n            </a>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n      <div class=\"col-auto text-right\" (click)=\"menu.isCollapse = !menu?.isCollapse\">\r\n        <button type=\"button\" class=\"btn btn-outline\" align-left>\r\n          <i class=\"fas fa-chevron-up\" *ngIf=\"!menu?.isCollapse\"></i>\r\n          <i class=\"fas fa-chevron-down\" *ngIf=\"menu?.isCollapse\"></i>\r\n        </button>\r\n      </div>\r\n    </div>\r\n    <div class=\"row\">\r\n      <div class=\"col-lg-12\" id=\"collapseExample\" [ngbCollapse]=\"menu?.isCollapse\">\r\n        <ul class=\"navbar-nav\">\r\n          <li class=\"nav-item\" [ngClass]=\"item?.items_class ? 'nav-item ' + item.items_class : 'nav-item'\"\r\n              *ngFor=\"let subMenu of menu?.children\">\r\n            <a class=\"nav-link\" routerLink=\"{{subMenu?.data?.path}}\"\r\n               (click)=\"page.emit(subMenu?.data?.path)\">\r\n              {{subMenu?.data?.name}}\r\n            </a>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], MobileSitemapMenuComponent);

let WebsiteFooterModule = class WebsiteFooterModule {
};
WebsiteFooterModule = __decorate([
    NgModule({
        declarations: [WebsiteFooterComponent, DesktopSitemapMenuComponent, MobileSitemapMenuComponent],
        imports: [
            CommonModule,
            RouterModule,
            NgbCollapseModule,
            SharedModule,
            PipesModule
        ],
        exports: [WebsiteFooterComponent]
    })
], WebsiteFooterModule);

let WebsiteDetailedBannerComponent = class WebsiteDetailedBannerComponent {
    constructor() {
        this.overlappingBox = false;
        this.medias = [
            { style: 'large', media: '(min-width:421px)' },
            { style: '289x290', media: '(min-width:421px)' },
            { style: '241x256', media: '(max-width:420px)' },
        ];
    }
};
__decorate([
    Input()
], WebsiteDetailedBannerComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteDetailedBannerComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteDetailedBannerComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteDetailedBannerComponent.prototype, "overlappingBox", void 0);
WebsiteDetailedBannerComponent = __decorate([
    Component({
        selector: 'dmmp-website-detailed-banner',
        template: "<div class=\"website-detailed-banner\">\r\n  <dmmp-container\r\n    [identifier]=\"identifier\"\r\n    [data]=\"module || {}\"\r\n    [defaultClass]=\"'bg-banner'\"\r\n  >\r\n    <div class=\"container\">\r\n      <div class=\"row no-gutters\">\r\n        <div class=\"col-12 col-lg\">\r\n          <div class=\"content-banner\">\r\n            <div *ngIf=\"data?.faculty?.length > 0\" class=\"content-faculty\">\r\n              <i [ngClass]=\"data.faculty_class || ''\"></i>\r\n              <span>{{data?.faculty[0]}}</span>\r\n            </div>\r\n            <div *ngIf=\"data?.program_type?.length > 0\" class=\"content-studie-type\">\r\n              <p [ngClass]=\"data?.program_type_class\"> {{data?.program_type[0]}} </p>\r\n            </div>\r\n            <h1\r\n              *ngIf=\"data?.title\"\r\n              [ngClass]=\"data?.banner_title_class || ''\"\r\n            >\r\n              {{ data?.title }}\r\n            </h1>\r\n            <p\r\n              *ngIf=\"data.summary\"\r\n              [ngClass]=\"data?.summary_class || ''\"\r\n            >\r\n              {{ data?.summary }}\r\n            </p>\r\n            <div class=\"row no-gutters row-icon-button\">\r\n              <div class=\"col-auto\" *ngIf=\"data?.logo?.length > 0\">\r\n                <div class=\"image\">\r\n                  <dmmp-image-logo [data]=\"data?.logo\"></dmmp-image-logo>\r\n                </div>\r\n              </div>\r\n              <div\r\n                class=\"col-auto\"\r\n                *ngIf=\"data?.banner_button?.length > 0\"\r\n              >\r\n                <div class=\"button\">\r\n                  <dmmp-button [data]=\"data?.banner_button[0]\"></dmmp-button>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n        <div class=\"col-12 col-lg\">\r\n          <div\r\n            class=\"content-image\"\r\n            *ngIf=\"data?.banner_image?.length > 0 && !overlappingBox\"\r\n          >\r\n              <dmmp-image\r\n                [images]=\"data?.banner_image[0]\"\r\n                [medias]=\"medias\"\r\n              ></dmmp-image>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </dmmp-container>\r\n</div>\r\n"
    })
], WebsiteDetailedBannerComponent);

let WebsiteDetailedBannerModule = class WebsiteDetailedBannerModule {
};
WebsiteDetailedBannerModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule
        ],
        declarations: [WebsiteDetailedBannerComponent],
        exports: [
            WebsiteDetailedBannerComponent
        ],
        providers: []
    })
], WebsiteDetailedBannerModule);

let WebsiteDetailedTabsComponent = class WebsiteDetailedTabsComponent {
    constructor() {
        this.active = 0;
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], WebsiteDetailedTabsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteDetailedTabsComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteDetailedTabsComponent.prototype, "module", void 0);
WebsiteDetailedTabsComponent = __decorate([
    Component({
        selector: 'dmmp-website-detailed-tabs',
        template: "<div *ngIf=\"data?.tabs?.length > 0\" class=\"website-detailed-tabs\">\r\n  <dmmp-container\r\n    [identifier]=\"identifier\"\r\n    [data]=\"module || {}\"\r\n    [defaultClass]=\"'bg-tabs'\"\r\n  >\r\n    <div class=\"container\">\r\n      <div class=\"row no-gutters\">\r\n        <div class=\"col-lg-8\">\r\n          <div class=\"content-tabs\">\r\n            <ul ngbNav #nav=\"ngbNav\" [(activeId)]=\"active\" class=\"nav-tabs\">\r\n              <ng-container\r\n                *ngFor=\"let tabs of data?.tabs; let i = index\"\r\n              >\r\n                <li\r\n                  [ngbNavItem]=\"i\"\r\n                >\r\n                  <a\r\n                    ngbNavLink\r\n                    *ngIf=\"tabs?.title\"\r\n                    [ngClass]=\"tabs?.class || ''\"\r\n                  >{{ tabs?.title }}</a\r\n                  >\r\n                  <ng-template ngbNavContent>\r\n                    <div\r\n                      *ngIf=\"tabs?.text\"\r\n                      [innerHTML]=\"tabs?.text\"\r\n                      [ngClass]=\"tabs?.text_class || ''\"\r\n                    ></div>\r\n                  </ng-template>\r\n                </li>\r\n              </ng-container>\r\n            </ul>\r\n            <div [ngbNavOutlet]=\"nav\" class=\"mt-2\"></div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </dmmp-container>\r\n</div>\r\n"
    })
], WebsiteDetailedTabsComponent);

let WebsiteDetailedTabsModule = class WebsiteDetailedTabsModule {
};
WebsiteDetailedTabsModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            NgbNavModule,
        ],
        declarations: [WebsiteDetailedTabsComponent],
        exports: [
            WebsiteDetailedTabsComponent
        ],
        providers: []
    })
], WebsiteDetailedTabsModule);

let WebsiteCourseDetailedTabsComponent = class WebsiteCourseDetailedTabsComponent {
    constructor() {
        this.contentItemListCount = 4;
    }
    ngOnInit() {
    }
    showMore() {
        var _a, _b;
        this.contentItemListCount = (_b = (_a = this.data) === null || _a === void 0 ? void 0 : _a.chapters) === null || _b === void 0 ? void 0 : _b.length;
    }
};
__decorate([
    Input()
], WebsiteCourseDetailedTabsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteCourseDetailedTabsComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteCourseDetailedTabsComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteCourseDetailedTabsComponent.prototype, "contentItemListCount", void 0);
WebsiteCourseDetailedTabsComponent = __decorate([
    Component({
        selector: 'dmmp-website-course-detailed-tabs',
        template: "<dmmp-container [identifier]=\"identifier\" [data]=\"module || {}\" [defaultClass]=\"'website-course-detailed-tabs'\">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">\r\n      {{module.name}}\r\n    </h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"row\">\r\n      <div class=\"col-lg-{{data?.columns_content || 12}}\"\r\n        [ngClass]=\"(data?.columns_content > 8 ? 'bg-color-white z-index-4 position-relative' : '')\">\r\n        <div class=\"tabs-content\">\r\n          <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\">\r\n            <li ngbNavItem>\r\n              <ng-container>\r\n                <a ngbNavLink>\r\n                  <h3 class=\"h4 tab-title\">Overview</h3>\r\n                </a>\r\n                <ng-template ngbNavContent>\r\n                  <div class=\"row\">\r\n                    <div class=\"col\">\r\n                      <p class=\"overview-text\" [innerHTML]=\"data?.description\">\r\n                      </p>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"row\">\r\n                    <div class=\"col\">\r\n                      <h4 class=\"h3 color-purple-darkest mb-5 overview-title\">Learning Outcomes</h4>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"row\">\r\n                    <div class=\"col-12 item\">\r\n                      <p class=\"check-text\" [innerHTML]=\"data?.learning_benefits\"></p>\r\n                    </div>\r\n                  </div>\r\n                </ng-template>\r\n              </ng-container>\r\n            </li>\r\n            <li ngbNavItem>\r\n              <ng-container>\r\n                <a ngbNavLink>\r\n                  <h3 class=\"h4 tab-title\">Content</h3>\r\n                </a>\r\n                <ng-template ngbNavContent>\r\n                  <div class=\"row item\">\r\n                    <div class=\"col-12 col-md-6 d-flex item-img\">\r\n                      <div class=\"item-icon-content\">\r\n                        <i class=\"far fa-calendar-alt item-icon\"></i>\r\n                      </div>\r\n                      <div class=\"item-text-content\">\r\n                        <p class=\"item-text\" [innerHTML]=\"data?.duration\"></p>\r\n                      </div>\r\n                    </div>\r\n                    <div class=\"col-12 col-md-6 d-flex item-img\">\r\n                      <div class=\"item-icon-content\">\r\n                        <i class=\"far fa-file-pdf item-icon\"></i>\r\n                      </div>\r\n                      <div class=\"item-text-content\">\r\n                        <p class=\"item-text\" [innerHTML]=\"data?.number_resource\"></p>\r\n                      </div>\r\n                    </div>\r\n                    <div class=\"col-12 col-md-6 d-flex item-img\">\r\n                      <div class=\"item-icon-content\">\r\n                        <i class=\"fas fa-graduation-cap item-icon\"></i>\r\n                      </div>\r\n                      <div class=\"item-text-content\">\r\n                        <p class=\"item-text\" [innerHTML]=\"data?.student_title\"></p>\r\n                      </div>\r\n                    </div>\r\n                    <div class=\"col-12 col-md-6 d-flex item-img\">\r\n                      <div class=\"item-icon-content\">\r\n                        <i class=\"far fa-list-alt item-icon\"></i>\r\n                      </div>\r\n                      <div class=\"item-text-content\">\r\n                        <p class=\"item-text\" [innerHTML]=\"data?.optional_modules\"></p>\r\n                      </div>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"row item\">\r\n                    <ol class=\"item-list\">\r\n                      <ng-container *ngFor=\"let chapter of data?.chapters; let i = index\">\r\n                        <li *ngIf=\"i < contentItemListCount\">{{chapter?.title}}</li>\r\n                      </ng-container>\r\n                    </ol>\r\n                  </div>\r\n                  <div class=\"row item-buttons\">\r\n                    <div class=\"col-12 col-md-6 item-button\" *ngFor=\"let button of data?.detail_course_button\">\r\n                      <div *ngIf=\"button?.id_element === 'more_chapters'; else normalButton\">\r\n                        <a *ngIf=\"button\" [ngClass]=\"button?.class || ''\"\r\n                          [id]=\"button?.id_element || ''\" (click)=\"showMore()\">\r\n                          {{ button?.link[0]?.name }}\r\n                          <ng-container *ngIf=\"button?.icon?.length > 0\">\r\n                            <img class=\"btn-icons\"\r\n                              [src]=\"button?.icon[0]?.styles?.large || ''\"\r\n                              [alt]=\"button?.icon[0]?.texts?.alt || ''\"\r\n                              [title]=\"button?.icon[0].texts?.title || ''\" />\r\n                          </ng-container>\r\n                        </a>\r\n                      </div>\r\n                      <ng-template #normalButton>\r\n                        <dmmp-button class=\"box-button\" [data]=\"button\"></dmmp-button>\r\n                      </ng-template>\r\n                    </div>\r\n                  </div>\r\n                </ng-template>\r\n              </ng-container>\r\n            </li>\r\n            <!-- FIXME Se comentan opciones, no se tiene informaci\u00F3n para mostrar en el DEMO-->\r\n            <!--\r\n            <li ngbNavItem>\r\n              <ng-container>\r\n                <a ngbNavLink>\r\n                  <h3 class=\"h4 tab-title\">Start Dates</h3>\r\n                </a>\r\n                <ng-template ngbNavContent>\r\n                  <div class=\"row item\">\r\n                    <div class=\"col-12 d-flex box-item\">\r\n                      <div class=\"item-icon-content\">\r\n                        <i class=\"far fa-calendar-alt item-icon\"></i>\r\n                      </div>\r\n                      <div class=\"item-text-content d-flex\">\r\n                        <p class=\"p1 item-text-left\">Available</p>\r\n                        <p class=\"p2 item-text-right\">{{data.begin_date}}</p>\r\n                      </div>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"row item\">\r\n                    <div class=\"col-12 d-flex box-item\">\r\n                      <div class=\"item-icon-content\">\r\n                        <i class=\"far fa-calendar-alt item-icon\"></i>\r\n                      </div>\r\n                      <div class=\"item-text-content d-flex\">\r\n                        <p class=\"p1 item-text-left\">Pre-sale</p>\r\n                        <dmmp-button *ngIf=\"data.presale_button.length > 0\" [data]=\"data.presale_button[0]\">\r\n                        </dmmp-button>\r\n                      </div>\r\n                    </div>\r\n                  </div>\r\n                </ng-template>\r\n              </ng-container>\r\n            </li>\r\n            -->\r\n            <li ngbNavItem>\r\n              <ng-container>\r\n                <a ngbNavLink>\r\n                  <h3 class=\"h4 tab-title\">Student Profile</h3>\r\n                </a>\r\n                <ng-template ngbNavContent>\r\n                  <div class=\"row\">\r\n                    <div class=\"col\">\r\n                      <h4 class=\"h3 color-purple-darkest mb-5 overview-title\">Who is the course for?</h4>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"row\">\r\n                    <div class=\"col\">\r\n                      <p class=\"details-text\" [innerHTML]=\"data?.student_profile\"></p>\r\n                    </div>\r\n                  </div>\r\n                  <!-- FIXME -->\r\n                  <!--\r\n                  <div class=\"row item-table\">\r\n                    <div class=\"col-12 col-md-6\">\r\n                      <h5 class=\"h4 item-text\">Opcion 1</h5>\r\n                      <table class=\"item-text-table\">\r\n                        <tr>\r\n                          <th class=\"h5\">Hoy</th>\r\n                          <th class=\"h5\">Ma\u00F1ana</th>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 1</td>\r\n                          <td>Celda 2</td>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 4</td>\r\n                          <td>Celda 5</td>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 4</td>\r\n                          <td>Celda 5</td>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 4</td>\r\n                          <td>Celda 5</td>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 4</td>\r\n                          <td>Celda 5</td>\r\n                        </tr>\r\n                      </table>\r\n                    </div>\r\n                    <div class=\"col-12 col-md-6\">\r\n                      <h5 class=\"h4 item-text\">Opcion 2</h5>\r\n                      <table class=\"item-text-table\">\r\n                        <tr>\r\n                          <th class=\"h5\">Hoy</th>\r\n                          <th class=\"h5\">Ma\u00F1ana</th>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 1</td>\r\n                          <td>Celda 2</td>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 4</td>\r\n                          <td>Celda 5</td>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 4</td>\r\n                          <td>Celda 5</td>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 4</td>\r\n                          <td>Celda 5</td>\r\n                        </tr>\r\n                        <tr>\r\n                          <td>Celda 4</td>\r\n                          <td>Celda 5</td>\r\n                        </tr>\r\n                      </table>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"row item\">\r\n                    <div class=\"col-12 col-md-6\">\r\n                      <h5 class=\"h4 item-title\">Title 1</h5>\r\n                      <p class=\"item-text\">\r\n                        Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been\r\n                        the\r\n                      </p>\r\n                    </div>\r\n                    <div class=\"col-12 col-md-6\">\r\n                      <h5 class=\"h4 item-title\">Title 1</h5>\r\n                      <p class=\"item-text\">\r\n                        Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been\r\n                        the\r\n                      </p>\r\n                    </div>\r\n                  </div>\r\n                  -->\r\n                </ng-template>\r\n              </ng-container>\r\n            </li>\r\n          </ul>\r\n          <div [ngbNavOutlet]=\"nav\">\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteCourseDetailedTabsComponent);

let WebsiteCourseDetailedTabsModule = class WebsiteCourseDetailedTabsModule {
};
WebsiteCourseDetailedTabsModule = __decorate([
    NgModule({
        declarations: [WebsiteCourseDetailedTabsComponent],
        imports: [
            CommonModule,
            NgbNavModule,
            SharedModule
        ],
        exports: [WebsiteCourseDetailedTabsComponent]
    })
], WebsiteCourseDetailedTabsModule);

let WebsiteTenuredProfessorComponent = class WebsiteTenuredProfessorComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.defaultClass = 'website-tenured-professor';
        this.medias = [
            { style: '289x290', media: '(min-width:421px)' },
            { style: '241x256', media: '(max-width:420px)' }
        ];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], WebsiteTenuredProfessorComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteTenuredProfessorComponent.prototype, "teacher", void 0);
__decorate([
    Input()
], WebsiteTenuredProfessorComponent.prototype, "columnsContent", void 0);
__decorate([
    Input()
], WebsiteTenuredProfessorComponent.prototype, "module", void 0);
__decorate([
    Output()
], WebsiteTenuredProfessorComponent.prototype, "page", void 0);
__decorate([
    Output()
], WebsiteTenuredProfessorComponent.prototype, "anchorCustom", void 0);
__decorate([
    Input()
], WebsiteTenuredProfessorComponent.prototype, "professorTitle", void 0);
__decorate([
    Input()
], WebsiteTenuredProfessorComponent.prototype, "directorTitle", void 0);
__decorate([
    Input()
], WebsiteTenuredProfessorComponent.prototype, "defaultClass", void 0);
WebsiteTenuredProfessorComponent = __decorate([
    Component({
        selector: 'dmmp-website-tenured-professor',
        template: "<dmmp-container [data]=\"module\" [identifier]=\"identifier\" [defaultClass]=\"defaultClass\">\r\n  <div class=\"container\" [ngClass]=\"teacher?.detailed_class || ''\">\r\n    <div class=\"row\">\r\n      <div class=\"col-lg-{{ columnsContent || 12 }}\"\r\n        [ngClass]=\"columnsContent ? (columnsContent > 8 ? 'bg-color-white z-index-4 position-relative': '') : ''\">\r\n        <div class=\"content\">\r\n          <h2 *ngIf=\"module?.name\"\r\n              [ngClass]=\"module?.title_class || ''\">\r\n            {{module?.name}}\r\n          </h2>\r\n          <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n            <div\r\n              *ngFor=\"let textContent of module?.texts\"\r\n              [ngClass]=\"textContent?.class || ''\"\r\n              [innerHTML]=\"textContent?.text || ''\"\r\n            ></div>\r\n          </ng-container>\r\n          <div class=\"row\">\r\n            <div class=\"col-12 col-md-auto\">\r\n              <div class=\"content-img\" *ngIf=\"teacher?.image?.length > 0\">\r\n                <dmmp-image [images]=\"teacher?.image[0]\" [medias]=\"medias\"></dmmp-image>\r\n              </div>\r\n            </div>\r\n            <div class=\"col-12 col-md\">\r\n              <div class=\"content-info\">\r\n                <div *ngIf=\"teacher?.is_professor || teacher?.is_director\" class=\"box-role\">\r\n                  <p *ngIf=\"teacher?.is_professor\" class=\"small-text text-white\">{{professorTitle}}</p>\r\n                  <p *ngIf=\"teacher?.is_director\" class=\"small-text text-white\">{{directorTitle}}</p>\r\n                </div>\r\n                <p class=\"professor-name\" [ngClass]=\"teacher?.detailed_title_class || ''\">\r\n                  {{ teacher?.title }}\r\n                </p>\r\n                <p class=\"description-class\" *ngIf=\"teacher?.tabs?.length > 0\" [ngClass]=\"\r\n                    teacher?.tabs[0]?.text_class || ''\r\n                  \" [innerHTML]=\"teacher?.tabs[0]?.text\"></p>\r\n                <div class=\"content-link\" *ngIf=\"teacher?.card_button?.length > 0\">\r\n                  <dmmp-button [data]=\"teacher?.card_button[0]\" (page)=\"page.emit($event)\"\r\n                    (anchorCustom)=\"anchorCustom.emit($event)\">\r\n                  </dmmp-button>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteTenuredProfessorComponent);

let WebsiteTenuredProfessorModule = class WebsiteTenuredProfessorModule {
};
WebsiteTenuredProfessorModule = __decorate([
    NgModule({
        declarations: [WebsiteTenuredProfessorComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [WebsiteTenuredProfessorComponent]
    })
], WebsiteTenuredProfessorModule);

let WebsiteBoxFloatProgramComponent = class WebsiteBoxFloatProgramComponent {
    constructor(_document, richsnipetService, removeHtmlPipe) {
        this._document = _document;
        this.richsnipetService = richsnipetService;
        this.removeHtmlPipe = removeHtmlPipe;
        this.page = new EventEmitter();
        this.schemaItem = [];
    }
    ngOnInit() {
        if (this.data) {
            this.schemaItem = this.richsnipetService.setupJsonCourse([{
                    title: this.data.title ? this.data.title : '',
                    description: this.data.description ? this.removeHtmlPipe.transform(this.data.description) : '',
                    university: this.data.university && this.data.university.length > 0 ? this.data.university : [],
                }]);
        }
    }
    onScrollEvent() {
        const header = this._document.querySelector('header');
        const heightHeader = header ? header.offsetHeight : 64;
        this.classScroll = window.scrollY > heightHeader + 120;
        this.classScrollMobile = window.scrollY > 0;
    }
};
WebsiteBoxFloatProgramComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
    { type: RichsnipetService },
    { type: RemoveHtmlPipe }
];
__decorate([
    Input()
], WebsiteBoxFloatProgramComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramComponent.prototype, "module", void 0);
__decorate([
    Output()
], WebsiteBoxFloatProgramComponent.prototype, "page", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramComponent.prototype, "urlPayment", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramComponent.prototype, "privateKey", void 0);
__decorate([
    HostListener('window:scroll', [])
], WebsiteBoxFloatProgramComponent.prototype, "onScrollEvent", null);
WebsiteBoxFloatProgramComponent = __decorate([
    Component({
        selector: 'dmmp-website-box-float-program',
        template: "<ngx-json-ld *ngIf=\"schemaItem\" [json]=\"schemaItem\"></ngx-json-ld>\r\n<div class=\"container website-container-box\">\r\n  <div\r\n    class=\"website-box-float-program box-float-absolute\"\r\n    [ngClass]=\"classScroll ? 'box-float-fixed' : ''\"\r\n  >\r\n    <dmmp-container\r\n      [identifier]=\"identifier\"\r\n      [data]=\"module ? module : {}\"\r\n      [defaultClass]=\"'bg-box-float'\"\r\n    >\r\n      <div class=\"box-image\">\r\n        <div\r\n          class=\"content-image-float\"\r\n          *ngIf=\"data?.box_image?.length > 0\"\r\n        >\r\n          <dmmp-image\r\n            [images]=\"data.box_image[0]\"\r\n            [medias]=\"[\r\n              { style: '408x216', media: '(min-width:421px)' },\r\n              { style: '272x144', media: '(max-width:420px)' }\r\n            ]\"\r\n          ></dmmp-image>\r\n        </div>\r\n        <div class=\"content-box-title-program\" *ngIf=\"data?.title\">\r\n          {{ data.title }}\r\n        </div>\r\n        <div\r\n          class=\"content-price-button\"\r\n          [ngClass]=\"classScrollMobile ? 'box-float-fixed-mobile' : ''\">\r\n          <p class=\"price\" *ngIf=\"data?.price\">\r\n            {{ data.price }}\r\n          </p>\r\n          <div\r\n            class=\"btn-content\"\r\n            *ngIf=\"data?.box_buy_button?.length > 0\"\r\n          >\r\n            <dmmp-button\r\n              [data]=\"data.box_buy_button[0]\"\r\n              [urlPayment]=\"urlPayment\"\r\n              [privateKey]=\"privateKey\"\r\n              [programId]=\"\r\n                  data.course_id ? data.course_id : ''\r\n                \"\r\n              [programPrice]=\"data.value ? data.value : ''\"\r\n              [programExpiration]=\"\r\n                  data.course_expiration\r\n                    ? data.course_expiration\r\n                    : ''\r\n                \">\r\n            </dmmp-button>\r\n          </div>\r\n        </div>\r\n        <div class=\"content-box-text\" *ngIf=\"data?.box_text?.length > 0 \">\r\n          <div class=\"content-description-box-text\" [ngClass]=\"data.box_text[0].class ? data.box_text[0].class : ''\">\r\n            <div *ngIf=\"data?.box_text[0]?.text\" [outerHTML]=\"data.box_text[0].text\"></div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n      <div class=\"info-content\">\r\n        <div class=\"row-detail\">\r\n          <div class=\"col-icon-text student-title hide-scroll\">\r\n            <div class=\"image-icon\" *ngIf=\"data?.student_title_icon ? data?.student_title_icon?.length > 0 : false\">\r\n              <dmmp-image-logo [data]=\"data.student_title_icon\"></dmmp-image-logo>\r\n            </div>\r\n            <p *ngIf=\"data?.student_title\">{{ data.student_title }}</p>\r\n          </div>\r\n          <div class=\"col-icon-text faculty hide-scroll\">\r\n            <div class=\"image-icon\" *ngIf=\"data?.faculty_icon ? data?.faculty_icon?.length > 0 : false\">\r\n              <dmmp-image-logo [data]=\"data.faculty_icon\"></dmmp-image-logo>\r\n            </div>\r\n            <p *ngIf=\"data?.faculty\">{{ data.faculty }}</p>\r\n          </div>\r\n          <div class=\"col-icon-text duration\">\r\n            <div class=\"image-icon\" *ngIf=\"data?.duration_icon ? data?.duration_icon?.length > 0 : false\">\r\n              <dmmp-image-logo [data]=\"data.duration_icon\"></dmmp-image-logo>\r\n            </div>\r\n            <p *ngIf=\"data?.duration\">{{ data.duration }}</p>\r\n          </div>\r\n          <div class=\"col-icon-text frecuency\">\r\n            <div class=\"image-icon\" *ngIf=\"data?.frequency_icon ? data?.frequency_icon?.length > 0 : false\">\r\n              <dmmp-image-logo [data]=\"data.frequency_icon\"></dmmp-image-logo>\r\n            </div>\r\n            <p *ngIf=\"data?.frecuency\">{{ data.frecuency }}</p>\r\n          </div>\r\n          <div class=\"col-icon-text number-resource\">\r\n            <div class=\"image-icon\" *ngIf=\"data?.number_resource_icon ? data?.number_resource_icon?.length > 0 : false\">\r\n              <dmmp-image-logo [data]=\"data.number_resource_icon\"></dmmp-image-logo>\r\n            </div>\r\n            <p *ngIf=\"data?.number_resource\">{{ data.number_resource }}</p>\r\n          </div>\r\n          <ng-container *ngIf=\"data?.box_items ? data?.box_items?.length > 0 : false\">\r\n            <div *ngFor=\"let item of data.box_items\"\r\n                 [ngClass]=\"[item.class ? item.class : '', !item.fixed ? 'hide-scroll' : '']\"\r\n                 class=\"col-icon-text items-dynamics\">\r\n              <div class=\"image-icon\" *ngIf=\"item?.icon ? item?.icon?.length > 0 : false\">\r\n                <dmmp-image-logo [data]=\"item.icon\"></dmmp-image-logo>\r\n              </div>\r\n              <p *ngIf=\"item.text\">{{ item.text }}</p>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n        <div class=\"text\" *ngIf=\"data?.university && data?.university?.length > 0\">\r\n          A Programme by\r\n          <a\r\n            *ngIf=\"data?.university[0]?.title && data?.university[0]?.path\"\r\n            (click)=\"page.emit(data.university[0].path)\"\r\n            routerLink=\"{{ data.university[0].path }}\"\r\n          >{{ data.university[0].title }}</a\r\n          >\r\n        </div>\r\n      </div>\r\n    </dmmp-container>\r\n  </div>\r\n</div>\r\n"
    }),
    __param(0, Inject(DOCUMENT))
], WebsiteBoxFloatProgramComponent);

let WebsiteBoxFloatProgramModule = class WebsiteBoxFloatProgramModule {
};
WebsiteBoxFloatProgramModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            RouterModule,
            NgxJsonLdModule
        ],
        declarations: [WebsiteBoxFloatProgramComponent],
        exports: [
            WebsiteBoxFloatProgramComponent
        ],
        providers: [RichsnipetService, RemoveHtmlPipe]
    })
], WebsiteBoxFloatProgramModule);

let WebsiteRelatedProgramsComponent = class WebsiteRelatedProgramsComponent {
    constructor(richsnipetService) {
        this.richsnipetService = richsnipetService;
        this.page = new EventEmitter();
    }
    ngOnInit() {
        this.schema = this.richsnipetService.setupJsonCourse(this.data.content);
    }
};
WebsiteRelatedProgramsComponent.ctorParameters = () => [
    { type: RichsnipetService }
];
__decorate([
    Input()
], WebsiteRelatedProgramsComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteRelatedProgramsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteRelatedProgramsComponent.prototype, "category", void 0);
__decorate([
    Input()
], WebsiteRelatedProgramsComponent.prototype, "urlPayment", void 0);
__decorate([
    Input()
], WebsiteRelatedProgramsComponent.prototype, "privateKey", void 0);
__decorate([
    Output()
], WebsiteRelatedProgramsComponent.prototype, "page", void 0);
WebsiteRelatedProgramsComponent = __decorate([
    Component({
        selector: 'dmmp-website-related-programs',
        template: "<ngx-json-ld *ngFor=\"let schema of schema\" [json]=\"schema\"></ngx-json-ld>\r\n<dmmp-container [data]=\"data\" [identifier]=\"identifier\" [defaultClass]=\"\r\n    'web-site-realated-programs bg-color-white z-index-4 position-relative'\r\n  \">\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <ng-container *ngIf=\"category; else programTitle\">\r\n        <div class=\"col title-category\">\r\n          <h2 class=\"h2 color-purple-darkest\"\r\n              *ngIf=\"data?.name\"\r\n              [ngClass]=\"data?.title_class || ''\">\r\n            {{ data?.name }}\r\n          </h2>\r\n          <dmmp-simple-link class=\"pl-md-5\"\r\n                            *ngIf=\" data?.component === 'recommended_search_filter' && data?.see_more?.length > 0 \"\r\n                            [data]=\"data?.see_more[0]\"\r\n                            (page)=\"page.emit($event)\">\r\n            {{ data?.see_more[0]?.link[0]?.name }}</dmmp-simple-link>\r\n        </div>\r\n      </ng-container>\r\n      <ng-template #programTitle>\r\n        <div class=\"col\">\r\n          <h2 *ngIf=\"data?.name\" class=\"h2 color-purple-darkest\"\r\n              [ngClass]=\"data?.title_class || ''\">\r\n            {{ data?.name }}\r\n          </h2>\r\n        </div>\r\n      </ng-template>\r\n    </div>\r\n    <div class=\"row main-panel\" *ngIf=\"data?.content?.length > 0\">\r\n      <ng-container *ngFor=\"let program of data?.content\">\r\n        <dmmp-website-card-program\r\n          class=\"col-12 col-sm-12 col-md-4 col-lg-3 box-card\"\r\n          [program]=\"program\"\r\n          [differenceDays]=\"data?.difference_days\"\r\n          [urlPayment]=\"urlPayment || ''\"\r\n          [privateKey]=\"privateKey || ''\"\r\n          [programId]=\"program.course_id || ''\"\r\n          [programPrice]=\"program.value || ''\"\r\n          [programExpiration]=\"program.course_expiration || ''\"\r\n          [labelCategory]=\"program.recommended_label || ''\"\r\n          [labelPrice]=\"program.price || ''\"\r\n          (page)=\"page.emit($event)\">\r\n        </dmmp-website-card-program>\r\n      </ng-container>\r\n    </div>\r\n    <div class=\"row\" *ngIf=\"data?.component === 'recommended_programs' && data?.see_more?.length > 0 \">\r\n      <div class=\"col text-center\">\r\n        <dmmp-simple-link\r\n          [data]=\"data?.see_more[0]\" (page)=\"page.emit($event)\">\r\n          {{ data?.see_more[0]?.link[0]?.name }}</dmmp-simple-link>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteRelatedProgramsComponent);

let WebsiteRelatedProgramsModule = class WebsiteRelatedProgramsModule {
};
WebsiteRelatedProgramsModule = __decorate([
    NgModule({
        imports: [CommonModule, SharedModule, NgxJsonLdModule],
        declarations: [WebsiteRelatedProgramsComponent],
        exports: [WebsiteRelatedProgramsComponent],
        providers: [RichsnipetService],
    })
], WebsiteRelatedProgramsModule);

let WebsiteArticleListComponent = class WebsiteArticleListComponent {
    constructor() {
        this.page = new EventEmitter();
        this.infiniteScroll = new EventEmitter();
    }
    scrollEvent() {
        this.infiniteScroll.emit();
    }
};
__decorate([
    Input()
], WebsiteArticleListComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteArticleListComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteArticleListComponent.prototype, "module", void 0);
__decorate([
    Output()
], WebsiteArticleListComponent.prototype, "page", void 0);
__decorate([
    Output()
], WebsiteArticleListComponent.prototype, "infiniteScroll", void 0);
WebsiteArticleListComponent = __decorate([
    Component({
        selector: 'dmmp-website-article-list',
        template: "<dmmp-container [data]=\"module\" [identifier]=\"identifier\" [defaultClass]=\"'list-articles'\">\r\n  <div infiniteScroll [infiniteScrollDistance]=\"2\" [infiniteScrollThrottle]=\"50\" [fromRoot]=\"true\"\r\n       (scrolled)=\"scrollEvent()\">\r\n    <div class=\"container\">\r\n      <div class=\"row\">\r\n        <ng-container *ngFor=\"let article of data; let i = index\">\r\n          <div class=\"col-12\" *ngIf=\"i === 0; else secondaryArticle\">\r\n            <dmmp-website-article-banner-featured (page)=\"page.emit($event)\"\r\n                                                  [classArticle]=\"{title: article.title_class_list, summary: article.summary_class_list, date: article.date_class_list, buttonClass: article.button_class_list}\"\r\n                                                  [data]=\"article\"></dmmp-website-article-banner-featured>\r\n          </div>\r\n          <ng-template #secondaryArticle>\r\n            <div class=\"col-12 col-lg-4 col-md-6\" [id]=\"article?.identifier\">\r\n              <dmmp-website-card-article-featured (page)=\"page.emit($event)\" [data]=\"article\"\r\n                                                  [classArticle]=\"{title: article.title_class_list, summary: article.summary_class_list, date: article.date_class_list, buttonClass: article.button_class_list}\"\r\n                                                  [type]=\"2\"></dmmp-website-card-article-featured>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteArticleListComponent);

let WebsiteArticleListModule = class WebsiteArticleListModule {
};
WebsiteArticleListModule = __decorate([
    NgModule({
        declarations: [WebsiteArticleListComponent],
        imports: [
            CommonModule,
            SharedModule,
            InfiniteScrollModule
        ],
        exports: [WebsiteArticleListComponent]
    })
], WebsiteArticleListModule);

let WebsiteArticleBannerComponent = class WebsiteArticleBannerComponent {
    constructor() {
        this.page = new EventEmitter();
    }
};
__decorate([
    Input()
], WebsiteArticleBannerComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteArticleBannerComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteArticleBannerComponent.prototype, "module", void 0);
__decorate([
    Output()
], WebsiteArticleBannerComponent.prototype, "page", void 0);
WebsiteArticleBannerComponent = __decorate([
    Component({
        selector: 'dmmp-website-article-banner',
        template: "<dmmp-container [data]=\"module\" [identifier]=\"identifier\" [defaultClass]=\"'banner-articles'\">\r\n  <dmmp-website-article-banner-featured [type]=\"'story'\" [data]=\"data\"\r\n                                        [classArticle]=\"{title: data.title_class_detail, summary: '', date: data.date_class_detail, buttonClass: ''}\"\r\n                                        (page)=\"page.emit($event)\">\r\n\r\n  </dmmp-website-article-banner-featured>\r\n</dmmp-container>\r\n"
    })
], WebsiteArticleBannerComponent);

let WebsiteArticleBannerModule = class WebsiteArticleBannerModule {
};
WebsiteArticleBannerModule = __decorate([
    NgModule({
        declarations: [WebsiteArticleBannerComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [WebsiteArticleBannerComponent]
    })
], WebsiteArticleBannerModule);

let WebsiteArticleContentComponent = class WebsiteArticleContentComponent {
};
__decorate([
    Input()
], WebsiteArticleContentComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteArticleContentComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteArticleContentComponent.prototype, "module", void 0);
WebsiteArticleContentComponent = __decorate([
    Component({
        selector: 'dmmp-website-article-content',
        template: "<dmmp-container [data]=\"module\" [identifier]=\"identifier\" [defaultClass]=\"'body-article'\" *ngIf=\"this.data\">\r\n  <div class=\"container\" [id]=\"data.identifier ? data.identifier : ''\">\r\n    <div *ngIf=\"data.body || data.content\" [innerHTML]=\"data.body ? data.body : data.content |safe : 'html'\"></div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteArticleContentComponent);

let WebsiteArticleContentModule = class WebsiteArticleContentModule {
};
WebsiteArticleContentModule = __decorate([
    NgModule({
        declarations: [WebsiteArticleContentComponent],
        imports: [
            CommonModule,
            SharedModule,
            PipesModule
        ],
        exports: [WebsiteArticleContentComponent]
    })
], WebsiteArticleContentModule);

let WebsiteSearchFilterComponent = class WebsiteSearchFilterComponent {
    constructor(formBuilder, activatedRoute, router) {
        this.formBuilder = formBuilder;
        this.activatedRoute = activatedRoute;
        this.router = router;
        this.clearResult = new EventEmitter();
        this.search = new EventEmitter();
        this.page = new EventEmitter();
        this.resultLabelTitle = 'Search results for:';
        this.searchSubmit = this.formBuilder.group({
            search: ['', Validators.required],
            program: [''],
            university: [''],
        });
    }
    ngOnInit() {
        this.activatedRoute.queryParams.subscribe(params => {
            if (params['q']) {
                this.searchSubmit.get('search').setValue('');
                this.searchSubmit
                    .get('search')
                    .setValue(params['q'].split('-').join(' '));
                this.resultLabel = params['q'].split('-').join(' ');
                this.onSubmit();
            }
            else {
                this.clearResult.emit();
            }
        });
    }
    onSubmit() {
        this.router.navigate(['.'], {
            relativeTo: this.activatedRoute,
            queryParams: {
                q: this.replaceSpace(this.searchSubmit.value['search']),
            },
        });
        const searchLabel = this.searchSubmit.value['search']
            ? `${this.searchSubmit.value['search']}`
            : '';
        const programLabel = this.searchSubmit.value['program']
            ? `${searchLabel ? ', ' : ''}${this.getParamsForm(this.searchSubmit.value['program'])[1]}`
            : '';
        const universityLabel = this.searchSubmit.value['university']
            ? `${programLabel || searchLabel ? ', ' : ''}${this.getParamsForm(this.searchSubmit.value['university'])[1]}`
            : '';
        this.resultLabel = `${searchLabel}${programLabel}${universityLabel}`;
        const searchInput = this.searchSubmit.value['search']
            ? `(title:(${this.searchSubmit.value['search']}))`
            : '';
        const program = this.searchSubmit.value['program']
            ? `${searchInput ? 'AND' : ''}(content_category:(${this.getParamsForm(this.searchSubmit.value['program'])[0]}))`
            : '';
        const university = this.searchSubmit.value['university']
            ? `${program || searchInput ? 'AND' : ''}(content_course_university:(${this.getParamsForm(this.searchSubmit.value['university'])[0]}))`
            : '';
        this.search.emit(`${searchInput}${program}${university}`);
    }
    replaceSpace(words) {
        return words.split(' ').join('-');
    }
    reactiveInput() {
        if (this.searchSubmit.value['search'].length >= 3 || this.searchSubmit.value['search'].length === 0) {
            this.onSubmit();
        }
    }
    getParamsForm(value) {
        return value.split('|');
    }
};
WebsiteSearchFilterComponent.ctorParameters = () => [
    { type: FormBuilder },
    { type: ActivatedRoute },
    { type: Router }
];
__decorate([
    Input()
], WebsiteSearchFilterComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteSearchFilterComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteSearchFilterComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteSearchFilterComponent.prototype, "result", void 0);
__decorate([
    Input()
], WebsiteSearchFilterComponent.prototype, "urlPayment", void 0);
__decorate([
    Input()
], WebsiteSearchFilterComponent.prototype, "privateKey", void 0);
__decorate([
    Output()
], WebsiteSearchFilterComponent.prototype, "clearResult", void 0);
__decorate([
    Output()
], WebsiteSearchFilterComponent.prototype, "search", void 0);
__decorate([
    Output()
], WebsiteSearchFilterComponent.prototype, "page", void 0);
WebsiteSearchFilterComponent = __decorate([
    Component({
        selector: 'dmmp-website-search-filter',
        template: "<div class=\"website-search-filter\">\r\n  <dmmp-container\r\n    [identifier]=\"identifier\"\r\n    [data]=\"data || {}\"\r\n    [defaultClass]=\"'bg-banner'\"\r\n  >\r\n    <div class=\"container\">\r\n      <div class=\"content-search\">\r\n        <h1 *ngIf=\"data?.name\"\r\n            [ngClass]=\"data?.title_class || ''\"\r\n            class=\"h1 color-white text-center mb-4\">\r\n          {{ data?.name }}\r\n        </h1>\r\n        <div\r\n          *ngIf=\"data?.texts?.length > 0\"\r\n          class=\"p1 color-white text-center mb-4\"\r\n          [ngClass]=\"data?.texts[0]?.class || ''\"\r\n          [innerHTML]=\"data?.texts[0]?.text || ''\"\r\n        ></div>\r\n        <form [formGroup]=\"searchSubmit\" (ngSubmit)=\"onSubmit()\">\r\n          <div\r\n            class=\"row no-gutters input-container-search\"\r\n            *ngIf=\"data?.search\"\r\n          >\r\n            <div class=\"col-md-7\">\r\n              <div\r\n                class=\"input-container\"\r\n                [ngClass]=\"data?.search?.class || ''\"\r\n                [id]=\"\r\n                    data?.search?.id_element\r\n                    ? identifier + '_' + data?.search?.id_element\r\n                    : ''\r\n                \"\r\n              >\r\n                <input\r\n                  (keyup)=\"reactiveInput()\"\r\n                  [placeholder]=\"\r\n                    data?.search?.placeholder || ''\r\n                  \"\r\n                  type=\"text\"\r\n                  formControlName=\"search\"\r\n                />\r\n                <div class=\"btn-search\">\r\n                  <button\r\n                    type=\"submit\"\r\n                    [disabled]=\"searchSubmit?.invalid\"\r\n                    class=\"btn btn-success\"\r\n                  >\r\n                    <dmmp-image-logo\r\n                      [data]=\"data?.search?.image\"\r\n                    ></dmmp-image-logo>\r\n                  </button>\r\n                </div>\r\n              </div>\r\n            </div>\r\n            <div class=\"col-md-5\">\r\n              <div class=\"row no-gutters row-filters\">\r\n                <div\r\n                  class=\"select-container col-6\"\r\n                  *ngIf=\"data?.categories?.length > 0\"\r\n                >\r\n                  <select name=\"program\" formControlName=\"program\"\r\n                          (ngModelChange)=\"onSubmit()\">\r\n                    <option value=\"\">All programmes</option>\r\n                    <option\r\n                      *ngFor=\"let program of data?.categories\"\r\n                      [value]=\"program?.id + '|' + program?.name\"\r\n                    >{{ program?.name }}</option\r\n                    >\r\n                  </select>\r\n                </div>\r\n                <div\r\n                  class=\"select-container col-6\"\r\n                  *ngIf=\"data?.universities?.length > 0\"\r\n                >\r\n                  <select name=\"university\" formControlName=\"university\"\r\n                          (ngModelChange)=\"onSubmit()\">\r\n                    <option value=\"\">All Universities</option>\r\n                    <option\r\n                      *ngFor=\"let program of data?.universities\"\r\n                      [value]=\"program?.id + '|' + program?.name\"\r\n                    >{{ program?.name }}</option\r\n                    >\r\n                  </select>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </form>\r\n        <div class=\"arrow-more\">\r\n          <svg\r\n            xmlns=\"http://www.w3.org/2000/svg\"\r\n            width=\"21.486\"\r\n            height=\"11.965\"\r\n            viewBox=\"0 0 21.486 11.965\"\r\n          >\r\n            <path\r\n              id=\"prefix__Trazado_6021\"\r\n              fill=\"none\"\r\n              stroke=\"#fff\"\r\n              stroke-linecap=\"round\"\r\n              stroke-linejoin=\"round\"\r\n              stroke-width=\"2px\"\r\n              d=\"M0 .078l9.468 9.55 9.19-9.55\"\r\n              data-name=\"Trazado 6021\"\r\n              transform=\"translate(1.414 1.337)\"\r\n            />\r\n          </svg>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </dmmp-container>\r\n  <ng-container *ngIf=\"result\">\r\n    <div class=\"website-result\" *ngIf=\"result?.length > 0\">\r\n      <div class=\"container\">\r\n        <div class=\"row\">\r\n          <div class=\"col\">\r\n            <h2 class=\"h2 color-purple-darkest\">{{resultLabelTitle}}\r\n              &nbsp;<strong>{{resultLabel}}</strong>\r\n            </h2>\r\n          </div>\r\n        </div>\r\n        <div class=\"row main-panel\">\r\n          <div\r\n            *ngFor=\"let res of result\"\r\n            class=\"col-12 col-sm-12 col-md-4 col-lg-3 box-card\"\r\n          >\r\n            <dmmp-website-card-program\r\n              [program]=\"res\"\r\n              [differenceDays]=\"'3'\"\r\n              [urlPayment]=\"urlPayment || ''\"\r\n              [privateKey]=\"privateKey || ''\"\r\n              [programId]=\"res?.course_id || ''\"\r\n              [programPrice]=\"res?.value || ''\"\r\n              [programExpiration]=\"res?.course_expiration || ''\"\r\n              (page)=\"page.emit($event)\"\r\n            ></dmmp-website-card-program>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n</div>\r\n"
    })
], WebsiteSearchFilterComponent);

let WebsiteSearchFilterModule = class WebsiteSearchFilterModule {
};
WebsiteSearchFilterModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            SharedModule,
            RouterModule,
            BreadcrumbModule,
            FormsModule,
            ReactiveFormsModule
        ],
        declarations: [
            WebsiteSearchFilterComponent
        ],
        exports: [
            WebsiteSearchFilterComponent
        ],
        providers: []
    })
], WebsiteSearchFilterModule);

let WebsiteCarouselArticlesFeaturedComponent = class WebsiteCarouselArticlesFeaturedComponent {
    constructor(options, dateFormat) {
        this.options = options;
        this.dateFormat = dateFormat;
        this.page = new EventEmitter();
        this.currentPage = 1;
    }
    ngOnInit() {
        this.cantSlides = this.data.length < 4 ? this.data.length : 4;
        this.configBenefits = this.options.configurationBenefits(this.module);
    }
    newPageEvent(newPage) {
        if (newPage.direction === 'next') {
            this.carrousel.next();
            this.currentPage = newPage.number;
        }
        else {
            this.carrousel.prev();
            this.currentPage = newPage.number;
        }
    }
    changeOwl(event) {
        if (event.startPosition + 1 !== this.currentPage) {
            this.currentPage = event.startPosition + 1;
        }
    }
};
WebsiteCarouselArticlesFeaturedComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService },
    { type: DateFormatService }
];
__decorate([
    Input()
], WebsiteCarouselArticlesFeaturedComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteCarouselArticlesFeaturedComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteCarouselArticlesFeaturedComponent.prototype, "module", void 0);
__decorate([
    Output()
], WebsiteCarouselArticlesFeaturedComponent.prototype, "page", void 0);
__decorate([
    ViewChild('owl')
], WebsiteCarouselArticlesFeaturedComponent.prototype, "carrousel", void 0);
WebsiteCarouselArticlesFeaturedComponent = __decorate([
    Component({
        selector: 'dmmp-website-carousel-articles-featured',
        template: "<div class=\"owl-carousel-article\" *ngIf=\"data?.length > 0\">\r\n  <owl-carousel-o\r\n    [options]=\"configBenefits\"\r\n    #owl\r\n    class=\"row\"\r\n    (changed)=\"changeOwl($event)\"\r\n  >\r\n    <ng-container *ngFor=\"let article of data | slice: 0:cantSlides\">\r\n      <ng-template carouselSlide>\r\n        <div class=\"content-carousel\">\r\n          <div\r\n            class=\"col-image\"\r\n            *ngIf=\"article?.imagen?.length > 0\"\r\n          >\r\n            <div class=\"image\">\r\n              <dmmp-image\r\n                [images]=\"(article?.imagen)[0]\"\r\n                [medias]=\"[\r\n                  { style: '728x408', media: '(min-width:421px)' },\r\n                  { style: '644x429', media: '(max-width:420px)' }\r\n                ]\"\r\n              ></dmmp-image>\r\n            </div>\r\n          </div>\r\n          <div\r\n            class=\"box-content-float\"\r\n            [style.backgroundColor]=\"\r\n              article?.background_color.color\r\n                ? (article?.background_color.color\r\n                  | colorOpacity: article?.opacity_first_box)\r\n                : ''\r\n            \"\r\n          >\r\n            <div\r\n              class=\"icon-content\"\r\n              *ngIf=\"article?.icon?.length > 0\"\r\n              [class]=\"article.icon_class ? article.icon_class : ''\"\r\n            >\r\n              <dmmp-image-logo [data]=\"article?.icon\"></dmmp-image-logo>\r\n            </div>\r\n            <div class=\"box-date\" *ngIf=\"article?.created_at\">\r\n              <p [ngClass]=\"article.date_class ? article.date_class : ''\">\r\n                {{\r\n                dateFormat.convertFromTimestampToDate(article?.created_at)\r\n                  | date: 'longDate':'UTC'\r\n                }}\r\n              </p>\r\n            </div>\r\n            <div class=\"box-title\" *ngIf=\"article?.title\">\r\n              <h3 [ngClass]=\"article.title_class ? article.title_class : ''\">\r\n                {{ article.title }}\r\n              </h3>\r\n            </div>\r\n            <div class=\"box-description\" *ngIf=\"article?.summary\">\r\n              <p [ngClass]=\"article.summary_class ? article.summary_class : ''\">\r\n                {{ article.summary | truncatetext: 130 }}\r\n              </p>\r\n            </div>\r\n            <div class=\"box-button button-content\">\r\n              <a\r\n                *ngIf=\"article?.path\"\r\n                routerLink=\"{{ article.path }}\"\r\n                [ngClass]=\"article.button_class ? article.button_class : ''\"\r\n                (click)=\"page.emit(article.path ? article.path : '')\"\r\n              >\r\n                {{ article.button_label ? article.button_label : '' }}</a\r\n              >\r\n            </div>\r\n          </div>\r\n          <div\r\n            class=\"box-color\"\r\n            [style.backgroundColor]=\"\r\n              article?.background_second_color.color\r\n                ? article?.background_second_color.color\r\n                : ''\r\n            \"\r\n          ></div>\r\n        </div>\r\n      </ng-template>\r\n    </ng-container>\r\n  </owl-carousel-o>\r\n  <div\r\n    class=\"content-paginator-carousel\"\r\n    *ngIf=\"\r\n      module?.paginator_type === 'both' || module?.paginator_type === 'arrow'\r\n    \"\r\n  >\r\n    <dmmp-paginator\r\n      [loop]=\"module.loop\"\r\n      [paginatorType]=\"1\"\r\n      [totalPages]=\"cantSlides\"\r\n      [currentPage]=\"currentPage\"\r\n      (newPageEmitter)=\"newPageEvent($event)\"\r\n    ></dmmp-paginator>\r\n  </div>\r\n</div>\r\n"
    })
], WebsiteCarouselArticlesFeaturedComponent);

let WebsiteCarouselArticlesFeaturedModule = class WebsiteCarouselArticlesFeaturedModule {
};
WebsiteCarouselArticlesFeaturedModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            NgbNavModule,
            CarouselModule,
            PipesModule,
            RouterModule
        ],
        declarations: [WebsiteCarouselArticlesFeaturedComponent],
        exports: [
            WebsiteCarouselArticlesFeaturedComponent
        ],
        providers: []
    })
], WebsiteCarouselArticlesFeaturedModule);

let WebsiteArticlesFeaturedComponent = class WebsiteArticlesFeaturedComponent {
    constructor(localDeviceDetector) {
        this.localDeviceDetector = localDeviceDetector;
        this.featureHome = [];
        this.page = new EventEmitter();
    }
    ngOnInit() {
        this.data.forEach(articleItem => {
            if (articleItem.featured_home) {
                this.featureHome.push(articleItem);
            }
        });
    }
};
WebsiteArticlesFeaturedComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], WebsiteArticlesFeaturedComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteArticlesFeaturedComponent.prototype, "data", void 0);
__decorate([
    Input()
], WebsiteArticlesFeaturedComponent.prototype, "module", void 0);
__decorate([
    Output()
], WebsiteArticlesFeaturedComponent.prototype, "page", void 0);
WebsiteArticlesFeaturedComponent = __decorate([
    Component({
        selector: 'dmmp-website-articles-featured',
        template: "<dmmp-container *ngIf=\"data && module\" [identifier]=\"identifier\" [data]=\"module ? module : {}\"\r\n                [defaultClass]=\"'website-articles-featured bg-article'\">\r\n  <div class=\"container\">\r\n    <div class=\"content-articles\">\r\n      <h2 *ngIf=\"module?.name\"\r\n          [ngClass]=\"module.title_class ? module.title_class : ''\">{{module.name}}</h2>\r\n      <ng-container *ngIf=\"module?.texts ? module.texts.length > 0 : false\">\r\n        <div\r\n          *ngFor=\"let textContent of module.texts\"\r\n          [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n          [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n        ></div>\r\n      </ng-container>\r\n      <div class=\"carousel-content\">\r\n        <dmmp-website-carousel-articles-featured [module]=\"module\" [data]=\"featureHome\" (page)=\"page.emit($event)\">\r\n        </dmmp-website-carousel-articles-featured>\r\n      </div>\r\n      <div class=\"articles-content\" *ngIf=\"this.localDeviceDetector?.isDesktop()\">\r\n        <div class=\"row\" *ngIf=\"data?.length > 0\">\r\n          <ng-container *ngFor=\"let article of data | slice: 4:7\">\r\n            <div class=\"col-md-4\" *ngIf=\"article\">\r\n              <dmmp-website-card-article-featured [data]=\"article\" [type]=\"1\"\r\n                                                  [classArticle]=\"{title: article.title_class, summary: article.summary_class, date: article.date_class, buttonClass: article.button_class}\"\r\n                                                  (page)=\"page.emit($event)\"></dmmp-website-card-article-featured>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n      <div class=\"button-content\" *ngIf=\"module?.see_more && module?.see_more?.length > 0\">\r\n        <dmmp-button [data]=\"module.see_more[0]\" (page)=\"page.emit($event)\"></dmmp-button>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteArticlesFeaturedComponent);

let WebsiteArticlesFeaturedModule = class WebsiteArticlesFeaturedModule {
};
WebsiteArticlesFeaturedModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            NgbNavModule,
            CarouselModule,
            WebsiteCarouselArticlesFeaturedModule,
        ],
        declarations: [WebsiteArticlesFeaturedComponent],
        exports: [
            WebsiteArticlesFeaturedComponent
        ],
        providers: []
    })
], WebsiteArticlesFeaturedModule);

let FreeTextComponent = class FreeTextComponent {
};
__decorate([
    Input()
], FreeTextComponent.prototype, "data", void 0);
__decorate([
    Input()
], FreeTextComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], FreeTextComponent.prototype, "detailLayout", void 0);
FreeTextComponent = __decorate([
    Component({
        selector: 'dmmp-free-text',
        template: "<dmmp-container\r\n  [data]=\"data ? data : ''\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'web-site-information'\"\r\n>\r\n  <ng-container\r\n    *ngIf=\"\r\n      detailLayout?.content?.length > 0 ||\r\n        detailLayout?.description;\r\n      else simpleText\r\n    \"\r\n  >\r\n    <div class=\"container\">\r\n      <div class=\"row\">\r\n        <ng-container *ngIf=\"detailLayout?.content; else isDescription\">\r\n          <div class=\"col-12\">\r\n            <div [outerHTML]=\"detailLayout.content | safe: 'html'\"></div>\r\n          </div>\r\n        </ng-container>\r\n        <ng-template #isDescription>\r\n          <div class=\"col-12\">\r\n            <div [outerHTML]=\"detailLayout.description | safe: 'html'\"></div>\r\n          </div>\r\n        </ng-template>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n  <ng-template #simpleText>\r\n    <div class=\"container\">\r\n      <div class=\"row\">\r\n        <div class=\"col-12\">\r\n          <div *ngIf=\"data?.content?.body\" [innerHTML]=\"data.content.body\"></div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </ng-template>\r\n</dmmp-container>\r\n"
    })
], FreeTextComponent);

let FreeTextModule = class FreeTextModule {
};
FreeTextModule = __decorate([
    NgModule({
        imports: [CommonModule, SharedModule, PipesModule],
        declarations: [FreeTextComponent],
        exports: [FreeTextComponent],
    })
], FreeTextModule);

let WebsiteDropDownFilterComponent = class WebsiteDropDownFilterComponent {
    constructor() {
        this.selectEmmiter = new EventEmitter();
        this.currentUserSelect = 'All articles';
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], WebsiteDropDownFilterComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteDropDownFilterComponent.prototype, "module", void 0);
__decorate([
    Output()
], WebsiteDropDownFilterComponent.prototype, "selectEmmiter", void 0);
__decorate([
    Input()
], WebsiteDropDownFilterComponent.prototype, "currentUserSelect", void 0);
WebsiteDropDownFilterComponent = __decorate([
    Component({
        selector: 'dmmp-website-drop-down-filter',
        template: "<dmmp-container [data]=\"module\" [identifier]=\"identifier\" [defaultClass]=\"'filter-categories'\"\r\n                *ngIf=\"module?.categories?.length > 0\">\r\n  <div class=\"container\">\r\n    <select [(ngModel)]=\"currentUserSelect\" (ngModelChange)=\"selectEmmiter.emit(currentUserSelect)\"\r\n            [ngClass]=\"module?.class || ''\">\r\n      <option [value]=\"'All articles'\">All articles</option>\r\n      <option *ngFor=\"let category of module?.categories\" [value]=\"category?.name\">\r\n        {{category?.name}}\r\n      </option>\r\n    </select>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteDropDownFilterComponent);

let WebsiteDropDownFilterModule = class WebsiteDropDownFilterModule {
};
WebsiteDropDownFilterModule = __decorate([
    NgModule({
        declarations: [WebsiteDropDownFilterComponent],
        imports: [
            CommonModule,
            SharedModule,
            FormsModule
        ],
        exports: [WebsiteDropDownFilterComponent]
    })
], WebsiteDropDownFilterModule);

let BannerGridComponent = class BannerGridComponent {
    constructor(localDeviceDetector) {
        this.localDeviceDetector = localDeviceDetector;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
BannerGridComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], BannerGridComponent.prototype, "module", void 0);
__decorate([
    Input()
], BannerGridComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], BannerGridComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], BannerGridComponent.prototype, "page", void 0);
BannerGridComponent = __decorate([
    Component({
        selector: 'dmmp-banner-grid',
        template: "<div *ngIf=\"module.visible\" [id]=\" module?.id_element ? identifier + '_' + module?.id_element : ''\"\r\n  [style.backgroundImage]=\" (module?.background_image)?.length > 0 ? 'url(' + (module?.background_image)[0]?.styles?.large + ')' : ''\"\r\n  [style.backgroundColor]=\"module?.background_color?.color || ''\"\r\n  [style.opacity]=\"module?.background_color?.opacity || ''\" class=\"banner-grid\">\r\n  <ng-container *ngIf=\"(this.localDeviceDetector.isDesktop() || this.localDeviceDetector.isTablet())\">\r\n    <dmmp-banner-content-desktop [module]=\"module\" (page)=\"this.page.emit($event)\"\r\n      (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-banner-content-desktop>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"this.localDeviceDetector.isMobile()\">\r\n    <dmmp-banner-content-mobile [module]=\"module\" (page)=\"this.page.emit($event)\"\r\n      (anchorCustom)=\"anchorCustom.emit($event)\">\r\n    </dmmp-banner-content-mobile>\r\n  </ng-container>\r\n</div>\r\n"
    })
], BannerGridComponent);

let BannerItemContentComponent = class BannerItemContentComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
        var _a;
        this.content = this.relatedContent;
        (_a = this.externContent) === null || _a === void 0 ? void 0 : _a.forEach(item => {
            var _a, _b;
            (_b = (_a = item) === null || _a === void 0 ? void 0 : _a.columns) === null || _b === void 0 ? void 0 : _b.forEach(column => {
                var _a;
                if (((_a = column) === null || _a === void 0 ? void 0 : _a.in_related_content) === true) {
                    this.content = [...this.content, column];
                }
            });
        });
    }
};
__decorate([
    Input()
], BannerItemContentComponent.prototype, "relatedContent", void 0);
__decorate([
    Input()
], BannerItemContentComponent.prototype, "externContent", void 0);
__decorate([
    Output()
], BannerItemContentComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], BannerItemContentComponent.prototype, "page", void 0);
BannerItemContentComponent = __decorate([
    Component({
        selector: 'dmmp-banner-item-content',
        template: "<ng-container [ngSwitch]=\"content?.length\">\r\n  <ng-container *ngSwitchCase=\"1\">\r\n    <div class=\"row box-content-1\">\r\n\r\n      <ng-container *ngFor=\"let contentItem of content\">\r\n\r\n        <ng-container *ngIf=\"contentItem?.identifier === 'columns' && contentItem?.in_related_content; else related\">\r\n          <dmmp-banner-item-detail class=\"col-12\" [data]=\"contentItem\" (page)=\"page.emit($event)\">\r\n          </dmmp-banner-item-detail>\r\n        </ng-container>\r\n\r\n        <ng-template #related>\r\n          <dmmp-item-content class=\"col-12\" [relatedContent]=\"contentItem\" (page)=\"page.emit($event)\">\r\n          </dmmp-item-content>\r\n        </ng-template>\r\n      </ng-container>\r\n\r\n    </div>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"2\">\r\n    <div class=\"row box-content-2\">\r\n\r\n      <ng-container *ngFor=\"let contentItem of content\">\r\n\r\n        <ng-container *ngIf=\"contentItem?.identifier === 'columns' && contentItem?.in_related_content; else related\">\r\n          <dmmp-banner-item-detail class=\"col-12\" [data]=\"contentItem\" (page)=\"page.emit($event)\">\r\n          </dmmp-banner-item-detail>\r\n        </ng-container>\r\n\r\n        <ng-template #related>\r\n          <dmmp-item-content class=\"col-12\" [relatedContent]=\"contentItem\" (page)=\"page.emit($event)\">\r\n          </dmmp-item-content>\r\n        </ng-template>\r\n\r\n      </ng-container>\r\n    </div>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"3\">\r\n\r\n    <div class=\"row box-content-3\">\r\n      <ng-container *ngFor=\"let contentItem of content; let i = index\">\r\n\r\n        <ng-container *ngIf=\"i < 2\">\r\n          <ng-container *ngIf=\"contentItem?.identifier === 'columns' && contentItem?.in_related_content; else related\">\r\n            <dmmp-banner-item-detail class=\"col-6\" [data]=\"contentItem\" (page)=\"page.emit($event)\">\r\n            </dmmp-banner-item-detail>\r\n          </ng-container>\r\n\r\n          <ng-template #related>\r\n            <dmmp-item-content class=\"col-6\" [relatedContent]=\"contentItem\" (page)=\"page.emit($event)\">\r\n            </dmmp-item-content>\r\n          </ng-template>\r\n\r\n        </ng-container>\r\n      </ng-container>\r\n    </div>\r\n\r\n    <div class=\"row box-content-3\">\r\n      <ng-container *ngFor=\"let contentItem of content; let i = index\">\r\n\r\n        <ng-container *ngIf=\"i >= 2\">\r\n          <ng-container *ngIf=\"contentItem?.identifier === 'columns' && contentItem?.in_related_content; else related\">\r\n            <dmmp-banner-item-detail class=\"col-12\" [data]=\"contentItem\" (page)=\"page.emit($event)\">\r\n            </dmmp-banner-item-detail>\r\n          </ng-container>\r\n\r\n          <ng-template #related>\r\n            <dmmp-item-content class=\"col-12\" [relatedContent]=\"contentItem\" (page)=\"page.emit($event)\">\r\n            </dmmp-item-content>\r\n          </ng-template>\r\n      </ng-container>\r\n\r\n      </ng-container>\r\n    </div>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"4\">\r\n\r\n    <div class=\"row box-content-4\">\r\n      <ng-container *ngFor=\"let contentItem of content; let i = index\">\r\n\r\n        <ng-container *ngIf=\"i < 2\">\r\n          <ng-container *ngIf=\"contentItem?.identifier === 'columns' && contentItem?.in_related_content; else related\">\r\n            <dmmp-banner-item-detail class=\"col-6\" [data]=\"contentItem\" (page)=\"page.emit($event)\">\r\n            </dmmp-banner-item-detail>\r\n          </ng-container>\r\n\r\n          <ng-template #related>\r\n            <dmmp-item-content class=\"col-6\" [relatedContent]=\"contentItem\" (page)=\"page.emit($event)\">\r\n            </dmmp-item-content>\r\n          </ng-template>\r\n\r\n        </ng-container>\r\n      </ng-container>\r\n    </div>\r\n\r\n    <div class=\"row box-content-4\">\r\n      <ng-container *ngFor=\"let contentItem of content; let i = index\">\r\n        <ng-container *ngIf=\"i >= 2\">\r\n          <ng-container *ngIf=\"contentItem?.identifier === 'columns' && contentItem?.in_related_content; else related\">\r\n            <dmmp-banner-item-detail class=\"col-6\" [data]=\"contentItem\" (page)=\"page.emit($event)\">\r\n            </dmmp-banner-item-detail>\r\n          </ng-container>\r\n\r\n          <ng-template #related>\r\n            <dmmp-item-content class=\"col-6\" [relatedContent]=\"contentItem\" (page)=\"page.emit($event)\">\r\n            </dmmp-item-content>\r\n          </ng-template>\r\n        </ng-container>\r\n\r\n      </ng-container>\r\n    </div>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchDefault>\r\n    <ng-container *ngIf=\"content?.length > 0\">\r\n      <div class=\"row box-content-4\">\r\n        <ng-container *ngFor=\"let contentItem of content; let i = index\">\r\n\r\n          <ng-container *ngIf=\"i < 2\">\r\n            <ng-container *ngIf=\"contentItem?.identifier === 'columns' && contentItem?.in_related_content; else related\">\r\n              <dmmp-banner-item-detail class=\"col-6\" [data]=\"contentItem\" (page)=\"page.emit($event)\">\r\n              </dmmp-banner-item-detail>\r\n            </ng-container>\r\n\r\n            <ng-template #related>\r\n              <dmmp-item-content class=\"col-6\" [relatedContent]=\"contentItem\" (page)=\"page.emit($event)\">\r\n              </dmmp-item-content>\r\n            </ng-template>\r\n\r\n          </ng-container>\r\n        </ng-container>\r\n      </div>\r\n\r\n      <div class=\"row box-content-4\">\r\n        <ng-container *ngFor=\"let contentItem of content; let i = index\">\r\n          <ng-container *ngIf=\"i >= 2 && i < 4\">\r\n            <ng-container *ngIf=\"contentItem?.identifier === 'columns' && contentItem?.in_related_content; else related\">\r\n              <dmmp-banner-item-detail class=\"col-6\" [data]=\"contentItem\" (page)=\"page.emit($event)\">\r\n              </dmmp-banner-item-detail>\r\n            </ng-container>\r\n\r\n            <ng-template #related>\r\n              <dmmp-item-content class=\"col-6\" [relatedContent]=\"contentItem\" (page)=\"page.emit($event)\">\r\n              </dmmp-item-content>\r\n            </ng-template>\r\n          </ng-container>\r\n\r\n        </ng-container>\r\n      </div>\r\n    </ng-container>\r\n  </ng-container>\r\n</ng-container>\r\n\r\n\r\n"
    })
], BannerItemContentComponent);

let BannerContentDesktopComponent = class BannerContentDesktopComponent {
    constructor(options) {
        this.options = options;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
        this.configCarousel = this.options.configurationBenefits(this.module);
    }
};
BannerContentDesktopComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], BannerContentDesktopComponent.prototype, "module", void 0);
__decorate([
    Input()
], BannerContentDesktopComponent.prototype, "configCarousel", void 0);
__decorate([
    Output()
], BannerContentDesktopComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], BannerContentDesktopComponent.prototype, "page", void 0);
BannerContentDesktopComponent = __decorate([
    Component({
        selector: 'dmmp-banner-content-desktop',
        template: "<ng-container *ngIf=\"module?.content?.length > 0\">\r\n  <ng-container *ngIf=\"module?.content?.length > 1; else simpleBanner\">\r\n    <owl-carousel-o [options]=\"configCarousel\">\r\n      <ng-container *ngFor=\"let carouselBanner of module?.content; let i = index\">\r\n        <ng-template carouselSlide>\r\n          <dmmp-banner-slide [content]=\"carouselBanner\" (page)=\"page.emit($event)\"\r\n            (anchorCustom)=\"anchorCustom.emit($event)\">\r\n          </dmmp-banner-slide>\r\n          <div class=\"container\">\r\n            <div class=\"row content-paginator-box\">\r\n              <div class=\"paginator-box\">\r\n                <span>{{ i + 1 }} / {{ module?.content?.length }}</span>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </ng-template>\r\n      </ng-container>\r\n    </owl-carousel-o>\r\n  </ng-container>\r\n  <ng-template #simpleBanner>\r\n    <dmmp-banner-slide [content]=\"module?.content[0]\" (page)=\"page.emit($event)\"\r\n      (anchorCustom)=\"anchorCustom.emit($event)\">\r\n    </dmmp-banner-slide>\r\n  </ng-template>\r\n</ng-container>\r\n"
    })
], BannerContentDesktopComponent);

let BannerContentMobileComponent = class BannerContentMobileComponent {
    constructor(options) {
        this.options = options;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.totalSlides = 0;
        this.currentSlide = 0;
        this.externContent = [];
    }
    ngOnInit() {
        var _a, _b, _c, _d;
        this.configCarousel = this.options.configurationBenefits(this.module);
        this.totalSlides = (_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.length;
        (_d = (_c = this.module) === null || _c === void 0 ? void 0 : _c.content) === null || _d === void 0 ? void 0 : _d.forEach(contentItem => {
            var _a, _b;
            this.totalSlides += contentItem.related_content.length;
            ((_a = contentItem) === null || _a === void 0 ? void 0 : _a.row) ? (_b = contentItem) === null || _b === void 0 ? void 0 : _b.row.forEach(item => {
                item.columns ? item.columns.forEach(column => {
                    var _a;
                    if (((_a = column) === null || _a === void 0 ? void 0 : _a.in_related_content) === true) {
                        this.totalSlides += 1;
                        this.externContent = [...this.externContent, column];
                    }
                }) : false;
            }) : false;
        });
    }
    changeCarousel(event) {
        var _a;
        this.currentSlide = (_a = event) === null || _a === void 0 ? void 0 : _a.startPosition;
    }
};
BannerContentMobileComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], BannerContentMobileComponent.prototype, "module", void 0);
__decorate([
    Input()
], BannerContentMobileComponent.prototype, "configCarousel", void 0);
__decorate([
    Output()
], BannerContentMobileComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], BannerContentMobileComponent.prototype, "page", void 0);
__decorate([
    ViewChild('slide')
], BannerContentMobileComponent.prototype, "carrousel", void 0);
BannerContentMobileComponent = __decorate([
    Component({
        selector: 'dmmp-banner-content-mobile',
        template: "<ng-container *ngIf=\"module.content.length > 0\">\r\n  <ng-container>\r\n    <owl-carousel-o [options]=\"configCarousel\" (changed)=\"changeCarousel($event)\">\r\n      <ng-container *ngFor=\"let carouselBanner of module.content\">\r\n        <ng-template carouselSlide>\r\n          <div class=\"bg-banner-mobile\"\r\n            [style.backgroundColor]=\" (carouselBanner.background_color) ? (carouselBanner.background_color).color : ''\"\r\n            [style.backgroundImage]=\" (carouselBanner.background_image).length > 0 ? 'url(' + (carouselBanner.background_image)[0].styles.large + ')' : ''\">\r\n            <div [ngClass]=\"['item ', carouselBanner.class ? carouselBanner.class : 'container']\">\r\n              <div *ngFor=\"let rowItem of carouselBanner.row\" [ngClass]=\"rowItem.class ? 'row ' + rowItem.class : ''\"\r\n                [id]=\"rowItem.id ? rowItem.id : ''\">\r\n                <dmmp-banner-item (page)=\"this.page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                  [rowItem]=\"rowItem\">\r\n                </dmmp-banner-item>\r\n              </div>\r\n              <div class=\"row\">\r\n                <div class=\"col-12\">\r\n                  <div class=\"paginator-box\">\r\n                    <span>{{this.currentSlide + 1}} / {{this.totalSlides}}</span>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </ng-template>\r\n        <ng-template carouselSlide *ngFor=\"let contentItem of carouselBanner.related_content\">\r\n          <div class=\"bg-banner-mobile\">\r\n            <div class=\"container-fluid\">\r\n              <div class=\"row\">\r\n                <dmmp-item-content class=\"col-12\" [relatedContent]=\"contentItem\" (page)=\"this.page.emit($event)\"\r\n                  (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-item-content>\r\n                <div class=\"col-12 paginator\">\r\n                  <div class=\"paginator-box\">\r\n                    <span>{{this.currentSlide + 1}} / {{this.totalSlides}}</span>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </ng-template>\r\n      </ng-container>\r\n      <ng-template carouselSlide *ngFor=\"let contentItem of externContent\">\r\n        <div class=\"bg-banner-mobile\">\r\n          <div class=\"container-fluid\">\r\n            <div class=\"row\">\r\n              <dmmp-banner-item-detail class=\"col-12\" [data]=\"contentItem\" (page)=\"this.page.emit($event)\"\r\n                (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-banner-item-detail>\r\n              <div class=\"col-12 paginator\">\r\n                <div class=\"paginator-box\">\r\n                  <span>{{this.currentSlide + 1}} / {{this.totalSlides}}</span>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n    </ng-template>\r\n    </owl-carousel-o>\r\n  </ng-container>\r\n"
    })
], BannerContentMobileComponent);

let ItemContentComponent = class ItemContentComponent {
    constructor() {
        this.page = new EventEmitter();
        this.medias = [
            { style: 'large', media: '(min-width: 1301px)' },
            { style: 'max_1300x1300', media: '(max-width: 1300px) AND (min-width: 651px)' },
            { style: 'max_650x650', media: '(max-width: 650px) AND (min-width: 326px)' },
            { style: 'max_325x325', media: '(max-width: 325px)' },
        ];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], ItemContentComponent.prototype, "relatedContent", void 0);
__decorate([
    Output()
], ItemContentComponent.prototype, "page", void 0);
ItemContentComponent = __decorate([
    Component({
        selector: 'dmmp-item-content',
        template: "<ng-container>\r\n  <a class=\"story-button\"\r\n    (click)=\"page.emit(relatedContent?.path || '')\"\r\n    [routerLink]=\"relatedContent?.path || ''\">\r\n    <div>\r\n      <dmmp-image *ngIf=\"relatedContent?.image_related_content?.length > 0\"\r\n        [ngClass]=\"relatedContent?.class_filter_related_content || ''\"\r\n        [images]=\"relatedContent?.image_related_content[0]\"\r\n        [medias]=\"medias\">\r\n      </dmmp-image>\r\n      <div class=\"story-box\">\r\n        <p *ngIf=\"relatedContent?.identifier\" class=\"story-name\">\r\n            {{relatedContent?.identifier | contentType | uppercase}}\r\n        </p>\r\n        <p class=\"story-description\">\r\n        {{relatedContent?.name || relatedContent?.title | truncatetext : 83 }}\r\n        </p>\r\n        <div *ngIf=\"relatedContent?.identifier == 'event'\" class=\"box-date\">\r\n          <p class=\"date\">\r\n            <span class=\"month\" *ngIf=\"relatedContent?.date?.start\">\r\n              {{relatedContent?.date?.start  | date : 'MMM': 'UTC' | uppercase}}\r\n            </span>\r\n            <span class=\"day\" *ngIf=\"relatedContent?.date?.start\">\r\n              {{relatedContent?.date?.start  | date : 'd': 'UTC'}}\r\n            </span>\r\n          </p>\r\n        </div>\r\n        <a class=\"event-button\">{{relatedContent?.label_call_to_action_related_content}}</a>\r\n      </div>\r\n    </div>\r\n  </a>\r\n</ng-container>\r\n"
    })
], ItemContentComponent);

let BannerSlideComponent = class BannerSlideComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], BannerSlideComponent.prototype, "content", void 0);
__decorate([
    Output()
], BannerSlideComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], BannerSlideComponent.prototype, "page", void 0);
BannerSlideComponent = __decorate([
    Component({
        selector: 'dmmp-banner-slide',
        template: "<div class=\"bg-banner\" [style.backgroundColor]=\"content?.background_color?.color || ''\"\r\n  [style.backgroundImage]=\" (content?.background_image)?.length > 0 ? 'url(' + (content?.background_image)[0]?.styles?.large + ')' : ''\">\r\n  <div [ngClass]=\"['item ', content?.class || 'container']\">\r\n    <div *ngFor=\"let rowItem of content.row\" [ngClass]=\"rowItem?.class ? rowItem.class + ' row content-banner-box' : 'row content-banner-box'\" [id]=\"rowItem?.id\">\r\n      <div [ngClass]=\"content?.related_content?.length > 0 ? 'col-6 box-content': 'col-12 box-content'\">\r\n        <dmmp-banner-item class=\"row\" (page)=\"this.page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n          [rowItem]=\"rowItem\">\r\n        </dmmp-banner-item>\r\n      </div>\r\n      <div class=\"col-6\" *ngIf=\"content?.related_content?.length > 0\">\r\n        <dmmp-banner-item-content [externContent]=\"content?.row\" [relatedContent]=\"content?.related_content\" (page)=\"this.page.emit($event)\"\r\n          (anchorCustom)=\"anchorCustom.emit($event)\">\r\n        </dmmp-banner-item-content>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], BannerSlideComponent);

let BannerGridModule = class BannerGridModule {
};
BannerGridModule = __decorate([
    NgModule({
        declarations: [
            BannerGridComponent,
            BannerItemContentComponent,
            BannerContentDesktopComponent,
            BannerContentMobileComponent,
            ItemContentComponent,
            BannerSlideComponent
        ],
        imports: [
            CommonModule,
            LocalDeviceDetectorModule,
            SharedModule,
            CarouselModule,
            RouterModule,
            PipesModule
        ],
        exports: [
            BannerGridComponent
        ]
    })
], BannerGridModule);

let LogosLinkComponent = class LogosLinkComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
        var _a, _b;
        if (((_a = this.module) === null || _a === void 0 ? void 0 : _a.content) && ((_b = this.module) === null || _b === void 0 ? void 0 : _b.content) > 0) {
            this.module.content.forEach((logo) => {
                logo.showTooltip = false;
            });
        }
    }
    openTooltip(logo) {
        this.closeOthersTooltips(logo);
        logo.showTooltip = !logo.showTooltip;
    }
    closeOthersTooltips(currentLogo) {
        var _a, _b;
        if (((_a = this.module) === null || _a === void 0 ? void 0 : _a.content) && ((_b = this.module) === null || _b === void 0 ? void 0 : _b.content) > 0) {
            this.module.content.forEach((logo) => {
                if (logo.id !== currentLogo.id) {
                    logo.showTooltip = false;
                }
            });
        }
    }
};
__decorate([
    Input()
], LogosLinkComponent.prototype, "module", void 0);
__decorate([
    Input()
], LogosLinkComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], LogosLinkComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], LogosLinkComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], LogosLinkComponent.prototype, "page", void 0);
LogosLinkComponent = __decorate([
    Component({
        selector: 'dmmp-logos-link',
        template: "<dmmp-container [identifier]=\"identifier\"\r\n  [defaultClass]=\"module?.fixed_module ? (module?.class ? module?.class + ' footer-fixed logos-link': 'footer-fixed logos-link') : 'logos-link'\"\r\n  [data]=\"module\">\r\n  <div class=\"container\">\r\n    <div class=\"row\" *ngIf=\"module?.name\">\r\n      <div class=\"col-12\">\r\n        <h2 [ngClass]=\"module?.title_class || ''\">\r\n          {{ module.name }}\r\n        </h2>\r\n      </div>\r\n    </div>\r\n    <div class=\"content\" *ngIf=\"module?.content?.length > 0\">\r\n      <ng-container *ngFor=\"let logo of module?.content\">\r\n        <div class=\"row tooltip-custom\" *ngIf=\"(logo?.items?.length > 0 && logo?.showTooltip)\"\r\n          [style.backgroundColor]=\"logo?.background_color?.color || ''\">\r\n          <div *ngFor=\"let item of logo?.items\"\r\n            [ngClass]=\"item?.class ? item?.class + ' col tooltip-content' : 'col tooltip-content'\">\r\n\r\n            <dmmp-link [data]=\"item\" *ngIf=\"item?.link?.length > 0; else justImg\"\r\n              [ngClass]=\"item?.class ? item?.class + ' icon-text-content' : 'icon-text-content'\">\r\n              <dmmp-image-logo *ngIf=\"item?.image[0]?.image?.length > 0\"\r\n                [data]=\"item?.image[0]?.image\"></dmmp-image-logo>\r\n              <p *ngIf=\"item?.text\" [innerHTML]=\"item?.text\"></p>\r\n            </dmmp-link>\r\n            <ng-template #justImg>\r\n              <div [ngClass]=\"item?.class ? item?.class + ' icon-text-content' : 'icon-text-content'\">\r\n                <dmmp-image-logo *ngIf=\"item?.image[0]?.image?.length > 0\"\r\n                  [data]=\"item?.image[0]?.image\"></dmmp-image-logo>\r\n                <p *ngIf=\"item?.text\" [innerHTML]=\"item?.text\"></p>\r\n              </div>\r\n            </ng-template>\r\n            <dmmp-button *ngIf=\"item?.button?.length > 0\" [data]=\"item?.button[0]\" (page)=\"page.emit($event)\"\r\n              (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-button>\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"module?.component !== 'header_seals'; else headerSeal\">\r\n        <div *ngIf=\" module?.content?.length > 0\"\r\n          [ngClass]=\"module?.scroll_horizontal ? 'not-overflow row main-content': 'row main-content'\">\r\n          <div class=\"col-auto\" *ngFor=\"let logo of module?.content\">\r\n            <dmmp-logos-link-icon [ngClass]=\"logo?.showTooltip ? 'current-open-tooltip': ''\" [logo]=\"logo\" (closeTooltipEmitter)=\"openTooltip($event)\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-logos-link-icon>\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n      <ng-template #headerSeal>\r\n        <div class=\"row\" *ngIf=\"module?.content?.length > 0\">\r\n          <div class=\"col-lg-4 col-12\" *ngFor=\"let logo of module?.content\">\r\n            <dmmp-header-logo (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\" [logo]=\"logo\">\r\n            </dmmp-header-logo>\r\n          </div>\r\n        </div>\r\n      </ng-template>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], LogosLinkComponent);

let LogosLinkIconComponent = class LogosLinkIconComponent {
    constructor() {
        this.closeTooltipEmitter = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.medias = [
            { style: 'thumbnail', media: '(min-width:268px)' }
        ];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], LogosLinkIconComponent.prototype, "logo", void 0);
__decorate([
    Output()
], LogosLinkIconComponent.prototype, "closeTooltipEmitter", void 0);
__decorate([
    Output()
], LogosLinkIconComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], LogosLinkIconComponent.prototype, "page", void 0);
LogosLinkIconComponent = __decorate([
    Component({
        selector: 'dmmp-logos-link-icon',
        template: "<ng-container *ngIf=\"logo?.seal?.length > 0 && logo?.items?.length > 0; else linkIcon\">\r\n  <div [ngClass]=\"logo.seal[0].class ? logo.seal[0].class + ' icon-text-content' : 'icon-text-content'\"\r\n    (click)=\"closeTooltipEmitter.emit(logo)\">\r\n    <dmmp-image *ngIf=\"(logo?.seal[0]?.image?.length > 0 ) ? (logo?.seal[0]?.image[0]?.image?.length > 0) ? logo?.seal[0]?.image[0]?.image[0] : false : false\"\r\n                [medias]=\"medias\"\r\n                [images]=\"logo.seal[0].image[0].image[0]\">\r\n    </dmmp-image>\r\n    <p *ngIf=\"logo?.seal[0]?.text\" [innerHTML]=\"logo.seal[0].text\"></p>\r\n  </div>\r\n  <dmmp-button *ngIf=\"logo?.seal?.length > 0 ? (logo.seal[0]?.button?.length > 0) : false\" [data]=\"logo.seal[0].button[0]\" (page)=\"this.page.emit($event)\"\r\n    (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-button>\r\n</ng-container>\r\n<ng-template #linkIcon>\r\n  <ng-container *ngIf=\"logo?.seal?.length > 0\">\r\n    <dmmp-link [data]=\"logo.seal[0]\" *ngIf=\"logo.seal[0].link && logo.seal[0].link.length > 0; else justImg\"\r\n      [ngClass]=\"logo.seal[0].class ? logo.seal[0].class + ' icon-text-content' : 'icon-text-content'\"\r\n      (page)=\"page.emit($event)\">\r\n      <dmmp-image *ngIf=\"(logo?.seal[0]?.image.length > 0 ) ? (logo.seal[0]?.image[0]?.image?.length > 0) ? logo?.seal[0]?.image[0]?.image[0] : false : false\"\r\n                  [medias]=\"medias\"\r\n                  [images]=\"logo.seal[0].image[0].image[0]\"></dmmp-image>\r\n      <p *ngIf=\"logo?.seal[0]?.text\" [innerHTML]=\"logo.seal[0].text\"></p>\r\n    </dmmp-link>\r\n    <ng-template #justImg>\r\n      <div [ngClass]=\"logo.seal[0].class ? logo.seal[0].class + ' icon-text-content' : 'icon-text-content'\">\r\n        <dmmp-image *ngIf=\"(logo?.seal[0]?.image?.length > 0 ) ? (logo?.seal[0]?.image[0]?.image?.length > 0) ? logo?.seal[0]?.image[0]?.image[0] : false : false\"\r\n                    [medias]=\"medias\"\r\n                    [images]=\"logo.seal[0].image[0].image[0]\"></dmmp-image>\r\n        <p *ngIf=\"logo?.seal[0]?.text\" [innerHTML]=\"logo.seal[0].text\"></p>\r\n      </div>\r\n    </ng-template>\r\n    <dmmp-button *ngIf=\"logo?.seal[0]?.button && logo?.seal[0]?.button?.length > 0\" [data]=\"logo.seal[0].button[0]\" (page)=\"this.page.emit($event)\"\r\n      (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-button>\r\n  </ng-container>\r\n</ng-template>\r\n"
    })
], LogosLinkIconComponent);

let HeaderLogoComponent = class HeaderLogoComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], HeaderLogoComponent.prototype, "logo", void 0);
__decorate([
    Output()
], HeaderLogoComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], HeaderLogoComponent.prototype, "page", void 0);
HeaderLogoComponent = __decorate([
    Component({
        selector: 'dmmp-header-logo',
        template: "<ng-container *ngIf=\"logo?.seal?.length > 0\">\r\n  <dmmp-link [data]=\"logo.seal[0]\" *ngIf=\"logo?.seal[0]?.link?.length > 0; else justImg\"\r\n    [ngClass]=\"logo.seal[0].class ? logo.seal[0].class + ' icon-text-content' : 'icon-text-content'\">\r\n    <div class=\"link-header-box\" [style.backgroundColor]=\"logo.background_color.color ? logo.background_color.color : ''\">\r\n      <p *ngIf=\"logo?.seal[0]?.text\" [innerHTML]=\"logo.seal[0].text\"></p>\r\n      <dmmp-image-logo *ngIf=\"logo?.seal[0]?.image?.length > 0 && logo.seal[0].image[0].image.length > 0\"\r\n        [data]=\"logo.seal[0].image[0].image\"></dmmp-image-logo>\r\n    </div>\r\n  </dmmp-link>\r\n  <ng-template #justImg>\r\n    <div class=\"link-header-box\" [style.backgroundColor]=\"logo.background_color.color ? logo.background_color.color : ''\">\r\n      <div [ngClass]=\"logo.seal[0].class ? logo.seal[0].class + ' icon-text-content' : 'icon-text-content'\">\r\n        <p *ngIf=\"logo?.seal[0]?.text\" [innerHTML]=\"logo.seal[0].text\"></p>\r\n        <dmmp-image-logo *ngIf=\"logo.seal[0].image.length > 0 && logo.seal[0].image[0].image.length > 0\"\r\n          [data]=\"logo?.seal[0]?.image[0]?.image\"></dmmp-image-logo>\r\n      </div>\r\n    </div>\r\n  </ng-template>\r\n</ng-container>\r\n"
    })
], HeaderLogoComponent);

let LogosLinkModule = class LogosLinkModule {
};
LogosLinkModule = __decorate([
    NgModule({
        declarations: [LogosLinkComponent, LogosLinkIconComponent, HeaderLogoComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [LogosLinkComponent],
    })
], LogosLinkModule);

let BenefitsVideoComponent = class BenefitsVideoComponent {
    constructor(richsnipetService) {
        this.richsnipetService = richsnipetService;
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
        if (((_c = (_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content[0]) === null || _b === void 0 ? void 0 : _b.images) === null || _c === void 0 ? void 0 : _c.length) > 0 ||
            (((_f = (_e = (_d = this.module) === null || _d === void 0 ? void 0 : _d.content[0]) === null || _e === void 0 ? void 0 : _e.video) === null || _f === void 0 ? void 0 : _f.length) > 0 &&
                ((_k = (_j = (_h = (_g = this.module) === null || _g === void 0 ? void 0 : _g.content[0]) === null || _h === void 0 ? void 0 : _h.video[0]) === null || _j === void 0 ? void 0 : _j.video) === null || _k === void 0 ? void 0 : _k.length) > 0)) {
            this.schema = this.richsnipetService.setupJsonBeneficVideo((_m = (_l = this.module) === null || _l === void 0 ? void 0 : _l.content[0]) === null || _m === void 0 ? void 0 : _m.video[0]);
        }
    }
};
BenefitsVideoComponent.ctorParameters = () => [
    { type: RichsnipetService }
];
__decorate([
    Input()
], BenefitsVideoComponent.prototype, "module", void 0);
__decorate([
    Input()
], BenefitsVideoComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], BenefitsVideoComponent.prototype, "page", void 0);
__decorate([
    Output()
], BenefitsVideoComponent.prototype, "anchorCustom", void 0);
BenefitsVideoComponent = __decorate([
    Component({
        selector: 'dmmp-benefits-video',
        template: "<ngx-json-ld [json]=\"schema\"></ngx-json-ld>\r\n<dmmp-container [data]=\"module\" [defaultClass]=\"'benefits-video'\">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">\r\n      {{ module?.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"row\" *ngIf=\"module?.content?.length > 0\">\r\n      <div class=\"col-12 col-lg-7 content-video\">\r\n        <ng-container\r\n          *ngIf=\"module?.content[0]?.video?.length > 0 && module?.content[0]?.video[0]?.video?.length > 0; else imgItem\">\r\n          <dmmp-video-player [type]=\"module?.content[0]?.video[0]?.type\" [src]=\"module?.content[0]?.video[0]?.video[0]?.value\">\r\n          </dmmp-video-player>\r\n        </ng-container>\r\n        <ng-template #imgItem>\r\n          <dmmp-image-logo *ngIf=\"module?.content[0]?.images?.length > 0\" [data]=\"module?.content[0]?.images\">\r\n          </dmmp-image-logo>\r\n        </ng-template>\r\n      </div>\r\n      <div class=\"col-12 col-lg-5 box-content\">\r\n        <h3 [ngClass]=\"module?.content[0]?.title_class ? module?.content[0]?.title_class + ' h3' : 'h3'\">\r\n          {{module?.content[0]?.title}}</h3>\r\n        <p [ngClass]=\"module?.content[0]?.description_class ? module?.content[0]?.description_class : ''\"\r\n           [innerHTML]=\"module?.content[0]?.description\"></p>\r\n        <ng-container *ngIf=\"module?.content[0]?.links_icon?.length > 0\">\r\n          <dmmp-link-icon *ngFor=\"let link of module?.content[0]?.links_icon\" [data]=\"link\"\r\n                          (page)=\"page.emit($event)\"\r\n                          (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-link-icon>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], BenefitsVideoComponent);

let BenefitsVideoModule = class BenefitsVideoModule {
};
BenefitsVideoModule = __decorate([
    NgModule({
        declarations: [BenefitsVideoComponent],
        imports: [
            CommonModule,
            SharedModule,
            NgxJsonLdModule
        ],
        exports: [
            BenefitsVideoComponent
        ]
    })
], BenefitsVideoModule);

let ToggleMenuComponent$1 = class ToggleMenuComponent {
    constructor() {
        this.page = new EventEmitter();
        this.clickAction = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Output()
], ToggleMenuComponent$1.prototype, "page", void 0);
__decorate([
    Output()
], ToggleMenuComponent$1.prototype, "clickAction", void 0);
__decorate([
    Input()
], ToggleMenuComponent$1.prototype, "menuIsOpened", void 0);
ToggleMenuComponent$1 = __decorate([
    Component({
        selector: 'dmmp-toggle-menu',
        template: "<div class=\"col-auto d-xl-none nav-menu\">\r\n  <button class=\"navbar-toggler pull-right\" type=\"button\" data-toggle=\"collapse\" data-target=\"#navbarNavDropdown\"\r\n    aria-controls=\"navbarNavDropdown\" aria-expanded=\"false\" aria-label=\"Toggle navigation\" (click)=\"clickAction.emit()\">\r\n    <span class=\"sr-only\">Toggle navigation</span>\r\n    <span [ngClass]=\"menuIsOpened ? 'fas fa-times' : 'fas fa-bars'\"></span>\r\n  </button>\r\n</div>\r\n"
    })
], ToggleMenuComponent$1);

let ContentRowsComponent = class ContentRowsComponent {
    constructor(localDeviceDetector) {
        this.localDeviceDetector = localDeviceDetector;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.menuEmitter = new EventEmitter();
        this.contentEmitter = new EventEmitter();
        this.externalLink = new EventEmitter();
        this.hoverEmitter = new EventEmitter();
        this.medias = [
            { style: 'max_650x650', media: '(min-width: 326px)' },
            { style: 'max_325x325', media: '(max-width: 325px)' },
        ];
    }
    ngOnInit() {
    }
    buttonContentEmit(relatedContent) {
        if (relatedContent.length > 0) {
            this.contentEmitter.emit(relatedContent[0]);
            this.closeRelatedContentButtons(relatedContent[0]);
        }
    }
    closeRelatedContentButtons(currentRelatedContent) {
        this.colItem.items_column.forEach(itemColum => {
            if (itemColum.related_module.length > 0) {
                if (itemColum.identifier === 'button_content' && itemColum.related_module[0].title !== currentRelatedContent.title) {
                    itemColum.active = false;
                }
            }
        });
    }
    clickActionEmitter(itemMenuTo) {
        this.menu.forEach(itemMenu => {
            if (itemMenuTo !== itemMenu) {
                itemMenu.data.active = false;
            }
        });
        this.menuEmitter.emit(itemMenuTo);
    }
};
ContentRowsComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], ContentRowsComponent.prototype, "colItem", void 0);
__decorate([
    Input()
], ContentRowsComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], ContentRowsComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ContentRowsComponent.prototype, "page", void 0);
__decorate([
    Output()
], ContentRowsComponent.prototype, "menuEmitter", void 0);
__decorate([
    Output()
], ContentRowsComponent.prototype, "contentEmitter", void 0);
__decorate([
    Output()
], ContentRowsComponent.prototype, "externalLink", void 0);
__decorate([
    Output()
], ContentRowsComponent.prototype, "hoverEmitter", void 0);
__decorate([
    Input()
], ContentRowsComponent.prototype, "module", void 0);
__decorate([
    Input()
], ContentRowsComponent.prototype, "menu", void 0);
ContentRowsComponent = __decorate([
    Component({
        selector: 'dmmp-content-rows',
        template: "<ng-container *ngIf=\"colItem?.items_column?.length > 0\">\r\n  <ng-container *ngFor=\"let info of colItem?.items_column\">\r\n    <ng-container *ngIf=\"info?.identifier === 'images_link'\">\r\n      <div class=\"content content-logo\" *ngIf=\"info?.link?.length > 0\" (mouseover)=\"hoverEmitter.emit()\">\r\n        <dmmp-simple-link [data]=\"info\" (page)=\"page.emit($event)\" [identifier]=\"identifier\">\r\n          <dmmp-image *ngIf=\"info?.image?.length > 0\" [images]=\"info?.image[0]\" [medias]=\"medias\"></dmmp-image>\r\n        </dmmp-simple-link>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"info?.identifier === 'textos'\">\r\n      <div class=\"content content-text\" *ngIf=\"info?.text\" [ngClass]=\"info?.class || ''\"\r\n        [innerHTML]=\"info?.text\" (mouseover)=\"hoverEmitter.emit()\"></div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"info?.identifier === 'menu'\">\r\n      <div *ngIf=\"localDeviceDetector.isDesktop()\" class=\"content content-menu\">\r\n        <div [style.backgroundColor]=\"module?.background_color?.color || ''\">\r\n          <div class=\"box-menu\" *ngIf=\"menu?.length > 0\">\r\n            <dmmp-item-menu [menuItem]=\"itemMenu\" (actionEmitter)=\"clickActionEmitter(itemMenu)\"\r\n              *ngFor=\"let itemMenu of menu\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (externalLink)=\"externalLink.emit($event)\">\r\n            </dmmp-item-menu>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"info.identifier === 'button'\">\r\n      <div class=\"content content-button buttons-header-desktop\" *ngIf=\"info?.link?.length > 0\" (mouseover)=\"hoverEmitter.emit()\">\r\n        <ul class=\"buttons-actions\">\r\n          <li class=\"nav-item\">\r\n            <dmmp-button [data]=\"info\" [identifier]=\"identifier\" (page)=\"page.emit($event)\"\r\n              (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-button>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"info.identifier === 'button_content'\">\r\n      <div class=\"content button-content\" [ngClass]=\"info?.class || ''\"\r\n        (click)=\"buttonContentEmit(info?.related_module); info.active = !info?.active\" (mouseover)=\"hoverEmitter.emit()\">\r\n        <dmmp-image [medias]=\"medias\" [images]=\"info.icon[0]\" *ngIf=\"info?.icon?.length > 0\"></dmmp-image>\r\n        <a [ngClass]=\"info?.active ? 'active' : ''\">{{info?.label}}</a>\r\n      </div>\r\n    </ng-container>\r\n  </ng-container>\r\n</ng-container>\r\n"
    })
], ContentRowsComponent);

let DynamicsModuleComponent = class DynamicsModuleComponent {
    constructor() {
        this.notSupportedEmitter = new EventEmitter();
        this.clearResult = new EventEmitter();
        this.close = new EventEmitter();
        this.search = new EventEmitter();
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], DynamicsModuleComponent.prototype, "dataComponent", void 0);
__decorate([
    Input()
], DynamicsModuleComponent.prototype, "result", void 0);
__decorate([
    Input()
], DynamicsModuleComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], DynamicsModuleComponent.prototype, "inSlide", void 0);
__decorate([
    Output()
], DynamicsModuleComponent.prototype, "notSupportedEmitter", void 0);
__decorate([
    Output()
], DynamicsModuleComponent.prototype, "clearResult", void 0);
__decorate([
    Output()
], DynamicsModuleComponent.prototype, "close", void 0);
__decorate([
    Output()
], DynamicsModuleComponent.prototype, "search", void 0);
__decorate([
    Output()
], DynamicsModuleComponent.prototype, "page", void 0);
__decorate([
    Output()
], DynamicsModuleComponent.prototype, "anchorCustom", void 0);
DynamicsModuleComponent = __decorate([
    Component({
        selector: 'dmmp-dynamics-module',
        template: "<div class=\"row no-gutters\" *ngIf=\"dataComponent\">\r\n  <div *ngFor=\"let mod of dataComponent\" class=\"col-lg-{{ mod?.number_columns }}\">\r\n    <ng-container dynamicsModule [module]=\"mod\" [identifier]=\"identifier\"\r\n      (notSupportedEmitter)=\"notSupportedEmitter.emit($event)\" (clearResult)=\"clearResult.emit($event)\"\r\n      (search)=\"search.emit($event)\" [searchResult]=\"result\" (close)=\"close.emit()\" [inSlide]=\"inSlide\"\r\n      (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"></ng-container>\r\n  </div>\r\n</div>\r\n"
    })
], DynamicsModuleComponent);

let ReactiveSearchComponent = class ReactiveSearchComponent {
    constructor(richsnipetService) {
        this.richsnipetService = richsnipetService;
        this.clearResult = new EventEmitter();
        this.close = new EventEmitter();
        this.search = new EventEmitter();
        this.page = new EventEmitter();
        this.currentSearch = new EventEmitter();
        this.buildSchema('');
    }
    buildSchema(userSearch) {
        this.schema = this.richsnipetService.setupJsonSearchUniversity(userSearch);
        this.currentSearch.emit(userSearch);
    }
};
ReactiveSearchComponent.ctorParameters = () => [
    { type: RichsnipetService }
];
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "module", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "result", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "inSlide", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "paginationState", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "searchName", void 0);
__decorate([
    Output()
], ReactiveSearchComponent.prototype, "clearResult", void 0);
__decorate([
    Output()
], ReactiveSearchComponent.prototype, "close", void 0);
__decorate([
    Output()
], ReactiveSearchComponent.prototype, "search", void 0);
__decorate([
    Output()
], ReactiveSearchComponent.prototype, "page", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "currentFilters", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "currentSearchUpdate", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "contentResult", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "loaderState", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "isGeneralSearch", void 0);
__decorate([
    Output()
], ReactiveSearchComponent.prototype, "currentSearch", void 0);
__decorate([
    Input()
], ReactiveSearchComponent.prototype, "relateUrl", void 0);
ReactiveSearchComponent = __decorate([
    Component({
        selector: 'dmmp-reactive-search',
        template: "<dmmp-container\r\n  [identifier]=\"identifier\"\r\n  [data]=\"module ? module : {}\"\r\n  [defaultClass]=\"'reactive-search'\"\r\n>\r\n  <div\r\n    class=\"container programs-search\"\r\n    *ngIf=\"\r\n      this.module?.search_content_index?.includes('programs') &&\r\n        this.module.search_content_index.length === 1;\r\n      else searchEventTemplate\r\n    \"\r\n  >\r\n    <ng-container *ngTemplateOutlet=\"searchContentTemplate\"></ng-container>\r\n  </div>\r\n  <ng-template #searchEventTemplate>\r\n    <div\r\n      class=\"container events-search\"\r\n      *ngIf=\"\r\n        this.module?.search_content_index?.includes('event') &&\r\n          this.module.search_content_index.length === 1;\r\n        else blogSearchTemplate\r\n      \"\r\n    >\r\n      <ng-container *ngTemplateOutlet=\"searchContentTemplate\"></ng-container>\r\n    </div>\r\n  </ng-template>\r\n  <ng-template #blogSearchTemplate>\r\n    <div\r\n      class=\"container blog-search\"\r\n      *ngIf=\"\r\n        this.module?.search_content_index?.includes('blog') &&\r\n          this.module.search_content_index.length === 1;\r\n        else newsSearchTemplate\r\n      \"\r\n    >\r\n      <ng-container *ngTemplateOutlet=\"searchContentTemplate\"></ng-container>\r\n    </div>\r\n  </ng-template>\r\n  <ng-template #newsSearchTemplate>\r\n    <div\r\n      class=\"container news-search\"\r\n      *ngIf=\"\r\n        this.module?.search_content_index?.includes('news') &&\r\n          this.module.search_content_index.length === 1;\r\n        else generalSearchTemplate\r\n      \"\r\n    >\r\n      <ng-container *ngTemplateOutlet=\"searchContentTemplate\"></ng-container>\r\n    </div>\r\n  </ng-template>\r\n  <ng-template #generalSearchTemplate>\r\n    <div\r\n      class=\"container general-search\"\r\n      *ngIf=\"\r\n          this.module?.search_content_index?.length > 1 &&\r\n          isGeneralSearch;\r\n        else headerSearchTemplate\r\n      \"\r\n    >\r\n      <ng-container *ngTemplateOutlet=\"searchContentTemplate\"></ng-container>\r\n    </div>\r\n  </ng-template>\r\n  <ng-template #headerSearchTemplate>\r\n    <div class=\"container header-search\">\r\n      <ngx-json-ld *ngIf=\"schema !== {}\" [json]=\"schema\"></ngx-json-ld>\r\n      <ng-container *ngTemplateOutlet=\"searchContentTemplate\"></ng-container>\r\n    </div>\r\n  </ng-template>\r\n</dmmp-container>\r\n<ng-template #searchContentTemplate>\r\n  <dmmp-content-search\r\n    [module]=\"module\"\r\n    [identifier]=\"identifier\"\r\n    [inSlide]=\"inSlide\"\r\n    [result]=\"result\"\r\n    (clearResult)=\"clearResult.emit($event)\"\r\n    (close)=\"close.emit($event)\"\r\n    (page)=\"page.emit($event)\"\r\n    (search)=\"search.emit($event)\"\r\n    [searchName]=\"searchName\"\r\n    (schema)=\"buildSchema($event)\"\r\n    [paginationState]=\"paginationState\"\r\n    [currentFilters]=\"currentFilters\"\r\n    [contentResult]=\"contentResult\"\r\n    [loaderState]=\"loaderState\"\r\n    [currentSearchUpdate]=\"currentSearchUpdate\"\r\n    [relateUrl]=\"relateUrl\"\r\n  ></dmmp-content-search>\r\n</ng-template>\r\n"
    })
], ReactiveSearchComponent);

const componentMapper = {
    search: ReactiveSearchComponent,
    header_seals: LogosLinkComponent
};
let DynamicsModuleDirective = class DynamicsModuleDirective {
    constructor(resolver, container) {
        this.resolver = resolver;
        this.container = container;
        this.notSupportedEmitter = new EventEmitter();
        this.clearResult = new EventEmitter();
        this.close = new EventEmitter();
        this.search = new EventEmitter();
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (this.componentRef) {
            this.componentRef.instance.result = this.searchResult;
        }
    }
    ngOnInit() {
        var _a;
        if (componentMapper[(_a = this.module) === null || _a === void 0 ? void 0 : _a.component]) {
            const factory = this.resolver.resolveComponentFactory(componentMapper[this.module.component]);
            this.componentRef = this.container.createComponent(factory);
            this.componentRef.instance.identifier = this.identifier;
            this.componentRef.instance.module = this.module;
            this.componentRef.instance.clearResult = this.clearResult;
            this.componentRef.instance.search = this.search;
            this.componentRef.instance.close = this.close;
            this.componentRef.instance.inSlide = this.inSlide;
            this.componentRef.instance.result = this.searchResult;
            this.componentRef.instance.page = this.page;
        }
        else {
            this.notSupportedEmitter.emit(this.module);
        }
    }
};
DynamicsModuleDirective.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ViewContainerRef }
];
__decorate([
    Input()
], DynamicsModuleDirective.prototype, "module", void 0);
__decorate([
    Input()
], DynamicsModuleDirective.prototype, "searchResult", void 0);
__decorate([
    Input()
], DynamicsModuleDirective.prototype, "identifier", void 0);
__decorate([
    Input()
], DynamicsModuleDirective.prototype, "detailLayout", void 0);
__decorate([
    Input()
], DynamicsModuleDirective.prototype, "inSlide", void 0);
__decorate([
    Output()
], DynamicsModuleDirective.prototype, "notSupportedEmitter", void 0);
__decorate([
    Output()
], DynamicsModuleDirective.prototype, "clearResult", void 0);
__decorate([
    Output()
], DynamicsModuleDirective.prototype, "close", void 0);
__decorate([
    Output()
], DynamicsModuleDirective.prototype, "search", void 0);
__decorate([
    Output()
], DynamicsModuleDirective.prototype, "page", void 0);
__decorate([
    Output()
], DynamicsModuleDirective.prototype, "anchorCustom", void 0);
DynamicsModuleDirective = __decorate([
    Directive({
        selector: '[dynamicsModule]'
    })
], DynamicsModuleDirective);

let ContentSearchComponent = class ContentSearchComponent {
    constructor(formBuilder, router, location, activatedRoute) {
        this.formBuilder = formBuilder;
        this.router = router;
        this.location = location;
        this.activatedRoute = activatedRoute;
        this.clearResult = new EventEmitter();
        this.close = new EventEmitter();
        this.search = new EventEmitter();
        this.schema = new EventEmitter();
        this.page = new EventEmitter();
        this.linkResultSearch = '/resultado-busqueda';
        this.relateUrl = '/filtros-programas';
        this.isSearching = false;
        this.searchTitle = 'Búsquedas relacionadas';
        this.resultEntriesLabel = 'entradas encontradas';
    }
    ngOnChanges(simpleChange) {
        var _a, _b, _c;
        if (((_b = (_a = simpleChange) === null || _a === void 0 ? void 0 : _a.currentSearchUpdate) === null || _b === void 0 ? void 0 : _b.currentValue) === '') {
            (_c = this.searchGroup) === null || _c === void 0 ? void 0 : _c.reset();
        }
    }
    ngOnInit() {
        if (this.activatedRoute.snapshot.queryParams.q &&
            this.location.pathname !== this.relateUrl) {
            this.searchGroup = this.formBuilder.group({
                search: [
                    this.activatedRoute.snapshot.queryParams.q,
                    [Validators.required, Validators.minLength(3)],
                ],
            });
        }
        else if (this.activatedRoute.snapshot.queryParams.q &&
            this.location.pathname === this.relateUrl) {
            this.searchGroup = this.formBuilder.group({
                search: [
                    this.activatedRoute.snapshot.queryParams.q,
                    [Validators.required, Validators.minLength(3)],
                ],
            });
            this.reactiveInput();
        }
        else {
            this.searchGroup = this.formBuilder.group({
                search: [''],
            });
            this.reactiveInput();
        }
    }
    onSubmit() {
        const searchContentIndex = this.module.search_content_index.length;
        if (this.searchGroup.value['search'] === '') {
            this.router.navigate([], {
                queryParams: { q: null },
                queryParamsHandling: 'merge',
            });
            this.search.emit({
                searchString: null,
                from: 0,
                size: this.paginationState.quantityForPages,
            });
            if (searchContentIndex > 1) {
                this.router.navigate([this.linkResultSearch], {
                    queryParams: { q: this.searchGroup.value['search'] },
                });
                this.page.emit();
            }
        }
        else {
            this.makeQueryString();
        }
    }
    makeQueryString() {
        let contentTypeQuery = '';
        const searchContentIndex = this.module.search_content_index.length;
        if (searchContentIndex > 1) {
            this.isSearching = true;
        }
        if (searchContentIndex > 0) {
            contentTypeQuery = 'AND(';
            this.module.search_content_index.forEach((indexType) => {
                contentTypeQuery += `(content_type:(${indexType}))OR`;
            });
            contentTypeQuery =
                contentTypeQuery.substring(0, contentTypeQuery.length - 2) + ')';
        }
        const searchInput = this.searchGroup.value['search']
            ? this.searchGroup.value['search'].length < 3
                ? ''
                : `(title:(${this.searchGroup.value['search']}))${contentTypeQuery}`
            : '';
        if (searchContentIndex === 1) {
            this.search.emit({
                searchString: `${searchInput}`,
                from: 0,
                size: this.paginationState.quantityForPages,
            });
        }
        else {
            this.search.emit({
                searchString: `${searchInput}`,
                from: 0,
                size: 10,
            });
        }
        if (searchInput === '') {
            this.isSearching = false;
        }
    }
    reactiveInput() {
        const searchContentIndex = this.module.search_content_index.length;
        if (this.module.search_type === 'reactive_search' ||
            (this.module.search_type === 'redirect_search' && searchContentIndex > 1)) {
            this.searchGroup.controls.search.valueChanges
                .pipe(debounceTime(500), distinctUntilChanged(), filter((valueSearch) => { var _a, _b; return ((_a = valueSearch) === null || _a === void 0 ? void 0 : _a.length) >= 3 || ((_b = valueSearch) === null || _b === void 0 ? void 0 : _b.length) === 0; }), tap(() => {
                this.onSubmit();
            }))
                .subscribe();
        }
        else if (this.location.pathname === this.relateUrl) {
            this.searchGroup.controls.search.valueChanges
                .pipe(debounceTime(500), distinctUntilChanged(), filter((valueSearch) => { var _a; return ((_a = valueSearch) === null || _a === void 0 ? void 0 : _a.length) === 0; }), tap(() => {
                this.onSubmit();
            }))
                .subscribe();
        }
    }
    redirectToPage() {
        const searchContentIndex = this.module.search_content_index.length;
        if (searchContentIndex === 1 &&
            this.module.search_content_index.includes('programs') &&
            this.location.pathname !== this.relateUrl) {
            this.router.navigate([this.relateUrl], {
                queryParams: { q: this.searchGroup.value['search'] },
            });
            this.page.emit();
        }
        else if (searchContentIndex === 1 &&
            this.module.search_content_index.includes('programs') &&
            this.location.pathname === this.relateUrl) {
            this.router.navigate([this.relateUrl], {
                queryParams: { q: this.searchGroup.value['search'] },
            });
            this.onSubmit();
        }
        else if (searchContentIndex > 1) {
            this.router.navigate([this.linkResultSearch], {
                queryParams: { q: this.searchGroup.value['search'] },
            });
            this.page.emit();
        }
    }
    closeSearch() {
        this.searchGroup.reset();
        this.onSubmit();
        this.close.emit();
    }
    resetSearch() {
        this.isSearching = false;
        this.searchGroup.reset();
        this.search.emit({ searchString: '', from: 0, size: 10 });
    }
};
ContentSearchComponent.ctorParameters = () => [
    { type: FormBuilder },
    { type: Router },
    { type: PlatformLocation },
    { type: ActivatedRoute }
];
__decorate([
    Input()
], ContentSearchComponent.prototype, "module", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "result", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "inSlide", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "searchName", void 0);
__decorate([
    Output()
], ContentSearchComponent.prototype, "clearResult", void 0);
__decorate([
    Output()
], ContentSearchComponent.prototype, "close", void 0);
__decorate([
    Output()
], ContentSearchComponent.prototype, "search", void 0);
__decorate([
    Output()
], ContentSearchComponent.prototype, "schema", void 0);
__decorate([
    Output()
], ContentSearchComponent.prototype, "page", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "paginationState", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "linkResultSearch", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "currentFilters", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "contentResult", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "loaderState", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "currentSearchUpdate", void 0);
__decorate([
    Input()
], ContentSearchComponent.prototype, "relateUrl", void 0);
ContentSearchComponent = __decorate([
    Component({
        selector: 'dmmp-content-search',
        template: "<div class=\"content-search\">\r\n  <div class=\"content-search-info\">\r\n    <ng-container *ngIf=\"module?.show_h1; else alternativeTitle\">\r\n      <h1 *ngIf=\"module?.name || searchName\" class=\"search-title\">\r\n        {{ searchName ? searchName : module.name }}\r\n      </h1>\r\n    </ng-container>\r\n    <ng-template #alternativeTitle>\r\n      <p *ngIf=\"module.name || searchName\" class=\"search-title\">\r\n        {{ searchName ? searchName : module.name }} </p>\r\n    </ng-template>\r\n    <p class=\"search-filter-result\" *ngIf=\"(module?.search_content_index?.includes('blog')\r\n    || this.module.search_content_index.includes('news')) && this.searchGroup.value['search']?.length > 0\r\n    && module.search_content_index?.length === 1 && !loaderState && this.module?.show_search_results_number\">\r\n      {{result?.length}} {{resultEntriesLabel}}</p>\r\n    <div *ngIf=\"module?.texts?.length > 0\" class=\"search-label\"\r\n      [ngClass]=\"module.texts[0].class ? module.texts[0].class : ''\"\r\n      [innerHTML]=\"module.texts[0].text ? module.texts[0].text : ''\"></div>\r\n  </div>\r\n  <div class=\"search-input-back\">\r\n    <div class=\"back-icon-item\" *ngIf=\"inSlide\" (click)=\"close.emit()\">\r\n      <i class=\"fas fa-arrow-left\"></i>\r\n    </div>\r\n    <form [formGroup]=\"searchGroup\"\r\n      (ngSubmit)=\"this.module?.search_type !== 'redirect_search' ? onSubmit() : redirectToPage()\">\r\n      <div class=\"row no-gutters input-container-search\" *ngIf=\"module?.search\">\r\n        <div class=\"col-md-12\">\r\n          <div class=\"input-container\" [ngClass]=\"module.search.class ? module.search.class : ''\"\r\n            [id]=\"module?.search.id_element ? identifier + '_' + module?.search.id_element : ''\">\r\n            <input [placeholder]=\"module.search.placeholder ? module.search.placeholder : ''\" type=\"text\"\r\n              formControlName=\"search\" />\r\n            <div class=\"btn-search\">\r\n              <button type=\"submit\" [disabled]=\"searchGroup.invalid\" class=\"btn btn-success\">\r\n                <dmmp-image-logo *ngIf=\"module?.search?.image?.length > 0 && !isSearching\"\r\n                  [data]=\"module.search.image\">\r\n                </dmmp-image-logo>\r\n                <div class=\"back-times\" *ngIf=\"isSearching\">\r\n                  <i class=\"fas fa-times\" (click)=\"resetSearch()\"></i>\r\n                </div>\r\n              </button>\r\n            </div>\r\n            <div class=\"btn-close\" (click)=\"closeSearch()\">\r\n              <span [ngClass]=\"'fas fa-times'\"></span>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </form>\r\n  </div>\r\n  <div class=\"result-content-box\">\r\n    <div class=\"row box-result-title\">\r\n      <div class=\"col-md-12\" *ngIf=\"module?.search_results_section_name\">\r\n        <span class=\"result-title\">{{module.search_results_section_name}}</span>\r\n      </div>\r\n    </div>\r\n    <ng-container *ngIf=\"result?.length === 0 && searchGroup?.value['search']?.length >= 3; else resultsTemplate\">\r\n      <div class=\"row box-not-found-title\">\r\n        <p>{{module.search_label_not_found}}</p>\r\n      </div>\r\n    </ng-container>\r\n    <ng-template #resultsTemplate>\r\n      <div class=\"row\" *ngFor=\"let resultItem of result | slice:0:5\">\r\n        <div class=\"col-md-12 result-item\">\r\n          <i class=\"fas fa-search\"></i>\r\n          <ng-container [ngSwitch]=\"resultItem.identifier\">\r\n            <ng-container *ngSwitchCase=\"'event'\">\r\n              <dmmp-path-link [path]=\"resultItem.path\" (page)=\"page.emit($event)\">\r\n                <p [innerHTML]=\"resultItem.name | highligthSearchText : this.searchGroup.value['search']\"></p>\r\n              </dmmp-path-link>\r\n            </ng-container>\r\n            <ng-container *ngSwitchDefault>\r\n              <dmmp-path-link [path]=\"resultItem.path\" (page)=\"page.emit($event)\">\r\n                <p [innerHTML]=\"resultItem.title | highligthSearchText : this.searchGroup.value['search']\"></p>\r\n              </dmmp-path-link>\r\n            </ng-container>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n    </ng-template>\r\n  </div>\r\n</div>\r\n"
    })
], ContentSearchComponent);

let ReactiveSearchModule = class ReactiveSearchModule {
};
ReactiveSearchModule = __decorate([
    NgModule({
        declarations: [ReactiveSearchComponent, ContentSearchComponent],
        imports: [
            CommonModule,
            SharedModule,
            FormsModule,
            ReactiveFormsModule,
            NgxJsonLdModule,
            PipesModule
        ],
        exports: [ReactiveSearchComponent]
    })
], ReactiveSearchModule);

let DynamicsModuleModule = class DynamicsModuleModule {
};
DynamicsModuleModule = __decorate([
    NgModule({
        declarations: [DynamicsModuleComponent, DynamicsModuleDirective],
        imports: [
            CommonModule,
            ReactiveSearchModule,
            LogosLinkModule
        ],
        exports: [DynamicsModuleComponent]
    })
], DynamicsModuleModule);

let MultilevelMenuComponent = class MultilevelMenuComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.externalLink = new EventEmitter();
    }
    ngOnInit() {
    }
    clickAction(data) {
        var _a, _b;
        if (((_b = (_a = data[0]) === null || _a === void 0 ? void 0 : _a.data.content_menu) === null || _b === void 0 ? void 0 : _b.length) > 0) {
            this.selectedContent = data[0].data.content_menu;
        }
        switch (data[1]) {
            case 2: {
                this.changeThirdLevel(data);
                this.closeSecondLevel(data);
                this.closeThirdLevel(data);
                this.closeFourthLevel(data);
                break;
            }
            case 3: {
                this.changeFourthLevel(data);
                this.closeThirdLevel(data);
                this.closeFourthLevel(data);
                break;
            }
            case 4: {
                this.closeFourthLevel(data);
                break;
            }
        }
    }
    changeFourthLevel(data) {
        if (data[0].data.same_column) {
            this.fourthLevelMenuMode = 'same_column';
            if (this.fourthLevelMenu !== data[0]) {
                data[0].data.isCollapse = true;
                this.fourthLevelMenu = data[0];
            }
            else {
                this.fourthLevelMenu = null;
            }
        }
        else {
            if (this.fourthLevelMenu !== data[0]) {
                this.fourthLevelMenu = data[0];
            }
            else {
                this.fourthLevelMenu = null;
            }
            this.fourthLevelMenuMode = 'new_column';
        }
    }
    changeThirdLevel(data) {
        var _a, _b;
        this.fourthLevelMenu = null;
        this.fourthLevelMenuMode = null;
        if (((_b = (_a = data) === null || _a === void 0 ? void 0 : _a.children) === null || _b === void 0 ? void 0 : _b.length) === 0) {
            this.thirdLevelMenu = null;
            return;
        }
        if (this.thirdLevelMenu !== data[0]) {
            this.thirdLevelMenu = data[0];
        }
    }
    closeSecondLevel(data) {
        var _a;
        (_a = this.secondLevelMenu) === null || _a === void 0 ? void 0 : _a.forEach(secondLevelItem => {
            if (secondLevelItem !== data[0]) {
                secondLevelItem.data.active = false;
            }
        });
    }
    closeThirdLevel(data) {
        var _a, _b;
        (_b = (_a = this.thirdLevelMenu) === null || _a === void 0 ? void 0 : _a.children) === null || _b === void 0 ? void 0 : _b.forEach(thirdLevelItem => {
            if (thirdLevelItem !== data[0]) {
                thirdLevelItem.data.active = false;
                thirdLevelItem.data.isCollapse = false;
            }
        });
    }
    closeFourthLevel(data) {
        var _a, _b;
        (_b = (_a = this.fourthLevelMenu) === null || _a === void 0 ? void 0 : _a.children) === null || _b === void 0 ? void 0 : _b.forEach(fourthLevelItem => {
            if (fourthLevelItem !== data[0]) {
                fourthLevelItem.data.active = false;
            }
        });
    }
};
__decorate([
    Input()
], MultilevelMenuComponent.prototype, "secondLevelMenu", void 0);
__decorate([
    Input()
], MultilevelMenuComponent.prototype, "thirdLevelMenu", void 0);
__decorate([
    Input()
], MultilevelMenuComponent.prototype, "fourthLevelMenu", void 0);
__decorate([
    Input()
], MultilevelMenuComponent.prototype, "selectedContent", void 0);
__decorate([
    Input()
], MultilevelMenuComponent.prototype, "safeZone", void 0);
__decorate([
    Input()
], MultilevelMenuComponent.prototype, "backgrounds", void 0);
__decorate([
    Output()
], MultilevelMenuComponent.prototype, "page", void 0);
__decorate([
    Output()
], MultilevelMenuComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], MultilevelMenuComponent.prototype, "externalLink", void 0);
MultilevelMenuComponent = __decorate([
    Component({
        selector: 'dmmp-multilevel-menu',
        template: "<div [ngClass]=\"!safeZone ? 'container-fluid' : 'container'\" *ngIf=\"secondLevelMenu\">\r\n  <div class=\"row box-multilevel\">\r\n    <div class=\"col first-column\"\r\n      [style.backgroundColor]=\"backgrounds?.length > 1 && safeZone ? (backgrounds[1]?.background_levels_color?.color | colorOpacity : backgrounds[1]?.background_levels_color?.opacity) : ''\">\r\n      <div class=\"row\" *ngFor=\"let secondLevelItem of secondLevelMenu\">\r\n        <dmmp-item-menu [menuItem]=\"secondLevelItem\" [menuLevel]=\"2\" (actionEmitter)=\"clickAction($event)\"\r\n          (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n          (externalLink)=\"externalLink.emit($event)\">\r\n        </dmmp-item-menu>\r\n      </div>\r\n    </div>\r\n    <div class=\"col second-column\" *ngIf=\"thirdLevelMenu?.children?.length\"\r\n      [style.backgroundColor]=\"backgrounds?.length > 2 && safeZone ? (backgrounds[2]?.background_levels_color?.color | colorOpacity : backgrounds[2]?.background_levels_color?.opacity) : ''\">\r\n      <div data-container=\"scroll\">\r\n        <div class=\"row\" *ngFor=\"let thirdLevelItem of thirdLevelMenu.children\">\r\n          <div class=\"col-12\">\r\n            <dmmp-item-menu [menuItem]=\"thirdLevelItem\" [menuLevel]=\"3\" (actionEmitter)=\"clickAction($event)\"\r\n              (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (externalLink)=\"externalLink.emit($event)\">\r\n            </dmmp-item-menu>\r\n          </div>\r\n          <div class=\"col-12 third-column\"\r\n            [style.backgroundColor]=\"backgrounds?.length > 3 && safeZone ? (backgrounds[3]?.background_levels_color?.color | colorOpacity : backgrounds[3]?.background_levels_color?.opacity) : ''\"\r\n            *ngIf=\"thirdLevelItem?.data?.isCollapse && fourthLevelMenu?.children?.length > 0 && fourthLevelMenuMode === 'same_column'\">\r\n            <div class=\"row\" *ngFor=\"let fourthLevelItem of fourthLevelMenu.children\">\r\n              <dmmp-item-menu [menuItem]=\"fourthLevelItem\" [menuLevel]=\"4\" (actionEmitter)=\"clickAction($event)\"\r\n                (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                (externalLink)=\"externalLink.emit($event)\">\r\n              </dmmp-item-menu>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <div class=\"col third-column\"\r\n      [style.backgroundColor]=\"backgrounds?.length > 3 && safeZone ? (backgrounds[3]?.background_levels_color?.color | colorOpacity : backgrounds[3]?.background_levels_color?.opacity) : ''\"\r\n      *ngIf=\"fourthLevelMenu?.children?.length > 0 && fourthLevelMenuMode === 'new_column'\">\r\n      <div class=\"row\" *ngFor=\"let fourthLevelItem of fourthLevelMenu.children\">\r\n        <dmmp-item-menu [menuItem]=\"fourthLevelItem\" [menuLevel]=\"4\" (actionEmitter)=\"clickAction($event)\"\r\n          (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n          (externalLink)=\"externalLink.emit($event)\">\r\n        </dmmp-item-menu>\r\n      </div>\r\n    </div>\r\n    <div class=\"col multilevel-menu-content\"\r\n      [style.backgroundColor]=\"backgrounds?.length > 4 && safeZone ? (backgrounds[4]?.background_levels_color.color | colorOpacity : backgrounds[4]?.background_levels_color.opacity) : ''\">\r\n      <dmmp-item-content [content]=\"selectedContent\" (page)=\"page.emit($event)\"\r\n        (anchorCustom)=\"anchorCustom.emit($event)\" (externalLink)=\"externalLink.emit($event)\"></dmmp-item-content>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], MultilevelMenuComponent);

let ItemMenuComponent = class ItemMenuComponent {
    constructor() {
        this.actionEmitter = new EventEmitter();
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.externalLink = new EventEmitter();
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e, _f;
        this.linkData = {
            link: [
                {
                    link: (_b = (_a = this.menuItem) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.link,
                    name: (_d = (_c = this.menuItem) === null || _c === void 0 ? void 0 : _c.data) === null || _d === void 0 ? void 0 : _d.name
                }
            ],
            target: (_f = (_e = this.menuItem) === null || _e === void 0 ? void 0 : _e.data) === null || _f === void 0 ? void 0 : _f.target
        };
    }
};
__decorate([
    Input()
], ItemMenuComponent.prototype, "menuItem", void 0);
__decorate([
    Input()
], ItemMenuComponent.prototype, "menuLevel", void 0);
__decorate([
    Output()
], ItemMenuComponent.prototype, "actionEmitter", void 0);
__decorate([
    Output()
], ItemMenuComponent.prototype, "page", void 0);
__decorate([
    Output()
], ItemMenuComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ItemMenuComponent.prototype, "externalLink", void 0);
ItemMenuComponent = __decorate([
    Component({
        selector: 'dmmp-item-menu',
        template: "<ng-container>\r\n    <div class=\"link-content\" [ngClass]=\"menuItem?.data?.active ? 'active' : ''\"\r\n      (mouseenter)=\"actionEmitter.emit([this.menuItem, this.menuLevel]); menuItem?.data?.active ? menuItem.data.active = false : menuItem.data.active = true\">\r\n      <div class=\"item-menu\">\r\n        <dmmp-image-logo *ngIf=\"menuItem?.data?.icon?.length > 0\" [data]=\"menuItem?.data?.icon\"></dmmp-image-logo>\r\n\r\n        <dmmp-link *ngIf=\"menuItem?.data?.link; else noLink\" [data]=\"linkData\"\r\n          [defaultClass]=\"(menuItem?.children?.length > 0) ? 'nav-link arrow-link' : 'nav-link'\"\r\n          (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n          (externalLink)=\"externalLink.emit($event)\">\r\n          {{menuItem?.data?.name}}\r\n        </dmmp-link>\r\n\r\n        <ng-template #noLink>\r\n          <p [class]=\"(menuItem?.children?.length > 0) ? 'nav-link arrow-link' : 'nav-link'\">{{menuItem?.data?.name}}</p>\r\n        </ng-template>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n\r\n"
    })
], ItemMenuComponent);

let ItemContentComponent$1 = class ItemContentComponent {
    constructor(dateFormatService) {
        this.dateFormatService = dateFormatService;
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.externalLink = new EventEmitter();
        this.medias = [
            { style: 'large', media: '(min-width:421px)' },
        ];
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
        if (((_a = this.content) === null || _a === void 0 ? void 0 : _a.length) > 0) {
            switch ((_b = this.content[0]) === null || _b === void 0 ? void 0 : _b.identifier) {
                case 'related_content_menu': {
                    if (((_d = (_c = this.content[0]) === null || _c === void 0 ? void 0 : _c.related_content) === null || _d === void 0 ? void 0 : _d.length) > 0) {
                        switch ((_e = this.content[0]) === null || _e === void 0 ? void 0 : _e.related_content[0].identifier) {
                            case 'event': {
                                if (!(((_h = (_g = (_f = this.content[0]) === null || _f === void 0 ? void 0 : _f.related_content[0]) === null || _g === void 0 ? void 0 : _g.date) === null || _h === void 0 ? void 0 : _h.start) instanceof Date)) {
                                    this.content[0].related_content[0].date.start = this.dateFormatService.convertFromTimestampToDate((_j = this.content[0].related_content[0].date) === null || _j === void 0 ? void 0 : _j.start);
                                }
                                break;
                            }
                            case 'story': {
                                if (!(((_l = (_k = this.content[0]) === null || _k === void 0 ? void 0 : _k.related_content[0]) === null || _l === void 0 ? void 0 : _l.created_at) instanceof Date)) {
                                    this.content[0].related_content[0].created_at = this.dateFormatService.convertFromTimestampToDate(this.content[0].related_content[0].created_at);
                                }
                                break;
                            }
                            case 'course': {
                                this.content[0].related_content[0].callToActionText = 'Ver mas';
                                break;
                            }
                        }
                    }
                    break;
                }
            }
        }
    }
};
ItemContentComponent$1.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], ItemContentComponent$1.prototype, "content", void 0);
__decorate([
    Output()
], ItemContentComponent$1.prototype, "page", void 0);
__decorate([
    Output()
], ItemContentComponent$1.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ItemContentComponent$1.prototype, "externalLink", void 0);
ItemContentComponent$1 = __decorate([
    Component({
        selector: 'dmmp-item-content',
        template: "<ng-container *ngIf=\"content?.length > 0\">\r\n  <ng-container [ngSwitch]=\"content[0]?.identifier\">\r\n    <ng-container *ngSwitchCase=\"'content_menu'\">\r\n      <div class=\"content-menu-box\">\r\n        <dmmp-image-logo *ngIf=\"(content[0]?.imagen).length > 0\" [data]=\"content[0]?.imagen\"></dmmp-image-logo>\r\n        <p class=\"title-item\" [ngClass]=\"content[0]?.class ? content[0]?.class : ''\">{{content[0]?.title}}</p>\r\n        <p class=\"subtitle-item\" [ngClass]=\"content[0]?.subtitle_class ? content[0]?.subtitle_class : ''\">\r\n          {{content[0]?.subtitle}}</p>\r\n        <dmmp-link *ngIf=\" content[0]?.link?.length > 0\" [data]=\"content[0]\"\r\n          (page)=\"page.emit($event)\" [defaultClass]=\"'link-item'\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n          (externalLink)=\"externalLink.emit($event)\">\r\n          {{content[0]?.link[0]?.name}}\r\n        </dmmp-link>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngSwitchCase=\"'related_content_menu'\">\r\n      <ng-container *ngIf=\"content[0]?.related_content?.length > 0\"\r\n        [ngSwitch]=\"content[0]?.related_content[0].identifier\">\r\n        <ng-container *ngSwitchCase=\"'blog'\">\r\n          <div class=\"content-menu-box\">\r\n            <dmmp-image-logo *ngIf=\"(content[0]?.related_content[0]?.image).length > 0\"\r\n              [data]=\"content[0]?.related_content[0]?.image\"></dmmp-image-logo>\r\n            <p class=\"title-item\"\r\n              [ngClass]=\"content[0]?.related_content[0]?.title_class ? content[0]?.related_content[0].title_class : ''\">\r\n              {{content[0]?.related_content[0].title}}\r\n            </p>\r\n            <p class=\"subtitle-item\" *ngIf=\"content[0]?.related_content[0]?.categories?.length > 0\">\r\n              {{content[0]?.related_content[0]?.categories[0]}}</p>\r\n            <dmmp-link *ngIf=\"content[0]?.related_content[0]?.link && content[0]?.related_content[0]?.link?.length > 0\"\r\n              [data]=\"content[0]?.related_content[0]\" (page)=\"page.emit($event)\" [defaultClass]=\"'link-item'\"\r\n              (anchorCustom)=\"anchorCustom.emit($event)\" (externalLink)=\"externalLink.emit($event)\">\r\n              {{content[0]?.related_content[0]?.link[0]?.name}}\r\n            </dmmp-link>\r\n          </div>\r\n        </ng-container>\r\n        <ng-container *ngSwitchCase=\"'course'\">\r\n          <div class=\"content-menu-box\">\r\n            <dmmp-image *ngIf=\"(content[0]?.related_content[0]?.recommended_image).length > 0\"\r\n              [images]=\"content[0]?.related_content[0]?.recommended_image[0]\" [medias]=\"medias\"></dmmp-image>\r\n            <p class=\"title-item\">\r\n              {{content[0]?.related_content[0]?.title}}\r\n            </p>\r\n            <p class=\"subtitle-item\" *ngIf=\"content[0]?.related_content[0]?.university?.length > 0\">\r\n              {{content[0]?.related_content[0]?.university[0].title}}</p>\r\n            <dmmp-link *ngIf=\"content[0]?.related_content[0]?.path\"\r\n              [data]=\"{ link: [{ link: content[0]?.related_content[0]?.path, name: content[0]?.related_content[0]?.title }], target: content[0]?.related_content[0]?.target_link }\"\r\n              (page)=\"page.emit($event)\" [defaultClass]=\"'link-item'\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (externalLink)=\"externalLink.emit($event)\">\r\n              {{content[0]?.related_content[0]?.callToActionText}}\r\n            </dmmp-link>\r\n          </div>\r\n        </ng-container>\r\n        <ng-container *ngSwitchCase=\"'event'\">\r\n          <div class=\"content-menu-box\">\r\n            <dmmp-image-logo *ngIf=\"(content[0]?.related_content[0]?.image).length > 0\"\r\n              [data]=\"content[0]?.related_content[0]?.image\"></dmmp-image-logo>\r\n            <p class=\"title-item\"\r\n              [ngClass]=\"content[0]?.related_content[0]?.title_class ? content[0]?.related_content[0]?.title_class : ''\">\r\n              {{content[0]?.related_content[0]?.name}}\r\n            </p>\r\n            <p class=\"subtitle-item\"\r\n              [ngClass]=\"content[0]?.related_content[0]?.date_class ? content[0]?.related_content[0]?.date_class : ''\">\r\n              {{content[0]?.related_content[0]?.date.start | date : 'longDate': 'UTC'}}</p>\r\n            <dmmp-link *ngIf=\"content[0]?.related_content[0]?.path\"\r\n              [data]=\"{ link: [{ link: content[0]?.related_content[0]?.path, name: content[0]?.related_content[0]?.name }], target: content[0]?.related_content[0]?.target_link }\"\r\n              (page)=\"page.emit($event)\" [defaultClass]=\"'link-item'\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (externalLink)=\"externalLink.emit($event)\">\r\n              {{content[0]?.related_content[0]?.button_label}}\r\n            </dmmp-link>\r\n          </div>\r\n        </ng-container>\r\n        <ng-container *ngSwitchCase=\"'story'\">\r\n          <div class=\"content-menu-box\">\r\n            <dmmp-image-logo *ngIf=\"(content[0]?.related_content[0]?.imagen).length > 0\"\r\n              [data]=\"content[0]?.related_content[0]?.imagen\"></dmmp-image-logo>\r\n            <p class=\"title-item\"\r\n              [ngClass]=\"content[0]?.related_content[0]?.title_class ? content[0]?.related_content[0]?.title_class : ''\">\r\n              {{content[0]?.related_content[0]?.title}}\r\n            </p>\r\n            <p class=\"subtitle-item\"\r\n              [ngClass]=\"content[0]?.related_content[0]?.date_class ? content[0]?.related_content[0]?.date_class : ''\">\r\n              {{content[0]?.related_content[0]?.created_at | date : 'longDate': 'UTC'}}</p>\r\n            <dmmp-link *ngIf=\"content[0]?.related_content[0]?.path\"\r\n              [data]=\"{ link: [{ link: content[0]?.related_content[0]?.path, name: content[0]?.related_content[0]?.title }], target: content[0]?.related_content[0]?.target_link }\"\r\n              (page)=\"page.emit($event)\" [defaultClass]=\"'link-item'\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (externalLink)=\"externalLink.emit($event)\">\r\n              {{content[0]?.related_content[0]?.button_label}}\r\n            </dmmp-link>\r\n          </div>\r\n        </ng-container>\r\n      </ng-container>\r\n    </ng-container>\r\n  </ng-container>\r\n</ng-container>\r\n"
    })
], ItemContentComponent$1);

let MultilevelMenuModule = class MultilevelMenuModule {
};
MultilevelMenuModule = __decorate([
    NgModule({
        declarations: [MultilevelMenuComponent, ItemMenuComponent, ItemContentComponent$1],
        imports: [
            CommonModule,
            SharedModule,
            RouterModule,
            PipesModule
        ],
        exports: [MultilevelMenuComponent]
    })
], MultilevelMenuModule);

let MobileMenuComponent$1 = class MobileMenuComponent {
    constructor(localDeviceDetector) {
        this.localDeviceDetector = localDeviceDetector;
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.externalLink = new EventEmitter();
        this.buttons = [];
        this.mode = 'm';
    }
    ngOnInit() {
    }
};
MobileMenuComponent$1.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], MobileMenuComponent$1.prototype, "menu", void 0);
__decorate([
    Input()
], MobileMenuComponent$1.prototype, "menuItemColumn", void 0);
__decorate([
    Input()
], MobileMenuComponent$1.prototype, "universityInfo", void 0);
__decorate([
    Output()
], MobileMenuComponent$1.prototype, "page", void 0);
__decorate([
    Output()
], MobileMenuComponent$1.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], MobileMenuComponent$1.prototype, "externalLink", void 0);
__decorate([
    Input()
], MobileMenuComponent$1.prototype, "buttons", void 0);
MobileMenuComponent$1 = __decorate([
    Component({
        selector: 'dmmp-mobile-menu',
        template: "<div [ngSwitch]=\"universityInfo?.universityIdentifier?.toLowerCase()\">\r\n  <div *ngSwitchCase=\"'siglo'\">\r\n    <dmmp-collapse-mobile-menu [menu]=\"menu\" [menuItemColumn]=\"menuItemColumn\"\r\n      (anchorCustom)=\"anchorCustom.emit($event)\" (externalLink)=\"externalLink.emit($event)\" (page)=\"page.emit($event)\">\r\n    </dmmp-collapse-mobile-menu>\r\n  </div>\r\n  <div *ngSwitchCase=\"'moc'\">\r\n    <dmmp-horizontal-mobile-menu [menu]=\"menu\" [menuItemColumn]=\"menuItemColumn\"\r\n      (anchorCustom)=\"anchorCustom.emit($event)\" (externalLink)=\"externalLink.emit($event)\" (page)=\"page.emit($event)\"\r\n      [buttons]=\"buttons\">\r\n    </dmmp-horizontal-mobile-menu>\r\n  </div>\r\n</div>\r\n"
    })
], MobileMenuComponent$1);

let ItemMenuComponent$1 = class ItemMenuComponent {
    constructor() {
        this.actionEmitter = new EventEmitter();
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.externalLink = new EventEmitter();
        this.medias = [
            { style: 'max_650x650', media: '(min-width: 326px)' },
            { style: 'max_325x325', media: '(max-width: 325px)' },
        ];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], ItemMenuComponent$1.prototype, "menuItem", void 0);
__decorate([
    Input()
], ItemMenuComponent$1.prototype, "menuLevel", void 0);
__decorate([
    Output()
], ItemMenuComponent$1.prototype, "actionEmitter", void 0);
__decorate([
    Output()
], ItemMenuComponent$1.prototype, "page", void 0);
__decorate([
    Output()
], ItemMenuComponent$1.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ItemMenuComponent$1.prototype, "externalLink", void 0);
ItemMenuComponent$1 = __decorate([
    Component({
        selector: 'dmmp-item-menu',
        template: "<ng-container>\r\n  <div class=\"link-content link-menu\" [ngClass]=\"menuItem?.data?.active ? 'active' : ''\"\r\n  (mouseenter)=\"actionEmitter.emit([menuItem, menuLevel]); menuItem?.data?.active ? menuItem?.data.active = false : menuItem?.data.active = true\">\r\n    <dmmp-image *ngIf=\"menuItem?.data?.icon?.length > 0\" [images]=\"menuItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n    <dmmp-link *ngIf=\"menuItem?.data?.link; else noLink\" [data]=\"{ link: [{ link: menuItem?.data?.link, name: menuItem?.data?.name }], target: '_blank' }\"\r\n      [defaultClass]=\"menuItem?.children?.length > 0 ? 'nav-link arrow-link' : 'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n      (externalLink)=\"externalLink.emit($event)\">\r\n      {{menuItem?.data?.name}}\r\n    </dmmp-link>\r\n    <ng-template #noLink>\r\n      <p [class]=\"menuItem?.children?.length > 0 ? 'nav-link arrow-link' : 'nav-link'\">{{menuItem?.data?.name}}</p>\r\n    </ng-template>\r\n  </div>\r\n</ng-container>\r\n"
    })
], ItemMenuComponent$1);

let WebsiteHeaderV2Component = class WebsiteHeaderV2Component {
    constructor(localDeviceDetector, richsnipetService) {
        this.localDeviceDetector = localDeviceDetector;
        this.richsnipetService = richsnipetService;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.notSupportedEmitter = new EventEmitter();
        this.clearResult = new EventEmitter();
        this.search = new EventEmitter();
        this.menuIsOpened = false;
        this.searchIsOpened = false;
        this.buttonsHeader = [];
    }
    ngOnInit() {
        var _a, _b, _c;
        (_c = (_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.row) === null || _c === void 0 ? void 0 : _c.forEach(rowItem => {
            var _a;
            (_a = rowItem) === null || _a === void 0 ? void 0 : _a.column.forEach(column => {
                var _a, _b;
                (_b = (_a = column) === null || _a === void 0 ? void 0 : _a.items_column) === null || _b === void 0 ? void 0 : _b.forEach(itemColumn => {
                    var _a, _b;
                    if (((_a = itemColumn) === null || _a === void 0 ? void 0 : _a.identifier) === 'menu') {
                        this.menuItemColumn = itemColumn;
                    }
                    if (((_b = itemColumn) === null || _b === void 0 ? void 0 : _b.identifier) === 'button') {
                        this.buttonsHeader.push(itemColumn);
                    }
                });
            });
        });
        this.schema = this.richsnipetService.setupJsonUniversity(this.universityInfo);
    }
    closeAndOpenMenu() {
        this.menuIsOpened ? this.menuIsOpened = false : this.menuIsOpened = true;
        this.multilevelMenu = null;
        this.closeMultilevelMenu();
    }
    closeAll() {
        this.searchIsOpened = false;
        this.menuIsOpened = false;
        this.currentRelatedContent = null;
        this.multilevelMenu = null;
        this.notSupportedEmitter.emit(null);
        this.closeMultilevelMenu();
        this.closeRelatedContentButtons();
        if (this.multilevelMenuC) {
            this.multilevelMenuC.closeSecondLevel(event);
            this.multilevelMenuC.closeThirdLevel(event);
            this.multilevelMenuC.selectedContent = [];
            this.multilevelMenuC.fourthLevelMenu = [];
            this.multilevelMenuC.thirdLevelMenu = [];
            this.multilevelMenuC.fourthLevelMenuMode = null;
        }
    }
    relatedContentUpdate(relatedContent) {
        var _a, _b, _c, _d, _e, _f;
        this.multilevelMenu = null;
        this.searchIsOpened = false;
        this.menuIsOpened = false;
        this.notSupportedEmitter.emit(null);
        if (this.currentRelatedContent) {
            if (((_a = this.currentRelatedContent) === null || _a === void 0 ? void 0 : _a.id) === ((_b = relatedContent) === null || _b === void 0 ? void 0 : _b.id) && ((_c = this.currentRelatedContent) === null || _c === void 0 ? void 0 : _c.component) === ((_d = relatedContent) === null || _d === void 0 ? void 0 : _d.component)) {
                this.searchIsOpened = false;
                this.currentRelatedContent = null;
            }
            else {
                if (this.localDeviceDetector.isMobile() && ((_e = relatedContent) === null || _e === void 0 ? void 0 : _e.component) === 'search') {
                    this.searchIsOpened = true;
                }
                else {
                    this.searchIsOpened = false;
                }
                this.currentRelatedContent = relatedContent;
            }
        }
        else {
            if (this.localDeviceDetector.isMobile() && ((_f = relatedContent) === null || _f === void 0 ? void 0 : _f.component) === 'search') {
                this.searchIsOpened = true;
            }
            else {
                this.searchIsOpened = false;
            }
            this.currentRelatedContent = relatedContent;
        }
    }
    changeSecondLevel(event) {
        this.searchIsOpened = false;
        this.notSupportedEmitter.emit(null);
        this.currentRelatedContent = null;
        if (this.multilevelMenu !== event) {
            this.multilevelMenu = event;
        }
        if (this.multilevelMenuC) {
            this.multilevelMenuC.closeSecondLevel(event);
            this.multilevelMenuC.closeThirdLevel(event);
            this.multilevelMenuC.fourthLevelMenu = [];
            this.multilevelMenuC.thirdLevelMenu = [];
            this.multilevelMenuC.fourthLevelMenuMode = null;
        }
    }
    notSupportedEvent(notSupportedModule) {
        if (notSupportedModule) {
            this.notSupportedEmitter.emit(notSupportedModule);
        }
    }
    closeSearch() {
        this.multilevelMenu = null;
        this.searchIsOpened = false;
        this.menuIsOpened = false;
        this.currentRelatedContent = null;
        this.notSupportedEmitter.emit(null);
        this.closeMultilevelMenu();
        this.closeRelatedContentButtons();
    }
    closeRelatedContentButtons() {
        var _a, _b, _c;
        (_c = (_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.row[0]) === null || _c === void 0 ? void 0 : _c.column.forEach(column => {
            var _a, _b;
            (_b = (_a = column) === null || _a === void 0 ? void 0 : _a.items_column) === null || _b === void 0 ? void 0 : _b.forEach(itemColum => {
                itemColum.active = false;
            });
        });
    }
    closeMultilevelMenu() {
        var _a;
        this.multilevelMenu = null;
        (_a = this.principalMenu['main-menu']) === null || _a === void 0 ? void 0 : _a.forEach(itemMenu => {
            itemMenu.data.active = false;
        });
    }
    pageEmitter(event) {
        this.closeAll();
        this.page.emit(event);
    }
    anchorEmitter(event) {
        this.closeAll();
        this.anchorCustom.emit(event);
    }
    externalLinkEmitter() {
        this.closeAll();
    }
};
WebsiteHeaderV2Component.ctorParameters = () => [
    { type: LocalDeviceDetectorService },
    { type: RichsnipetService }
];
__decorate([
    Output()
], WebsiteHeaderV2Component.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], WebsiteHeaderV2Component.prototype, "page", void 0);
__decorate([
    Output()
], WebsiteHeaderV2Component.prototype, "notSupportedEmitter", void 0);
__decorate([
    Output()
], WebsiteHeaderV2Component.prototype, "clearResult", void 0);
__decorate([
    Output()
], WebsiteHeaderV2Component.prototype, "search", void 0);
__decorate([
    Input()
], WebsiteHeaderV2Component.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteHeaderV2Component.prototype, "result", void 0);
__decorate([
    Input()
], WebsiteHeaderV2Component.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteHeaderV2Component.prototype, "principalMenu", void 0);
__decorate([
    Input()
], WebsiteHeaderV2Component.prototype, "multilevelMenu", void 0);
__decorate([
    Input()
], WebsiteHeaderV2Component.prototype, "universityInfo", void 0);
__decorate([
    ViewChild('multilevelMenuC')
], WebsiteHeaderV2Component.prototype, "multilevelMenuC", void 0);
WebsiteHeaderV2Component = __decorate([
    Component({
        selector: 'dmmp-website-header-v2',
        template: "<ngx-json-ld [json]=\"schema\"></ngx-json-ld>\r\n<header dmmpShowItemOnUpScroll class=\"website-header\">\r\n  <div class=\"sidebar-container\" *ngIf=\"menuIsOpened\">\r\n    <div class=\"sidebar-menu-content\">\r\n      <div *ngIf=\"!localDeviceDetector.isDesktop()\">\r\n        <dmmp-mobile-menu [menuItemColumn]=\"menuItemColumn\" [menu]=\"principalMenu['main-menu']\"\r\n                          (page)=\"pageEmitter($event)\" (anchorCustom)=\"anchorEmitter($event)\"\r\n                          (externalLink)=\"externalLinkEmitter()\"\r\n                          [buttons]=\"buttonsHeader\" [universityInfo]=\"universityInfo\">\r\n        </dmmp-mobile-menu>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div class=\"sidebar-container slide-container-search\" *ngIf=\"searchIsOpened\">\r\n    <div class=\"sidebar-menu slide-menu-search\">\r\n      <dmmp-dynamics-module *ngIf=\"currentRelatedContent\" [identifier]=\"identifier\"\r\n                            [dataComponent]=\"[currentRelatedContent]\" (notSupportedEmitter)=\"notSupportedEvent($event)\"\r\n                            (clearResult)=\"clearResult.emit($event)\" (search)=\"search.emit($event)\" [result]=\"result\"\r\n                            [inSlide]=\"true\"\r\n                            (page)=\"pageEmitter($event)\"\r\n                            (close)=\"closeSearch()\">\r\n      </dmmp-dynamics-module>\r\n    </div>\r\n  </div>\r\n  <div class=\"back-times-item\" *ngIf=\"menuIsOpened\">\r\n    <button (click)=\"closeAndOpenMenu()\">\r\n      <span class=\"fas fa-times\"></span>\r\n    </button>\r\n  </div>\r\n  <div class=\"overlay-header\" *ngIf=\"menuIsOpened || currentRelatedContent || multilevelMenu || searchIsOpened\"\r\n       (click)=\"closeAll()\"></div>\r\n  <dmmp-container [data]=\"module ? module : {}\" [identifier]=\"identifier\">\r\n    <nav class=\"navbar navbar-expand-xl navbar-light\" *ngIf=\"module?.content?.row?.length > 0\">\r\n      <div class=\"container\">\r\n        <div class=\"row header-content\">\r\n          <dmmp-toggle-menu (clickAction)=\"closeAndOpenMenu()\" [menuIsOpened]=\"menuIsOpened\">\r\n          </dmmp-toggle-menu>\r\n          <ng-container *ngIf=\"module?.content?.row[0]?.column?.length > 0\">\r\n            <div *ngFor=\"let col of module?.content?.row[0]?.column\"\r\n                 class=\"col-auto col-lg-{{ col?.number_columns || 'auto' }}\"\r\n                 [ngClass]=\"col?.class || ''\" [id]=\"col?.id_element || ''\">\r\n              <dmmp-content-rows [colItem]=\"col\" [identifier]=\"identifier\" [module]=\"module\"\r\n                                 (menuEmitter)=\"changeSecondLevel($event)\" (page)=\"pageEmitter($event)\"\r\n                                 (anchorCustom)=\"anchorEmitter($event)\" (contentEmitter)=\"relatedContentUpdate($event)\"\r\n                                 (externalLink)=\"externalLinkEmitter()\" [menu]=\"principalMenu['main-menu']\"\r\n                                 (hoverEmitter)=\"closeMultilevelMenu()\">\r\n              </dmmp-content-rows>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n    </nav>\r\n    <div class=\"container-fluid content-box-multilevel\"\r\n         [style.backgroundColor]=\"menuItemColumn?.background_color[0]?.background_levels_color?.color | colorOpacity : menuItemColumn?.background_color[0]?.background_levels_color?.opacity || ''\">\r\n      <div class=\"row\">\r\n        <ng-container *ngIf=\"multilevelMenu\">\r\n          <dmmp-multilevel-menu #multilevelMenuC [secondLevelMenu]=\"multilevelMenu.children\"\r\n                                [backgrounds]=\"menuItemColumn?.background_color\"\r\n                                [selectedContent]=\"this.multilevelMenu?.data?.content_menu\"\r\n                                (page)=\"pageEmitter($event)\" [safeZone]=\"module?.safe_zone\"\r\n                                (anchorCustom)=\"anchorEmitter($event)\"\r\n                                (externalLink)=\"externalLinkEmitter()\">\r\n          </dmmp-multilevel-menu>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n    <ng-container\r\n      *ngIf=\"(this.localDeviceDetector.isMobile() && currentRelatedContent?.component === 'search') !== true\">\r\n      <div class=\"close-seals\" *ngIf=\"currentRelatedContent?.component === 'header_seals'\"\r\n           (click)=\"closeAll()\"><img src=\"assets/images/times.png\"/></div>\r\n      <dmmp-dynamics-module *ngIf=\"currentRelatedContent\" [identifier]=\"identifier\"\r\n                            [dataComponent]=\"[currentRelatedContent]\" (notSupportedEmitter)=\"notSupportedEvent($event)\"\r\n                            (clearResult)=\"clearResult.emit($event)\" (search)=\"search.emit($event)\" [result]=\"result\"\r\n                            (page)=\"pageEmitter($event)\" (anchorCustom)=\"anchorEmitter($event)\" (close)=\"closeAll()\">\r\n      </dmmp-dynamics-module>\r\n    </ng-container>\r\n  </dmmp-container>\r\n</header>\r\n"
    })
], WebsiteHeaderV2Component);

let CollapseMobileMenuComponent = class CollapseMobileMenuComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.externalLink = new EventEmitter();
        this.medias = [
            { style: 'max_650x650', media: '(min-width: 326px)' },
            { style: 'max_325x325', media: '(max-width: 325px)' },
        ];
    }
    ngOnInit() {
    }
    collapseOthers(currentCollapse, brothers) {
        var _a;
        (_a = brothers) === null || _a === void 0 ? void 0 : _a.forEach(menuItem => {
            var _a, _b, _c, _d;
            if (((_b = (_a = menuItem) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.name) !== ((_d = (_c = currentCollapse) === null || _c === void 0 ? void 0 : _c.data) === null || _d === void 0 ? void 0 : _d.name)) {
                menuItem.collapse = false;
            }
        });
    }
};
__decorate([
    Input()
], CollapseMobileMenuComponent.prototype, "menu", void 0);
__decorate([
    Input()
], CollapseMobileMenuComponent.prototype, "menuItemColumn", void 0);
__decorate([
    Output()
], CollapseMobileMenuComponent.prototype, "page", void 0);
__decorate([
    Output()
], CollapseMobileMenuComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], CollapseMobileMenuComponent.prototype, "externalLink", void 0);
CollapseMobileMenuComponent = __decorate([
    Component({
        selector: 'dmmp-collapse-mobile-menu',
        template: "<div class=\"navbar-content\">\r\n  <div class=\"item-logo\" *ngIf=\"menu?.length > 0 && !secondaryMenu\">\r\n    <dmmp-image *ngIf=\"menuItemColumn?.image?.length > 0\" [images]=\"menuItemColumn?.image[0]\" [medias]=\"medias\"></dmmp-image>\r\n  </div>\r\n  <ul class=\"navbar-nav first-level\" *ngIf=\"menu?.length > 0 && !secondaryMenu\">\r\n    <li class=\"nav-item\" *ngFor=\"let menuItem of menu\">\r\n      <dmmp-image *ngIf=\"menuItem?.data?.icon?.length > 0\" [images]=\"menuItem?.data?.icon[0]\"  [medias]=\"medias\"></dmmp-image>\r\n      <ng-container *ngIf=\"menuItem?.data?.link && menuItem?.children?.length === 0; else simpleLink\">\r\n        <dmmp-link [data]=\"{ link: [{ link: menuItem?.data?.link, name: menuItem?.data?.name }], target: menuItem?.data?.target }\"\r\n          [defaultClass]=\"'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n          (externalLink)=\"externalLink.emit($event)\">\r\n          {{menuItem.data.name}}\r\n        </dmmp-link>\r\n      </ng-container>\r\n      <ng-template #simpleLink>\r\n        <p [class]=\"(menuItem?.children?.length > 0) ? 'nav-link arrow-link' : 'nav-link'\" (click)=\"secondaryMenu = menuItem?.children; firstLevelName = menuItem?.data?.name\">\r\n          {{menuItem?.data?.name}}</p>\r\n      </ng-template>\r\n    </li>\r\n  </ul>\r\n  <ng-container *ngIf=\"secondaryMenu\">\r\n    <div class=\"item-back\">\r\n      <span class=\"back-icon\" (click)=\"secondaryMenu = undefined\">{{this.menuItemColumn?.label}}</span>\r\n    </div>\r\n    <div class=\"item-name\">\r\n      <span>{{firstLevelName}}</span>\r\n    </div>\r\n    <ul class=\"navbar-nav second-level\">\r\n      <ng-container *ngFor=\"let subMenuItem of secondaryMenu\">\r\n        <ng-container *ngIf=\"subMenuItem?.data?.link && subMenuItem?.children?.length === 0; else simpleLink\">\r\n          <li class=\"nav-item\" [ngClass]=\"subMenuItem?.collapse ? 'active' : ''\">\r\n            <dmmp-image *ngIf=\"subMenuItem?.data?.icon?.length > 0\" [images]=\"subMenuItem?.data?.icon[0]\"  [medias]=\"medias\"></dmmp-image>\r\n            <dmmp-link\r\n              [data]=\"{ link: [{ link: subMenuItem?.data?.link, name: subMenuItem?.data?.name }], target: subMenuItem?.data?.target }\"\r\n              [defaultClass]=\"'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (externalLink)=\"externalLink.emit($event)\">\r\n              {{subMenuItem?.data?.name}}\r\n            </dmmp-link>\r\n          </li>\r\n        </ng-container>\r\n        <ng-template #simpleLink>\r\n          <li class=\"nav-item\" [ngClass]=\"subMenuItem?.collapse ? 'active' : ''\"\r\n            (click)=\"subMenuItem.collapse = !subMenuItem?.collapse; collapseOthers(subMenuItem, secondaryMenu)\">\r\n            <dmmp-image *ngIf=\"subMenuItem?.data?.icon?.length > 0\" [images]=\"subMenuItem?.data?.icon[0]\"  [medias]=\"medias\"></dmmp-image>\r\n            <p [class]=\"(subMenuItem?.children?.length > 0) ? 'nav-link arrow-link' : 'nav-link'\">{{subMenuItem.data.name}}</p>\r\n          </li>\r\n        </ng-template>\r\n        <ng-container *ngIf=\"subMenuItem.collapse\">\r\n          <ng-container *ngFor=\"let thirdLevelItem of subMenuItem.children\">\r\n            <ng-container *ngIf=\"thirdLevelItem?.data?.link && thirdLevelItem?.children?.length === 0; else simpleLink\">\r\n              <li class=\"nav-item third-level\">\r\n                <dmmp-image *ngIf=\"thirdLevelItem?.data?.icon?.length > 0\" [images]=\"thirdLevelItem?.data?.icon[0]\">\r\n                 [medias]=\"medias\" </dmmp-image>\r\n                <dmmp-link\r\n                  [data]=\"{ link: [{ link: thirdLevelItem?.data?.link, name: thirdLevelItem?.data?.name }], target: thirdLevelItem?.data?.target }\"\r\n                  [defaultClass]=\"'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                  (externalLink)=\"externalLink.emit($event)\">\r\n                  {{thirdLevelItem.data.name}}\r\n                </dmmp-link>\r\n              </li>\r\n            </ng-container>\r\n            <ng-template #simpleLink>\r\n              <li class=\"nav-item third-level\" [ngClass]=\"thirdLevelItem?.collapse ? 'active' : ''\"\r\n                (click)=\"thirdLevelItem.collapse = !thirdLevelItem.collapse; collapseOthers(thirdLevelItem, subMenuItem?.children)\">\r\n                <dmmp-image *ngIf=\"thirdLevelItem?.data?.icon?.length > 0\" [images]=\"thirdLevelItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n                <p [class]=\"(thirdLevelItem?.children?.length > 0) ? 'nav-link arrow-link' : 'nav-link'\">{{thirdLevelItem?.data?.name}}</p>\r\n              </li>\r\n            </ng-template>\r\n            <ng-container *ngIf=\"thirdLevelItem?.collapse\">\r\n              <ng-container *ngFor=\"let fourthLevelItem of thirdLevelItem?.children\">\r\n                <ng-container *ngIf=\"fourthLevelItem?.data?.link && fourthLevelItem?.children?.length === 0; else simpleLink\">\r\n                  <li class=\"nav-item fourth-level\">\r\n                    <dmmp-image *ngIf=\"fourthLevelItem?.data?.icon?.length > 0\" [images]=\"fourthLevelItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n                    <dmmp-link\r\n                      [data]=\"{ link: [{ link: fourthLevelItem?.data?.link, name: fourthLevelItem?.data?.name }], target: fourthLevelItem?.data?.target }\"\r\n                      [defaultClass]=\"'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                      (externalLink)=\"externalLink.emit($event)\">\r\n                      {{fourthLevelItem?.data?.name}}\r\n                    </dmmp-link>\r\n                  </li>\r\n                </ng-container>\r\n                <ng-template #simpleLink>\r\n                  <li class=\"nav-item fourth-level\">\r\n                    <dmmp-image *ngIf=\"fourthLevelItem?.data?.icon?.length > 0\" [images]=\"fourthLevelItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n                    <p [class]=\"(fourthLevelItem?.children?.length > 0) ? 'nav-link arrow-link' : 'nav-link'\">{{fourthLevelItem?.data?.name}}</p>\r\n                  </li>\r\n                </ng-template>\r\n              </ng-container>\r\n            </ng-container>\r\n          </ng-container>\r\n        </ng-container>\r\n      </ng-container>\r\n    </ul>\r\n  </ng-container>\r\n</div>\r\n"
    })
], CollapseMobileMenuComponent);

let HorizontalMobileMenuComponent = class HorizontalMobileMenuComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.externalLink = new EventEmitter();
        this.buttons = [];
        this.medias = [
            { style: 'max_650x650', media: '(min-width: 326px)' },
            { style: 'max_325x325', media: '(max-width: 325px)' },
        ];
    }
    ngOnInit() {
    }
    collapseOthers(currentCollapse, brothers) {
        brothers.forEach(menuItem => {
            if (menuItem.data.name !== currentCollapse.data.name) {
                menuItem.collapse = false;
            }
        });
    }
};
__decorate([
    Input()
], HorizontalMobileMenuComponent.prototype, "menu", void 0);
__decorate([
    Input()
], HorizontalMobileMenuComponent.prototype, "menuItemColumn", void 0);
__decorate([
    Output()
], HorizontalMobileMenuComponent.prototype, "page", void 0);
__decorate([
    Output()
], HorizontalMobileMenuComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], HorizontalMobileMenuComponent.prototype, "externalLink", void 0);
__decorate([
    Input()
], HorizontalMobileMenuComponent.prototype, "buttons", void 0);
HorizontalMobileMenuComponent = __decorate([
    Component({
        selector: 'dmmp-horizontal-mobile-menu',
        template: "<div class=\"navbar-content\">\r\n  <div class=\"item-logo\" *ngIf=\"menu?.length > 0 && !secondaryMenu\">\r\n    <dmmp-image *ngIf=\"menuItemColumn?.image?.length > 0\" [images]=\"menuItemColumn?.image[0]\" [medias]=\"medias\"></dmmp-image>\r\n  </div>\r\n  <ul class=\"navbar-nav first-level\" *ngIf=\"menu && menu?.length > 0 && !secondaryMenu\">\r\n    <li class=\"nav-item\" *ngFor=\"let menuItem of menu\">\r\n      <dmmp-image *ngIf=\"menuItem?.data?.icon.length > 0\" [images]=\"menuItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n      <ng-container *ngIf=\"menuItem?.data?.link; else simpleLink\">\r\n        <dmmp-link\r\n          [data]=\"{ link: [{ link: menuItem?.data?.link, name: menuItem?.data?.name }], target: menuItem?.data?.target }\"\r\n          [defaultClass]=\"'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n          (externalLink)=\"externalLink.emit($event)\">\r\n          {{menuItem?.data?.name}}\r\n        </dmmp-link>\r\n      </ng-container>\r\n      <ng-template #simpleLink>\r\n        <p class=\"nav-link arrow-link\" (click)=\"secondaryMenu = menuItem?.children; firstLevelName = menuItem?.data?.name\">\r\n          {{menuItem?.data?.name}}</p>\r\n      </ng-template>\r\n    </li>\r\n  </ul>\r\n  <ng-container *ngIf=\"secondaryMenu && !thirdLevelMenu\">\r\n    <div class=\"item-back\">\r\n      <span class=\"back-icon\" (click)=\"secondaryMenu = undefined\">{{this.menuItemColumn?.label}}</span>\r\n    </div>\r\n    <div class=\"item-name\">\r\n      <span>{{firstLevelName}}</span>\r\n    </div>\r\n    <ul class=\"navbar-nav second-level\">\r\n      <ng-container *ngFor=\"let subMenuItem of secondaryMenu\">\r\n        <ng-container *ngIf=\"subMenuItem?.data?.link; else simpleLink\">\r\n          <li class=\"nav-item\">\r\n            <dmmp-image *ngIf=\"subMenuItem?.data?.icon?.length > 0\" [images]=\"subMenuItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n            <dmmp-link\r\n              [data]=\"{ link: [{ link: subMenuItem?.data?.link, name: subMenuItem?.data?.name }], target: subMenuItem?.data?.target }\"\r\n              [defaultClass]=\"'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (externalLink)=\"externalLink.emit($event)\">\r\n              {{subMenuItem?.data?.name}}\r\n            </dmmp-link>\r\n          </li>\r\n        </ng-container>\r\n        <ng-template #simpleLink>\r\n          <li class=\"nav-item\">\r\n            <dmmp-image *ngIf=\"subMenuItem?.data?.icon?.length > 0\" [images]=\"subMenuItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n            <p class=\"nav-link arrow-link\"\r\n              (click)=\"thirdLevelMenu = subMenuItem?.children; secondLevelName = subMenuItem?.data?.name\">\r\n              {{subMenuItem?.data?.name}}</p>\r\n          </li>\r\n        </ng-template>\r\n      </ng-container>\r\n    </ul>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"thirdLevelMenu\">\r\n    <div class=\"item-back\">\r\n      <span class=\"back-icon\" (click)=\"thirdLevelMenu = undefined\">{{this.menuItemColumn?.label}}</span>\r\n    </div>\r\n    <div class=\"item-name\">\r\n      <span>{{secondLevelName}}</span>\r\n    </div>\r\n    <ul class=\"navbar-nav third-level\">\r\n      <ng-container *ngFor=\"let subMenuItem of thirdLevelMenu\">\r\n        <ng-container *ngIf=\"subMenuItem?.data?.link; else simpleLink\">\r\n          <li class=\"nav-item\">\r\n            <dmmp-image *ngIf=\"subMenuItem?.data?.icon?.length > 0\" [images]=\"subMenuItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n            <dmmp-link\r\n              [data]=\"{ link: [{ link: subMenuItem?.data?.link, name: subMenuItem?.data?.name }], target: subMenuItem?.data?.target }\"\r\n              [defaultClass]=\"'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (externalLink)=\"externalLink.emit($event)\">\r\n              {{subMenuItem?.data?.name}}\r\n            </dmmp-link>\r\n          </li>\r\n        </ng-container>\r\n        <ng-template #simpleLink>\r\n          <li class=\"nav-item\"\r\n            (click)=\"subMenuItem.collapse = !subMenuItem?.collapse; collapseOthers(subMenuItem, thirdLevelMenu)\"\r\n            [ngClass]=\"subMenuItem?.collapse ? 'active' : ''\">\r\n            <dmmp-image *ngIf=\"subMenuItem?.data?.icon?.length > 0\" [images]=\"subMenuItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n            <p class=\"nav-link arrow-link\">{{subMenuItem?.data?.name}}</p>\r\n          </li>\r\n        </ng-template>\r\n        <ng-container *ngIf=\"subMenuItem?.collapse\">\r\n          <ng-container *ngFor=\"let fourthLevelItem of subMenuItem?.children\">\r\n            <ng-container *ngIf=\"fourthLevelItem?.data?.link; else simpleLink\">\r\n              <li class=\"nav-item fourth-level\">\r\n                <dmmp-image *ngIf=\"fourthLevelItem?.data?.icon?.length > 0\" [images]=\"fourthLevelItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n                <dmmp-link\r\n                  [data]=\"{ link: [{ link: fourthLevelItem?.data?.link, name: fourthLevelItem?.data?.name }], target: fourthLevelItem?.data?.target }\"\r\n                  [defaultClass]=\"'nav-link'\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                  (externalLink)=\"externalLink.emit($event)\">\r\n                  {{fourthLevelItem?.data?.name}}\r\n                </dmmp-link>\r\n              </li>\r\n            </ng-container>\r\n            <ng-template #simpleLink>\r\n              <li class=\"nav-item fourth-level\">\r\n                <dmmp-image *ngIf=\"fourthLevelItem?.data?.icon?.length > 0\" [images]=\"fourthLevelItem?.data?.icon[0]\" [medias]=\"medias\"></dmmp-image>\r\n                <p class=\"nav-link arrow-link\">{{fourthLevelItem?.data?.name}}</p>\r\n              </li>\r\n            </ng-template>\r\n          </ng-container>\r\n        </ng-container>\r\n      </ng-container>\r\n    </ul>\r\n  </ng-container>\r\n  <ng-container *ngFor=\"let buttonItem of buttons\">\r\n    <div class=\"content content-button buttons-header-desktop\" *ngIf=\"buttonItem?.link?.length > 0\">\r\n      <ul class=\"buttons-actions\">\r\n        <li class=\"nav-item\">\r\n          <dmmp-button [data]=\"buttonItem\" [identifier]=\"buttonItem\" (page)=\"page.emit($event)\"\r\n            (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-button>\r\n        </li>\r\n      </ul>\r\n    </div>\r\n  </ng-container>\r\n</div>\r\n"
    })
], HorizontalMobileMenuComponent);

let WebsiteHeaderV2Module = class WebsiteHeaderV2Module {
};
WebsiteHeaderV2Module = __decorate([
    NgModule({
        declarations: [
            WebsiteHeaderV2Component,
            ToggleMenuComponent$1,
            ContentRowsComponent,
            MobileMenuComponent$1,
            ItemMenuComponent$1,
            CollapseMobileMenuComponent,
            HorizontalMobileMenuComponent
        ],
        imports: [
            CommonModule,
            SharedModule,
            RouterModule,
            DynamicsModuleModule,
            MultilevelMenuModule,
            NgxJsonLdModule,
            PipesModule
        ],
        exports: [WebsiteHeaderV2Component]
    })
], WebsiteHeaderV2Module);

let LinkImageCampusComponent = class LinkImageCampusComponent {
    constructor() {
        this.page = new EventEmitter();
    }
};
__decorate([
    Input()
], LinkImageCampusComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], LinkImageCampusComponent.prototype, "data", void 0);
__decorate([
    Output()
], LinkImageCampusComponent.prototype, "page", void 0);
LinkImageCampusComponent = __decorate([
    Component({
        selector: 'dmmp-link-image-campus',
        template: "<dmmp-container [data]=\"data\" [identifier]=\"identifier\" [defaultClass]=\"'link-image-campus container'\">\r\n  <ng-container *ngIf=\"data?.name\">\r\n    <div class=\"row\">\r\n      <div class=\"col-12 col-md\">\r\n        <h2 class=\"h2\" [ngClass]=\"data.title_class ? data.title_class : ''\">{{ data.name }}</h2>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"data?.content?.length > 0\">\r\n    <div class=\"row justify-content-center\">\r\n      <ng-container *ngFor=\"let campus of data.content | slice: 0:4\">\r\n        <dmmp-card-image-campus [data]=\"campus\" [identifier]=\"identifier\" (page)=\"page.emit($event)\">\r\n        </dmmp-card-image-campus>\r\n      </ng-container>\r\n    </div>\r\n  </ng-container>\r\n</dmmp-container>\r\n"
    })
], LinkImageCampusComponent);

let CardImageCampusComponent = class CardImageCampusComponent {
    constructor() {
        this.page = new EventEmitter();
        this.medias = [
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width:351px)' },
            { style: 'max_325x325', media: '(max-width:350px)' },
        ];
    }
};
__decorate([
    Input()
], CardImageCampusComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], CardImageCampusComponent.prototype, "data", void 0);
__decorate([
    Output()
], CardImageCampusComponent.prototype, "page", void 0);
CardImageCampusComponent = __decorate([
    Component({
        selector: 'dmmp-card-image-campus',
        template: "<div class=\"col-12 col-md box-card\" *ngIf=\"data && data.link_image && data.link_image.length > 0\">\r\n  <div\r\n    *ngIf=\"\r\n      data?.link_image[0]?.link[0]?.link?.substring(0, 1) === '/';\r\n      else urlCard\r\n    \" class=\"content-card\" (click)=\"\r\n      page.emit(\r\n        data.link_image[0].link[0].link ? data.link_image[0].link[0].link : ''\r\n      )\r\n    \" routerLink=\"{{\r\n      data.link_image[0].link[0].link ? data.link_image[0].link[0].link : ''\r\n    }}\">\r\n    <ng-container *ngTemplateOutlet=\"contentCampus\"></ng-container>\r\n  </div>\r\n  <ng-template #urlCard>\r\n    <a *ngIf=\"data?.link_image?.length > 0\" [href]=\"\r\n        data.link_image[0].link[0].link ? data.link_image[0].link[0].link : ''\r\n      \" [target]=\"data.link_image[0].target ? data.link_image[0].target : ''\">\r\n      <div class=\"content-card\">\r\n        <ng-container *ngTemplateOutlet=\"contentCampus\"></ng-container>\r\n      </div>\r\n    </a>\r\n  </ng-template>\r\n</div>\r\n<ng-template #contentCampus>\r\n  <ng-container *ngIf=\"data?.image && data?.image?.length > 0\">\r\n    <div class=\"box-images\" [ngClass]=\"data.image_class ? data.image_class : ''\">\r\n      <dmmp-image [images]=\"data.image[0]\" [medias]=\"medias\"></dmmp-image>\r\n    </div>\r\n    <ng-container *ngIf=\"data?.link_image && data?.link_image?.length > 0\">\r\n      <div\r\n        class=\"box-links\"\r\n        [ngClass]=\"data.link_image[0].class ? data.link_image[0].class : ''\"\r\n      >\r\n        <dmmp-simple-link\r\n          [data]=\"data.link_image[0]\"\r\n          [identifier]=\"identifier\"\r\n          (page)=\"page.emit($event)\"\r\n        >\r\n          {{\r\n          data.link_image[0].link[0].name ? data.link_image[0].link[0].name : ''\r\n          }}\r\n          <img\r\n            *ngIf=\"data?.link_image[0]?.icon?.length > 0\"\r\n            [src]=\"\r\n            data.link_image[0].icon[0].styles\r\n              ? data.link_image[0].icon[0].styles.large\r\n              : ''\r\n          \"\r\n            [alt]=\"data.link_image[0].icon[0].texts.alt\"\r\n            [title]=\"data.link_image[0].icon[0].texts.title\"\r\n          />\r\n        </dmmp-simple-link>\r\n      </div>\r\n    </ng-container>\r\n  </ng-container>\r\n</ng-template>\r\n"
    })
], CardImageCampusComponent);

let LinkImageCampusModule = class LinkImageCampusModule {
};
LinkImageCampusModule = __decorate([
    NgModule({
        declarations: [LinkImageCampusComponent, CardImageCampusComponent],
        imports: [CommonModule, SharedModule, RouterModule],
        exports: [LinkImageCampusComponent],
        providers: [],
    })
], LinkImageCampusModule);

let WebsiteCourseDetailedTabsV2Component = class WebsiteCourseDetailedTabsV2Component {
    constructor(dateService, deviceDetectorService, richsnipetService) {
        this.dateService = dateService;
        this.deviceDetectorService = deviceDetectorService;
        this.richsnipetService = richsnipetService;
        this.moment = moment_;
        this.schema = [];
    }
    ngOnInit() {
        var _a, _b, _c, _d;
        if (((_b = (_a = this.layout) === null || _a === void 0 ? void 0 : _a.items) === null || _b === void 0 ? void 0 : _b.length) > 0) {
            (_d = (_c = this.layout) === null || _c === void 0 ? void 0 : _c.items) === null || _d === void 0 ? void 0 : _d.forEach(item => {
                var _a, _b, _c, _d;
                if (((_b = (_a = item) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.length) > 0) {
                    (_d = (_c = item) === null || _c === void 0 ? void 0 : _c.options) === null || _d === void 0 ? void 0 : _d.filter(res => {
                        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
                        if (((_a = res) === null || _a === void 0 ? void 0 : _a.identifier) === 'program_video' && ((_c = (_b = res) === null || _b === void 0 ? void 0 : _b.video) === null || _c === void 0 ? void 0 : _c.length) > 0) {
                            if (((_e = (_d = res) === null || _d === void 0 ? void 0 : _d.video[0]) === null || _e === void 0 ? void 0 : _e.type) === 'youtube') {
                                const video = (_h = (_g = (_f = res) === null || _f === void 0 ? void 0 : _f.video[0]) === null || _g === void 0 ? void 0 : _g.video[0]) === null || _h === void 0 ? void 0 : _h.value;
                                this.richsnipetService.getInfoVideo(video.substr(video.indexOf('v=') + 2, (_j = video) === null || _j === void 0 ? void 0 : _j.length)).pipe(map((data) => {
                                    var _a, _b, _c;
                                    if (data) {
                                        this.createRichSnipet(res, (_c = (_b = (_a = data) === null || _a === void 0 ? void 0 : _a.items[0]) === null || _b === void 0 ? void 0 : _b.contentDetails) === null || _c === void 0 ? void 0 : _c.duration);
                                    }
                                })).subscribe();
                            }
                            else {
                                this.createRichSnipet(res);
                            }
                        }
                    });
                }
            });
        }
    }
    createRichSnipet(res, duration = '') {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q;
        this.schema.push(this.richsnipetService.setupJsonVideo(((_b = (_a = res) === null || _a === void 0 ? void 0 : _a.video[0]) === null || _b === void 0 ? void 0 : _b.title) || '', ((_d = (_c = res) === null || _c === void 0 ? void 0 : _c.video[0]) === null || _d === void 0 ? void 0 : _d.description) || '', ((_h = (_g = (_f = (_e = res) === null || _e === void 0 ? void 0 : _e.video[0]) === null || _f === void 0 ? void 0 : _f.image[0]) === null || _g === void 0 ? void 0 : _g.styles) === null || _h === void 0 ? void 0 : _h.large) || '', ((_k = (_j = res) === null || _j === void 0 ? void 0 : _j.video[0]) === null || _k === void 0 ? void 0 : _k.created_at) ? this.dateService.convertFromTimestampToDate((_m = (_l = res) === null || _l === void 0 ? void 0 : _l.video[0]) === null || _m === void 0 ? void 0 : _m.created_at) : '', ((_q = (_p = (_o = res) === null || _o === void 0 ? void 0 : _o.video[0]) === null || _p === void 0 ? void 0 : _p.video[0]) === null || _q === void 0 ? void 0 : _q.value) || '', duration || ''));
    }
};
WebsiteCourseDetailedTabsV2Component.ctorParameters = () => [
    { type: DateFormatService },
    { type: DeviceDetectorService },
    { type: RichsnipetService }
];
__decorate([
    Input()
], WebsiteCourseDetailedTabsV2Component.prototype, "layout", void 0);
__decorate([
    Input()
], WebsiteCourseDetailedTabsV2Component.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteCourseDetailedTabsV2Component.prototype, "identifier", void 0);
WebsiteCourseDetailedTabsV2Component = __decorate([
    Component({
        selector: 'dmmp-website-course-detailed-tabs-v2',
        template: "<ngx-json-ld *ngFor=\"let schemaItem of schema\" [json]=\"schemaItem\"></ngx-json-ld>\r\n<dmmp-container [data]=\"module || {}\" [identifier]=\"identifier || ''\"\r\n  [defaultClass]=\"'tabs-program detail-tabs-course'\">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module.title_class || ''\">\r\n      {{module?.name}}\r\n    </h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"row\" *ngIf=\"layout\">\r\n      <div class=\"col-lg-{{\r\n            layout?.columns_content || 12\r\n          }}\" [ngClass]=\"\r\n                layout?.columns_content > 8\r\n                ? 'bg-color-white z-index-4 position-relative'\r\n                : ''\r\n          \">\r\n        <div class=\"tabs-content\" *ngIf=\"layout?.items?.length > 0\">\r\n          <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\" [ngClass]=\"layout?.items?.length > 3 ? 'swift-desktop' : ''\">\r\n            <li ngbNavItem *ngFor=\"let data of layout?.items\">\r\n              <ng-container>\r\n                <a ngbNavLink>\r\n                  <p [ngClass]=\"data?.class || ''\" class=\"tab-title\" *ngIf=\"data?.title\">\r\n                    {{ data?.title }}\r\n                  </p>\r\n                </a>\r\n                <ng-template ngbNavContent>\r\n                  <div class=\"content-tabs\" *ngIf=\"data?.options?.length > 0\">\r\n                    <ng-container *ngFor=\"let option of data?.options\">\r\n                      <ng-container *ngIf=\"option?.identifier\">\r\n                        <!-- Componente Texto enriquecido-->\r\n                        <ng-container *ngIf=\"option?.identifier === 'textos'\">\r\n                          <dmmp-shared-text [textEnriched]=\"option?.text || ''\"\r\n                            [classTextEnriched]=\"option.class || ''\"\r\n                            [quantityCharacters]=\"option?.text ? (option?.text?.length <= 400 || this.deviceDetectorService.isDesktop() ? option?.text?.length : 400): 0 \"\r\n                            [class]=\"option?.text?.length > 400 && !this.deviceDetectorService.isDesktop() ? 'summarized' : ''\"\r\n                            [buttonShow]=\"option?.text?.length > 400 && !this.deviceDetectorService.isDesktop()\">\r\n                          </dmmp-shared-text>\r\n                        </ng-container>\r\n                        <!-- Componente Button tabs-->\r\n                        <ng-container *ngIf=\"option?.identifier === 'button'\">\r\n                          <div class=\"button-tabs\">\r\n                            <dmmp-button [data]=\"option\" [identifier]=\"identifier\"></dmmp-button>\r\n                          </div>\r\n                        </ng-container>\r\n                        <!-- Componente Card Horizontal -->\r\n                        <ng-container *ngIf=\"option?.identifier === 'program_image_link'\">\r\n                          <dmmp-card-horizontal-image-link [image]=\"\r\n                                option?.image?.length > 0\r\n                                  ? option?.image\r\n                                  : []\"\r\n                                [text]=\"{\r\n                                text: option?.text || '',\r\n                                text_class: option?.text_class || ''\r\n                              }\" [link]=\"{\r\n                                link: option?.link || [],\r\n                                class: option?.class || '',\r\n                                target: option?.target || ''\r\n                              }\" [identifier]=\"identifier\"></dmmp-card-horizontal-image-link>\r\n                        </ng-container>\r\n                        <!-- Componente Acordeon-->\r\n                        <ng-container *ngIf=\"option?.identifier === 'programs_accordion'\">\r\n                          <dmmp-shared-accordion *ngIf=\"option?.accordions?.length > 0\"\r\n                                [contentAccordion]=\"option?.accordions\"\r\n                                [class]=\"option?.class || ''\" [identifier]=\"identifier || ''\">\r\n                          </dmmp-shared-accordion>\r\n                        </ng-container>\r\n                        <!-- Componente Video-->\r\n                        <ng-container *ngIf=\"option?.identifier === 'program_video'\">\r\n                          <dmmp-video-player *ngIf=\"option?.video?.length > 0\" [type]=\"option?.video[0]?.type || ''\"\r\n                                [src]=\"option?.video[0]?.video[0]?.value || ''\"></dmmp-video-player>\r\n                        </ng-container>\r\n                      </ng-container>\r\n                    </ng-container>\r\n                  </div>\r\n                </ng-template>\r\n              </ng-container>\r\n            </li>\r\n          </ul>\r\n          <div [ngbNavOutlet]=\"nav\"></div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteCourseDetailedTabsV2Component);

let WebsiteCourseDetailedTabsV2Module = class WebsiteCourseDetailedTabsV2Module {
};
WebsiteCourseDetailedTabsV2Module = __decorate([
    NgModule({
        declarations: [WebsiteCourseDetailedTabsV2Component],
        imports: [
            CommonModule,
            SharedModule,
            NgbNavModule,
            NgxJsonLdModule
        ],
        exports: [
            WebsiteCourseDetailedTabsV2Component
        ],
        providers: [RichsnipetService],
    })
], WebsiteCourseDetailedTabsV2Module);

let RecentArticlesComponent = class RecentArticlesComponent {
    constructor(dateFormatService) {
        this.dateFormatService = dateFormatService;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.medias = [
            { style: 'max_1300x1300', media: '(min-width: 1301px)' },
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width:351px)' },
            { style: 'file_entity_browser_thumbnail', media: '(max-width:350px) AND (min-width:326px)' },
            { style: 'max_325x325', media: '(max-width:325px)' },
        ];
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e;
        if (((_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.length) > 0) {
            (_d = (_c = this.module) === null || _c === void 0 ? void 0 : _c.content) === null || _d === void 0 ? void 0 : _d.forEach(contentItem => {
                var _a;
                contentItem.created_at = this.dateFormatService.convertFromTimestampToDate((_a = contentItem) === null || _a === void 0 ? void 0 : _a.created_at);
            });
            this.firstArticle = Object.assign({}, (_e = this.module) === null || _e === void 0 ? void 0 : _e.content[0]);
            this.module.content.splice(0, 1);
        }
    }
};
RecentArticlesComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], RecentArticlesComponent.prototype, "module", void 0);
__decorate([
    Input()
], RecentArticlesComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], RecentArticlesComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], RecentArticlesComponent.prototype, "page", void 0);
RecentArticlesComponent = __decorate([
    Component({
        selector: 'dmmp-recent-articles',
        template: "<dmmp-container [defaultClass]=\"'recent-articles'\" [data]=\"module\" [identifier]=\"identifier\">\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <div class=\"col-12\">\r\n        <h2 *ngIf=\"module?.name\" [ngClass]=\"module?.title?.class || ''\">{{module?.name}}</h2>\r\n        <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n          <div *ngFor=\"let text of module?.texts\" [innerHTML]=\"text?.text\" [ngClass]=\"text?.class\"></div>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n    <div class=\"row\">\r\n      <div class=\"col-md-6\" *ngIf=\"firstArticle\">\r\n        <div class=\"outstanding-container\">\r\n          <div class=\"outstanding-featured\" *ngIf=\"firstArticle?.featured?.length > 0\"\r\n               [style.background]=\"firstArticle?.featured[0]?.featured_background?.color ? firstArticle?.featured[0]?.featured_background?.color : ''\"\r\n               [ngClass]=\"firstArticle?.featured[0]?.class ? firstArticle?.featured[0]?.class : ''\">\r\n            <p class=\"mb-0\"><span>{{firstArticle?.featured[0]?.title}}</span></p>\r\n          </div>\r\n          <div class=\"outstanding-image-container\">\r\n            <div class=\"outstanding-image\" *ngIf=\"firstArticle?.image?.length\">\r\n              <dmmp-image\r\n                [images]=\"firstArticle?.image[0]\" [medias]=\"medias\">\r\n              </dmmp-image>\r\n            </div>\r\n            <div class=\"outstanding-info\">\r\n              <div *ngIf=\"firstArticle?.categories?.length > 0\">\r\n                <p *ngFor=\"let categoryItem of firstArticle?.categories\" class=\"category-blog\">\r\n                  {{categoryItem}}\r\n                </p>\r\n              </div>\r\n              <h3 class=\"title-blog\">\r\n                <ng-container *ngIf=\"firstArticle?.link?.length > 0; else noLinkTemplate\">\r\n                  <dmmp-link [data]=\"firstArticle\" [identifier]=\"identifier\" (page)=\"page.emit($event)\"\r\n                             (anchorCustom)=\"anchorCustom.emit($event)\">\r\n                    {{firstArticle?.title}}\r\n                  </dmmp-link>\r\n                </ng-container>\r\n                <ng-template #noLinkTemplate>\r\n                  {{firstArticle?.title}}\r\n                </ng-template>\r\n              </h3>\r\n              <p class=\"date-blog\">\r\n                {{firstArticle?.promotion_date | date : 'longDate': 'UTC'}}</p>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n      <div class=\"col-md-6\" *ngIf=\"firstArticle\">\r\n        <div class=\"list-recent-articles\" *ngIf=\"module?.content?.length > 0\">\r\n          <div class=\"row\" *ngFor=\"let contentItem of module?.content\">\r\n            <div class=\"col-12\">\r\n              <div class=\"article-info\">\r\n                <div *ngIf=\"contentItem?.categories?.length > 0\">\r\n                  <p *ngFor=\"let categoryItem of contentItem?.categories\" class=\"category-blog\">\r\n                    {{categoryItem}}\r\n                  </p>\r\n                </div>\r\n                <h3 class=\"title-blog\">\r\n                  <ng-container *ngIf=\"contentItem?.link?.length > 0; else noLinkTemplate\">\r\n                    <dmmp-link [data]=\"contentItem\" [identifier]=\"identifier\" (page)=\"page.emit($event)\"\r\n                               (anchorCustom)=\"anchorCustom.emit($event)\">\r\n                      {{contentItem?.title}}\r\n                    </dmmp-link>\r\n                  </ng-container>\r\n                  <ng-template #noLinkTemplate>\r\n                    {{contentItem?.title}}\r\n                  </ng-template>\r\n                </h3>\r\n                <p class=\"date-blog\">\r\n                  {{contentItem?.promotion_date | date : 'longDate': 'UTC'}}</p>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <div class=\"row\" *ngIf=\"module?.see_more?.length > 0\">\r\n      <div class=\"col-12\">\r\n        <div class=\"box-button\">\r\n          <dmmp-button [data]=\"module?.see_more[0]\" [identifier]=\"identifier\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                       (page)=\"page.emit($event)\"></dmmp-button>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], RecentArticlesComponent);

let RecentArticlesModule = class RecentArticlesModule {
};
RecentArticlesModule = __decorate([
    NgModule({
        declarations: [RecentArticlesComponent],
        imports: [
            CommonModule,
            SharedModule,
            PipesModule
        ],
        exports: [RecentArticlesComponent]
    })
], RecentArticlesModule);

let WebsiteNewsComponent = class WebsiteNewsComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], WebsiteNewsComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteNewsComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], WebsiteNewsComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], WebsiteNewsComponent.prototype, "page", void 0);
WebsiteNewsComponent = __decorate([
    Component({
        selector: 'dmmp-website-news',
        template: "<dmmp-container [data]=\"module\" [defaultClass]=\"'website-news'\" [identifier]=\"identifier\">\r\n  <div class=\"container\">\r\n    <h2 class=\"h2\"\r\n        *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">{{module?.name}}</h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"row main-panel\">\r\n      <div class=\"col-12 col-md-4 col-lg-3 box-card\" *ngFor=\"let contentItem of module?.content\">\r\n        <dmmp-card-new [path]=\"contentItem?.path\"\r\n                       [image]=\"contentItem?.image_items[0]?.image\"\r\n                       [featured]=\"contentItem?.featured\"\r\n                       [categories]=\"contentItem?.categories\"\r\n                       [date]=\"contentItem?.created_at\"\r\n                       [title]=\"'<h3 class='+'p1'+'>'+ contentItem?.title + '</h3>'\"\r\n                       [defaultClass]=\"'card'\"\r\n                       (page)=\"page.emit($event)\"\r\n        ></dmmp-card-new>\r\n      </div>\r\n    </div>\r\n    <div class=\"box-button\" *ngIf=\"module?.see_more?.length > 0\">\r\n      <dmmp-button\r\n        (page)=\"page.emit($event)\"\r\n        (anchorCustom)=\"anchorCustom.emit($event)\"\r\n        [data]=\"module?.see_more[0]\"\r\n        [identifier]=\"identifier\">\r\n      </dmmp-button>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteNewsComponent);

let WebsiteNewsModule = class WebsiteNewsModule {
};
WebsiteNewsModule = __decorate([
    NgModule({
        declarations: [WebsiteNewsComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [WebsiteNewsComponent]
    })
], WebsiteNewsModule);

let FiltersProgrammesComponent = class FiltersProgrammesComponent {
    constructor(localDeviceDetector, router, activatedRoute, filterService, location) {
        this.localDeviceDetector = localDeviceDetector;
        this.router = router;
        this.activatedRoute = activatedRoute;
        this.filterService = filterService;
        this.location = location;
        this.changeSelectedValues = new EventEmitter();
        this.uncheckAllValues = new EventEmitter();
        this.showFilters = new EventEmitter();
        this.redirectPage = new EventEmitter();
        this.textMobile = {
            title: 'Filtrar por',
            applyFilter: 'Aplicar Filtros',
            clearFilter: 'Borrar todo',
        };
        this.queryString = '';
        this.relateUrls = {
            academicOfferUrl: '',
            programsFilterUrl: '',
        };
    }
    ngOnInit() {
        this.isMobile();
        this.formOptions = this.form.get('options');
    }
    ngOnChanges(changes) {
        this.verifyFilters(this.currentFilters);
    }
    ngAfterViewInit() {
        var _a;
        this.filterService.selectedUrlFilter(this.data, this.relateUrls, this.checkboxesFilters, this.currentFilters, this.formOptions);
        this.checkTopic();
        this.changeSelectedValues.emit((_a = this.data) === null || _a === void 0 ? void 0 : _a.vocabulary_content_type);
    }
    checkTopic() {
        if (this.activatedRoute.snapshot.queryParams.topic) {
            this.filterService.checkQueryTopic(this.data, this.checkboxesFilters, this.formOptions, this.activatedRoute.snapshot.queryParams.topic);
        }
    }
    isMobile() {
        var _a, _b, _c, _d;
        if (this.localDeviceDetector.isMobile()) {
            (_b = (_a = this.data) === null || _a === void 0 ? void 0 : _a.vocabularies) === null || _b === void 0 ? void 0 : _b.forEach((item, index) => {
                if (index > 0) {
                    item.vocabulary.isCollapsed = true;
                }
            });
        }
        else {
            (_d = (_c = this.data) === null || _c === void 0 ? void 0 : _c.vocabularies) === null || _d === void 0 ? void 0 : _d.forEach((item) => {
                item.vocabulary.isCollapsed = false;
            });
        }
    }
    onCheckboxChange(event, path, label, vocabularyName) {
        var _a, _b;
        if (((_a = this.data) === null || _a === void 0 ? void 0 : _a.vocabulary_content_type) === 'event') {
            if (event.target.checked) {
                this.filterService.pushOptionForm(label, event.target.value, path, vocabularyName, this.formOptions);
            }
            else {
                this.filterService.uncheckOption(event.target.value, this.formOptions);
            }
        }
        else {
            if (this.activatedRoute.snapshot.queryParams.q) {
                this.queryString = this.activatedRoute.snapshot.queryParams.q;
            }
            if (event.target.checked) {
                if (event.target.value === 'vocabulary') {
                    this.filterService.selectedCategory(this.data, path, vocabularyName, true, this.formOptions, this.checkboxesFilters);
                }
                else {
                    this.filterService.pushOptionForm(label, event.target.value, path, vocabularyName, this.formOptions);
                }
                this.counter = this.formOptions.length;
                if (path && this.counter === 1 && this.queryString === '') {
                    this.router.navigate([path]);
                    this.redirectPage.emit();
                }
                if (this.location.pathname !== this.relateUrls.programsFilterUrl &&
                    this.counter > 1 &&
                    this.queryString === '') {
                    this.router.navigate([this.relateUrls.programsFilterUrl]);
                    this.redirectPage.emit();
                }
            }
            else {
                if (event.target.value === 'vocabulary') {
                    this.filterService.selectedCategory(this.data, path, vocabularyName, false, this.formOptions, this.checkboxesFilters);
                }
                else {
                    this.filterService.uncheckOption(event.target.value, this.formOptions);
                }
                this.counter = this.formOptions.length;
                if (this.counter === 1 && this.queryString === '') {
                    this.router.navigate([this.formOptions.value[0].path]);
                    this.redirectPage.emit();
                }
                if (this.counter === 0 && this.queryString === '') {
                    this.router.navigate([this.relateUrls.programsFilterUrl]);
                    this.redirectPage.emit();
                }
            }
        }
        this.changeSelectedValues.emit((_b = this.data) === null || _b === void 0 ? void 0 : _b.vocabulary_content_type);
    }
    uncheckAll() {
        this.checkboxesFilters.forEach((element) => {
            element.nativeElement.checked = false;
        });
        while (this.formOptions.length !== 0) {
            this.formOptions.removeAt(0);
        }
        this.counter = 0;
        this.uncheckAllValues.emit();
    }
    verifyFilters(currentFilter) {
        var _a, _b, _c, _d, _e, _f;
        if (((_a = currentFilter.options) === null || _a === void 0 ? void 0 : _a.length) === 0) {
            (_b = this.checkboxesFilters) === null || _b === void 0 ? void 0 : _b.forEach((element) => {
                element.nativeElement.checked = false;
            });
            if (this.formOptions) {
                while (((_c = this.formOptions) === null || _c === void 0 ? void 0 : _c.length) !== 0) {
                    this.formOptions.removeAt(0);
                }
            }
            this.counter = 0;
        }
        else {
            (_e = (_d = this.formOptions) === null || _d === void 0 ? void 0 : _d.controls) === null || _e === void 0 ? void 0 : _e.forEach((option) => {
                var _a, _b;
                const index = (_b = (_a = currentFilter) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.findIndex((currentOption) => {
                    return option.value.id === currentOption.id;
                });
                if (index === -1) {
                    const indexToDelete = this.formOptions.controls.findIndex((optionToDelete) => {
                        if (option.value.id !== 'vocabulary') {
                            return optionToDelete.value.id === option.value.id;
                        }
                    });
                    this.formOptions.removeAt(indexToDelete);
                }
            });
            (_f = this.checkboxesFilters) === null || _f === void 0 ? void 0 : _f.forEach((checkbox) => {
                var _a;
                const index = (_a = currentFilter.options) === null || _a === void 0 ? void 0 : _a.findIndex((option) => {
                    return checkbox.nativeElement.id === option.id;
                });
                if (index === -1) {
                    if (!checkbox.nativeElement.id.includes('vocabulary')) {
                        checkbox.nativeElement.checked = false;
                    }
                }
            });
        }
    }
};
FiltersProgrammesComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService },
    { type: Router },
    { type: ActivatedRoute },
    { type: FilterService },
    { type: PlatformLocation }
];
__decorate([
    ViewChildren('checkboxesFilters')
], FiltersProgrammesComponent.prototype, "checkboxesFilters", void 0);
__decorate([
    Input()
], FiltersProgrammesComponent.prototype, "form", void 0);
__decorate([
    Input()
], FiltersProgrammesComponent.prototype, "data", void 0);
__decorate([
    Input()
], FiltersProgrammesComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], FiltersProgrammesComponent.prototype, "openFilters", void 0);
__decorate([
    Input()
], FiltersProgrammesComponent.prototype, "currentFilters", void 0);
__decorate([
    Output()
], FiltersProgrammesComponent.prototype, "changeSelectedValues", void 0);
__decorate([
    Output()
], FiltersProgrammesComponent.prototype, "uncheckAllValues", void 0);
__decorate([
    Output()
], FiltersProgrammesComponent.prototype, "showFilters", void 0);
__decorate([
    Output()
], FiltersProgrammesComponent.prototype, "redirectPage", void 0);
__decorate([
    Input()
], FiltersProgrammesComponent.prototype, "relateUrls", void 0);
FiltersProgrammesComponent = __decorate([
    Component({
        selector: 'dmmp-filters-programmes',
        template: "<dmmp-container\r\n  [data]=\"data\"\r\n  [identifier]=\"identifier\"\r\n  [style.display]=\"openFilters ? 'block' : 'none'\"\r\n>\r\n  <div class=\"programs-filters\">\r\n    <div class=\"row\" *ngIf=\"data?.vocabulary_content_type === 'programs'\">\r\n      <div class=\"col\">\r\n        <div class=\"box-header-filter\">\r\n          <p class=\"filters-title\" *ngIf=\"textMobile?.title\">{{ textMobile?.title }}</p>\r\n          <ng-container *ngIf=\"localDeviceDetector.isMobile()\">\r\n            <div class=\"box-header-button\">\r\n              <a class=\"all-deleted\" (click)=\"uncheckAll()\">\r\n                {{ textMobile?.clearFilter }}\r\n              </a>\r\n              <i class=\"fas fa-times\" (click)=\"showFilters.emit()\"></i>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <ng-container *ngIf=\"data?.vocabularies?.length > 0\">\r\n      <ng-container *ngFor=\"let filter of data?.vocabularies\">\r\n        <ng-container *ngIf=\"filter?.vocabulary?.terms?.length > 0\">\r\n          <div class=\"item-accordion\">\r\n            <div\r\n              class=\"row filter-category\"\r\n              (click)=\"\r\n                filter.vocabulary.isCollapsed = !filter.vocabulary.isCollapsed\r\n              \"\r\n            >\r\n              <div class=\"col text-left\">\r\n                <p [ngClass]=\"filter?.class || ''\">\r\n                  {{ filter?.vocabulary?.name }}\r\n                </p>\r\n              </div>\r\n              <div class=\"text-right\">\r\n                <button type=\"button\" class=\"btn btn-outline\" align-left>\r\n                  <i\r\n                    class=\"fas fa-chevron-up\"\r\n                    *ngIf=\"!filter?.vocabulary?.isCollapsed\"\r\n                  ></i>\r\n                  <i\r\n                    class=\"fas fa-chevron-down\"\r\n                    *ngIf=\"filter?.vocabulary?.isCollapsed\"\r\n                  ></i>\r\n                </button>\r\n              </div>\r\n            </div>\r\n            <div class=\"row\">\r\n              <div\r\n                class=\"col\"\r\n                id=\"collapseFilters\"\r\n                [ngbCollapse]=\"filter?.vocabulary?.isCollapsed\"\r\n              >\r\n                <form [formGroup]=\"form\">\r\n                  <div\r\n                    class=\"custom-control custom-checkbox\"\r\n                    *ngIf=\"filter?.link?.length > 0 &&\r\n                      filter?.link[0]?.name\r\n                    \"\r\n                  >\r\n                    <input\r\n                      #checkboxesFilters\r\n                      class=\"custom-control-input\"\r\n                      type=\"checkbox\"\r\n                      [id]=\"filter?.vocabulary?.name + '-' + filter?.identifier\"\r\n                      [name]=\"filter?.link[0]?.link ? filter?.link[0]?.link : ''\"\r\n                      [value]=\"filter?.identifier || ''\"\r\n                      (change)=\"\r\n                        onCheckboxChange(\r\n                          $event,\r\n                          filter?.link[0]?.link,\r\n                          filter?.link[0]?.name,\r\n                          filter?.vocabulary?.name\r\n                        )\r\n                      \"\r\n                    />\r\n                    <label\r\n                      class=\"custom-control-label\"\r\n                      [for]=\"filter?.vocabulary?.name + '-' + filter?.identifier\"\r\n                    >\r\n                      {{ filter?.link[0]?.name || '' }}\r\n                    </label>\r\n                  </div>\r\n                  <ng-container *ngFor=\"let options of filter?.vocabulary?.terms\">\r\n                    <div\r\n                      class=\"custom-control custom-checkbox\"\r\n                      *ngIf=\"options?.label && options?.name\"\r\n                    >\r\n                      <input\r\n                        #checkboxesFilters\r\n                        class=\"custom-control-input\"\r\n                        type=\"checkbox\"\r\n                        [ngClass]=\"options?.class || ''\"\r\n                        [id]=\"options?.id || ''\"\r\n                        [name]=\"options?.path || ''\"\r\n                        [value]=\"options?.id || ''\"\r\n                        (change)=\"\r\n                          onCheckboxChange(\r\n                            $event,\r\n                            options?.path,\r\n                            options?.label,\r\n                            filter?.vocabulary?.name\r\n                          )\r\n                        \"\r\n                      />\r\n                      <label\r\n                        class=\"custom-control-label\"\r\n                        [for]=\"options?.id || ''\"\r\n                      >\r\n                        {{ options?.label || '' }}\r\n                      </label>\r\n                    </div>\r\n                  </ng-container>\r\n                </form>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </ng-container>\r\n      </ng-container>\r\n    </ng-container>\r\n    <ng-container\r\n      *ngIf=\"data?.filter_program_button?.length > 0\">\r\n      <div class=\"row row-button\">\r\n        <div class=\"col\">\r\n          <div class=\"box-button\">\r\n            <ng-container\r\n              *ngIf=\"\r\n                localDeviceDetector.isDesktop() &&\r\n                data?.vocabulary_content_type === 'programs'\r\n              \"\r\n            >\r\n              <button\r\n                [ngClass]=\"data?.filter_program_button[0]?.class || ''\"\r\n                [id]=\"\r\n                  identifier + '_' + data?.filter_program_button[0]?.identifier\r\n                \"\r\n                (click)=\"uncheckAll()\"\r\n              >\r\n                {{ data?.filter_program_button[0]?.link[0]?.name }}\r\n              </button>\r\n            </ng-container>\r\n            <ng-container *ngIf=\"localDeviceDetector.isMobile()\">\r\n              <button\r\n                [ngClass]=\"data?.filter_program_button[0]?.class\r\n                    || ''\r\n                \"\r\n                [id]=\"\r\n                  identifier + '_' + data?.filter_program_button[0]?.identifier\r\n                \"\r\n                (click)=\"showFilters.emit()\"\r\n              >\r\n                {{ textMobile?.applyFilter }}\r\n                {{ counter !== 0 ? '(' + counter + ')' : '' }}\r\n              </button>\r\n            </ng-container>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], FiltersProgrammesComponent);

let FiltersProgrammesModule = class FiltersProgrammesModule {
};
FiltersProgrammesModule = __decorate([
    NgModule({
        declarations: [FiltersProgrammesComponent],
        imports: [
            CommonModule,
            SharedModule,
            NgbCollapseModule,
            FormsModule,
            ReactiveFormsModule,
            RouterModule,
        ],
        exports: [FiltersProgrammesComponent],
    })
], FiltersProgrammesModule);

let ProgrammesResultsComponent = class ProgrammesResultsComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.redirectPage = new EventEmitter();
        this.deleteFilterEmitter = new EventEmitter();
        this.clearFiltersEmitter = new EventEmitter();
        this.loaderState = false;
        this.clearAllLabel = 'Borrar todo';
    }
    deleteFilter(filterEle) {
        this.currentFilters.options.splice(this.currentFilters.options.indexOf(filterEle), 1);
        this.deleteFilterEmitter.emit(this.currentFilters);
    }
    clearFilters() {
        this.clearFiltersEmitter.emit();
    }
};
__decorate([
    Input()
], ProgrammesResultsComponent.prototype, "module", void 0);
__decorate([
    Input()
], ProgrammesResultsComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], ProgrammesResultsComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ProgrammesResultsComponent.prototype, "redirectPage", void 0);
__decorate([
    Output()
], ProgrammesResultsComponent.prototype, "deleteFilterEmitter", void 0);
__decorate([
    Output()
], ProgrammesResultsComponent.prototype, "clearFiltersEmitter", void 0);
__decorate([
    Input()
], ProgrammesResultsComponent.prototype, "programmesResult", void 0);
__decorate([
    Input()
], ProgrammesResultsComponent.prototype, "searchResult", void 0);
__decorate([
    Input()
], ProgrammesResultsComponent.prototype, "currentFilters", void 0);
__decorate([
    Input()
], ProgrammesResultsComponent.prototype, "loaderState", void 0);
__decorate([
    Input()
], ProgrammesResultsComponent.prototype, "clearAllLabel", void 0);
ProgrammesResultsComponent = __decorate([
    Component({
        selector: 'dmmp-programmes-results',
        template: "<dmmp-container\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'programmes-result'\"\r\n  [data]=\"module\"\r\n>\r\n  <div class=\"container\" *ngIf=\"!loaderState\">\r\n    <div\r\n      class=\"row box-filters-tags\"\r\n      *ngIf=\"currentFilters?.options?.length > 0\"\r\n    >\r\n      <div class=\"col-auto\" *ngFor=\"let filterItem of currentFilters.options\">\r\n        <div class=\"filter-box\">\r\n          <p>{{ filterItem.name }}</p>\r\n          <i class=\"fas fa-times\" (click)=\"deleteFilter(filterItem)\"></i>\r\n        </div>\r\n      </div>\r\n      <div class=\"col-auto\">\r\n        <div class=\"clear-action\">\r\n          <a (click)=\"clearFilters()\">{{ clearAllLabel }}</a>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <ng-container>\r\n      <ng-container\r\n        *ngIf=\"programmesResult?.length > 0; else searchResultTemplate\"\r\n      >\r\n        <dmmp-result-view\r\n          class=\"row\"\r\n          [programmesResult]=\"programmesResult\"\r\n          (redirectPage)=\"redirectPage.emit($event)\"\r\n          (anchorCustom)=\"anchorCustom.emit($event)\"\r\n        >\r\n        </dmmp-result-view>\r\n      </ng-container>\r\n      <ng-template #searchResultTemplate>\r\n        <ng-container *ngIf=\"searchResult?.length > 0\">\r\n          <dmmp-result-view\r\n            class=\"row\"\r\n            [programmesResult]=\"searchResult\"\r\n            (redirectPage)=\"redirectPage.emit($event)\"\r\n            (anchorCustom)=\"anchorCustom.emit($event)\"\r\n          >\r\n          </dmmp-result-view>\r\n        </ng-container>\r\n      </ng-template>\r\n    </ng-container>\r\n  </div>\r\n  <div class=\"loader\" *ngIf=\"loaderState\">\r\n    <div class=\"content-loader\">\r\n      <svg\r\n        class=\"spinner-content-result\"\r\n        width=\"65px\"\r\n        height=\"65px\"\r\n        viewBox=\"0 0 66 66\"\r\n        xmlns=\"http://www.w3.org/2000/svg\"\r\n      >\r\n        <circle\r\n          class=\"path-content-result\"\r\n          fill=\"none\"\r\n          stroke-width=\"6\"\r\n          stroke-linecap=\"round\"\r\n          cx=\"33\"\r\n          cy=\"33\"\r\n          r=\"30\"\r\n        ></circle>\r\n      </svg>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], ProgrammesResultsComponent);

let ResultViewComponent = class ResultViewComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.redirectPage = new EventEmitter();
        this.durationLabel = 'Duración: ';
        this.modalityLabel = 'Modalidad: ';
        this.medias = [
            {
                media: '(min-width:260px) AND (max-width:989px)',
                style: '289x290'
            },
            {
                media: '(min-width:990px)',
                style: 'file_entity_browser_thumbnail'
            }
        ];
    }
};
__decorate([
    Input()
], ResultViewComponent.prototype, "programmesResult", void 0);
__decorate([
    Input()
], ResultViewComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], ResultViewComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ResultViewComponent.prototype, "redirectPage", void 0);
__decorate([
    Input()
], ResultViewComponent.prototype, "durationLabel", void 0);
__decorate([
    Input()
], ResultViewComponent.prototype, "modalityLabel", void 0);
ResultViewComponent = __decorate([
    Component({
        selector: 'dmmp-result-view',
        template: "<div\r\n  class=\"col-md-4 col-sm-6 col-12 box-item-program\"\r\n  *ngFor=\"let program of programmesResult\"\r\n>\r\n  <div class=\"item-program\">\r\n    <div class=\"img-box\">\r\n      <div\r\n        class=\"tag-box\"\r\n        *ngIf=\"program?.flag?.length > 0\"\r\n        [style.backgroundColor]=\"\r\n          program.flag[0]?.background_color.color\r\n            ? program.flag[0]?.background_color.color\r\n            : ''\r\n        \"\r\n      >\r\n        <span\r\n          [ngClass]=\"program?.flag[0]?.class ? program.flag[0].class : ''\"\r\n          *ngIf=\"program?.flag[0].label\"\r\n        >\r\n          {{ program.flag[0].label }}\r\n        </span>\r\n      </div>\r\n      <dmmp-image  [medias]=\"medias\" *ngIf=\"program?.image?.length > 0\" [images]=\"program.image[0]\">\r\n      </dmmp-image>\r\n    </div>\r\n    <div class=\"txt-box\">\r\n      <div class=\"program-type-box\" *ngIf=\"program.program_type && program.program_type.length > 0\">\r\n        <p class=\"program-type-info\" *ngFor=\"let programTypeItem of program.program_type; let i = index\">\r\n          <ng-container *ngIf=\"i !== (program.program_type.length -  1); else lastTemplate\">{{programTypeItem + ', '}}\r\n          </ng-container>\r\n          <ng-template #lastTemplate>{{programTypeItem}}</ng-template>\r\n        </p>\r\n      </div>\r\n      <h2 class=\"program-title\">{{ program.title }}</h2>\r\n      <div\r\n        class=\"duration-box\"\r\n        *ngIf=\"program.duration\"\r\n        [ngClass]=\"program.duration_class ? program.duration_class : ''\"\r\n      >\r\n        <span class=\"duration-title\">{{ durationLabel }}</span>\r\n        <span class=\"duration-info\">{{ program.duration }}</span>\r\n      </div>\r\n      <div class=\"modality-box\" *ngIf=\"program.modality?.length > 0\">\r\n        <span class=\"modality-title\">{{modalityLabel}}</span>\r\n        <span class=\"modality-info\" *ngFor=\"let modalityItem of program.modality; let i = index\">\r\n          <ng-container *ngIf=\"i !== (program.modality.length - 1); else lastTemplate\">{{modalityItem + ', '}}\r\n          </ng-container>\r\n          <ng-template #lastTemplate>{{modalityItem}}</ng-template>\r\n        </span>\r\n      </div>\r\n    </div>\r\n    <div class=\"btn-box\">\r\n      <dmmp-button\r\n        *ngIf=\"program.button_card?.length > 0\"\r\n        [data]=\"program.button_card[0]\"\r\n        [identifier]=\"identifier\"\r\n        (anchorCustom)=\"anchorCustom.emit($event)\"\r\n        (page)=\"redirectPage.emit($event)\"\r\n      ></dmmp-button>\r\n    </div>\r\n  </div>\r\n</div>\r\n\r\n"
    })
], ResultViewComponent);

let ProgrammesResultsModule = class ProgrammesResultsModule {
};
ProgrammesResultsModule = __decorate([
    NgModule({
        declarations: [ProgrammesResultsComponent, ResultViewComponent],
        imports: [
            CommonModule,
            SharedModule,
            InfiniteScrollModule
        ],
        exports: [ProgrammesResultsComponent]
    })
], ProgrammesResultsModule);

let SearchHeadComponent = class SearchHeadComponent {
    constructor(activatedRoute) {
        this.activatedRoute = activatedRoute;
        this.checkboxFiltersAction = new EventEmitter();
        this.selectedFilter = new EventEmitter();
        this.selectedOrder = new EventEmitter();
        this.isSearching = false;
        this.labelSearch = {
            found: 'Resultados encontrados',
            notFound: 'Lo sentimos, no se ha encontrado',
            filter: 'Filtro',
            tryOtherFound: 'Intenta realizar otra búsqueda.',
            filterBy: 'Filtrar por',
            orderBy: 'Ordenar por',
            filterByAll: 'Todos',
            orderByNoOne: 'Ninguno',
        };
    }
    ngOnChanges(changes) {
        this.selectedTitle();
    }
    selectedTitle() {
        var _a;
        const filterSize = (_a = this.currentCheckboxFilters) === null || _a === void 0 ? void 0 : _a.options.length;
        const queryString = this.activatedRoute.snapshot.queryParams.q;
        const moduleName = this.module.name;
        if (moduleName) {
            if (queryString) {
                filterSize === 0
                    ? (this.titleSearchHead = queryString)
                    : (this.titleSearchHead = moduleName);
            }
            else if (filterSize === 1) {
                this.titleSearchHead = this.currentCheckboxFilters.options[0].name;
            }
            else if (this.resultTotal !== 0 ||
                (this.resultTotal === 0 && !this.isSearching)) {
                this.titleSearchHead = moduleName;
            }
            else {
                this.titleSearchHead = this.labelSearch.notFound;
            }
        }
    }
};
SearchHeadComponent.ctorParameters = () => [
    { type: ActivatedRoute }
];
__decorate([
    Input()
], SearchHeadComponent.prototype, "module", void 0);
__decorate([
    Input()
], SearchHeadComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SearchHeadComponent.prototype, "resultTotal", void 0);
__decorate([
    Input()
], SearchHeadComponent.prototype, "optionsFilterBy", void 0);
__decorate([
    Input()
], SearchHeadComponent.prototype, "optionsOrderBy", void 0);
__decorate([
    Input()
], SearchHeadComponent.prototype, "currentCheckboxFilters", void 0);
__decorate([
    Output()
], SearchHeadComponent.prototype, "checkboxFiltersAction", void 0);
__decorate([
    Output()
], SearchHeadComponent.prototype, "selectedFilter", void 0);
__decorate([
    Output()
], SearchHeadComponent.prototype, "selectedOrder", void 0);
__decorate([
    Input()
], SearchHeadComponent.prototype, "isSearching", void 0);
SearchHeadComponent = __decorate([
    Component({
        selector: 'dmmp-search-head',
        template: "<dmmp-container\r\n  [data]=\"module\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'search-head'\"\r\n>\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <div class=\"col-12 col-md-auto\">\r\n        <div class=\"box-text-filters\">\r\n          <ng-container>\r\n            <h1\r\n              *ngIf=\"module?.name\"\r\n              [ngClass]=\"module.title_class ? module.title_class : ''\"\r\n            >\r\n              {{ titleSearchHead }}\r\n            </h1>\r\n            <p *ngIf=\"isSearching\" class=\"total-result\">\r\n              {{ resultTotal }} {{ labelSearch.found }}\r\n            </p>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n      <div class=\"col-12 col-md-auto\">\r\n        <div class=\"row\">\r\n          <div class=\"col-auto button-filter\" *ngIf=\"module?.put_filter\">\r\n            <div class=\"box-button\">\r\n              <button\r\n                class=\"filter-button\"\r\n                (click)=\"checkboxFiltersAction.emit()\"\r\n              >\r\n                <i class=\"fas fa-filter\"></i>{{ labelSearch.filter }}\r\n              </button>\r\n            </div>\r\n          </div>\r\n          <div\r\n            class=\"col-auto select-filters\"\r\n            *ngIf=\"module?.put_filter_by && optionsFilterBy?.length > 0\"\r\n          >\r\n            <div class=\"box-input\">\r\n              <div class=\"box-select\">\r\n                <select\r\n                  class=\"select-custom\"\r\n                  (change)=\"selectedFilter.emit($event)\"\r\n                >\r\n                  <option disabled selected>{{ labelSearch.filterBy }}</option>\r\n                  <option [value]=\"'all'\">\r\n                    {{ labelSearch.filterByAll }}\r\n                  </option>\r\n                  <option\r\n                    [value]=\"options.value\"\r\n                    *ngFor=\"let options of optionsFilterBy\"\r\n                  >\r\n                    {{ options.label }}\r\n                  </option>\r\n                </select>\r\n              </div>\r\n            </div>\r\n          </div>\r\n          <div\r\n            class=\"col-auto select-orders\"\r\n            *ngIf=\"module?.put_order && optionsOrderBy?.length > 0\"\r\n          >\r\n            <div class=\"box-input\">\r\n              <div class=\"box-select\">\r\n                <select\r\n                  class=\"select-custom\"\r\n                  (change)=\"selectedOrder.emit($event)\"\r\n                >\r\n                  <option disabled selected>{{ labelSearch.orderBy }}</option>\r\n                  <option [value]=\"null\">\r\n                    {{ labelSearch.orderByNoOne }}\r\n                  </option>\r\n                  <option\r\n                    [value]=\"options.value\"\r\n                    *ngFor=\"let options of optionsOrderBy\"\r\n                  >\r\n                    {{ options.label }}\r\n                  </option>\r\n                </select>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], SearchHeadComponent);

let SearchHeadModule = class SearchHeadModule {
};
SearchHeadModule = __decorate([
    NgModule({
        declarations: [SearchHeadComponent],
        imports: [CommonModule, SharedModule],
        exports: [SearchHeadComponent],
    })
], SearchHeadModule);

let WebsiteBoxFloatProgramV2Component = class WebsiteBoxFloatProgramV2Component {
    constructor(dateService, richsnipetService, removeHtmlPipe) {
        this.dateService = dateService;
        this.richsnipetService = richsnipetService;
        this.removeHtmlPipe = removeHtmlPipe;
        this.duration = 'Duración:';
        this.title = 'Título:';
        this.titleComplementary = 'Titulo complementario:';
        this.doubleDegree = 'Doble titulación posible:';
        this.titleIntermediate = 'Título intermedio (3 años):';
        this.modalityText = 'Modalidad:';
        this.campusText = 'Sede:';
        this.resolutionText = 'Resolución Ministerial:';
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.schemaItemVideo = [];
        this.schemaItem = [];
        this.medias = [
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width:326px)' },
            { style: 'max_325x325', media: '(max-width:325px)' },
        ];
    }
    ngOnInit() {
        if (this.detailLayout && this.detailLayout.video_box && this.detailLayout.video_box.length > 0) {
            if (this.detailLayout.video_box[0].type === 'youtube') {
                const video = this.detailLayout.video_box[0].video[0].value;
                this.richsnipetService.getInfoVideo((video.substr(video.indexOf('v=') + 2, video.length))).pipe(map((data) => {
                    if (data) {
                        this.createRichSnipet(data.items[0].contentDetails.duration);
                    }
                })).subscribe();
            }
            else {
                this.createRichSnipet();
            }
        }
        if (this.detailLayout) {
            if (this.detailLayout.items && this.detailLayout.items.length > 0) {
                this.description = this.detailLayout.items[0].options.find(tabs => {
                    if (tabs.identifier === 'textos') {
                        return tabs.text;
                    }
                });
            }
            this.schemaItem = this.richsnipetService.setupJsonCourse([{
                    title: this.detailLayout.title ? this.detailLayout.title : '',
                    description: this.description ? this.removeHtmlPipe.transform(this.description.text) : '',
                    university: [{ title: this.university ? this.university : '' }],
                }]);
        }
    }
    createRichSnipet(duration = '') {
        this.schemaItemVideo = this.richsnipetService.setupJsonVideo(this.detailLayout.video_box[0].title ? this.detailLayout.video_box[0].title : '', this.detailLayout.video_box[0].description ? this.removeHtmlPipe.transform(this.detailLayout.video_box[0].description) : '', this.detailLayout.video_box[0].image && this.detailLayout.video_box[0].image.length > 0 && this.detailLayout.video_box[0].image[0].styles.large ? this.detailLayout.video_box[0].image[0].styles.large : '', this.detailLayout.video_box[0].created_at ? this.dateService.convertFromTimestampToDate(this.detailLayout.video_box[0].created_at) : '', this.detailLayout.video_box[0].video[0].value ? this.detailLayout.video_box[0].video[0].value : '', duration);
    }
    onScrollEvent() {
        const header = document.querySelector('header');
        const heightHeader = header ? header.offsetHeight : 64;
        this.classScroll = window.scrollY > heightHeader + 120;
        this.classScrollMobile = window.scrollY > 0;
    }
};
WebsiteBoxFloatProgramV2Component.ctorParameters = () => [
    { type: DateFormatService },
    { type: RichsnipetService },
    { type: RemoveHtmlPipe }
];
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "detailLayout", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "university", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "duration", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "title", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "titleComplementary", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "doubleDegree", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "titleIntermediate", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "modalityText", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "campusText", void 0);
__decorate([
    Input()
], WebsiteBoxFloatProgramV2Component.prototype, "resolutionText", void 0);
__decorate([
    Output()
], WebsiteBoxFloatProgramV2Component.prototype, "page", void 0);
__decorate([
    Output()
], WebsiteBoxFloatProgramV2Component.prototype, "anchorCustom", void 0);
__decorate([
    HostListener('window:scroll', [])
], WebsiteBoxFloatProgramV2Component.prototype, "onScrollEvent", null);
WebsiteBoxFloatProgramV2Component = __decorate([
    Component({
        selector: 'dmmp-website-box-float-program-v2',
        template: "<ngx-json-ld *ngIf=\"schemaItemVideo\" [json]=\"schemaItemVideo\"></ngx-json-ld>\r\n<ngx-json-ld *ngIf=\"schemaItem\" [json]=\"schemaItem\"></ngx-json-ld>\r\n<div class=\"container website-container-box\">\r\n  <div\r\n    class=\"website-box-float-program box-float-absolute\"\r\n    [ngClass]=\"classScroll ? 'box-float-fixed' : ''\"\r\n    *ngIf=\"detailLayout\"\r\n  >\r\n    <dmmp-container\r\n      [identifier]=\"identifier\"\r\n      [data]=\"module ? module : {}\"\r\n      [defaultClass]=\"'bg-box-float'\"\r\n    >\r\n      <div class=\"box-image\">\r\n        <div class=\"content-media-float\">\r\n          <div\r\n            class=\"flag-text\"\r\n            *ngIf=\"detailLayout?.flag?.length > 0\"\r\n            [style.backgroundColor]=\"\r\n              detailLayout.flag[0].background_color.color\r\n                ? detailLayout.flag[0].background_color.color\r\n                : ''\r\n            \"\r\n            [ngClass]=\"\r\n              detailLayout.flag[0].class ? detailLayout.flag[0].class : ''\r\n            \"\r\n          >\r\n            <p>\r\n              {{ detailLayout.flag[0].label ? detailLayout.flag[0].label : '' }}\r\n            </p>\r\n          </div>\r\n          <ng-container\r\n            *ngIf=\"\r\n                 detailLayout?.video_box?.length > 0;\r\n                else img\r\n              \"\r\n          >\r\n            <div\r\n              class=\"media video-box\"\r\n              (click)=\"\r\n                  detailLayout.video_box && detailLayout.video_box.length > 0\r\n                    ? (openModal = true)\r\n                    : ''\r\n                \">\r\n              <dmmp-image\r\n                class=\"video-with-image\"\r\n                *ngIf=\"detailLayout?.video_box[0]?.image?.length > 0\"\r\n                [images]=\"detailLayout?.video_box[0]?.image[0]\"\r\n                [medias]=\"medias\"\r\n              ></dmmp-image>\r\n            </div>\r\n\r\n          </ng-container>\r\n          <ng-template #img>\r\n            <div\r\n              class=\"media\">\r\n              <dmmp-image\r\n                class=\"image-alone\"\r\n                *ngIf=\"detailLayout?.image?.length > 0\"\r\n                [images]=\"detailLayout?.image[0]\"\r\n                [medias]=\"medias\"\r\n              ></dmmp-image>\r\n            </div>\r\n          </ng-template>\r\n        </div>\r\n        <div\r\n          class=\"content-price-button\"\r\n          [ngClass]=\"classScrollMobile ? 'box-float-fixed-mobile' : ''\"\r\n        >\r\n          <p\r\n            class=\"box-title-program show-element\"\r\n            *ngIf=\"detailLayout?.title\"\r\n          >\r\n            {{ detailLayout.title }}\r\n          </p>\r\n          <div\r\n            class=\"btn-content-mobile\"\r\n            *ngIf=\"\r\n              detailLayout?.button_box?.length > 0\r\n            \"\r\n          >\r\n            <dmmp-button\r\n              *ngIf=\"detailLayout?.button_box[0]\"\r\n              (anchorCustom)=\"anchorCustom.emit($event)\"\r\n              (page)=\"page.emit($event)\"\r\n              class=\"btn-action\"\r\n              [data]=\"detailLayout.button_box[0]\"\r\n            ></dmmp-button>\r\n          </div>\r\n        </div>\r\n      </div>\r\n      <div class=\"info-content\">\r\n        <div class=\"row-detail\">\r\n          <p\r\n            class=\"col-icon-text duration\"\r\n            *ngIf=\"detailLayout?.duration\"\r\n            [ngClass]=\"\r\n              detailLayout.duration_class ? detailLayout.duration_class : ''\r\n            \"\r\n          >\r\n            <strong>{{duration}}&nbsp;</strong>{{ detailLayout.duration ? detailLayout.duration : '' }}\r\n          </p>\r\n          <p\r\n            class=\"col-icon-text title-certificate\"\r\n            *ngIf=\"\r\n              detailLayout?.certification?.length > 0\r\n            \"\r\n            [ngClass]=\"\r\n              detailLayout.certification[0].class\r\n                ? detailLayout.certification[0].class\r\n                : ''\r\n            \"\r\n          >\r\n            <strong>{{title}}&nbsp;</strong><span\r\n            [outerHTML]=\" detailLayout.certification[0].text ? (detailLayout.certification[0].text | removeHtml) : ''\"></span>\r\n          </p>\r\n          <p\r\n            class=\"col-icon-text title-complementary hidden-element\"\r\n            *ngIf=\"\r\n              detailLayout?.certification_complementary?.length > 0\r\n            \"\r\n            [ngClass]=\"\r\n              detailLayout.certification_complementary[0].class\r\n                ? detailLayout.certification_complementary[0].class\r\n                : ''\r\n            \"\r\n          >\r\n            <strong>{{titleComplementary}}&nbsp;</strong><span [outerHTML]=\"\r\n                detailLayout.certification_complementary[0].text\r\n                  ? (detailLayout.certification_complementary[0].text | removeHtml)\r\n                  : ''\r\n              \"\r\n          ></span>\r\n          </p>\r\n          <p\r\n            class=\"col-icon-text title-double hidden-element\"\r\n            *ngIf=\"\r\n              detailLayout?.certification_double?.length > 0\r\n            \"\r\n            [ngClass]=\"\r\n              detailLayout.certification_double[0].class\r\n                ? detailLayout.certification_double[0].class\r\n                : ''\r\n            \"\r\n          >\r\n            <strong>{{doubleDegree}}&nbsp;</strong><span\r\n            [outerHTML]=\"\r\n                detailLayout.certification_double[0].text\r\n                  ? (detailLayout.certification_double[0].text | removeHtml)\r\n                  : ''\r\n              \"\r\n          ></span>\r\n          </p>\r\n          <p\r\n            class=\"col-icon-text title-intermediate hidden-element\"\r\n            *ngIf=\"\r\n              detailLayout?.certification_middle?.length > 0\r\n            \"\r\n            [ngClass]=\"\r\n              detailLayout.certification_middle[0].class\r\n                ? detailLayout.certification_middle[0].class\r\n                : ''\r\n            \"\r\n          >\r\n            <strong>{{titleIntermediate}}&nbsp;</strong><span\r\n            [outerHTML]=\"\r\n                detailLayout.certification_middle[0].text\r\n                  ? (detailLayout.certification_middle[0].text | removeHtml)\r\n                  : ''\r\n              \"\r\n          ></span>\r\n          </p>\r\n          <p\r\n            class=\"col-icon-text modality\"\r\n            *ngIf=\"detailLayout?.modality?.length > 0\"\r\n            [ngClass]=\"\r\n              detailLayout.modality_class ? detailLayout.modality_class : ''\r\n            \"\r\n          >\r\n            <strong>{{modalityText}}&nbsp;</strong>\r\n            <ng-container *ngFor=\"let modality of detailLayout.modality; let i = index\">\r\n              {{modality}}{{ (i + 1) < detailLayout.modality.length ? ', ' : '.'}}\r\n            </ng-container>\r\n          </p>\r\n          <p\r\n            class=\"col-icon-text campus\"\r\n            *ngIf=\"detailLayout?.campus?.length > 0\"\r\n          >\r\n            <strong>{{campusText}}&nbsp;</strong>\r\n            <ng-container *ngFor=\"let campus of detailLayout.campus; let i = index\">\r\n              {{campus.title ? campus.title : ''}}{{ (i + 1) < detailLayout.campus.length ? ', ' : '.'}}\r\n            </ng-container>\r\n\r\n          </p>\r\n        </div>\r\n        <div\r\n          class=\"btn-content-desktop\"\r\n          *ngIf=\"detailLayout?.button_box?.length > 0\"\r\n        >\r\n          <dmmp-button\r\n            *ngIf=\"detailLayout?.button_box[0]\"\r\n            (anchorCustom)=\"anchorCustom.emit($event)\"\r\n            (page)=\"page.emit($event)\"\r\n            class=\"btn-action\"\r\n            [data]=\"detailLayout.button_box[0]\"\r\n          ></dmmp-button>\r\n        </div>\r\n        <p\r\n          class=\"text\"\r\n          *ngIf=\"detailLayout?.snies_file?.length > 0 \"\r\n        >\r\n          {{resolutionText}}\r\n          <a\r\n            *ngFor=\"let snies of detailLayout.snies_file\"\r\n            [href]=\"snies.file ? snies.file : ''\"\r\n            target=\"_blank\"\r\n            [ngClass]=\"snies.title_class ? snies.title_class : ''\"\r\n            [id]=\"snies.id_element ? snies.id_element : ''\"\r\n          >\r\n            {{snies.title ? snies.title : ''}}\r\n          </a>\r\n        </p>\r\n      </div>\r\n    </dmmp-container>\r\n  </div>\r\n</div>\r\n<div class=\"modal-video\">\r\n  <dmmp-modal\r\n    [openModal]=\"openModal\"\r\n    [locationVertical]=\"'modal-dialog-centered'\"\r\n    (showModal)=\"openModal = $event\"\r\n  >\r\n    <div class=\"content-modal-video\">\r\n      <dmmp-video-player\r\n        *ngIf=\"detailLayout?.video_box?.length > 0\"\r\n        [type]=\"\r\n          detailLayout.video_box[0].type ? detailLayout.video_box[0].type : ''\r\n        \"\r\n        [src]=\"\r\n          detailLayout.video_box[0].video.length > 0 &&\r\n          detailLayout.video_box[0].video[0].value\r\n            ? detailLayout.video_box[0].video[0].value\r\n            : ''\r\n        \"\r\n      ></dmmp-video-player>\r\n    </div>\r\n  </dmmp-modal>\r\n</div>\r\n"
    })
], WebsiteBoxFloatProgramV2Component);

let WebsiteBoxFloatProgramV2Module = class WebsiteBoxFloatProgramV2Module {
};
WebsiteBoxFloatProgramV2Module = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            RouterModule,
            NgxJsonLdModule,
            PipesModule
        ],
        declarations: [WebsiteBoxFloatProgramV2Component],
        exports: [
            WebsiteBoxFloatProgramV2Component
        ],
        providers: [RichsnipetService, RemoveHtmlPipe]
    })
], WebsiteBoxFloatProgramV2Module);

let EventLocationComponent = class EventLocationComponent {
    constructor(buildInterfaceService) {
        this.buildInterfaceService = buildInterfaceService;
        this.defaultClass = 'event-information component-map';
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.marks = [];
        this.pinUrl = './assets/images/house-pin.png';
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
        if (this.detailLayout) {
            this.mapsConfig = {
                center: {
                    lat: ((_a = this.detailLayout) === null || _a === void 0 ? void 0 : _a.latitude) ? parseFloat((_b = this.detailLayout) === null || _b === void 0 ? void 0 : _b.latitude) : (((_c = this.module) === null || _c === void 0 ? void 0 : _c.maps_latitude) ? (_d = this.module) === null || _d === void 0 ? void 0 : _d.maps_latitude : 0),
                    lng: ((_e = this.detailLayout) === null || _e === void 0 ? void 0 : _e.longitude) ? parseFloat((_f = this.detailLayout) === null || _f === void 0 ? void 0 : _f.longitude) : (((_g = this.module) === null || _g === void 0 ? void 0 : _g.maps_longitude) ? (_h = this.module) === null || _h === void 0 ? void 0 : _h.maps_longitude : 0)
                },
                zoom: ((_j = this.module) === null || _j === void 0 ? void 0 : _j.maps_zoom) ? parseFloat((_k = this.module) === null || _k === void 0 ? void 0 : _k.maps_zoom) : 5 // Zoom default
            };
            this.marks.push(this.buildInterfaceService.buildMapMarkInterface(this.detailLayout, (_l = this.module) === null || _l === void 0 ? void 0 : _l.maps_latitude, (_m = this.module) === null || _m === void 0 ? void 0 : _m.maps_longitude, this.pinUrl));
        }
    }
};
EventLocationComponent.ctorParameters = () => [
    { type: BuildInterfaceService }
];
__decorate([
    Input()
], EventLocationComponent.prototype, "module", void 0);
__decorate([
    Input()
], EventLocationComponent.prototype, "detailLayout", void 0);
__decorate([
    Input()
], EventLocationComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], EventLocationComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], EventLocationComponent.prototype, "page", void 0);
__decorate([
    Output()
], EventLocationComponent.prototype, "anchorCustom", void 0);
__decorate([
    Input()
], EventLocationComponent.prototype, "pinUrl", void 0);
EventLocationComponent = __decorate([
    Component({
        selector: 'dmmp-event-location',
        template: "<dmmp-container [data]=\"module\" [defaultClass]=\"defaultClass\" [identifier]=\"identifier\">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">\r\n      {{module?.name}}\r\n    </h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <dmmp-maps [mapConfig]=\"mapsConfig\" [marks]=\"marks\" [type]=\"'event-information'\"\r\n      [mapClass]=\"'event-information-map'\">\r\n    </dmmp-maps>\r\n    <div class=\"box-button\" *ngIf=\"module?.see_more?.length > 0\">\r\n      <dmmp-button\r\n        (page)=\"page.emit($event)\"\r\n        (anchorCustom)=\"anchorCustom.emit($event)\"\r\n        [data]=\"module?.see_more[0]\"\r\n        [identifier]=\"identifier\">\r\n      </dmmp-button>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], EventLocationComponent);

let EventLocationModule = class EventLocationModule {
};
EventLocationModule = __decorate([
    NgModule({
        declarations: [EventLocationComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [EventLocationComponent]
    })
], EventLocationModule);

let CampusLocationFilterComponent = class CampusLocationFilterComponent {
    constructor(formBuilder) {
        this.formBuilder = formBuilder;
        this.defaultClass = 'campus-location-filter';
        this.branches = [];
        this.redirectPage = new EventEmitter();
        this.marks = [];
        this.filterButtons = [];
        this.filterButtonsMarks = [];
        this.searchFilterResult = [];
        this.addressTitle = 'Dirección';
        this.contactTitle = 'Contacto';
        this.scheduleTitle = 'Horario de atención';
        this.placeholderInput = 'Ingresa una dirección, ciudad o nombre';
        this.searchGroup = this.formBuilder.group({
            search: ['', Validators.required]
        });
    }
    ngOnInit() {
        var _a, _b, _c, _d;
        this.configMap((_a = this.module) === null || _a === void 0 ? void 0 : _a.maps_latitude, (_b = this.module) === null || _b === void 0 ? void 0 : _b.maps_longitude);
        this.searchFilterResult = [];
        (_d = (_c = this.module) === null || _c === void 0 ? void 0 : _c.maps_campus_type_values) === null || _d === void 0 ? void 0 : _d.split(',').forEach((filterItem) => {
            this.filterButtons.push({
                filter: filterItem.trim(),
                name: filterItem.trim() === 'branch' ? 'Sedes' : (filterItem.trim() === 'center' ? 'Centros' : 'Virtual'),
                active: false
            });
        });
        this.showAllMarks();
    }
    ngOnChanges() {
        this.showAllMarks();
    }
    configMap(latitude, longitude) {
        var _a, _b;
        this.mapsConfig = {
            center: {
                lat: latitude ? parseFloat(latitude) : 0,
                lng: longitude ? parseFloat(longitude) : 0
            },
            zoom: ((_a = this.module) === null || _a === void 0 ? void 0 : _a.maps_zoom) ? parseFloat((_b = this.module) === null || _b === void 0 ? void 0 : _b.maps_zoom) : 5 // Zoom default
        };
    }
    showAllMarks() {
        var _a;
        (_a = this.branches) === null || _a === void 0 ? void 0 : _a.forEach((branchItem) => {
            var _a;
            (_a = this.marks) === null || _a === void 0 ? void 0 : _a.push(this.buildMarkItem(branchItem));
        });
    }
    onSubmit() {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        if (((_b = (_a = this.searchGroup) === null || _a === void 0 ? void 0 : _a.value) === null || _b === void 0 ? void 0 : _b.search) && ((_e = (_d = (_c = this.searchGroup) === null || _c === void 0 ? void 0 : _c.value) === null || _d === void 0 ? void 0 : _d.search) === null || _e === void 0 ? void 0 : _e.length) > 0) {
            this.searchFilterResult = [];
            if (((_f = this.filterButtonsMarks) === null || _f === void 0 ? void 0 : _f.length) > 0) {
                (_g = this.filterButtonsMarks) === null || _g === void 0 ? void 0 : _g.forEach(resultItem => {
                    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
                    const reg = new RegExp((_b = (_a = this.searchGroup) === null || _a === void 0 ? void 0 : _a.value) === null || _b === void 0 ? void 0 : _b.search, 'gi');
                    if (((((_c = resultItem) === null || _c === void 0 ? void 0 : _c.title) || '') + (((_d = resultItem) === null || _d === void 0 ? void 0 : _d.street) ? ' - ' + ((_f = (_e = resultItem) === null || _e === void 0 ? void 0 : _e.street) === null || _f === void 0 ? void 0 : _f.toUpperCase()) : '')).search(reg) !== -1) {
                        const filterResultItem = Object.assign({}, resultItem);
                        filterResultItem.filterTitle = ((((_g = filterResultItem) === null || _g === void 0 ? void 0 : _g.title) || '')
                            + (((_h = filterResultItem) === null || _h === void 0 ? void 0 : _h.street) ? ' - ' + ((_k = (_j = filterResultItem) === null || _j === void 0 ? void 0 : _j.street) === null || _k === void 0 ? void 0 : _k.toUpperCase()) : '')).replace(reg, `<b>${(_m = (_l = this.searchGroup) === null || _l === void 0 ? void 0 : _l.value) === null || _m === void 0 ? void 0 : _m.search}</b>`);
                        this.searchFilterResult.push(filterResultItem);
                    }
                });
            }
            else {
                (_h = this.branches) === null || _h === void 0 ? void 0 : _h.forEach(resultItem => {
                    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
                    const reg = new RegExp((_b = (_a = this.searchGroup) === null || _a === void 0 ? void 0 : _a.value) === null || _b === void 0 ? void 0 : _b.search, 'gi');
                    if (((((_c = resultItem) === null || _c === void 0 ? void 0 : _c.title) || '') + (((_d = resultItem) === null || _d === void 0 ? void 0 : _d.street) ? ' - ' + ((_f = (_e = resultItem) === null || _e === void 0 ? void 0 : _e.street) === null || _f === void 0 ? void 0 : _f.toUpperCase()) : '')).search(reg) !== -1) {
                        const filterResultItem = Object.assign({}, resultItem);
                        filterResultItem.filterTitle = ((((_g = filterResultItem) === null || _g === void 0 ? void 0 : _g.title) || '')
                            + (((_h = filterResultItem) === null || _h === void 0 ? void 0 : _h.street) ? ' - ' + ((_k = (_j = filterResultItem) === null || _j === void 0 ? void 0 : _j.street) === null || _k === void 0 ? void 0 : _k.toUpperCase()) : '')).replace(reg, `<b>${(_m = (_l = this.searchGroup) === null || _l === void 0 ? void 0 : _l.value) === null || _m === void 0 ? void 0 : _m.search}</b>`);
                        this.searchFilterResult.push(filterResultItem);
                    }
                });
            }
        }
        else {
            this.searchFilterResult = [];
        }
    }
    filter(filterType) {
        var _a, _b;
        this.searchFilterResult = [];
        this.filterButtonsMarks = [];
        this.formReset();
        if (filterType === '') {
            this.showAllMarks();
        }
        else {
            this.marks = [];
            (_a = this.filterButtons) === null || _a === void 0 ? void 0 : _a.forEach((filterButton) => {
                var _a, _b;
                if (((_a = filterButton) === null || _a === void 0 ? void 0 : _a.filter) !== ((_b = filterType) === null || _b === void 0 ? void 0 : _b.filter)) {
                    filterButton.active = false;
                }
            });
            (_b = this.branches) === null || _b === void 0 ? void 0 : _b.forEach((branchItem) => {
                var _a, _b, _c;
                if (((_a = branchItem) === null || _a === void 0 ? void 0 : _a.campus_type) === ((_b = filterType) === null || _b === void 0 ? void 0 : _b.filter)) {
                    this.filterButtonsMarks.push(branchItem);
                    (_c = this.marks) === null || _c === void 0 ? void 0 : _c.push(this.buildMarkItem(branchItem));
                }
            });
        }
    }
    buildMarkItem(branchObject) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
        switch ((_a = branchObject) === null || _a === void 0 ? void 0 : _a.campus_type) {
            case 'center': {
                return ({
                    id: (_b = branchObject) === null || _b === void 0 ? void 0 : _b.id,
                    type: (_c = branchObject) === null || _c === void 0 ? void 0 : _c.campus_type,
                    lat: parseFloat((_d = branchObject) === null || _d === void 0 ? void 0 : _d.latitude),
                    lng: parseFloat((_e = branchObject) === null || _e === void 0 ? void 0 : _e.longitude),
                    title: (_f = branchObject) === null || _f === void 0 ? void 0 : _f.title,
                    link: null,
                    target: null,
                    pinUrl: './assets/images/21-pin.png'
                });
            }
            default: {
                return ({
                    id: (_g = branchObject) === null || _g === void 0 ? void 0 : _g.id,
                    type: (_h = branchObject) === null || _h === void 0 ? void 0 : _h.campus_type,
                    lat: parseFloat((_j = branchObject) === null || _j === void 0 ? void 0 : _j.latitude),
                    lng: parseFloat((_k = branchObject) === null || _k === void 0 ? void 0 : _k.longitude),
                    title: (_l = branchObject) === null || _l === void 0 ? void 0 : _l.title,
                    link: null,
                    target: null,
                    pinUrl: './assets/images/house-pin.png'
                });
            }
        }
    }
    selectBranchOrCampus(itemSelected) {
        var _a, _b;
        this.selectedResult = itemSelected;
        this.configMap((_a = itemSelected) === null || _a === void 0 ? void 0 : _a.latitude, (_b = itemSelected) === null || _b === void 0 ? void 0 : _b.longitude);
        this.marks.forEach((markItem) => {
            var _a, _b;
            if (((_a = markItem) === null || _a === void 0 ? void 0 : _a.id) !== ((_b = itemSelected) === null || _b === void 0 ? void 0 : _b.id)) {
                markItem.pinUrl = this.selectMarkColor(markItem, true);
            }
            else {
                markItem.pinUrl = this.selectMarkColor(markItem, false);
            }
        });
    }
    selectMarkColor(mark, lightMode) {
        var _a;
        switch ((_a = mark) === null || _a === void 0 ? void 0 : _a.type) {
            case 'center': {
                return lightMode ? './assets/images/21-pin-light.png' : './assets/images/21-pin.png';
            }
            default: {
                return lightMode ? './assets/images/house-pin-light.png' : './assets/images/house-pin.png';
            }
        }
    }
    goBack() {
        this.selectedResult = null;
        this.marks.forEach((markItem) => {
            markItem.pinUrl = this.selectMarkColor(markItem, false);
        });
    }
    formReset() {
        this.searchGroup.reset();
        this.searchFilterResult = [];
    }
    campusChange(selectedCampus) {
        this.selectBranchOrCampus(this.branches.find(branchItem => { var _a, _b; return ((_a = branchItem) === null || _a === void 0 ? void 0 : _a.id) === ((_b = selectedCampus) === null || _b === void 0 ? void 0 : _b.id); }));
    }
};
CampusLocationFilterComponent.ctorParameters = () => [
    { type: FormBuilder }
];
__decorate([
    Input()
], CampusLocationFilterComponent.prototype, "module", void 0);
__decorate([
    Input()
], CampusLocationFilterComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], CampusLocationFilterComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], CampusLocationFilterComponent.prototype, "branches", void 0);
__decorate([
    Output()
], CampusLocationFilterComponent.prototype, "redirectPage", void 0);
CampusLocationFilterComponent = __decorate([
    Component({
        selector: 'dmmp-campus-location-filter',
        template: "<dmmp-container [data]=\"module\" [defaultClass]=\"defaultClass\" [identifier]=\"identifier\">\r\n  <div class=\"container-fluid\">\r\n    <div class=\"box-content-map\">\r\n      <div class=\"container search-container\" *ngIf=\"!selectedResult\">\r\n        <div class=\"box-filter-map\">\r\n          <div class=\"row box-campus-input-search\">\r\n            <div class=\"col-12\">\r\n              <div class=\"input-container\">\r\n                <form [formGroup]=\"searchGroup\" (ngSubmit)=\"onSubmit()\">\r\n                  <input [placeholder]=\"placeholderInput\" (keyup)=\"onSubmit()\" type=\"text\" formControlName=\"search\" />\r\n                </form>\r\n                <div class=\"btn-search\">\r\n                  <button type=\"button\" class=\"btn btn-success\"\r\n                    *ngIf=\"searchGroup?.value?.search?.length === 0 || !searchGroup?.value?.search\" (click)=\"onSubmit()\">\r\n                  </button>\r\n                  <button type=\"button\" class=\"btn btn-close\" *ngIf=\"searchGroup?.value?.search?.length > 0\"\r\n                    (click)=\"formReset()\">\r\n                    <i class=\"fas fa-times\"></i>\r\n                  </button>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n          <div class=\"row box-campus-search-filter-results\" *ngIf=\"searchFilterResult?.length > 0\">\r\n            <div class=\"col-12\">\r\n              <div class=\"campus-result result-filter\" *ngFor=\"let resultItem of searchFilterResult | slice: 0:5\">\r\n                <a class=\"campus-filter-result-title\" [innerHTML]=\"resultItem?.filterTitle\"\r\n                  (click)=\"selectBranchOrCampus(resultItem)\"></a>\r\n              </div>\r\n            </div>\r\n          </div>\r\n          <div class=\"row box-campus-search-buttons\" [ngClass]=\"filterButtonsMarks?.length > 0 ? 'pb-3' : ''\">\r\n            <div class=\"col-12\">\r\n              <ng-container *ngFor=\"let filterType of filterButtons\">\r\n                <a type=\"button\" class=\"button-green\" [ngClass]=\"filterType?.active ? 'active': ''\" (click)=\"filterType.active = !filterType.active;\r\n                  filterType.active ? filter(filterType) : filter('')\">\r\n                  {{filterType?.name}}\r\n                </a>\r\n              </ng-container>\r\n            </div>\r\n          </div>\r\n          <div class=\"row box-campus-search-results\" *ngIf=\"filterButtonsMarks?.length > 0\">\r\n            <div class=\"col-12\">\r\n              <div class=\"campus-result result-filter\" *ngFor=\"let filterInfo of filterButtonsMarks\"\r\n                (click)=\"selectBranchOrCampus(filterInfo)\">\r\n                <img\r\n                  [src]=\"filterInfo?.campus_type === 'center' ? './assets/images/21-pin.png' : './assets/images/house-pin.png'\"\r\n                  class=\"campus-result-img\" />\r\n                <div class=\"box-text-result\">\r\n                  <p class=\"campus-result-title\">{{filterInfo?.title}}</p>\r\n                  <p class=\"campus-result-subtitle\">{{filterInfo?.street}}</p>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n      <div class=\"container\" *ngIf=\"selectedResult\">\r\n        <div class=\"view-info-container\">\r\n          <a type=\"button\" class=\"go-back-button\" (click)=\"goBack()\">\r\n            <i class=\"fas fa-arrow-left\"></i>\r\n          </a>\r\n          <div class=\"box-title-info\" *ngIf=\"selectedResult?.title\">\r\n            <p class=\"principal-name\">\r\n              {{selectedResult?.title}}\r\n            </p>\r\n          </div>\r\n          <div class=\"box-address-info\" *ngIf=\"selectedResult?.street\">\r\n            <p class=\"title\">{{addressTitle}}</p>\r\n            <p class=\"information\">{{selectedResult?.street}}</p>\r\n          </div>\r\n          <div class=\"box-contact-info\" *ngIf=\"selectedResult?.phone\">\r\n            <p class=\"title\">{{contactTitle}}</p>\r\n            <p class=\"information\">{{selectedResult?.phone}}</p>\r\n          </div>\r\n          <div class=\"box-schedule-info\" *ngIf=\"selectedResult?.schedule\">\r\n            <p class=\"title\">{{scheduleTitle}}</p>\r\n            <p class=\"information\">{{selectedResult?.schedule}}</p>\r\n          </div>\r\n          <div class=\"box-button-info\"\r\n            *ngIf=\"selectedResult?.button_contact?.length > 0 && selectedResult?.button_contact[0]?.link?.length > 0\">\r\n            <dmmp-button [data]=\"selectedResult?.button_contact[0]\" (page)=\"redirectPage.emit($event)\">\r\n              {{selectedResult?.button_contact[0]?.link[0]?.name}}\r\n            </dmmp-button>\r\n          </div>\r\n        </div>\r\n      </div>\r\n      <dmmp-maps [mapConfig]=\"mapsConfig\" [marks]=\"marks\" [type]=\"'campus-location-filter'\"\r\n        [mapClass]=\"'campus-location-filter-map'\" [mode]=\"'grey'\" (markerClickEmitter)=\"campusChange($event)\">\r\n      </dmmp-maps>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], CampusLocationFilterComponent);

let CampusLocationFilterModule = class CampusLocationFilterModule {
};
CampusLocationFilterModule = __decorate([
    NgModule({
        declarations: [CampusLocationFilterComponent],
        imports: [
            CommonModule,
            SharedModule,
            FormsModule,
            ReactiveFormsModule
        ],
        exports: [CampusLocationFilterComponent]
    })
], CampusLocationFilterModule);

let EventSearchResultComponent = class EventSearchResultComponent {
    constructor() {
        this.totalEventsTitle = 'eventos encontrados';
        this.moduleTitle = 'Resultados de la búsqueda';
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.deleteFilterEmitter = new EventEmitter();
        this.clearFiltersEmitter = new EventEmitter();
        this.loaderState = false;
        this.clearAllLabel = 'Borrar todo';
        this.redirectPage = new EventEmitter();
    }
    ngOnInit() {
    }
    deleteFilter(filterEle) {
        var _a, _b;
        this.currentFilters.options.splice((_b = (_a = this.currentFilters) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.indexOf(filterEle), 1);
        this.deleteFilterEmitter.emit(this.currentFilters);
    }
    clearFilters() {
        this.clearFiltersEmitter.emit();
    }
};
__decorate([
    Input()
], EventSearchResultComponent.prototype, "module", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "totalEventsTitle", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "moduleTitle", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "searchResult", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "currentFilters", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "paginationState", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "eventsResult", void 0);
__decorate([
    Output()
], EventSearchResultComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], EventSearchResultComponent.prototype, "page", void 0);
__decorate([
    Output()
], EventSearchResultComponent.prototype, "deleteFilterEmitter", void 0);
__decorate([
    Output()
], EventSearchResultComponent.prototype, "clearFiltersEmitter", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "loaderState", void 0);
__decorate([
    Input()
], EventSearchResultComponent.prototype, "clearAllLabel", void 0);
__decorate([
    Output()
], EventSearchResultComponent.prototype, "redirectPage", void 0);
EventSearchResultComponent = __decorate([
    Component({
        selector: 'dmmp-event-search-result',
        template: "<dmmp-container [identifier]=\"identifier\" [defaultClass]=\"'event-search-result'\" [data]=\"module\">\r\n  <div class=\"container\" *ngIf=\"!loaderState\">\r\n    <div class=\"row\" *ngIf=\"moduleTitle\">\r\n      <div class=\"col-12\">\r\n        <p>{{moduleTitle}}</p>\r\n      </div>\r\n    </div>\r\n    <div class=\"row box-result-number\">\r\n      <div class=\"col-12\">\r\n        <p>{{paginationState?.totalRegister}} {{totalEventsTitle}}</p>\r\n      </div>\r\n    </div>\r\n    <div class=\"row box-filters-tags\" *ngIf=\"currentFilters?.options?.length > 0\">\r\n      <div class=\"col-auto\" *ngFor=\"let filterItem of currentFilters?.options\">\r\n        <div class=\"filter-box\">\r\n          <p *ngIf=\"filterItem?.name\">{{filterItem?.name}}</p>\r\n          <i class=\"fas fa-times\" (click)=\"deleteFilter(filterItem)\"></i>\r\n        </div>\r\n      </div>\r\n      <div class=\"col-auto\">\r\n        <div class=\"clear-action\">\r\n          <a (click)=\"clearFilters()\">{{clearAllLabel}}</a>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <div class=\"row\">\r\n      <ng-container *ngIf=\"searchResult?.length === 0; else searchResultTemplate\">\r\n        <div class=\"col-lg-6 col-12 box-col-card\" *ngFor=\"let event of eventsResult\">\r\n          <dmmp-card-event [category]=\"event?.categories?.length > 0 ? event?.categories[0] : ''\"\r\n                           (redirectPage)=\"redirectPage.emit($event)\"\r\n                           [title]=\"'<h2>'+ event?.name + '</h2>'\" [image]=\"event?.image\" [date]=\"event?.date?.start\"\r\n                           [description]=\"event?.description\" [descriptionSize]=\"130\" [path]=\"event?.path\">\r\n          </dmmp-card-event>\r\n        </div>\r\n      </ng-container>\r\n      <ng-template #searchResultTemplate>\r\n        <div class=\"col-lg-6 col-12 box-col-card\" *ngFor=\"let event of searchResult\">\r\n          <dmmp-card-event [category]=\"event?.categories?.length > 0 ? event?.categories[0] : ''\"\r\n                           (redirectPage)=\"redirectPage.emit($event)\"\r\n                           [title]=\"'<h2>'+ event?.name + '</h2>'\" [image]=\"event?.image\" [date]=\"event?.date?.start\"\r\n                           [description]=\"event?.description\" [descriptionSize]=\"130\" [path]=\"event?.path\">\r\n          </dmmp-card-event>\r\n        </div>\r\n      </ng-template>\r\n    </div>\r\n  </div>\r\n  <div class=\"loader\" *ngIf=\"loaderState\">\r\n    <div class=\"content-loader\">\r\n      <svg class=\"spinner-content-result\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\"\r\n           xmlns=\"http://www.w3.org/2000/svg\">\r\n        <circle class=\"path-content-result\" fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\"\r\n                r=\"30\"></circle>\r\n      </svg>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], EventSearchResultComponent);

let EventSearchResultModule = class EventSearchResultModule {
};
EventSearchResultModule = __decorate([
    NgModule({
        declarations: [EventSearchResultComponent],
        imports: [
            CommonModule,
            SharedModule,
        ],
        exports: [EventSearchResultComponent]
    })
], EventSearchResultModule);

let ContentSearchResultComponent = class ContentSearchResultComponent {
    constructor() {
        this.defaultClass = 'content-search-result';
        this.searchResult = [];
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.loaderState = false;
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], ContentSearchResultComponent.prototype, "module", void 0);
__decorate([
    Input()
], ContentSearchResultComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ContentSearchResultComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], ContentSearchResultComponent.prototype, "articlesResult", void 0);
__decorate([
    Input()
], ContentSearchResultComponent.prototype, "searchResult", void 0);
__decorate([
    Output()
], ContentSearchResultComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], ContentSearchResultComponent.prototype, "page", void 0);
__decorate([
    Input()
], ContentSearchResultComponent.prototype, "loaderState", void 0);
ContentSearchResultComponent = __decorate([
    Component({
        selector: 'dmmp-content-search-result',
        template: "<dmmp-container [data]=\"module\" [identifier]=\"identifier\" [defaultClass]=\"defaultClass\">\r\n  <div class=\"container\" *ngIf=\"articlesResult?.length > 0 || searchResult?.length > 0 && !loaderState\">\r\n    <div class=\"row article-banner-box\" *ngIf=\"articlesResult?.length > 0\">\r\n      <div class=\"col-12\" *ngIf=\"articlesResult[0]?.identifier === 'blog'\">\r\n        <dmmp-banner-new [description]=\"articlesResult[0]?.content || ''\"\r\n                         [image]=\"articlesResult[0]?.image\" [date]=\"articlesResult[0]?.promotion_date\"\r\n                         [title]=\"articlesResult[0]?.title\"\r\n                         [path]=\"articlesResult[0]?.path\"\r\n                         [textLink]=\"articlesResult[0]?.link?.length > 0 ? articlesResult[0]?.link[0]?.name : ''\"\r\n                         [opacityBox]=\"articlesResult[0]?.opacity_first_box ? articlesResult[0]?.opacity_first_box : ''\"\r\n                         [backgroundColorBox]=\"articlesResult[0]?.background_color?.color || ''\"\r\n                         [quantityDescription]=\"130\" (page)=\"page.emit($event)\">\r\n        </dmmp-banner-new>\r\n      </div>\r\n      <div class=\"col-12\" *ngIf=\"articlesResult[0]?.identifier === 'news'\">\r\n        <dmmp-banner-new [description]=\"articlesResult[0]?.content || ''\"\r\n                         [image]=\"articlesResult[0]?.image_items?.length > 0 ? (articlesResult[0]?.image_items)[0]?.image : []\"\r\n                         [date]=\"articlesResult[0]?.promotion_date\" [title]=\"articlesResult[0]?.title\"\r\n                         [path]=\"articlesResult[0]?.path\"\r\n                         [textLink]=\"articlesResult[0]?.text_link\"\r\n                         [opacityBox]=\"articlesResult[0]?.opacity_first_box || ''\"\r\n                         [backgroundColorBox]=\"articlesResult[0]?.background_color?.color || ''\"\r\n                         [quantityDescription]=\"130\" (page)=\"page.emit($event)\"></dmmp-banner-new>\r\n      </div>\r\n    </div>\r\n    <div class=\"row article-results-box\">\r\n      <ng-container *ngIf=\"searchResult?.length === 0; else searchResultTemplate\">\r\n        <div class=\"col-12 col-lg-4 box-column\"\r\n             *ngFor=\"let articlesItem of articlesResult | slice: 1:articlesResult?.length\">\r\n          <dmmp-card [articlesItem]=\"articlesItem\" (page)=\"page.emit($event)\"></dmmp-card>\r\n        </div>\r\n      </ng-container>\r\n      <ng-template #searchResultTemplate>\r\n        <div class=\"col-12 col-lg-4 box-column\" *ngFor=\"let articlesItem of searchResult\">\r\n          <dmmp-card [articlesItem]=\"articlesItem\" (page)=\"page.emit($event)\"></dmmp-card>\r\n        </div>\r\n      </ng-template>\r\n    </div>\r\n  </div>\r\n  <div class=\"loader\" *ngIf=\"loaderState\">\r\n    <div class=\"content-loader\">\r\n      <svg class=\"spinner-content-result\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\">\r\n        <circle class=\"path-content-result\" fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle>\r\n      </svg>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], ContentSearchResultComponent);

let CardComponent$1 = class CardComponent {
    constructor() {
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], CardComponent$1.prototype, "articlesItem", void 0);
__decorate([
    Output()
], CardComponent$1.prototype, "page", void 0);
CardComponent$1 = __decorate([
    Component({
        selector: 'dmmp-card',
        template: "<dmmp-card-new [path]=\"articlesItem?.path\" [image]=\"\r\n            articlesItem?.identifier === 'blog' ? (articlesItem?.image) :\r\n            (articlesItem?.image_items?.length > 0 ? articlesItem?.image_items[0]?.image : [])\"\r\n  [featured]=\"articlesItem?.featured\" [categories]=\"articlesItem?.identifier !== 'blog' ? articlesItem?.categories : ''\" [date]=\"articlesItem?.promotion_date\"\r\n  [title]=\"'<h2>'+ articlesItem?.title + '</h2>'\"\r\n  [description]=\"articlesItem?.identifier === 'blog' ? articlesItem?.content : ''\"\r\n  [quantityDescription]=\"130\" [defaultClass]=\"'box-card-new'\" (page)=\"page.emit($event)\">\r\n</dmmp-card-new>\r\n"
    })
], CardComponent$1);

let ContentSearchResultModule = class ContentSearchResultModule {
};
ContentSearchResultModule = __decorate([
    NgModule({
        declarations: [ContentSearchResultComponent, CardComponent$1],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [ContentSearchResultComponent]
    })
], ContentSearchResultModule);

let ContentTableComponent = class ContentTableComponent {
    constructor(location) {
        this.location = location;
        this.defaultClass = 'content-table';
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        this.selectByCurrentRoute();
        this.closeCollapse(null);
        if ((_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.table_content) {
            if (((_e = (_d = (_c = this.module) === null || _c === void 0 ? void 0 : _c.content) === null || _d === void 0 ? void 0 : _d.table_content) === null || _e === void 0 ? void 0 : _e.length) > 0) {
                if (((_j = (_h = (_g = (_f = this.module) === null || _f === void 0 ? void 0 : _f.content) === null || _g === void 0 ? void 0 : _g.table_content[0]) === null || _h === void 0 ? void 0 : _h.children) === null || _j === void 0 ? void 0 : _j.length) > 0) {
                    this.module.content.table_content[0].data.isCollapse = false;
                }
            }
        }
    }
    closeCollapse(currentCollapseColumn) {
        var _a, _b;
        if ((_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.table_content) {
            this.module.content.table_content.forEach((columnItem) => {
                if (columnItem.data !== currentCollapseColumn) {
                    columnItem.data.isCollapse = true;
                }
            });
        }
    }
    removeActive(currentActiveLink) {
        var _a, _b;
        if ((_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.table_content) {
            this.module.content.table_content.forEach((columnItem) => {
                if (columnItem.data !== currentActiveLink) {
                    columnItem.data.isActive = false;
                }
                if (columnItem.children) {
                    columnItem.children.forEach(linkItem => {
                        if (currentActiveLink !== linkItem.data) {
                            linkItem.data.isActive = false;
                        }
                    });
                }
            });
        }
    }
    selectByCurrentRoute() {
        var _a, _b;
        (_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.table_content.forEach((columnItem) => {
            if ((columnItem.data.link === this.location.pathname) || (columnItem.data.path === this.location.pathname)) {
                columnItem.data.isActive = true;
            }
            if (columnItem.children) {
                columnItem.children.forEach(linkItem => {
                    if ((linkItem.data.link === this.location.pathname) || (linkItem.data.path === this.location.pathname)) {
                        linkItem.data.isActive = true;
                    }
                });
            }
        });
    }
};
ContentTableComponent.ctorParameters = () => [
    { type: PlatformLocation }
];
__decorate([
    Input()
], ContentTableComponent.prototype, "module", void 0);
__decorate([
    Input()
], ContentTableComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ContentTableComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], ContentTableComponent.prototype, "page", void 0);
__decorate([
    Output()
], ContentTableComponent.prototype, "anchorCustom", void 0);
ContentTableComponent = __decorate([
    Component({
        selector: 'dmmp-content-table',
        template: "<dmmp-container [data]=\"module\" [defaultClass]=\"defaultClass\" [identifier]=\"identifier\"\r\n  *ngIf=\"module?.content?.table_content?.length > 0\">\r\n  <ng-container *ngFor=\"let columnItem of module?.content?.table_content\">\r\n    <div class=\"item-accordion\">\r\n      <div class=\"row filter-category\"\r\n        (click)=\"columnItem.data.isCollapse = !columnItem?.data?.isCollapse; closeCollapse(columnItem?.data)\">\r\n        <div class=\"col text-left\" *ngIf=\"columnItem?.children?.length > 0\">\r\n          <p>{{ columnItem?.data?.label }}</p>\r\n        </div>\r\n        <div class=\"col text-left\" *ngIf=\"columnItem?.children?.length === 0\"\r\n          [ngClass]=\"[columnItem?.data?.isActive ? 'active' : '']\">\r\n          <dmmp-path-link-template [defaultClass]=\"defaultClass\" [identifier]=\"identifier\" [columItem]=\"columnItem\"\r\n              (anchorCustom)=\"anchorCustom.emit($event)\" (page)=\"page.emit($event)\" (removeActive)=\"removeActive($event)\"></dmmp-path-link-template>\r\n        </div>\r\n        <div class=\"col-auto text-right\" *ngIf=\"columnItem?.children?.length > 0\">\r\n          <button type=\"button\" class=\"btn btn-outline\" align-left>\r\n            <i class=\"fas fa-chevron-up\" *ngIf=\"!columnItem?.data?.isCollapse\"></i>\r\n            <i class=\"fas fa-chevron-down\" *ngIf=\"columnItem?.data?.isCollapse\"></i>\r\n          </button>\r\n        </div>\r\n      </div>\r\n      <div class=\"row\" *ngIf=\"columnItem?.children?.length > 0\">\r\n        <div class=\"col\" id=\"collapseFilters\" [ngbCollapse]=\"columnItem?.data?.isCollapse\">\r\n          <ul class=\"list-items\">\r\n            <li [ngClass]=\"['item', columLinkItem?.data?.isActive ? 'active' : '']\"\r\n              *ngFor=\"let columLinkItem of columnItem?.children\">\r\n              <dmmp-path-link-template [defaultClass]=\"defaultClass\" [identifier]=\"identifier\" [columItem]=\"columLinkItem\"\r\n              (anchorCustom)=\"anchorCustom.emit($event)\" (page)=\"page.emit($event)\" (removeActive)=\"removeActive($event)\"></dmmp-path-link-template>\r\n            </li>\r\n          </ul>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n</dmmp-container>\r\n"
    })
], ContentTableComponent);

let PathLinkTemplateComponent = class PathLinkTemplateComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
        this.removeActive = new EventEmitter();
    }
};
__decorate([
    Input()
], PathLinkTemplateComponent.prototype, "columItem", void 0);
__decorate([
    Input()
], PathLinkTemplateComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], PathLinkTemplateComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], PathLinkTemplateComponent.prototype, "page", void 0);
__decorate([
    Output()
], PathLinkTemplateComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], PathLinkTemplateComponent.prototype, "removeActive", void 0);
PathLinkTemplateComponent = __decorate([
    Component({
        selector: 'dmmp-path-link-template',
        template: "<ng-container *ngIf=\"columItem?.data?.link; else pathLinkTemplate\">\r\n  <dmmp-link\r\n    [data]=\"{ link: [ { link: columItem?.data?.link, name: columItem?.data?.name }], target: '_self'}\"\r\n    [identifier]=\"identifier\" [defaultClass]=\"defaultClass\" (anchorCustom)=\"anchorCustom.emit($event)\"\r\n    (page)=\"page.emit($event)\">\r\n    {{columItem?.data?.label}}</dmmp-link>\r\n</ng-container>\r\n<ng-template #pathLinkTemplate>\r\n  <dmmp-path-link [path]=\"columItem?.data?.path\" (page)=\"page.emit($event)\"\r\n    (click)=\"columItem.data.isActive = !columItem?.data?.isActive; removeActive.emit(columItem?.data)\">\r\n    {{columItem?.data?.label}}\r\n  </dmmp-path-link>\r\n</ng-template>\r\n"
    })
], PathLinkTemplateComponent);

let ContentTableModule = class ContentTableModule {
};
ContentTableModule = __decorate([
    NgModule({
        declarations: [ContentTableComponent, PathLinkTemplateComponent],
        imports: [
            CommonModule,
            SharedModule,
            NgbCollapseModule,
            RouterModule
        ],
        exports: [ContentTableComponent]
    })
], ContentTableModule);

let WebsiteCourseCampusComponent = class WebsiteCourseCampusComponent {
    constructor(options, cdRef) {
        this.options = options;
        this.cdRef = cdRef;
        this.currentPage = 1;
    }
    ngOnInit() {
        var _a, _b;
        this.totalPages = (_b = (_a = this.detailLayout) === null || _a === void 0 ? void 0 : _a.campus) === null || _b === void 0 ? void 0 : _b.length;
        this.configCarousel = this.options.configurationBenefits(this.module);
    }
    newPageEvent(newPage) {
        var _a, _b, _c;
        if (((_a = newPage) === null || _a === void 0 ? void 0 : _a.direction) === 'next') {
            this.carousel.next();
            this.currentPage = (_b = newPage) === null || _b === void 0 ? void 0 : _b.number;
        }
        else {
            this.carousel.prev();
            this.currentPage = (_c = newPage) === null || _c === void 0 ? void 0 : _c.number;
        }
    }
    nextPage() {
        var _a;
        if (((_a = this.module) === null || _a === void 0 ? void 0 : _a.loop) && (this.totalPages < this.currentPage + 1)) {
            this.newPageEvent({ number: 1, direction: 'next' });
        }
        else {
            this.newPageEvent({ number: this.currentPage + 1, direction: 'next' });
        }
    }
    previousPage() {
        var _a;
        if (((_a = this.module) === null || _a === void 0 ? void 0 : _a.loop) && (this.currentPage - 1) === 0) {
            this.newPageEvent({ number: this.totalPages, direction: 'prev' });
        }
        else {
            this.newPageEvent({ number: this.currentPage - 1, direction: 'prev' });
        }
    }
    changeOwl(event) {
        var _a, _b;
        if (((_a = event) === null || _a === void 0 ? void 0 : _a.startPosition) + 1 !== this.currentPage) {
            this.currentPage = ((_b = event) === null || _b === void 0 ? void 0 : _b.startPosition) + 1;
        }
    }
};
WebsiteCourseCampusComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService },
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], WebsiteCourseCampusComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteCourseCampusComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteCourseCampusComponent.prototype, "detailLayout", void 0);
__decorate([
    ViewChild('owl')
], WebsiteCourseCampusComponent.prototype, "carousel", void 0);
WebsiteCourseCampusComponent = __decorate([
    Component({
        selector: 'dmmp-website-course-campus',
        template: "<div [id]=\" module?.id_element ? identifier + '_' + module?.id_element : ''\"\r\n     class=\"website-course-campus\"\r\n     [ngClass]=\"module?.class || ''\"\r\n     [style.backgroundColor]=\"module?.background_color?.color || ''\"\r\n     [style.backgroundImage]=\"module?.background_image?.length > 0 ? 'url(' + module?.background_image[0]?.styles?.large + ')' : ''\">\r\n  <div class=\"container\" *ngIf=\"detailLayout\">\r\n    <div class=\"row\"\r\n         *ngIf=\"detailLayout?.campus?.length > 0\">\r\n      <div\r\n        class=\"col-lg-{{\r\n            detailLayout?.columns_content || 12\r\n          }}\"\r\n        [ngClass]=\"\r\n                detailLayout?.columns_content > 8\r\n                ? 'bg-color-white z-index-4 position-relative'\r\n                : ''\r\n          \">\r\n        <owl-carousel-o\r\n          #owl\r\n          [options]=\"configCarousel\"\r\n          (changed)=\"changeOwl($event)\">\r\n          <ng-container *ngFor=\"let content of detailLayout.campus\">\r\n            <ng-template carouselSlide>\r\n              <div class=\"content-campus\">\r\n                <div class=\"row\">\r\n                  <div class=\"col-12 col-md-6\"\r\n                       *ngIf=\"content?.image?.length > 0\">\r\n                    <div class=\"image\">\r\n                      <dmmp-image-logo\r\n                        [data]=\"content?.image\"\r\n                      ></dmmp-image-logo>\r\n                    </div>\r\n                  </div>\r\n                  <div class=\"col-12 col-md-6\">\r\n                    <div class=\"content-info\">\r\n                      <h3 class=\"h3 color-green-lightest\" *ngIf=\"content?.title\">{{content?.title}}</h3>\r\n                      <p class=\"text-desc\"\r\n                         [ngClass]=\"content?.street_class || ''\">\r\n                        {{content.street || '' }} | {{content.phone || ''}}\r\n                      </p>\r\n                      <div class=\"btn-content\">\r\n                        <div class=\"row\">\r\n                          <div class=\"col-auto\" *ngIf=\"content?.button_map?.length > 0\">\r\n                            <dmmp-button [data]=\"content?.button_map[0]\"></dmmp-button>\r\n                          </div>\r\n                          <div class=\"col-auto\" *ngIf=\"content?.button_arrive?.length > 0\">\r\n                            <dmmp-button [data]=\"content?.button_arrive[0]\"></dmmp-button>\r\n                          </div>\r\n                        </div>\r\n                      </div>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </ng-template>\r\n          </ng-container>\r\n        </owl-carousel-o>\r\n        <div class=\"content-arrows\"\r\n             *ngIf=\"(module?.paginator_type === 'arrow' || module?.paginator_type === 'both') && detailLayout?.campus?.length > 1\">\r\n          <div class=\"content\">\r\n            <div class=\"paginator-box\">\r\n              <span>{{ currentPage }} / {{ detailLayout?.campus?.length }}</span>\r\n            </div>\r\n            <div class=\"arrow\">\r\n              <button class=\"prev\"\r\n                      (click)=\"previousPage()\"\r\n                      [disabled]=\"(!module?.loop && currentPage === 1)\">\r\n                <i class=\"fas fa-chevron-left\"></i>\r\n              </button>\r\n              <button class=\"next\"\r\n                      (click)=\"nextPage()\"\r\n                      [disabled]=\"(!module?.loop && currentPage === detailLayout?.campus?.length)\">\r\n                <i class=\"fas fa-chevron-right\"></i>\r\n              </button>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n\r\n"
    })
], WebsiteCourseCampusComponent);

let WebsiteCourseCampusModule = class WebsiteCourseCampusModule {
};
WebsiteCourseCampusModule = __decorate([
    NgModule({
        declarations: [WebsiteCourseCampusComponent],
        imports: [
            CommonModule,
            SharedModule,
            NgbNavModule,
            NgxJsonLdModule,
            CarouselModule,
        ],
        exports: [
            WebsiteCourseCampusComponent
        ],
        providers: [RichsnipetService],
    })
], WebsiteCourseCampusModule);

let AccessFilterImageComponent = class AccessFilterImageComponent {
    constructor() {
        this.page = new EventEmitter();
        this.medias = [
            { style: 'large', media: '(min-width:421px)' },
        ];
    }
};
__decorate([
    Input()
], AccessFilterImageComponent.prototype, "data", void 0);
__decorate([
    Input()
], AccessFilterImageComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], AccessFilterImageComponent.prototype, "page", void 0);
AccessFilterImageComponent = __decorate([
    Component({
        selector: 'dmmp-access-filter-image',
        template: "<dmmp-container\r\n  [data]=\"data\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'access-filter-image'\"\r\n>\r\n  <ng-container *ngIf=\"data?.vocabularies?.length > 0\">\r\n    <div class=\"container\">\r\n      <div class=\"row\">\r\n        <ng-container *ngFor=\"let vocabularies of data?.vocabularies\">\r\n          <div class=\"col-12 box-col-card\">\r\n            <div class=\"box-content-card\">\r\n              <div *ngIf=\"vocabularies?.image?.length > 0\" class=\"box-image\">\r\n                <dmmp-image [images]=\"vocabularies?.image[0]\" [medias]=\"medias\">\r\n                </dmmp-image>\r\n              </div>\r\n              <div class=\"box-content\">\r\n                <ng-container *ngIf=\"vocabularies?.vocabulary\">\r\n                  <div *ngIf=\"vocabularies?.vocabulary?.name\" class=\"box-title\">\r\n                    <div class=\"col-12\">\r\n                      <h2 [ngClass]=\"vocabularies?.class || ''\">\r\n                        {{ vocabularies?.vocabulary?.name }}\r\n                      </h2>\r\n                    </div>\r\n                  </div>\r\n                  <ng-container\r\n                    *ngIf=\"vocabularies?.vocabulary?.terms?.length > 0\"\r\n                  >\r\n                    <div class=\"box-links\">\r\n                      <ng-container *ngFor=\"let terms of vocabularies?.vocabulary?.terms\">\r\n                        <div *ngIf=\"terms?.label\" class=\"col-12\">\r\n                          <a (click)=\"page.emit(terms?.path || '')\"\r\n                             routerLink=\"{{ terms?.path || '' }}\"\r\n                             [ngClass]=\"terms?.class || ''\">{{ terms?.label }}</a>\r\n                        </div>\r\n                      </ng-container>\r\n                    </div>\r\n                  </ng-container>\r\n                </ng-container>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n</dmmp-container>\r\n"
    })
], AccessFilterImageComponent);

let AccessFilterImageModule = class AccessFilterImageModule {
};
AccessFilterImageModule = __decorate([
    NgModule({
        declarations: [AccessFilterImageComponent],
        imports: [
            CommonModule,
            SharedModule,
            RouterModule,
        ],
        exports: [
            AccessFilterImageComponent
        ]
    })
], AccessFilterImageModule);

let DirectAccessFilterComponent = class DirectAccessFilterComponent {
    constructor() {
        this.page = new EventEmitter();
        this.medias = [
            { style: 'large', media: '(min-width:421px)' },
        ];
    }
};
__decorate([
    Input()
], DirectAccessFilterComponent.prototype, "data", void 0);
__decorate([
    Input()
], DirectAccessFilterComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], DirectAccessFilterComponent.prototype, "page", void 0);
DirectAccessFilterComponent = __decorate([
    Component({
        selector: 'dmmp-direct-access-filter',
        template: "<dmmp-container\r\n  [data]=\"data\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'direct-access-filter'\"\r\n>\r\n  <div class=\"container\">\r\n    <ng-container *ngIf=\"data?.vocabularies?.length > 0\">\r\n      <ng-container *ngFor=\"let vocabularies of data?.vocabularies\">\r\n        <div *ngIf=\"vocabularies?.vocabulary?.name\" class=\"row\">\r\n          <div class=\"col\">\r\n            <h2 [ngClass]=\"vocabularies?.class || ''\">\r\n              {{ vocabularies?.vocabulary?.name }}\r\n            </h2>\r\n          </div>\r\n        </div>\r\n        <ng-container *ngIf=\"vocabularies?.vocabulary.terms?.length > 0\">\r\n          <div class=\"row\">\r\n            <ng-container *ngFor=\"let terms of vocabularies?.vocabulary?.terms\">\r\n              <ng-container *ngIf=\"terms?.label\">\r\n                <div class=\"col-12 col-md-6\">\r\n                  <dmmp-path-link [path]=\"terms?.path || ''\" (page)=\"page.emit($event)\">\r\n                    <div\r\n                      [style.backgroundImage]=\"\r\n                    terms?.background_image?.length > 0\r\n                      ? 'url(' + terms?.background_image[0]?.styles?.large + ')'\r\n                      : ''\r\n                  \"\r\n                      class=\"box-filter\"\r\n                    >\r\n                      <div class=\"box-image\">\r\n                        <ng-container *ngIf=\"terms?.icon_class; else simpleImage\">\r\n                          <i [ngClass]=\"terms?.icon_class\"></i>\r\n                        </ng-container>\r\n                        <ng-template #simpleImage>\r\n                          <ng-container *ngIf=\"terms?.image?.length > 0\">\r\n                            <dmmp-image\r\n                              [images]=\"terms?.image[0]\"\r\n                              [medias]=\"medias\"\r\n                            ></dmmp-image>\r\n                          </ng-container>\r\n                        </ng-template>\r\n                      </div>\r\n                      <div class=\"box-text\">\r\n                        <p [ngClass]=\"terms?.class || ''\">\r\n                          {{ terms?.label }}\r\n                        </p>\r\n                      </div>\r\n                    </div>\r\n                  </dmmp-path-link>\r\n                </div>\r\n              </ng-container>\r\n            </ng-container>\r\n          </div>\r\n        </ng-container>\r\n      </ng-container>\r\n    </ng-container>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], DirectAccessFilterComponent);

let DirectAccessFilterModule = class DirectAccessFilterModule {
};
DirectAccessFilterModule = __decorate([
    NgModule({
        declarations: [DirectAccessFilterComponent],
        imports: [
            CommonModule,
            SharedModule,
            RouterModule
        ],
        exports: [DirectAccessFilterComponent],
    })
], DirectAccessFilterModule);

let EventsSectionComponent = class EventsSectionComponent {
    constructor() {
        this.redirectPage = new EventEmitter();
    }
};
__decorate([
    Input()
], EventsSectionComponent.prototype, "module", void 0);
__decorate([
    Input()
], EventsSectionComponent.prototype, "data", void 0);
__decorate([
    Input()
], EventsSectionComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], EventsSectionComponent.prototype, "redirectPage", void 0);
EventsSectionComponent = __decorate([
    Component({
        selector: 'dmmp-events-section',
        template: "<dmmp-container\r\n  [data]=\"module\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'events-section'\"\r\n>\r\n  <div class=\"container\">\r\n    <ng-container *ngIf=\"module?.name\">\r\n      <div class=\"row\">\r\n        <div class=\"col\">\r\n          <h2 [ngClass]=\"module?.title_class || ''\">\r\n            {{ module?.name }}\r\n          </h2>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"data?.content?.length > 0\">\r\n      <div class=\"row\">\r\n        <ng-container *ngFor=\"let event of data?.content\">\r\n          <div class=\"box-col-card col-12 col-md-4\">\r\n            <dmmp-card-event\r\n              [category]=\"event?.type?.length > 0 ? event?.type[0]?.label : ''\"\r\n              [title]=\"'<h3>' + event?.name + '</h3>'\"\r\n              [image]=\"event?.image\"\r\n              [date]=\"event?.date?.start\"\r\n              [description]=\"event?.description\"\r\n              [descriptionSize]=\"150\"\r\n              [path]=\"event?.path\"\r\n              [showImage]=\"module?.show_image\"\r\n              [classDate]=\"event?.date_class || ''\"\r\n              [classHour]=\"event?.hour_class || ''\"\r\n              [classDescription]=\"event?.description_class || ''\"\r\n              [classCategory]=\"event?.category_class || ''\"\r\n              [classTitle]=\"event?.title_class || ''\"\r\n              [classImage]=\"event?.image_class || ''\"\r\n              (redirectPage)=\"redirectPage.emit()\"\r\n            >\r\n            </dmmp-card-event>\r\n          </div>\r\n        </ng-container>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"module?.see_more?.length > 0\">\r\n      <div class=\"row\">\r\n        <div class=\"col\">\r\n          <div class=\"box-button\">\r\n            <dmmp-button\r\n              [data]=\"module?.see_more[0]\"\r\n              [identifier]=\"identifier\"\r\n              (page)=\"redirectPage.emit()\"\r\n            >\r\n            </dmmp-button>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], EventsSectionComponent);

let EventsSectionModule = class EventsSectionModule {
};
EventsSectionModule = __decorate([
    NgModule({
        declarations: [EventsSectionComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [EventsSectionComponent]
    })
], EventsSectionModule);

let WebsiteRelatedContentTagsComponent = class WebsiteRelatedContentTagsComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() { }
};
__decorate([
    Input()
], WebsiteRelatedContentTagsComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteRelatedContentTagsComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], WebsiteRelatedContentTagsComponent.prototype, "page", void 0);
__decorate([
    Output()
], WebsiteRelatedContentTagsComponent.prototype, "anchorCustom", void 0);
WebsiteRelatedContentTagsComponent = __decorate([
    Component({
        selector: 'dmmp-website-related-content-tags',
        template: "<dmmp-container *ngIf=\"module\"\r\n                [identifier]=\"identifier || ''\" [data]=\"module\"\r\n                [defaultClass]=\"'website-featured-news-category'\">\r\n  <div class=\"container\">\r\n    <h2 class=\"h2\" *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">{{module?.name}}</h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"module?.visualization_tag_related === 'content_notice'\">\r\n      <div class=\"row justify-content-center\"\r\n           *ngIf=\"module?.content?.length > 0\">\r\n        <div class=\"col-12 col-md-{{module?.content?.length <= 3 ? 4 : 3}}\"\r\n             *ngFor=\"let newContent of module?.content  | slice: 0:4\">\r\n          <dmmp-card-new [path]=\"newContent?.path || ''\"\r\n                         [image]=\"newContent?.image_items[0]?.image || {}\"\r\n                         [featured]=\"newContent?.featured || []\"\r\n                         [categories]=\"newContent?.categories || []\"\r\n                         [date]=\"newContent?.created_at || ''\"\r\n                         [title]=\"newContent?.title ? '<h3 class=h3'+''+'>'+ (newContent?.title | truncatetext: 74) + '</h3>' : ''\"\r\n                         [description]=\"newContent?.content || ''\"\r\n                         [quantityDescription]=\"130\"\r\n                         [defaultClass]=\"'box-card-new'\"\r\n                         (page)=\"page.emit($event)\"\r\n          ></dmmp-card-new>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"module?.visualization_tag_related === 'related_content'\">\r\n      <div *ngIf=\"module?.content?.length > 0\"\r\n           class=\"row\">\r\n        <div class=\"col-12 box-related-content\"\r\n             *ngFor=\"let relatedContent of module?.content\">\r\n          <dmmp-related-content\r\n            [title]=\"relatedContent?.title ? '<h3 class=h3'+''+'>'+ (relatedContent?.title) + '</h3>' : ''\"\r\n            [date]=\"relatedContent?.created_at || ''\"\r\n            [path]=\"relatedContent?.path || ''\"\r\n            [defaultClass]=\"'box-content'\"\r\n            (page)=\"page.emit($event)\">\r\n          </dmmp-related-content>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n    <div class=\"content-btn\" *ngIf=\"module?.see_more?.length > 0\">\r\n      <dmmp-button [data]=\"module?.see_more[0]\" [identifier]=\"identifier || ''\"\r\n                   (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                   (page)=\"page.emit($event)\"></dmmp-button>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteRelatedContentTagsComponent);

let WebsiteRelatedContentTagsModule = class WebsiteRelatedContentTagsModule {
};
WebsiteRelatedContentTagsModule = __decorate([
    NgModule({
        imports: [CommonModule, SharedModule, PipesModule],
        declarations: [WebsiteRelatedContentTagsComponent],
        exports: [WebsiteRelatedContentTagsComponent],
        providers: [],
    })
], WebsiteRelatedContentTagsModule);

let FeaturedEventsComponent = class FeaturedEventsComponent {
    constructor(options, cdRef) {
        this.options = options;
        this.cdRef = cdRef;
        this.redirectPage = new EventEmitter();
        this.currentPage = 1;
    }
    ngOnInit() {
        var _a, _b;
        this.totalPages = (_b = (_a = this.data) === null || _a === void 0 ? void 0 : _a.content) === null || _b === void 0 ? void 0 : _b.length;
        this.configCarousel = this.options.configurationBenefits(this.module);
    }
    newPageEvent(newPage) {
        var _a, _b, _c;
        if (((_a = newPage) === null || _a === void 0 ? void 0 : _a.direction) === 'next') {
            this.carousel.next();
            this.currentPage = (_b = newPage) === null || _b === void 0 ? void 0 : _b.number;
        }
        else {
            this.carousel.prev();
            this.currentPage = (_c = newPage) === null || _c === void 0 ? void 0 : _c.number;
        }
    }
    nextPage() {
        var _a;
        if (((_a = this.module) === null || _a === void 0 ? void 0 : _a.loop) && (this.totalPages < this.currentPage + 1)) {
            this.newPageEvent({ number: 1, direction: 'next' });
        }
        else {
            this.newPageEvent({ number: this.currentPage + 1, direction: 'next' });
        }
    }
    previousPage() {
        var _a;
        if (((_a = this.module) === null || _a === void 0 ? void 0 : _a.loop) && (this.currentPage - 1) === 0) {
            this.newPageEvent({ number: this.totalPages, direction: 'prev' });
        }
        else {
            this.newPageEvent({ number: this.currentPage - 1, direction: 'prev' });
        }
    }
    changeOwl(event) {
        var _a, _b;
        if (((_a = event) === null || _a === void 0 ? void 0 : _a.startPosition) + 1 !== this.currentPage) {
            this.currentPage = ((_b = event) === null || _b === void 0 ? void 0 : _b.startPosition) + 1;
        }
    }
};
FeaturedEventsComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService },
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], FeaturedEventsComponent.prototype, "module", void 0);
__decorate([
    Input()
], FeaturedEventsComponent.prototype, "data", void 0);
__decorate([
    Input()
], FeaturedEventsComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], FeaturedEventsComponent.prototype, "redirectPage", void 0);
__decorate([
    ViewChild('owl')
], FeaturedEventsComponent.prototype, "carousel", void 0);
FeaturedEventsComponent = __decorate([
    Component({
        selector: 'dmmp-featured-events',
        template: "<div [id]=\" module?.id_element ? identifier + '_' + module?.id_element : ''\"\r\n     class=\"featured-events\"\r\n     [ngClass]=\"module?.class ? module?.class : ''\"\r\n     [style.backgroundColor]=\"module?.background_color?.color || ''\"\r\n     [style.backgroundImage]=\"module?.background_image?.length > 0 ? 'url(' + (module?.background_image)[0]?.styles?.large + ')' : ''\">\r\n  <div class=\"container\" *ngIf=\"data\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">\r\n      {{ module?.name }}\r\n    </h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"data?.content?.length > 0\">\r\n      <owl-carousel-o\r\n        #owl\r\n        [options]=\"configCarousel\"\r\n        (changed)=\"changeOwl($event)\">\r\n        <ng-container *ngFor=\"let content of data?.content\">\r\n          <ng-template carouselSlide>\r\n            <div class=\"content-event\">\r\n              <div class=\"row\">\r\n                <div class=\"col\">\r\n                  <dmmp-card-event\r\n                    [category]=\"content?.topic?.length > 0 ? content?.topic[0]?.label : ''\"\r\n                    [title]=\"'<h3 class='+ content?.title_class +' >' + content?.name + '</h3>'\"\r\n                    [image]=\"content?.image\"\r\n                    [date]=\"content?.date?.start\"\r\n                    [description]=\"content?.description\"\r\n                    [descriptionSize]=\"150\"\r\n                    [path]=\"content?.path\"\r\n                    [showImage]=\"true\"\r\n                    (redirectPage)=\"redirectPage.emit()\"\r\n                  >\r\n                  </dmmp-card-event>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </owl-carousel-o>\r\n      <div class=\"content-arrows\"\r\n           *ngIf=\"(module?.paginator_type === 'arrow' || module?.paginator_type === 'both') && data?.content?.length > 1\">\r\n        <div class=\"content\">\r\n          <div class=\"paginator-box\">\r\n            <span>{{ currentPage }} / {{ data?.content?.length }}</span>\r\n          </div>\r\n          <div class=\"arrow\">\r\n            <button class=\"prev\"\r\n                    (click)=\"previousPage()\"\r\n                    [disabled]=\"(!module?.loop && currentPage === 1)\">\r\n              <i class=\"fas fa-chevron-left\"></i>\r\n            </button>\r\n            <button class=\"next\"\r\n                    (click)=\"nextPage()\"\r\n                    [disabled]=\"(!module?.loop && currentPage === data?.content?.length)\">\r\n              <i class=\"fas fa-chevron-right\"></i>\r\n            </button>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n"
    })
], FeaturedEventsComponent);

let FeaturedEventsModule = class FeaturedEventsModule {
};
FeaturedEventsModule = __decorate([
    NgModule({
        declarations: [FeaturedEventsComponent],
        imports: [
            CommonModule,
            SharedModule,
            CarouselModule
        ],
        exports: [FeaturedEventsComponent]
    })
], FeaturedEventsModule);

let BannerVideoImageComponent = class BannerVideoImageComponent {
    constructor(options) {
        this.options = options;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.videos = [];
        this.images = [];
    }
    ngOnInit() {
        this.configCarousel = this.options.configurationBenefits(this.module);
        this.configVideosAndImages();
    }
    changeSlide(movInfo) {
        this.videoState = movInfo;
    }
    configVideosAndImages() {
        var _a, _b, _c, _d, _e, _f, _g;
        switch ((_a = this.detailLayout) === null || _a === void 0 ? void 0 : _a.identifier) {
            case 'basic_page': {
                this.images = (_b = this.detailLayout) === null || _b === void 0 ? void 0 : _b.banner;
                break;
            }
            case 'event': {
                this.videos = (_c = this.detailLayout) === null || _c === void 0 ? void 0 : _c.video_related;
                this.images = (_d = this.detailLayout) === null || _d === void 0 ? void 0 : _d.image;
                break;
            }
            case 'blog': {
                this.images = (_e = this.detailLayout) === null || _e === void 0 ? void 0 : _e.image;
                break;
            }
            case 'news': {
                (_g = (_f = this.detailLayout) === null || _f === void 0 ? void 0 : _f.image_items) === null || _g === void 0 ? void 0 : _g.forEach(imageItem => {
                    var _a;
                    this.images.push((_a = imageItem) === null || _a === void 0 ? void 0 : _a.image[0]);
                });
                break;
            }
        }
    }
};
BannerVideoImageComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], BannerVideoImageComponent.prototype, "module", void 0);
__decorate([
    Input()
], BannerVideoImageComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], BannerVideoImageComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], BannerVideoImageComponent.prototype, "detailLayout", void 0);
__decorate([
    Output()
], BannerVideoImageComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], BannerVideoImageComponent.prototype, "page", void 0);
BannerVideoImageComponent = __decorate([
    Component({
        selector: 'dmmp-banner-video-image',
        template: "<div *ngIf=\"module?.visible\" [id]=\" module?.id_element ? identifier + '_' + module?.id_element : ''\"\r\n  [style.backgroundImage]=\"module?.background_image?.length > 0 ? 'url(' + (module?.background_image)[0]?.styles?.large + ')' : ''\"\r\n  [style.backgroundColor]=\"module?.background_color?.color || ''\"\r\n  [style.opacity]=\"module?.background_color?.opacity || ''\"\r\n     [ngClass]=\"defaultClass\">\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <div class=\"content-box col-12 col-md-6\"\r\n        *ngIf=\"detailLayout\">\r\n        <ng-container [ngSwitch]=\"detailLayout?.identifier\">\r\n          <ng-container *ngSwitchCase=\"'event'\">\r\n            <dmmp-event-view [eventInfo]=\"detailLayout\" class=\"event-box\" (page)=\"page.emit($event)\"\r\n              (anchorCustom)=\"anchorCustom.emit($event)\">\r\n            </dmmp-event-view>\r\n          </ng-container>\r\n          <ng-container *ngSwitchCase=\"'blog'\">\r\n            <dmmp-blog-view [blogInfo]=\"detailLayout\" [module]=\"module\" class=\"blog-box\"></dmmp-blog-view>\r\n          </ng-container>\r\n          <ng-container *ngSwitchCase=\"'news'\">\r\n            <dmmp-new-view [newInfo]=\"detailLayout\" [module]=\"module\" class=\"news-box\"></dmmp-new-view>\r\n          </ng-container>\r\n          <ng-container *ngSwitchCase=\"'basic_page'\">\r\n            <dmmp-basic-view [basicInfo]=\"detailLayout\" [module]=\"module\" class=\"news-box\"></dmmp-basic-view>\r\n          </ng-container>\r\n        </ng-container>\r\n      </div>\r\n      <div class=\"carrousel-box col-12 col-md-6\">\r\n        <ng-container *ngIf=\"(videos?.length + images?.length) > 1;\r\n          else simpleBanner\">\r\n          <owl-carousel-o [options]=\"configCarousel\" (changed)=\"changeSlide($event)\">\r\n            <ng-container *ngFor=\"let carouselBannerVideo of videos; let i = index\">\r\n              <ng-template carouselSlide>\r\n                <dmmp-slide-view [slideInfo]=\"carouselBannerVideo\" [mode]=\"'video'\" [videoState]=\"videoState\">\r\n                </dmmp-slide-view>\r\n              </ng-template>\r\n            </ng-container>\r\n            <ng-container *ngFor=\"let carouselBannerImage of images; let i = index\">\r\n              <ng-template carouselSlide>\r\n                <dmmp-slide-view [slideInfo]=\"carouselBannerImage\" [mode]=\"'img'\">\r\n                </dmmp-slide-view>\r\n              </ng-template>\r\n            </ng-container>\r\n          </owl-carousel-o>\r\n        </ng-container>\r\n        <ng-template #simpleBanner>\r\n          <ng-container *ngIf=\"videos?.length > 0\">\r\n            <dmmp-slide-view [slideInfo]=\"videos[0]\" [mode]=\"'video'\" [videoState]=\"videoState\">\r\n            </dmmp-slide-view>\r\n          </ng-container>\r\n          <ng-container *ngIf=\"images?.length > 0\">\r\n            <dmmp-slide-view [slideInfo]=\"images[0]\" [mode]=\"'img'\">\r\n            </dmmp-slide-view>\r\n          </ng-container>\r\n        </ng-template>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], BannerVideoImageComponent);

let BlogViewComponent = class BlogViewComponent {
    constructor(dateFormatService) {
        this.dateFormatService = dateFormatService;
    }
    ngOnInit() {
        var _a;
        this.blogInfo.promotion_date = this.dateFormatService.convertFromTimestampToDate((_a = this.blogInfo) === null || _a === void 0 ? void 0 : _a.promotion_date);
    }
};
BlogViewComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], BlogViewComponent.prototype, "blogInfo", void 0);
__decorate([
    Input()
], BlogViewComponent.prototype, "module", void 0);
BlogViewComponent = __decorate([
    Component({
        selector: 'dmmp-blog-view',
        template: "<div class=\"row\">\r\n  <div class=\"col-12\">\r\n    <div class=\"category-box\" *ngIf=\"blogInfo?.categories?.length > 0\">\r\n      <p *ngFor=\"let category of blogInfo?.categories\">{{category}} </p>\r\n    </div>\r\n    <div class=\"title-box\" *ngIf=\"blogInfo?.title\">\r\n      <h1 [ngClass]=\"module?.title_class || ''\">{{blogInfo?.title}}</h1>\r\n    </div>\r\n    <div class=\"date-author-box\" *ngIf=\"blogInfo?.promotion_date || blogInfo?.author\">\r\n      <p *ngIf=\"blogInfo?.promotion_date\" class=\"date-box\">{{blogInfo?.promotion_date | date : 'longDate': 'UTC'}}</p>\r\n      <p *ngIf=\"blogInfo?.author\" class=\"author-box\">| {{blogInfo?.author}}</p>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], BlogViewComponent);

let NewViewComponent = class NewViewComponent {
    constructor(dateFormatService) {
        this.dateFormatService = dateFormatService;
    }
    ngOnInit() {
        var _a;
        this.newInfo.promotion_date = this.dateFormatService.convertFromTimestampToDate((_a = this.newInfo) === null || _a === void 0 ? void 0 : _a.promotion_date);
    }
};
NewViewComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], NewViewComponent.prototype, "newInfo", void 0);
__decorate([
    Input()
], NewViewComponent.prototype, "module", void 0);
NewViewComponent = __decorate([
    Component({
        selector: 'dmmp-new-view',
        template: "<div class=\"row\">\r\n  <div class=\"col-12\">\r\n    <div class=\"category-box\" *ngIf=\"newInfo?.categories?.length > 0\">\r\n      <p>{{newInfo?.categories[0]}} </p>\r\n    </div>\r\n    <div class=\"title-box\" *ngIf=\"newInfo?.title\">\r\n      <h1 [ngClass]=\"module?.title_class || ''\">{{newInfo?.title}}</h1>\r\n    </div>\r\n    <div class=\"date-author-box\" *ngIf=\"newInfo?.promotion_date || newInfo?.author\">\r\n      <p *ngIf=\"newInfo?.created_at\" class=\"date-box\">{{newInfo?.promotion_date | date : 'longDate': 'UTC'}}</p>\r\n      <p *ngIf=\"newInfo?.author\" class=\"author-box\">| {{newInfo?.author}}</p>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], NewViewComponent);

let EventViewComponent = class EventViewComponent {
    constructor(dateFormatServices) {
        this.dateFormatServices = dateFormatServices;
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
        var _a, _b;
        this.eventInfo.date.start = this.dateFormatServices.convertFromTimestampToDate((_b = (_a = this.eventInfo) === null || _a === void 0 ? void 0 : _a.date) === null || _b === void 0 ? void 0 : _b.start);
    }
};
EventViewComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], EventViewComponent.prototype, "eventInfo", void 0);
__decorate([
    Output()
], EventViewComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], EventViewComponent.prototype, "page", void 0);
EventViewComponent = __decorate([
    Component({
        selector: 'dmmp-event-view',
        template: "<div class=\"row\">\r\n  <div class=\"box-body\">\r\n    <div class=\"content-text\">\r\n      <div class=\"box-date\">\r\n        <p class=\"month\" *ngIf=\"eventInfo?.date?.start\">\r\n          {{eventInfo?.date?.start  | date : 'MMM': 'UTC'}}\r\n        </p>\r\n        <p class=\"day\" *ngIf=\"eventInfo?.date?.start\">\r\n          {{eventInfo?.date?.start  | date : 'd': 'UTC'}}\r\n        </p>\r\n      </div>\r\n      <div class=\"box-text\">\r\n        <div class=\"category-box\" *ngIf=\"eventInfo?.type?.length > 0\">\r\n          {{eventInfo?.type[0]?.label}}\r\n        </div>\r\n        <h1 class=\"title-box\" *ngIf=\"eventInfo?.name\">\r\n          {{eventInfo?.name}}\r\n        </h1>\r\n        <ng-container class=\"title-box\" *ngIf=\"eventInfo?.items_order?.length > 0\">\r\n          <ng-container *ngFor=\"let itemOrder of eventInfo?.items_order\">\r\n            <div class=\"location-box\" *ngIf=\"itemOrder?.type?.toLowerCase() === 'lugar' && eventInfo?.location\">\r\n              <i class=\"fas fa-map-marker-alt\"></i>\r\n              <p>{{eventInfo?.location}}</p>\r\n            </div>\r\n            <div class=\"location-box\" *ngIf=\"itemOrder?.type?.toLowerCase() === 'hora' && eventInfo?.date?.start\">\r\n              <i class=\"far fa-clock\"></i>\r\n              <p>{{eventInfo?.date?.start  | date : 'HH:mm': 'UTC'}} hs.</p>\r\n            </div>\r\n          </ng-container>\r\n        </ng-container>\r\n        <div class=\"box-button\">\r\n          <div *ngIf=\"eventInfo?.button_inscription?.length > 0\" class=\"inscription-button-box\">\r\n            <dmmp-button [data]=\"eventInfo?.button_inscription[0]\" (page)=\"page.emit($event)\"\r\n                         (anchorCustom)=\"anchorCustom.emit($event)\"></dmmp-button>\r\n          </div>\r\n          <div *ngIf=\"eventInfo?.button_invitation?.length > 0\" class=\"invitation-button-box\">\r\n            <button class=\"button-border-white\" (click)=\"eventInfo.button_invitation[0].open ?\r\n              eventInfo.button_invitation[0].open = false :\r\n              eventInfo.button_invitation[0].open = true\">\r\n              {{eventInfo?.button_invitation[0]?.sub_title}}</button>\r\n            <div class=\"invitation-popup\" *ngIf=\"eventInfo?.button_invitation[0]?.open &&\r\n              eventInfo?.button_invitation[0]?.buttons_tooltip?.length > 0\">\r\n              <dmmp-button *ngFor=\"let popUpButton of eventInfo?.button_invitation[0]?.buttons_tooltip\"\r\n                           [data]=\"popUpButton\" (page)=\"page.emit($event)\" (anchorCustom)=\"anchorCustom.emit($event)\">\r\n              </dmmp-button>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], EventViewComponent);

let SlideViewComponent = class SlideViewComponent {
    constructor(richsnipetService) {
        this.richsnipetService = richsnipetService;
        this.medias = [
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width:326px)' },
            { style: 'max_325x325', media: '(max-width:325px)' },
        ];
    }
    set videoState(val) {
        this._videoState = val;
        this.stopVideo();
    }
    ngOnInit() {
        var _a, _b, _c, _d;
        if (this.mode === 'video') {
            if (((_b = (_a = this.slideInfo) === null || _a === void 0 ? void 0 : _a.image) === null || _b === void 0 ? void 0 : _b.length) > 0
                && ((_d = (_c = this.slideInfo) === null || _c === void 0 ? void 0 : _c.video) === null || _d === void 0 ? void 0 : _d.length) > 0) {
                this.schema = this.richsnipetService.setupJsonBeneficVideo(this.slideInfo);
            }
        }
    }
    stopVideo() {
        var _a;
        (_a = this.videoPlayer) === null || _a === void 0 ? void 0 : _a.stopVideo();
    }
};
SlideViewComponent.ctorParameters = () => [
    { type: RichsnipetService }
];
__decorate([
    Input()
], SlideViewComponent.prototype, "slideInfo", void 0);
__decorate([
    Input()
], SlideViewComponent.prototype, "mode", void 0);
__decorate([
    Input()
], SlideViewComponent.prototype, "videoState", null);
__decorate([
    ViewChild('videoPlayer')
], SlideViewComponent.prototype, "videoPlayer", void 0);
SlideViewComponent = __decorate([
    Component({
        selector: 'dmmp-slide-view',
        template: "<ng-container [ngSwitch]=\"mode\">\r\n  <ng-container *ngSwitchCase=\"'img'\">\r\n    <dmmp-image [images]=\"slideInfo\" [medias]=\"medias\"></dmmp-image>\r\n  </ng-container>\r\n  <ng-container *ngSwitchCase=\"'video'\">\r\n    <ngx-json-ld [json]=\"schema\"></ngx-json-ld>\r\n    <dmmp-video-player [type]=\"slideInfo.type\" [src]=\"slideInfo?.video[0]?.value\" #videoPlayer></dmmp-video-player>\r\n  </ng-container>\r\n</ng-container>\r\n"
    })
], SlideViewComponent);

let BasicViewComponent = class BasicViewComponent {
    constructor() { }
};
__decorate([
    Input()
], BasicViewComponent.prototype, "basicInfo", void 0);
__decorate([
    Input()
], BasicViewComponent.prototype, "module", void 0);
BasicViewComponent = __decorate([
    Component({
        selector: 'dmmp-basic-view',
        template: "<div class=\"row\">\r\n  <div class=\"col-12\">\r\n    <div class=\"title-box\" *ngIf=\"basicInfo?.title\">\r\n      <h1 [ngClass]=\"module?.title_class || ''\">{{basicInfo?.title}}</h1>\r\n    </div>\r\n    <div class=\"date-author-box\" *ngIf=\"basicInfo?.subtitle\">\r\n      <p *ngIf=\"basicInfo?.subtitle\" class=\"author-box\">{{basicInfo?.subtitle}}</p>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], BasicViewComponent);

let BannerVideoImageModule = class BannerVideoImageModule {
};
BannerVideoImageModule = __decorate([
    NgModule({
        declarations: [BannerVideoImageComponent, BlogViewComponent, NewViewComponent, EventViewComponent, SlideViewComponent, BasicViewComponent],
        imports: [
            CommonModule,
            SharedModule,
            CarouselModule,
            NgxJsonLdModule
        ],
        exports: [BannerVideoImageComponent]
    })
], BannerVideoImageModule);

let WebsiteCourseFilterImageComponent = class WebsiteCourseFilterImageComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
        this.medias = [
            { style: 'large', media: '(min-width:1301px)' },
            { style: 'max_1300x1300', media: '(min-width:651px) AND (max-width:1300px)' },
            { style: 'max_650x650', media: '(max-width:650px) AND (min-width:351px)' },
            { style: 'file_entity_browser_thumbnail', media: '(max-width:350px)' },
        ];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], WebsiteCourseFilterImageComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteCourseFilterImageComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], WebsiteCourseFilterImageComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], WebsiteCourseFilterImageComponent.prototype, "page", void 0);
WebsiteCourseFilterImageComponent = __decorate([
    Component({
        selector: 'dmmp-website-course-filter-image',
        template: "<div\r\n  *ngIf=\"module?.visible\"\r\n  [id]=\"module?.id_element ? identifier + '_' + module?.id_element : ''\"\r\n  class=\"website-course-filter-image\"\r\n  [ngClass]=\"module?.class || ''\"\r\n  [style.backgroundColor]=\"module?.background_color?.color || ''\"\r\n>\r\n  <div class=\"content\">\r\n    <div class=\"image\"\r\n         *ngIf=\"module?.background_image?.length > 0\">\r\n      <dmmp-image\r\n        *ngIf=\"module?.background_image[0]?.styles\"\r\n        [images]=\"module?.background_image[0]\" [medias]=\"medias\">\r\n      </dmmp-image>\r\n    </div>\r\n    <div class=\"box-content\">\r\n      <div class=\"container\">\r\n        <div class=\"content-info\">\r\n          <h2 class=\"h2\" *ngIf=\"module?.name\"\r\n              [ngClass]=\"module?.title_class || ''\">{{module?.name}}</h2>\r\n          <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n            <div\r\n              *ngFor=\"let textContent of module?.texts\"\r\n              [ngClass]=\"textContent.class || ''\"\r\n              [innerHTML]=\"textContent.text || ''\"\r\n            ></div>\r\n          </ng-container>\r\n          <div class=\"content-links\" *ngIf=\"module?.links_box?.length > 0\">\r\n            <div class=\"item-link\" *ngFor=\"let link of module?.links_box\">\r\n              <dmmp-button *ngIf=\"link\"\r\n                           [data]=\"link\"\r\n                           (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                           (page)=\"page.emit()\"></dmmp-button>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
    })
], WebsiteCourseFilterImageComponent);

let WebsiteCourseFilterImageModule = class WebsiteCourseFilterImageModule {
};
WebsiteCourseFilterImageModule = __decorate([
    NgModule({
        declarations: [WebsiteCourseFilterImageComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [WebsiteCourseFilterImageComponent]
    })
], WebsiteCourseFilterImageModule);

let WebsiteRelatedContentUrlComponent = class WebsiteRelatedContentUrlComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() { }
};
__decorate([
    Input()
], WebsiteRelatedContentUrlComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteRelatedContentUrlComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], WebsiteRelatedContentUrlComponent.prototype, "page", void 0);
__decorate([
    Output()
], WebsiteRelatedContentUrlComponent.prototype, "anchorCustom", void 0);
WebsiteRelatedContentUrlComponent = __decorate([
    Component({
        selector: 'dmmp-website-related-content-url',
        template: "<dmmp-container\r\n  *ngIf=\"module\"\r\n  [identifier]=\"identifier || ''\"\r\n  [data]=\"module\"\r\n  [defaultClass]=\"'website-related-content-url bg-color-white z-index-4 position-relative' \">\r\n  <div class=\"container\">\r\n    <h2 class=\"h2\" *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">{{module?.name}}</h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"module?.visualization_tag_related === 'related_programs'\">\r\n      <div class=\"row main-panel\"\r\n           *ngIf=\"module?.content?.length > 0\">\r\n        <div class=\"col-12 col-sm-12 col-md-4 col-lg-3 box-card\"\r\n             *ngFor=\"let relatedContent of module?.content  | slice: 0:4\">\r\n          <dmmp-card-related-program\r\n            [flag]=\"relatedContent?.flag[0]?.label || ''\"\r\n            [backgroundColorFlag]=\"relatedContent?.flag[0]?.background_color?.color || ''\"\r\n            [image]=\"relatedContent?.image[0] || ''\"\r\n            [medias]=\"[{ style: 'large', media: '(min-width:421px)' }]\"\r\n            [category]=\"relatedContent?.categories[0] || ''\"\r\n            [title]=\"relatedContent?.title || ''\"\r\n            [titleClass]=\"relatedContent?.card_title_class || ''\"\r\n            [duration]=\"relatedContent?.duration || ''\"\r\n            [modality]=\"relatedContent?.modality[0] || ''\"\r\n            [button]=\"relatedContent?.button_card || ''\"\r\n            (page)=\"page.emit()\">\r\n          </dmmp-card-related-program>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n    <div class=\"content-btn\" *ngIf=\"module?.see_more?.length > 0\">\r\n      <dmmp-button\r\n        [data]=\"module?.see_more[0]\"\r\n        [identifier]=\"identifier || ''\"\r\n        (anchorCustom)=\"anchorCustom.emit($event)\"\r\n        (page)=\"page.emit($event)\">\r\n      </dmmp-button>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteRelatedContentUrlComponent);

let WebsiteRelatedContentUrlModule = class WebsiteRelatedContentUrlModule {
};
WebsiteRelatedContentUrlModule = __decorate([
    NgModule({
        imports: [CommonModule, SharedModule, PipesModule, RouterModule],
        declarations: [WebsiteRelatedContentUrlComponent],
        exports: [WebsiteRelatedContentUrlComponent],
        providers: [],
    })
], WebsiteRelatedContentUrlModule);

let SearchErrorComponent = class SearchErrorComponent {
    constructor() {
        this.medias = [
            { style: 'thumbnail', media: '(max-width:421px)' },
            { style: 'medium', media: '(min-width:600px)' },
        ];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], SearchErrorComponent.prototype, "module", void 0);
__decorate([
    Input()
], SearchErrorComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], SearchErrorComponent.prototype, "identifier", void 0);
SearchErrorComponent = __decorate([
    Component({
        selector: 'dmmp-search-error',
        template: "<dmmp-container [data]=\"module\" [identifier]=\"identifier\" [defaultClass]=\"defaultClass\">\r\n  <div class=\"container\">\r\n    <div class=\"align-items-center row\">\r\n      <div class=\"col-lg-2 col-md-3 mb-2\" *ngIf=\"module?.search_error_image?.length  > 0\">\r\n        <div class=\"search-error__img\">\r\n          <dmmp-image [images]=\"module.search_error_image[0]\"  [medias]=\"medias\"></dmmp-image>\r\n        </div>\r\n      </div>\r\n      <div class=\"col-lg-10 col-md-9\" *ngIf=\"module?.search_tips\">\r\n        <div class=\"search-error__title\">\r\n          <p *ngIf=\"this.module?.name\" [ngClass]=\"this.module.title_class ? this.module.title_class : ''\">\r\n            {{this.module.name}}</p>\r\n        </div>\r\n        <div class=\"search-error__content\">\r\n          <div [outerHTML]=\"module.search_tips\">\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], SearchErrorComponent);

let SearchErrorModule = class SearchErrorModule {
};
SearchErrorModule = __decorate([
    NgModule({
        declarations: [SearchErrorComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [SearchErrorComponent]
    })
], SearchErrorModule);

let WebsiteTrendingArticlesComponent = class WebsiteTrendingArticlesComponent {
    constructor(dateFormat) {
        this.dateFormat = dateFormat;
        this.isDate = true;
        this.quantityDescription = 120;
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
WebsiteTrendingArticlesComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], WebsiteTrendingArticlesComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteTrendingArticlesComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteTrendingArticlesComponent.prototype, "articlesList", void 0);
__decorate([
    Input()
], WebsiteTrendingArticlesComponent.prototype, "isDate", void 0);
__decorate([
    Input()
], WebsiteTrendingArticlesComponent.prototype, "quantityDescription", void 0);
__decorate([
    Output()
], WebsiteTrendingArticlesComponent.prototype, "page", void 0);
WebsiteTrendingArticlesComponent = __decorate([
    Component({
        selector: 'dmmp-website-trending-articles',
        template: "<dmmp-container [data]=\"module\"\r\n                [identifier]=\"identifier\"\r\n                [defaultClass]=\"'website-trending-articles'\r\n  \">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">\r\n      {{module?.name}}\r\n    </h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"tabs-content-article\" *ngIf=\"module?.trending_configuration?.length > 0\">\r\n      <ul ngbNav #nav=\"ngbNav\" class=\"nav-tabs\">\r\n        <li ngbNavItem *ngFor=\"let data of module?.trending_configuration; let i = index\">\r\n          <ng-container>\r\n            <a ngbNavLink>\r\n              <p class=\"tab-title\" *ngIf=\"data?.tab_title\">\r\n                {{data?.tab_title}}\r\n              </p>\r\n            </a>\r\n            <ng-template ngbNavContent>\r\n              <div class=\"content-articles\">\r\n                <div class=\"row-article\" *ngIf=\"articlesList[i]?.length > 0\">\r\n                  <div class=\"col-article\" *ngFor=\"let article of articlesList[i]\">\r\n                    <div class=\"row\">\r\n                      <div class=\"col-12 col-sm-3\">\r\n                        <div class=\"content-title\"\r\n                             [ngClass]=\"data?.class_category_date || ''\">\r\n                          <p class=\"category\" *ngIf=\"article?.categories?.length > 0\">\r\n                            {{article?.categories[0]}}\r\n                          </p>\r\n                          <p class=\"date\" *ngIf=\"isDate && article?.created_at\">\r\n                            {{\r\n                            dateFormat.convertFromTimestampToDate(article?.created_at)\r\n                              | date: 'longDate':'UTC'\r\n                            }}\r\n                          </p>\r\n                        </div>\r\n                      </div>\r\n                      <div class=\"col-12 col-sm-9\">\r\n                        <div class=\"content-info-article\">\r\n                          <a *ngIf=\"article?.title\"\r\n                             [routerLink]=\"article?.path || ''\"\r\n                             (click)=\"page.emit(article?.path || '')\"\r\n                             [ngClass]=\"data?.class_title || ''\">\r\n                            {{article?.title}}</a>\r\n                          <p [ngClass]=\"data?.class_description || ''\">\r\n                            {{(article?.body || article?.content || '')  | removeHtml | truncatetext: quantityDescription}}\r\n                          </p>\r\n                        </div>\r\n                      </div>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n              </div>\r\n            </ng-template>\r\n          </ng-container>\r\n        </li>\r\n      </ul>\r\n      <div [ngbNavOutlet]=\"nav\"></div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteTrendingArticlesComponent);

let WebsiteTrendingArticlesModule = class WebsiteTrendingArticlesModule {
};
WebsiteTrendingArticlesModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            NgbNavModule,
            RouterModule,
            PipesModule
        ],
        declarations: [WebsiteTrendingArticlesComponent],
        exports: [
            WebsiteTrendingArticlesComponent
        ],
        providers: []
    })
], WebsiteTrendingArticlesModule);

let WebsiteFeaturedLinkComponent = class WebsiteFeaturedLinkComponent {
    constructor() {
        this.anchorCustom = new EventEmitter();
        this.page = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], WebsiteFeaturedLinkComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteFeaturedLinkComponent.prototype, "module", void 0);
__decorate([
    Output()
], WebsiteFeaturedLinkComponent.prototype, "anchorCustom", void 0);
__decorate([
    Output()
], WebsiteFeaturedLinkComponent.prototype, "page", void 0);
WebsiteFeaturedLinkComponent = __decorate([
    Component({
        selector: 'dmmp-website-featured-link',
        template: "<dmmp-container\r\n  [identifier]=\"identifier\"\r\n  [data]=\"module\"\r\n  [defaultClass]=\"'website-featured-link'\"\r\n>\r\n  <h2 *ngIf=\"module?.name\"\r\n      [ngClass]=\"module?.title_class || ''\">\r\n    {{ module.name }}\r\n  </h2>\r\n  <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n    <div\r\n      *ngFor=\"let textContent of module?.texts\"\r\n      [ngClass]=\"textContent?.class || ''\"\r\n      [innerHTML]=\"textContent?.text || ''\"\r\n    ></div>\r\n  </ng-container>\r\n  <div class=\"row-content\" *ngIf=\"module?.featured_link?.length > 0\">\r\n    <div class=\"col-link\" *ngFor=\"let featuredLink of module?.featured_link\">\r\n      <dmmp-button *ngIf=\"featuredLink\"\r\n                   [data]=\"featuredLink\"\r\n                   (anchorCustom)=\"anchorCustom.emit($event)\"\r\n                   (page)=\"page.emit()\"></dmmp-button>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteFeaturedLinkComponent);

let WebsiteFeaturedLinkModule = class WebsiteFeaturedLinkModule {
};
WebsiteFeaturedLinkModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            SharedModule
        ],
        declarations: [WebsiteFeaturedLinkComponent],
        exports: [
            WebsiteFeaturedLinkComponent
        ]
    })
], WebsiteFeaturedLinkModule);

let WebsiteRelatedContentComponent = class WebsiteRelatedContentComponent {
    constructor() {
        this.page = new EventEmitter();
        this.anchorCustom = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], WebsiteRelatedContentComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteRelatedContentComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], WebsiteRelatedContentComponent.prototype, "page", void 0);
__decorate([
    Output()
], WebsiteRelatedContentComponent.prototype, "anchorCustom", void 0);
WebsiteRelatedContentComponent = __decorate([
    Component({
        selector: 'dmmp-website-related-content',
        template: "<dmmp-container *ngIf=\"module\"\r\n                [identifier]=\"identifier || ''\" [data]=\"module\"\r\n                [defaultClass]=\"'website-related-content'\">\r\n  <div class=\"container\">\r\n    <h2 class=\"h2\" *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">{{module?.name}}</h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"module?.visualization_tag_related === 'video_gallery'\">\r\n      <ng-container *ngIf=\"module?.content?.length > 0\">\r\n        <div class=\"row box-video-gallery\">\r\n          <ng-container *ngFor=\"let content of module?.content | slice:0:1; let i = index\">\r\n            <ng-container *ngIf=\"content?.video_related?.length > 0\">\r\n              <ng-container *ngFor=\"let videoRelated of content?.video_related;let j = index\">\r\n                <div *ngIf=\"i === 0 && j === 0\" class=\"col-12 col-lg-6 box-col-video\">\r\n                  <dmmp-video-gallery\r\n                    [videoSrc]=\"videoRelated?.video[0]?.value || ''\"\r\n                    [videoType]=\"videoRelated?.type || ''\"\r\n                    [title]=\"videoRelated?.title ? '<h3 class=h3'+''+'>'+ (videoRelated?.title) + '</h3>' : ''\"\r\n                    [categories]=\"content?.identifier ? content : ''\"\r\n                    [date]=\"videoRelated?.created_at || ''\"\r\n                    [path]=\"content?.path || ''\"\r\n                    [image]=\"videoRelated?.image[0] || ''\"\r\n                    [description]=\"videoRelated?.description || ''\"\r\n                    (page)=\"page.emit($event)\">\r\n                  </dmmp-video-gallery>\r\n                </div>\r\n              </ng-container>\r\n            </ng-container>\r\n          </ng-container>\r\n          <div class=\"col-12 col-lg-6 box-col-images\">\r\n            <ng-container *ngFor=\"let content of module?.content | slice:0:4; let i = index\">\r\n              <ng-container *ngIf=\"content?.video_related?.length > 0\">\r\n                <ng-container *ngFor=\"let videoRelated of content?.video_related;let j = index\">\r\n                  <div *ngIf=\"i !== 0 && j === 0\" class=\"col-12\">\r\n                    <dmmp-video-gallery\r\n                      [title]=\"videoRelated?.title ? '<h3 class=h3'+''+'>'+ (videoRelated?.title) + '</h3>' : ''\"\r\n                      [categories]=\"content?.identifier ? content : ''\"\r\n                      [image]=\"videoRelated?.image[0] || ''\"\r\n                      [date]=\"videoRelated?.created_at || ''\"\r\n                      [medias]=\"[{ style: 'large', media: '(min-width:421px)' }]\"\r\n                      [path]=\"content?.path || ''\"\r\n                      (page)=\"page.emit($event)\">\r\n                    </dmmp-video-gallery>\r\n                  </div>\r\n                </ng-container>\r\n              </ng-container>\r\n            </ng-container>\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n    </ng-container>\r\n    <div class=\"content-btn\" *ngIf=\"module.see_more && module.see_more.length > 0\">\r\n      <dmmp-button\r\n        [data]=\"module.see_more[0]\"\r\n        [identifier]=\"identifier ? identifier : ''\"\r\n        (anchorCustom)=\"anchorCustom.emit($event)\"\r\n        (page)=\"page.emit($event)\">\r\n      </dmmp-button>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteRelatedContentComponent);

let WebsiteRelatedContentModule = class WebsiteRelatedContentModule {
};
WebsiteRelatedContentModule = __decorate([
    NgModule({
        imports: [CommonModule, SharedModule, PipesModule],
        declarations: [WebsiteRelatedContentComponent],
        exports: [WebsiteRelatedContentComponent],
        providers: [],
    })
], WebsiteRelatedContentModule);

let WebsiteCookiesComponent = class WebsiteCookiesComponent {
    constructor(cookieService) {
        this.cookieService = cookieService;
    }
    ngOnInit() {
    }
    validateCookie() {
        const dateNow = new Date();
        dateNow.setDate(dateNow.getDate() + 180);
        this.cookieService.set('politicaDatos', 'true', dateNow, '/');
    }
};
WebsiteCookiesComponent.ctorParameters = () => [
    { type: CookieService }
];
__decorate([
    Input()
], WebsiteCookiesComponent.prototype, "module", void 0);
WebsiteCookiesComponent = __decorate([
    Component({
        selector: 'dmmp-website-cookies',
        template: "<div\r\n  *ngIf=\"module\"\r\n  [ngClass]=\"module.class || ''\"\r\n  [style.backgroundColor]=\"module?.background_color?.color || ''\"\r\n  class=\"website-cookies\"\r\n>\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <div class=\"col-auto\" *ngIf=\"module?.content\">\r\n        <div class=\"content-text\" [innerHTML]=\"module?.content\"></div>\r\n      </div>\r\n      <div class=\"col-auto\" *ngIf=\"module?.button_cookie?.length > 0\">\r\n        <div class=\"btn-content\">\r\n          <a class=\"button-cookies\" [ngClass]=\"module?.button_cookie[0]?.class || ''\"\r\n             (click)=\"validateCookie()\">\r\n            {{module?.button_cookie[0]?.label_button || ''}}\r\n          </a>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n\r\n"
    })
], WebsiteCookiesComponent);

let WebsiteCookiesModule = class WebsiteCookiesModule {
};
WebsiteCookiesModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            RouterModule,
        ],
        declarations: [WebsiteCookiesComponent],
        exports: [
            WebsiteCookiesComponent
        ],
        providers: []
    })
], WebsiteCookiesModule);

let FloatingMenuComponent = class FloatingMenuComponent {
    constructor(localDeviceDetectorService) {
        this.localDeviceDetectorService = localDeviceDetectorService;
        this.defaultClass = 'floating-menu';
        this.isCollapse = true;
        this.medias = [
            { style: 'large', media: '(min-width:421px)' },
        ];
        this.filterEmitter = new EventEmitter();
    }
    filter(selectedTerm) {
        var _a, _b, _c, _d;
        this.filterEmitter.emit(selectedTerm);
        (_d = (_c = (_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.vocabularies[0]) === null || _b === void 0 ? void 0 : _b.vocabulary) === null || _c === void 0 ? void 0 : _c.terms) === null || _d === void 0 ? void 0 : _d.forEach(termItem => {
            if (selectedTerm !== termItem) {
                termItem.active = false;
            }
        });
    }
};
FloatingMenuComponent.ctorParameters = () => [
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], FloatingMenuComponent.prototype, "module", void 0);
__decorate([
    Input()
], FloatingMenuComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], FloatingMenuComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], FloatingMenuComponent.prototype, "filterEmitter", void 0);
FloatingMenuComponent = __decorate([
    Component({
        selector: 'dmmp-floating-menu',
        template: "<dmmp-container [data]=\"module\" [defaultClass]=\"defaultClass\" [ngClass]=\"identifier\">\r\n  <div class=\"container floating-menu__container\" *ngIf=\"module?.vocabularies?.length > 0\">\r\n    <ng-container *ngIf=\"localDeviceDetectorService.isDesktop(); else mobileView\">\r\n      <div class=\"row\">\r\n        <div class=\"col-auto floating-menu__logo\" *ngIf=\"module?.vocabulary_logo?.length > 0\">\r\n          <dmmp-image [images]=\"module?.vocabulary_logo[0]\" [medias]=\"medias\">\r\n          </dmmp-image>\r\n        </div>\r\n        <ng-container *ngIf=\"module?.vocabularies?.length > 0\">\r\n          <ng-container *ngFor=\"let itemTerm of module?.vocabularies[0]?.vocabulary.terms | slice: 0 : 4\">\r\n            <div class=\"col-auto floating-menu__item\" *ngIf=\"!itemTerm?.path; else linkTemp\">\r\n              <p class=\"floating-menu__link\">{{itemTerm?.name}}</p>\r\n            </div>\r\n            <ng-template #linkTemp>\r\n              <div class=\"col-auto floating-menu__item\">\r\n                <a (click)=\"filter(itemTerm); itemTerm.active = true\" [ngClass]=\"itemTerm?.active ? 'active': ''\"\r\n                  class=\"floating-menu__link\">{{itemTerm?.name}}</a>\r\n              </div>\r\n            </ng-template>\r\n          </ng-container>\r\n        </ng-container>\r\n        <div class=\"col-auto text-right collapse-box floating-menu__item floating-menu__collapse\"\r\n          (click)=\"isCollapse = !isCollapse\"\r\n          *ngIf=\"module?.vocabularies?.length > 0 && module?.vocabularies[0]?.vocabulary?.terms?.length > 4\">\r\n          <p [ngClass]=\"!isCollapse ? 'active' : ''\" class=\"floating-menu__link\">\r\n            {{module?.vocabularies[0]?.vocabulary?.name}}\r\n          </p>\r\n          <button type=\"button\" class=\"btn btn-outline\" align-left>\r\n            <i class=\"fas fa-chevron-up\" *ngIf=\"!isCollapse\"></i>\r\n            <i class=\"fas fa-chevron-down\" *ngIf=\"isCollapse\"></i>\r\n          </button>\r\n          <ul *ngIf=\"!isCollapse\" class=\"floating-menu__submenu\">\r\n            <ng-container\r\n              *ngFor=\"let itemTerm of module?.vocabularies[0]?.vocabulary?.terms | slice: 5 : module?.vocabularies[0]?.vocabulary?.terms?.length\">\r\n              <li class=\"floating-menu__item\">\r\n                <ng-container *ngIf=\"!itemTerm?.path; else linkTemp\">\r\n                  <p class=\"floating-menu__link\">{{itemTerm?.name}}</p>\r\n                </ng-container>\r\n                <ng-template #linkTemp>\r\n                  <a (click)=\"filter(itemTerm); itemTerm.active = true\" [ngClass]=\"itemTerm?.active ? 'active': ''\"\r\n                    class=\"floating-menu__link\">{{itemTerm?.name}}</a>\r\n                </ng-template>\r\n              </li>\r\n            </ng-container>\r\n          </ul>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n    <ng-template #mobileView>\r\n      <div class=\"row\">\r\n        <div class=\"mobile-sub-menu-box\">\r\n          <div class=\"col-auto floating-menu__logo\" *ngIf=\"module?.vocabulary_logo?.length > 0\">\r\n            <dmmp-image [images]=\"module?.vocabulary_logo[0]\" [medias]=\"medias\">\r\n            </dmmp-image>\r\n          </div>\r\n          <div class=\"col-auto text-right collapse-box floating-menu__item floating-menu__collapse\"\r\n            (click)=\"isCollapse = !isCollapse\" *ngIf=\"module?.vocabularies?.length > 0\">\r\n            <p [ngClass]=\"!isCollapse ? 'active' : ''\" class=\"floating-menu__link\">\r\n              {{module?.vocabularies[0]?.vocabulary?.name}}\r\n            </p>\r\n            <button type=\"button\" class=\"btn btn-outline\" align-left>\r\n              <i class=\"fas fa-chevron-up\" *ngIf=\"!isCollapse\"></i>\r\n              <i class=\"fas fa-chevron-down\" *ngIf=\"isCollapse\"></i>\r\n            </button>\r\n          </div>\r\n        </div>\r\n        <ul *ngIf=\"!isCollapse\" class=\"floating-menu__submenu\">\r\n          <ng-container *ngFor=\"let itemTerm of module?.vocabularies[0]?.vocabulary?.terms\">\r\n            <li class=\"floating-menu__item\">\r\n              <ng-container *ngIf=\"!itemTerm.path; else linkTemp\">\r\n                <p class=\"floating-menu__link\">{{itemTerm?.name}}</p>\r\n              </ng-container>\r\n              <ng-template #linkTemp>\r\n                <a (click)=\"filter(itemTerm); itemTerm.active = true\" [ngClass]=\"itemTerm?.active ? 'active': ''\"\r\n                  class=\"floating-menu__link\">{{itemTerm?.name}}</a>\r\n              </ng-template>\r\n            </li>\r\n          </ng-container>\r\n        </ul>\r\n      </div>\r\n    </ng-template>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], FloatingMenuComponent);

let FloatingMenuModule = class FloatingMenuModule {
};
FloatingMenuModule = __decorate([
    NgModule({
        declarations: [FloatingMenuComponent],
        imports: [
            CommonModule,
            SharedModule,
            NgbCollapseModule
        ],
        exports: [FloatingMenuComponent]
    })
], FloatingMenuModule);

let WebsiteShareSocialNetworksComponent = class WebsiteShareSocialNetworksComponent {
    constructor(socialNetworksService, platformLocation) {
        this.socialNetworksService = socialNetworksService;
        this.platformLocation = platformLocation;
        this.tooltipOpened = false;
        this.currentUrl = this.platformLocation.href;
    }
    ngOnInit() {
        this.socialNetworkQuantity = Number(this.module.social_network_quantity);
    }
    openSocialNetwork(social) {
        switch (social.name) {
            case 'facebook':
                this.socialNetworksService.facebookService.initApp();
                this.socialNetworksService.facebookService.shareFacebook(this.currentUrl);
                break;
            case 'whatsapp':
                this.socialNetworksService.whatsAppService.openWhatsAppApp(this.currentUrl);
                break;
            case 'linkedin':
                this.socialNetworksService.linkedInService.shareLinkedin(this.currentUrl);
                break;
            case 'messenger':
                this.socialNetworksService.messengerService.shareMessengerMobile(this.currentUrl);
                break;
            case 'twitter':
                this.socialNetworksService.twitterService.openTwitter(this.currentUrl);
                break;
            case 'skype':
                this.socialNetworksService.skypeService.shareURL(this.currentUrl);
                break;
        }
    }
    toggleTooltip() {
        this.tooltipOpened = !this.tooltipOpened;
    }
};
WebsiteShareSocialNetworksComponent.ctorParameters = () => [
    { type: SocialNetworksService },
    { type: PlatformLocation }
];
__decorate([
    Input()
], WebsiteShareSocialNetworksComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteShareSocialNetworksComponent.prototype, "identifier", void 0);
WebsiteShareSocialNetworksComponent = __decorate([
    Component({
        selector: 'dmmp-website-share-social-networks',
        template: "<dmmp-container\r\n  *ngIf=\"module\"\r\n  [identifier]=\"identifier || ''\"\r\n  [data]=\"module\"\r\n  [defaultClass]=\"'website-share-social-networks'\">\r\n  <div [class]=\"module?.class\" class=\"box-social\">\r\n    <div class=\"box-social__container\">\r\n      <ng-container\r\n        *ngFor=\"let social of module?.content | slice: 0:socialNetworkQuantity\">\r\n        <a\r\n          class=\"box-social__link\"\r\n          [class]=\"social?.class\"\r\n          (click)=\"openSocialNetwork(social)\"\r\n          [rel]=\"social?.nofollow ? 'nofollow' : ''\">\r\n          <i class=\"box-social__icon\" [class]=\"social?.icon\"></i>\r\n          {{ social?.title }}\r\n        </a>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"module?.social_network_tooltip?.length > 0\">\r\n        <a [ngStyle]=\"{\r\n      'color': module?.social_network_tooltip[0]?.color?.color,\r\n      'opacity': module?.social_network_tooltip[0]?.color?.opacity }\"\r\n           (click)=\"toggleTooltip()\"\r\n           [class]=\"module?.social_network_tooltip[0]?.class\"\r\n           [ngClass]=\"{open: tooltipOpened  }\" class=\"box-social__link\">\r\n          <i [class]=\"module?.social_network_tooltip[0]?.icon\" class=\"box-social__icon \"></i>\r\n        </a>\r\n      </ng-container>\r\n    </div>\r\n\r\n    <div [@fadeIn] class=\"box-social__tooltip\" *ngIf=\"tooltipOpened\">\r\n      <ng-container\r\n        *ngFor=\"\r\n        let social of module?.content\r\n          | slice: socialNetworkQuantity:module?.content?.length\">\r\n        <a\r\n          class=\"box-social__link\"\r\n          [class]=\"social?.class\"\r\n          (click)=\"openSocialNetwork(social)\"\r\n          [rel]=\"social?.nofollow ? 'nofollow' : ''\">\r\n          <i class=\"box-social__icon\" [class]=\"social?.icon\"></i>\r\n          {{ social?.title }}\r\n        </a>\r\n      </ng-container>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        animations: [
            trigger('fadeIn', [
                transition('* <=> *', [
                    query(':enter', [
                        style({ opacity: 0 }),
                        stagger(100, [animate('0.2s ease-in-out', style({ opacity: 1 }))])
                    ], { optional: true }),
                    query(':leave', [
                        style({ opacity: 1 }),
                        stagger(-100, [animate('0.2s ease-in-out', style({ opacity: 0 }))])
                    ], { optional: true })
                ])
            ])
        ]
    })
], WebsiteShareSocialNetworksComponent);

var WebsiteShareSocialNetworksModule_1;
let WebsiteShareSocialNetworksModule = WebsiteShareSocialNetworksModule_1 = class WebsiteShareSocialNetworksModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('WebsiteShareSocialNetworksModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(config) {
        return {
            ngModule: WebsiteShareSocialNetworksModule_1,
            providers: [
                { provide: SocialNetwork, useValue: config },
            ]
        };
    }
};
WebsiteShareSocialNetworksModule.ctorParameters = () => [
    { type: WebsiteShareSocialNetworksModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];
WebsiteShareSocialNetworksModule = WebsiteShareSocialNetworksModule_1 = __decorate([
    NgModule({
        imports: [CommonModule, SharedModule, SocialNetworkServiceModule],
        declarations: [WebsiteShareSocialNetworksComponent],
        exports: [WebsiteShareSocialNetworksComponent],
    }),
    __param(0, Optional()), __param(0, SkipSelf())
], WebsiteShareSocialNetworksModule);

let PressRoomComponent = class PressRoomComponent {
    constructor(dateFormatService) {
        this.dateFormatService = dateFormatService;
        this.page = new EventEmitter();
    }
};
PressRoomComponent.ctorParameters = () => [
    { type: DateFormatService }
];
__decorate([
    Input()
], PressRoomComponent.prototype, "data", void 0);
__decorate([
    Input()
], PressRoomComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], PressRoomComponent.prototype, "page", void 0);
PressRoomComponent = __decorate([
    Component({
        selector: 'dmmp-press-room',
        template: "<dmmp-container\r\n  [data]=\"data\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'press-room'\"\r\n>\r\n  <div class=\"container\">\r\n    <div class=\"box-title\">\r\n      <h2 *ngIf=\"data?.name\"\r\n          [ngClass]=\"data.title_class ? data.title_class : ''\">\r\n        {{ data.name }}\r\n      </h2>\r\n    </div>\r\n    <ng-container *ngIf=\"data?.texts ? data?.texts?.length > 0 : false\">\r\n      <div\r\n        *ngFor=\"let textContent of data.texts\"\r\n        [ngClass]=\"textContent.class ? textContent.class : ''\"\r\n        [innerHTML]=\"textContent.text ? textContent.text : ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\" data?.content?.length > 0\">\r\n      <div class=\"row row-items\">\r\n        <ng-container *ngFor=\"let press of data.content | slice :0:4\">\r\n          <div class=\"col-12 col-md-3\">\r\n            <div class=\"box-content\">\r\n              <ng-container *ngIf=\"press?.name\">\r\n                <div class=\"box-title\">\r\n                  <dmmp-link [data]=\"press.link_icon[0]\" [identifier]=\"identifier\">\r\n                    {{ press.name }}\r\n                  </dmmp-link>\r\n                </div>\r\n              </ng-container>\r\n              <ng-container *ngIf=\"press?.medio\">\r\n                <div class=\"box-category\">\r\n                  <p>{{ press.medio }}</p>\r\n                </div>\r\n              </ng-container>\r\n              <ng-container *ngIf=\"press?.date\">\r\n                <div class=\"box-date\">\r\n                  <p>\r\n                    {{\r\n                    dateFormatService.convertFromTimestampToDate(\r\n                      press.date\r\n                    ) | date: 'dd MMMM yyyy':'UTC'\r\n                    }}\r\n                  </p>\r\n                </div>\r\n              </ng-container>\r\n            </div>\r\n          </div>\r\n        </ng-container>\r\n      </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"data?.see_more && data?.see_more?.length > 0\">\r\n      <div class=\"row\">\r\n        <div class=\"col box-button\">\r\n          <dmmp-button\r\n            [data]=\"data.see_more[0]\"\r\n            [identifier]=\"identifier\"\r\n            (page)=\"page.emit($event)\"\r\n          >\r\n          </dmmp-button>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], PressRoomComponent);

let PressRoomModule = class PressRoomModule {
};
PressRoomModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            SharedModule,
            PipesModule,
        ],
        declarations: [PressRoomComponent],
        exports: [PressRoomComponent],
    })
], PressRoomModule);

let GeneralSearchResultComponent = class GeneralSearchResultComponent {
    constructor() {
        this.redirectPage = new EventEmitter();
    }
};
__decorate([
    Input()
], GeneralSearchResultComponent.prototype, "module", void 0);
__decorate([
    Input()
], GeneralSearchResultComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], GeneralSearchResultComponent.prototype, "searchingResult", void 0);
__decorate([
    Input()
], GeneralSearchResultComponent.prototype, "initialResult", void 0);
__decorate([
    Output()
], GeneralSearchResultComponent.prototype, "redirectPage", void 0);
__decorate([
    Input()
], GeneralSearchResultComponent.prototype, "currentSearch", void 0);
GeneralSearchResultComponent = __decorate([
    Component({
        selector: 'dmmp-general-search-result',
        template: "<dmmp-container\r\n  [data]=\"module\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'general-search-result'\"\r\n>\r\n  <ng-container *ngIf=\"initialResult?.length > 0; else resultSearch\">\r\n    <div class=\"container\">\r\n      <div class=\"row\">\r\n        <ng-container *ngFor=\"let result of initialResult\">\r\n          <div class=\"col-12\">\r\n            <dmmp-card-general-result\r\n              [image]=\"result.image ? result.image : ''\"\r\n              [title]=\"\r\n                result.name ? result.name : result.title ? result.title : ''\r\n              \"\r\n              [titleSize]=\"90\"\r\n              [type]=\"result.identifier ? result.identifier : ''\"\r\n              [description]=\"\r\n                result.description\r\n                  ? result.description\r\n                  : result.content\r\n                  ? result.content\r\n                  : ''\r\n              \"\r\n              [descriptionSize]=\"190\"\r\n              [classDescription]=\"\r\n                result.description_class ? result.description_class : ''\r\n              \"\r\n              [classTitle]=\"result.title_class ? result.title_class : ''\"\r\n              [classImage]=\"result.image_class ? result.image_class : ''\"\r\n              [path]=\"result.path ? result.path : ''\"\r\n              (redirectPage)=\"redirectPage.emit($event)\"\r\n            >\r\n            </dmmp-card-general-result>\r\n          </div>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n  <ng-template #resultSearch>\r\n    <ng-container *ngIf=\"searchingResult?.length > 0\">\r\n      <div class=\"container\">\r\n        <div class=\"row\">\r\n          <ng-container *ngFor=\"let result of searchingResult\">\r\n            <div class=\"col-12\">\r\n              <dmmp-card-general-result\r\n                [image]=\"result.image ? result.image : ''\"\r\n                [title]=\"\r\n                  (result.name ? result.name : result.title ? result.title : '')\r\n                    | highligthSearchText: currentSearch\r\n                \"\r\n                [titleSize]=\"90\"\r\n                [type]=\"result.identifier ? result.identifier : ''\"\r\n                [description]=\"\r\n                  (result.description\r\n                    ? result.description\r\n                    : result.content\r\n                    ? result.content\r\n                    : ''\r\n                  ) | highligthSearchText: currentSearch\r\n                \"\r\n                [descriptionSize]=\"190\"\r\n                [classDescription]=\"\r\n                  result.description_class ? result.description_class : ''\r\n                \"\r\n                [classTitle]=\"result.title_class ? result.title_class : ''\"\r\n                [classImage]=\"result.image_class ? result.image_class : ''\"\r\n                [path]=\"result.path ? result.path : ''\"\r\n                (redirectPage)=\"redirectPage.emit($event)\"\r\n              >\r\n              </dmmp-card-general-result>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n  </ng-template>\r\n</dmmp-container>\r\n"
    })
], GeneralSearchResultComponent);

let GeneralSearchResultModule = class GeneralSearchResultModule {
};
GeneralSearchResultModule = __decorate([
    NgModule({
        declarations: [GeneralSearchResultComponent],
        imports: [CommonModule, SharedModule, PipesModule],
        exports: [GeneralSearchResultComponent],
    })
], GeneralSearchResultModule);

let WebsitePreviousOrNextContentComponent = class WebsitePreviousOrNextContentComponent {
    constructor() {
        this.path = new EventEmitter();
    }
};
__decorate([
    Input()
], WebsitePreviousOrNextContentComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsitePreviousOrNextContentComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsitePreviousOrNextContentComponent.prototype, "articlesPaginator$", void 0);
__decorate([
    Output()
], WebsitePreviousOrNextContentComponent.prototype, "path", void 0);
WebsitePreviousOrNextContentComponent = __decorate([
    Component({
        selector: 'dmmp-website-previous-or-next-content',
        template: "<dmmp-container\r\n  [data]=\"module\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'website-previous-or-next-content'\">\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <div class=\"col-12 col-md-6\">\r\n        <ng-container *ngIf=\"(articlesPaginator$ | async)?.previous\">\r\n          <p [class]=\"module?.previous_class\">{{ module?.previous }}</p>\r\n          <dmmp-path-link\r\n            (page)=\"path.emit($event)\"\r\n            [path]=\"(articlesPaginator$ | async)?.previous?.path\"\r\n          >\r\n            <a class=\"website-previous-or-next-content__link\">{{\r\n              (articlesPaginator$ | async)?.previous?.title\r\n              }}</a>\r\n          </dmmp-path-link>\r\n          <p class=\"website-previous-or-next-content__date\">\r\n            {{\r\n            (articlesPaginator$ | async)?.previous?.updated_at\r\n              | date: 'dd MMMM yyyy':'UTC'\r\n            }}\r\n          </p>\r\n        </ng-container>\r\n      </div>\r\n\r\n      <div class=\"col-12 col-md-6\">\r\n        <ng-container *ngIf=\"(articlesPaginator$ | async)?.next\">\r\n          <p [class]=\"module?.next_class\">{{ module?.next }}</p>\r\n          <dmmp-path-link\r\n            (page)=\"path.emit($event)\"\r\n            [path]=\"(articlesPaginator$ | async)?.next?.path\"\r\n          >\r\n            <a class=\"website-previous-or-next-content__link\">{{\r\n              (articlesPaginator$ | async)?.next?.title\r\n              }}</a>\r\n          </dmmp-path-link>\r\n          <p class=\"website-previous-or-next-content__date\">\r\n            {{\r\n            (articlesPaginator$ | async)?.next?.updated_at\r\n              | date: 'dd MMMM yyyy':'UTC'\r\n            }}\r\n          </p>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], WebsitePreviousOrNextContentComponent);

let WebsitePreviousOrNextContentModule = class WebsitePreviousOrNextContentModule {
};
WebsitePreviousOrNextContentModule = __decorate([
    NgModule({
        declarations: [WebsitePreviousOrNextContentComponent],
        imports: [
            CommonModule,
            SharedModule,
        ],
        exports: [WebsitePreviousOrNextContentComponent]
    })
], WebsitePreviousOrNextContentModule);

let WebsiteUpcomingEventsComponent = class WebsiteUpcomingEventsComponent {
    constructor() {
        this.redirectPage = new EventEmitter();
        this.getMore = new EventEmitter();
    }
};
__decorate([
    Input()
], WebsiteUpcomingEventsComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteUpcomingEventsComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteUpcomingEventsComponent.prototype, "totalPaginator", void 0);
__decorate([
    Input()
], WebsiteUpcomingEventsComponent.prototype, "currentPaginator", void 0);
__decorate([
    Output()
], WebsiteUpcomingEventsComponent.prototype, "redirectPage", void 0);
__decorate([
    Input()
], WebsiteUpcomingEventsComponent.prototype, "allUpcomingEvents", void 0);
__decorate([
    Output()
], WebsiteUpcomingEventsComponent.prototype, "getMore", void 0);
WebsiteUpcomingEventsComponent = __decorate([
    Component({
        selector: 'dmmp-website-upcoming-events',
        template: "<dmmp-container [data]=\"module\"\r\n                *ngIf=\"module\"\r\n                [identifier]=\"identifier || ''\"\r\n                [defaultClass]=\"'website-upcoming-events'\">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">\r\n      {{ module?.name }}\r\n    </h2>\r\n    <div\r\n      *ngIf=\"allUpcomingEvents?.length > 0\"\r\n      class=\"row\">\r\n      <div\r\n        *ngFor=\"let card of allUpcomingEvents\"\r\n        class=\"col-md-6 col-xs-12\"\r\n      >\r\n        <dmmp-card-event\r\n          [category]=\"\r\n          card?.topic[0]?.label || ''\r\n        \"\r\n          [title]=\"'<h3>' + card?.name + '</h3>'\"\r\n          [image]=\"card?.image\"\r\n          [date]=\"card?.date?.start\"\r\n          [description]=\"card?.description\"\r\n          [descriptionSize]=\"150\"\r\n          [path]=\"card?.path\"\r\n          [showImage]=\"true\"\r\n          (redirectPage)=\"redirectPage.emit()\"\r\n        >\r\n        </dmmp-card-event>\r\n      </div>\r\n      <div *ngIf=\"totalPaginator\" class=\"col-12 text-center\">\r\n        <button\r\n          [disabled]=\"\r\n          (totalPaginator ) - 1 === (currentPaginator)\r\n        \"\r\n          [ngClass]=\"module?.see_more[0]?.class\"\r\n          (click)=\"getMore.emit()\"\r\n        >\r\n          {{ module.see_more[0]?.link[0]?.name }}\r\n        </button>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], WebsiteUpcomingEventsComponent);

let WebsiteUpcomingEventsModule = class WebsiteUpcomingEventsModule {
};
WebsiteUpcomingEventsModule = __decorate([
    NgModule({
        declarations: [WebsiteUpcomingEventsComponent],
        imports: [
            CommonModule,
            SharedModule,
        ],
        exports: [WebsiteUpcomingEventsComponent]
    })
], WebsiteUpcomingEventsModule);

let TagsContentComponent = class TagsContentComponent {
    constructor(router) {
        this.router = router;
        this.page = new EventEmitter();
        this.labelTags = 'Tags:';
    }
    ngOnInit() {
        this.url = '/' + this.router.url.split('/')[1];
    }
    redirect(tag) {
        this.router.navigate([this.url], {
            queryParams: {
                tag: this.formatText(tag),
            },
        });
        this.page.emit();
    }
    formatText(word) {
        return word.split(' ').join('-').toLowerCase().normalize('NFD')
            .replace(/([^n\u0300-\u036f]|n(?!\u0303(?![\u0300-\u036f])))[\u0300-\u036f]+/gi, "$1")
            .normalize();
    }
};
TagsContentComponent.ctorParameters = () => [
    { type: Router }
];
__decorate([
    Input()
], TagsContentComponent.prototype, "module", void 0);
__decorate([
    Input()
], TagsContentComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], TagsContentComponent.prototype, "detailLayout", void 0);
__decorate([
    Output()
], TagsContentComponent.prototype, "page", void 0);
TagsContentComponent = __decorate([
    Component({
        selector: 'dmmp-tags-content',
        template: "<dmmp-container [data]=\"module\" [defaultClass]=\"'tags-content'\" [identifier]=\"identifier\">\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <div class=\"tags-content__tags\">\r\n        <ng-container *ngIf=\"detailLayout?.categories\">\r\n          <p class=\"tags-content__title\" *ngIf=\"labelTags\">{{labelTags}} </p>\r\n          <ng-container *ngIf=\"detailLayout?.categories?.length > 0\">\r\n            <a *ngFor=\"let categories of detailLayout.categories\"\r\n               (click)=\"redirect(categories)\" routerLink={{categories}}>{{categories}}</a>\r\n          </ng-container>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], TagsContentComponent);

let TagsContentModule = class TagsContentModule {
};
TagsContentModule = __decorate([
    NgModule({
        declarations: [TagsContentComponent],
        imports: [
            CommonModule,
            SharedModule,
            RouterModule
        ],
        exports: [TagsContentComponent]
    })
], TagsContentModule);

let ArticleTopicsComponent = class ArticleTopicsComponent {
    constructor(options, deviceDetector) {
        this.options = options;
        this.deviceDetector = deviceDetector;
        this.redirectPage = new EventEmitter();
        this.allVocabularies = [];
    }
    ngOnInit() {
        this.configCarousel = this.options.configurationBenefits(this.module || {});
        this.getAllTerms();
    }
    getAllTerms() {
        var _a, _b, _c, _d, _e;
        if (((_a = this.module) === null || _a === void 0 ? void 0 : _a.vocabularies) && ((_c = (_b = this.module) === null || _b === void 0 ? void 0 : _b.vocabularies) === null || _c === void 0 ? void 0 : _c.length) > 0) {
            (_e = (_d = this.module) === null || _d === void 0 ? void 0 : _d.vocabularies) === null || _e === void 0 ? void 0 : _e.forEach((item) => {
                var _a, _b, _c, _d, _e, _f, _g, _h;
                if (((_b = (_a = item) === null || _a === void 0 ? void 0 : _a.vocabulary) === null || _b === void 0 ? void 0 : _b.terms) && ((_e = (_d = (_c = item) === null || _c === void 0 ? void 0 : _c.vocabulary) === null || _d === void 0 ? void 0 : _d.terms) === null || _e === void 0 ? void 0 : _e.length) > 0) {
                    (_h = (_g = (_f = item) === null || _f === void 0 ? void 0 : _f.vocabulary) === null || _g === void 0 ? void 0 : _g.terms) === null || _h === void 0 ? void 0 : _h.forEach((term) => {
                        this.allVocabularies.push(term);
                    });
                }
            });
        }
    }
};
ArticleTopicsComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService },
    { type: LocalDeviceDetectorService }
];
__decorate([
    Input()
], ArticleTopicsComponent.prototype, "module", void 0);
__decorate([
    Input()
], ArticleTopicsComponent.prototype, "identifier", void 0);
__decorate([
    Output()
], ArticleTopicsComponent.prototype, "redirectPage", void 0);
__decorate([
    ViewChild('owl')
], ArticleTopicsComponent.prototype, "carousel", void 0);
ArticleTopicsComponent = __decorate([
    Component({
        selector: 'dmmp-article-topics',
        template: "<div\r\n  *ngIf=\"module?.visible\"\r\n  [id]=\"module?.id_element ? identifier + '_' + module?.id_element : ''\"\r\n  [style.backgroundImage]=\"\r\n    module?.background_image?.length > 0\r\n      ? 'url(' + (module?.background_image)[0]?.styles?.large + ')'\r\n      : ''\r\n  \"\r\n  [style.backgroundColor]=\"module?.background_color?.color || ''\"\r\n  [style.opacity]=\"module?.background_color?.opacity || ''\"\r\n  class=\"articles-topics\"\r\n>\r\n  <div class=\"container\">\r\n    <ng-container *ngIf=\"module?.name\">\r\n      <div class=\"row\">\r\n        <div class=\"col\">\r\n          <p [ngClass]=\"module?.title_class || ''\">\r\n            {{ module?.name }}\r\n          </p>\r\n        </div>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n  <ng-container *ngIf=\"deviceDetector.isDesktop()\">\r\n    <ng-container *ngIf=\"module?.vocabularies && module?.vocabularies?.length > 0\">\r\n      <dmmp-article-topics-desktop\r\n        [vocabularies]=\"allVocabularies\"\r\n        [configCarousel]=\"configCarousel\"\r\n        (redirectPage)=\"redirectPage.emit($event)\"\r\n      ></dmmp-article-topics-desktop>\r\n    </ng-container>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"deviceDetector.isMobile()\">\r\n    <ng-container *ngIf=\"module?.vocabularies && module?.vocabularies?.length > 0\">\r\n      <dmmp-article-topics-mobile\r\n        [vocabularies]=\"allVocabularies\"\r\n        [configCarousel]=\"configCarousel\"\r\n        (redirectPage)=\"redirectPage.emit($event)\"\r\n      ></dmmp-article-topics-mobile>\r\n    </ng-container>\r\n  </ng-container>\r\n</div>\r\n"
    })
], ArticleTopicsComponent);

let ArticleTopicsDesktopComponent = class ArticleTopicsDesktopComponent {
    constructor() {
        this.redirectPage = new EventEmitter();
        this.carouselVocabularies = [];
    }
    ngOnInit() {
        var _a, _b;
        const lengthSlide = 8;
        if (((_a = this.vocabularies) === null || _a === void 0 ? void 0 : _a.length) > 8) {
            for (let i = 0; i < ((_b = this.vocabularies) === null || _b === void 0 ? void 0 : _b.length); i += lengthSlide) {
                const slide = this.vocabularies.slice(i, i + lengthSlide);
                this.carouselVocabularies.push({ slide: slide });
            }
        }
    }
};
__decorate([
    Input()
], ArticleTopicsDesktopComponent.prototype, "vocabularies", void 0);
__decorate([
    Input()
], ArticleTopicsDesktopComponent.prototype, "configCarousel", void 0);
__decorate([
    Output()
], ArticleTopicsDesktopComponent.prototype, "redirectPage", void 0);
ArticleTopicsDesktopComponent = __decorate([
    Component({
        selector: 'dmmp-article-topics-desktop',
        template: "<ng-container *ngIf=\"vocabularies?.length > 0\">\r\n  <ng-container *ngIf=\"vocabularies?.length <= 8\"\r\n  >\r\n    <div class=\"row\">\r\n      <ng-container *ngFor=\"let term of vocabularies\">\r\n        <div class=\"col-12 col-md-3 box-vocabulary\">\r\n          <ng-container *ngIf=\"term?.name\">\r\n            <dmmp-path-link [path]=\"term?.path\" (page)=\"redirectPage.emit($event)\">\r\n              <div class=\"box-term\">\r\n                <p [ngClass]=\"term?.class || ''\">\r\n                  {{ term?.name }}\r\n                </p>\r\n              </div>\r\n            </dmmp-path-link>\r\n          </ng-container>\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"vocabularies?.length > 8\">\r\n    <owl-carousel-o [options]=\"configCarousel\">\r\n      <ng-container *ngIf=\"carouselVocabularies?.length > 0\">\r\n        <ng-container *ngFor=\"let vocabularies of carouselVocabularies\">\r\n          <ng-template carouselSlide>\r\n            <div class=\"row\">\r\n              <ng-container *ngFor=\"let term of vocabularies?.slide\">\r\n                <div class=\"col-3 box-vocabulary\">\r\n                  <ng-container *ngIf=\"term?.name\">\r\n                    <dmmp-path-link\r\n                      [path]=\"term?.path\"\r\n                      (page)=\"redirectPage.emit($event)\"\r\n                    >\r\n                      <div class=\"box-term\">\r\n                        <p [ngClass]=\"term?.class || ''\">\r\n                          {{ term.name }}\r\n                        </p>\r\n                      </div>\r\n                    </dmmp-path-link>\r\n                  </ng-container>\r\n                </div>\r\n              </ng-container>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </ng-container>\r\n    </owl-carousel-o>\r\n  </ng-container>\r\n</ng-container>\r\n"
    })
], ArticleTopicsDesktopComponent);

let ArticleTopicsMobileComponent = class ArticleTopicsMobileComponent {
    constructor() {
        this.redirectPage = new EventEmitter();
        this.carouselVocabularies = [];
    }
    ngOnInit() {
        let lengthSlide = 4;
        if (this.vocabularies.length > 4) {
            for (let i = 0; i < this.vocabularies.length; i += lengthSlide) {
                let slide = this.vocabularies.slice(i, i + lengthSlide);
                this.carouselVocabularies.push({ slide: slide });
            }
        }
    }
};
__decorate([
    Input()
], ArticleTopicsMobileComponent.prototype, "vocabularies", void 0);
__decorate([
    Input()
], ArticleTopicsMobileComponent.prototype, "configCarousel", void 0);
__decorate([
    Output()
], ArticleTopicsMobileComponent.prototype, "redirectPage", void 0);
ArticleTopicsMobileComponent = __decorate([
    Component({
        selector: 'dmmp-article-topics-mobile',
        template: "<ng-container *ngIf=\"vocabularies?.length > 0\">\r\n  <ng-container *ngIf=\"vocabularies?.length <= 4\">\r\n    <div class=\"row\">\r\n      <ng-container *ngFor=\"let term of vocabularies\">\r\n        <div class=\"col-6 box-vocabulary\">\r\n          <ng-container *ngIf=\"term?.name\">\r\n            <dmmp-path-link [path]=\"term?.path\" (page)=\"redirectPage.emit($event)\">\r\n              <div class=\"box-term\">\r\n                <p [ngClass]=\"term?.class || ''\">\r\n                  {{ term?.name }}\r\n                </p>\r\n              </div>\r\n            </dmmp-path-link>\r\n          </ng-container>\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"vocabularies?.length > 4\">\r\n    <owl-carousel-o [options]=\"configCarousel\">\r\n      <ng-container *ngFor=\"let vocabularies of carouselVocabularies\">\r\n        <ng-template carouselSlide>\r\n          <div class=\"row\">\r\n            <ng-container *ngFor=\"let term of vocabularies?.slide\">\r\n              <div class=\"col-6 box-vocabulary\">\r\n                <ng-container *ngIf=\"term?.name\">\r\n                  <dmmp-path-link\r\n                    [path]=\"term?.path\"\r\n                    (page)=\"redirectPage.emit($event)\"\r\n                  >\r\n                    <div class=\"box-term\">\r\n                      <p [ngClass]=\"term?.class || ''\">\r\n                        {{ term?.name }}\r\n                      </p>\r\n                    </div>\r\n                  </dmmp-path-link>\r\n                </ng-container>\r\n              </div>\r\n            </ng-container>\r\n          </div>\r\n        </ng-template>\r\n      </ng-container>\r\n    </owl-carousel-o>\r\n  </ng-container>\r\n</ng-container>\r\n"
    })
], ArticleTopicsMobileComponent);

let ArticleTopicsModule = class ArticleTopicsModule {
};
ArticleTopicsModule = __decorate([
    NgModule({
        declarations: [
            ArticleTopicsComponent,
            ArticleTopicsDesktopComponent,
            ArticleTopicsMobileComponent,
        ],
        exports: [
            ArticleTopicsComponent,
            ArticleTopicsDesktopComponent,
            ArticleTopicsMobileComponent,
        ],
        imports: [CommonModule, SharedModule, CarouselModule],
    })
], ArticleTopicsModule);

let DescriptiveEventTableComponent = class DescriptiveEventTableComponent {
    constructor(router) {
        this.router = router;
        this.redirectPage = new EventEmitter();
    }
    dynamicGoTo(link, itemLinks) {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        if ((_a = itemLinks) === null || _a === void 0 ? void 0 : _a.is_topic) {
            this.router.navigate([this.pathTo], {
                queryParams: { topic: (_c = (_b = this.layout) === null || _b === void 0 ? void 0 : _b.topic[0]) === null || _c === void 0 ? void 0 : _c.id }
            });
            this.redirectPage.emit();
            return;
        }
        if (((_d = itemLinks) === null || _d === void 0 ? void 0 : _d.is_contact) && ((_e = this.layout) === null || _e === void 0 ? void 0 : _e.email)) {
            window.open(`mailto:${(_f = this.layout) === null || _f === void 0 ? void 0 : _f.email}`);
            return;
        }
        if (((_g = link) === null || _g === void 0 ? void 0 : _g.name) !== '') {
            window.open((_h = link) === null || _h === void 0 ? void 0 : _h.link, '_blank');
        }
    }
};
DescriptiveEventTableComponent.ctorParameters = () => [
    { type: Router }
];
__decorate([
    Input()
], DescriptiveEventTableComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], DescriptiveEventTableComponent.prototype, "module", void 0);
__decorate([
    Input()
], DescriptiveEventTableComponent.prototype, "layout", void 0);
__decorate([
    Input()
], DescriptiveEventTableComponent.prototype, "pathTo", void 0);
__decorate([
    Output()
], DescriptiveEventTableComponent.prototype, "redirectPage", void 0);
DescriptiveEventTableComponent = __decorate([
    Component({
        selector: 'dmmp-descriptive-event-table',
        template: "<dmmp-container\r\n  *ngIf=\"module\"\r\n  [data]=\"module\"\r\n  [identifier]=\"identifier ? identifier : ''\"\r\n  [defaultClass]=\"'website-descriptive-table'\"\r\n>\r\n  <div class=\"container\">\r\n    <div *ngIf=\"module?.events_items\"\r\n         [class]=\"'items-' + module?.events_items?.length\"\r\n         class=\"row\">\r\n      <div *ngFor=\"let event of module?.events_items; first as first\" class=\"col-sm-12 col-md-6\">\r\n        <h6 [class]=\"event?.item_class || ''\">{{ event?.title }}</h6>\r\n        <ng-container *ngIf=\"event?.events_item?.length > 0\">\r\n          <div *ngFor=\"let eventItem of event?.events_item\">\r\n            <ng-container *ngIf=\"eventItem?.items_links?.length > 0\">\r\n              <div *ngFor=\"let itemLinks of eventItem?.items_links\">\r\n                <ng-container *ngIf=\"itemLinks?.link?.length > 0\">\r\n                  <a [target]=\"itemLinks?.items_target || ''\"\r\n                     (click)=\"dynamicGoTo(links, event)\"\r\n                     *ngFor=\"let links of itemLinks?.link\">\r\n                    {{ itemLinks?.link[0]?.name }}</a>\r\n                </ng-container>\r\n              </div>\r\n            </ng-container>\r\n          </div>\r\n        </ng-container>\r\n        <hr/>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], DescriptiveEventTableComponent);

let DescriptiveEventTableModule = class DescriptiveEventTableModule {
};
DescriptiveEventTableModule = __decorate([
    NgModule({
        declarations: [DescriptiveEventTableComponent],
        imports: [
            CommonModule,
            SharedModule,
            PipesModule,
            RouterModule,
        ],
        exports: [DescriptiveEventTableComponent]
    })
], DescriptiveEventTableModule);

let WebsiteSocialNetworkCardsComponent = class WebsiteSocialNetworkCardsComponent {
    constructor(instagramService) {
        this.instagramService = instagramService;
        this.responseDataInstagram = [];
    }
    ngOnInit() {
        var _a, _b, _c;
        if (((_b = (_a = this.module) === null || _a === void 0 ? void 0 : _a.social_network_card) === null || _b === void 0 ? void 0 : _b.length) > 0) {
            from((_c = this.module) === null || _c === void 0 ? void 0 : _c.social_network_card).pipe(concatMap((data) => {
                var _a, _b, _c, _d;
                if (((_a = data) === null || _a === void 0 ? void 0 : _a.social_network_type) === 'instagram') {
                    if (((_c = (_b = data) === null || _b === void 0 ? void 0 : _b.links) === null || _c === void 0 ? void 0 : _c.length) > 0) {
                        return from((_d = data) === null || _d === void 0 ? void 0 : _d.links)
                            .pipe(concatMap(((res) => {
                            return this.instagramService.getInfoVideo(res.value).pipe(tap((response) => {
                                this.responseDataInstagram.push(response);
                            }));
                        })));
                    }
                }
                else {
                    return EMPTY;
                }
            })).subscribe();
        }
    }
    executeProcess() {
        instgrm.Embeds.process();
        return true;
    }
    ngAfterViewInit() {
        if (FB != null && FB.XFBML != null) {
            FB.XFBML.parse();
        }
        let ngJs;
        const ngFjs = document.getElementsByTagName('script')[0];
        const ngP = 'https';
        if (!document.getElementById('twitter-wjs')) {
            ngJs = document.createElement('script');
            ngJs.id = 'twitter-wjs';
            ngJs.src = ngP + '://platform.twitter.com/widgets.js';
            ngFjs.parentNode.insertBefore(ngJs, ngFjs);
        }
    }
};
WebsiteSocialNetworkCardsComponent.ctorParameters = () => [
    { type: InstagramService }
];
__decorate([
    Input()
], WebsiteSocialNetworkCardsComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteSocialNetworkCardsComponent.prototype, "identifier", void 0);
WebsiteSocialNetworkCardsComponent = __decorate([
    Component({
        selector: 'dmmp-website-social-network-cards',
        template: "<dmmp-container\r\n  [data]=\"module\"\r\n  [defaultClass]=\"'website-social-network-cards'\"\r\n  [identifier]=\"identifier || ''\">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">\r\n      {{module?.name}}\r\n    </h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"row justify-content-center\" *ngIf=\"module?.social_network_card?.length > 0\">\r\n      <div *ngFor=\"let dat of module?.social_network_card | slice : 0 : 3\"\r\n           [ngClass]=\"module?.number_columns <= 5 ? 'col-md-12' : module?.number_columns <= 7 ? 'col-md-6' : 'col-md-4'\"\r\n           class=\"col-12 col-sm-12\">\r\n        <div class=\"content-social-network\">\r\n          <p *ngIf=\"dat?.title\" [ngClass]=\"dat?.title_class || ''\">{{dat?.title}}</p>\r\n          <ng-container *ngIf=\"dat?.social_network_type === 'facebook'\">\r\n            <div *ngIf=\"dat?.links?.length > 0\"\r\n                 class=\"social-network facebook-content\"\r\n                 [ngClass]=\"dat?.content_class || ''\">\r\n              <div *ngIf=\"dat?.links[0]?.value\" class=\"fb-page\" [attr.data-href]=\"dat?.links[0]?.value\"\r\n                   data-tabs=\"timeline\"\r\n                   data-width=\"\" data-height=\"\"\r\n                   data-small-header=\"true\" data-adapt-container-width=\"true\"\r\n                   data-hide-cover=\"true\" data-show-facepile=\"true\"></div>\r\n            </div>\r\n          </ng-container>\r\n          <ng-container *ngIf=\"dat?.social_network_type === 'twitter'\">\r\n            <div *ngIf=\"dat?.links?.length > 0\"\r\n                 class=\"social-network twitter-content\"\r\n                 [ngClass]=\"dat?.content_class || ''\">\r\n              <a *ngIf=\"dat?.links[0]?.value\"\r\n                 class=\"twitter-timeline\" [href]=\"dat?.links[0]?.value\"\r\n                 data-chrome=\"nofooter noborders\"></a>\r\n            </div>\r\n          </ng-container>\r\n          <ng-container *ngIf=\"dat?.social_network_type === 'instagram'\">\r\n            <div *ngIf=\"responseDataInstagram?.length > 0\"\r\n                 class=\"social-network instagram-content\"\r\n                 [ngClass]=\"dat?.content_class || ''\">\r\n              <ng-container *ngFor=\"let story of responseDataInstagram; last as last\">\r\n                <div\r\n                  *ngIf=\"last ? executeProcess() : true\"\r\n                  [outerHTML]=\"story?.html\">\r\n                </div>\r\n              </ng-container>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteSocialNetworkCardsComponent);

let WebsiteSocialNetworkCardsModule = class WebsiteSocialNetworkCardsModule {
};
WebsiteSocialNetworkCardsModule = __decorate([
    NgModule({
        declarations: [WebsiteSocialNetworkCardsComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [WebsiteSocialNetworkCardsComponent]
    })
], WebsiteSocialNetworkCardsModule);

let BasicPageComponent = class BasicPageComponent {
    constructor() { }
    ngOnInit() {
    }
};
__decorate([
    Input()
], BasicPageComponent.prototype, "module", void 0);
__decorate([
    Input()
], BasicPageComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], BasicPageComponent.prototype, "detailLayout", void 0);
BasicPageComponent = __decorate([
    Component({
        selector: 'dmmp-basic-page',
        template: "<div class=\"basic-page\">\r\n  <div class=\"container\">\r\n    <div class=\"row\">\r\n      <ng-container *ngIf=\"module?.visible\">\r\n        <!-- Left Content -->\r\n        <div\r\n          *ngIf=\"detailLayout?.left?.length > 0\"\r\n          [class]=\"'col-12 col-lg-' + module?.size_left\"\r\n          [style.background]=\"module?.background_left\"\r\n        >\r\n          <div *ngFor=\"let left of detailLayout?.left\">\r\n            <dmmp-basic-content\r\n              [module]=\"module\"\r\n              [identifier]=\"identifier\"\r\n              [data]=\"left\"\r\n            ></dmmp-basic-content>\r\n          </div>\r\n        </div>\r\n        <!-- Right Content -->\r\n        <div\r\n          *ngIf=\"detailLayout?.right?.length > 0\"\r\n          [class]=\"'col-12 col-lg-' + module?.size_right\"\r\n          [style.background]=\"module?.background_right\"\r\n        >\r\n          <div *ngFor=\"let right of detailLayout?.right\">\r\n            <dmmp-basic-content\r\n              [module]=\"module\"\r\n              [identifier]=\"identifier\"\r\n              [data]=\"right\"\r\n            ></dmmp-basic-content>\r\n          </div>\r\n        </div>\r\n        <!-- Full Content -->\r\n        <div\r\n          *ngIf=\"detailLayout?.full?.length > 0\"\r\n          [class]=\"'col-12 col-lg-' + module?.size_left_to_right\"\r\n          [style.background]=\"module?.background_left_to_right\"\r\n        >\r\n          <div *ngFor=\"let full of detailLayout?.full\">\r\n            <dmmp-basic-content\r\n              [module]=\"module\"\r\n              [identifier]=\"identifier\"\r\n              [data]=\"full\"\r\n            ></dmmp-basic-content>\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n  </div>\r\n</div>\r\n\r\n\r\n\r\n\r\n\r\n"
    })
], BasicPageComponent);

let SubcontentBulletsComponent = class SubcontentBulletsComponent {
    constructor() { }
    ngOnInit() {
    }
};
__decorate([
    Input()
], SubcontentBulletsComponent.prototype, "bullets", void 0);
SubcontentBulletsComponent = __decorate([
    Component({
        selector: 'dmmp-subcontent-bullets',
        template: "<ng-container>\r\n  <ul class=\"bullets\" *ngIf=\"bullets?.length > 0\">\r\n    <li *ngFor=\"let bullet of bullets\">\r\n      {{bullet?.value}}\r\n    </li>\r\n  </ul>\r\n</ng-container>\r\n"
    })
], SubcontentBulletsComponent);

let SubcontentComponent = class SubcontentComponent {
    constructor() { }
    ngOnInit() {
    }
};
__decorate([
    Input()
], SubcontentComponent.prototype, "module", void 0);
__decorate([
    Input()
], SubcontentComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SubcontentComponent.prototype, "subcontentInfo", void 0);
SubcontentComponent = __decorate([
    Component({
        selector: 'dmmp-subcontent',
        template: "<dmmp-subcontent-view\r\n  [title]=\"subcontentInfo?.title\"\r\n  [title_hidden]=\"subcontentInfo?.title_hidden\"\r\n  [icon]=\"subcontentInfo?.icon\"\r\n  [body]=\"subcontentInfo?.body\"\r\n  [image]=\"subcontentInfo?.image\"\r\n  [image_on_text]=\"subcontentInfo?.image_over_text\"\r\n  [image_class]=\"subcontentInfo?.image_class\"\r\n  [title_class]=\"subcontentInfo?.title_class\"\r\n  [separator]=\"subcontentInfo?.field_subcontet_show_separator\"\r\n>\r\n</dmmp-subcontent-view>\r\n\r\n<ng-container *ngIf=\"subcontentInfo?.links?.length > 0\">\r\n  <dmmp-subcontent-links [links]=\"subcontentInfo?.links\"></dmmp-subcontent-links>\r\n</ng-container>\r\n\r\n<ng-container *ngIf=\"subcontentInfo?.list\">\r\n  <dmmp-subcontent-bullets [bullets]=\"subcontentInfo?.list\"></dmmp-subcontent-bullets>\r\n</ng-container>\r\n"
    })
], SubcontentComponent);

let SubcontentLinksComponent = class SubcontentLinksComponent {
    constructor() { }
    ngOnInit() {
    }
};
__decorate([
    Input()
], SubcontentLinksComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SubcontentLinksComponent.prototype, "links", void 0);
__decorate([
    Input()
], SubcontentLinksComponent.prototype, "target", void 0);
__decorate([
    Input()
], SubcontentLinksComponent.prototype, "image", void 0);
SubcontentLinksComponent = __decorate([
    Component({
        selector: 'dmmp-subcontent-links',
        template: "<ul class=\"item-link\">\r\n  <li *ngFor=\"let linkInfo of links\">\r\n    <dmmp-simple-link\r\n    [data]=\"linkInfo\"\r\n    [identifier]=\"identifier\"\r\n    >\r\n      {{linkInfo?.link[0]?.name}}\r\n    </dmmp-simple-link>\r\n  </li>\r\n</ul>\r\n"
    })
], SubcontentLinksComponent);

let SubcontentViewComponent = class SubcontentViewComponent {
    constructor() {
        this.medias = [
            { style: 'large', media: '(min-width:421px)' },
        ];
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], SubcontentViewComponent.prototype, "title", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "title_class", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "title_hidden", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "body", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "image", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "image_class", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "icon", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "image_on_text", void 0);
__decorate([
    Input()
], SubcontentViewComponent.prototype, "separator", void 0);
SubcontentViewComponent = __decorate([
    Component({
        selector: 'dmmp-subcontent-view',
        template: "<div [class]=\"separator ? 'border-box' : ''\" *ngIf=\"image_on_text else noImgOnText\">\r\n  <ng-container *ngIf=\"!title_hidden\">\r\n    <p class=\"title\" [ngClass]=\"title_class || ''\">\r\n      <i *ngIf=\"icon\" [class]=\"icon\"></i>\r\n      {{title}}\r\n    </p>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"image?.length > 0\">\r\n    <dmmp-image [defaultClass]=\"image_class\" [images]=\"image[0]\" [medias]=\"medias\"></dmmp-image>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"body\">\r\n    <div [outerHTML]=\"body | safe : 'html'\"></div>\r\n  </ng-container>\r\n</div>\r\n\r\n<ng-template #noImgOnText>\r\n  <div class=\"container\">\r\n    <div class=\"row\" [class]=\"separator ? 'border-box' : ''\">\r\n      <div class=\"col-12\">\r\n        <ng-container *ngIf=\"!title_hidden\">\r\n          <p class=\"title\" [ngClass]=\"title_class || ''\">\r\n            <i *ngIf=\"icon\" [class]=\"icon\"></i>\r\n            {{title}}\r\n          </p>\r\n        </ng-container>\r\n      </div>\r\n      <div class=\"col-12 col-lg-3\">\r\n        <ng-container *ngIf=\"image?.length > 0\">\r\n          <dmmp-image [defaultClass]=\"image_class\" [images]=\"image[0]\" [medias]=\"medias\"></dmmp-image>\r\n        </ng-container>\r\n      </div>\r\n      <div class=\"col-12 col-lg-9\">\r\n        <ng-container *ngIf=\"body\">\r\n          <div [outerHTML]=\"body | safe : 'html'\"></div>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n"
    })
], SubcontentViewComponent);

let BasicPageGalleryComponent = class BasicPageGalleryComponent {
    constructor(options) {
        this.options = options;
    }
    ngOnInit() {
        this.configCarrousel = this.options.configurationBenefits(this.module);
    }
};
BasicPageGalleryComponent.ctorParameters = () => [
    { type: OptionsNgxOwCarouselService }
];
__decorate([
    Input()
], BasicPageGalleryComponent.prototype, "data", void 0);
__decorate([
    Input()
], BasicPageGalleryComponent.prototype, "module", void 0);
__decorate([
    Input()
], BasicPageGalleryComponent.prototype, "identifier", void 0);
BasicPageGalleryComponent = __decorate([
    Component({
        selector: 'dmmp-gallery',
        template: "<div *ngIf=\"module?.visible\">\r\n  <div class=\"container gallery-box\">\r\n    <ng-container *ngIf=\"data?.length > 0\">\r\n      <owl-carousel-o [options]=\"configCarrousel\" class=\"row\">\r\n        <ng-container *ngFor=\"let slide of data\">\r\n          <ng-template carouselSlide>\r\n            <div class=\"col\">\r\n              <div class=\"slide\">\r\n                <div>\r\n                  <img *ngIf=\"slide?.image?.length > 0\"\r\n                       [src]=\"slide?.image[0]?.styles?.large\"\r\n                       [alt]=\"slide?.image[0]?.texts?.alt\"\r\n                       [title]=\"slide?.image[0]?.texts?.title\"\r\n                  />\r\n                </div>\r\n              </div>\r\n            </div>\r\n          </ng-template>\r\n        </ng-container>\r\n      </owl-carousel-o>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n"
    })
], BasicPageGalleryComponent);

let BasicContentComponent = class BasicContentComponent {
    constructor() { }
    ngOnInit() {
    }
};
__decorate([
    Input()
], BasicContentComponent.prototype, "module", void 0);
__decorate([
    Input()
], BasicContentComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], BasicContentComponent.prototype, "data", void 0);
BasicContentComponent = __decorate([
    Component({
        selector: 'dmmp-basic-content',
        template: "<dmmp-subcontent\r\n  *ngIf=\"data?.identifier === 'subcontent'\"\r\n  [subcontentInfo]=\"data\"\r\n  [module]=\"module\">\r\n</dmmp-subcontent>\r\n\r\n<dmmp-gallery\r\n  *ngIf=\"data?.identifier === 'gallery'\"\r\n  [data]=\"data?.items\"\r\n  [module]=\"module\"\r\n  [identifier]=\"data?.identifier\"\r\n>\r\n</dmmp-gallery>\r\n"
    })
], BasicContentComponent);

let BasicPageModule = class BasicPageModule {
};
BasicPageModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            CarouselModule,
            PipesModule
        ],
        declarations: [
            BasicPageComponent,
            SubcontentBulletsComponent,
            SubcontentComponent,
            SubcontentLinksComponent,
            SubcontentViewComponent,
            BasicPageGalleryComponent,
            BasicContentComponent
        ],
        exports: [BasicPageComponent],
        providers: [],
    })
], BasicPageModule);

let WebsiteDetailCampusInfoComponent = class WebsiteDetailCampusInfoComponent {
    constructor() {
        this.city = 'Ciudad:';
        this.telephone = 'Tel:';
        this.street = 'Dirección:';
    }
};
__decorate([
    Input()
], WebsiteDetailCampusInfoComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], WebsiteDetailCampusInfoComponent.prototype, "module", void 0);
__decorate([
    Input()
], WebsiteDetailCampusInfoComponent.prototype, "detailLayout", void 0);
__decorate([
    Input()
], WebsiteDetailCampusInfoComponent.prototype, "city", void 0);
__decorate([
    Input()
], WebsiteDetailCampusInfoComponent.prototype, "telephone", void 0);
__decorate([
    Input()
], WebsiteDetailCampusInfoComponent.prototype, "street", void 0);
WebsiteDetailCampusInfoComponent = __decorate([
    Component({
        selector: 'dmmp-website-detail-campus-info',
        template: "<dmmp-container\r\n  *ngIf=\"module\"\r\n  [data]=\"module\"\r\n  [identifier]=\"identifier\"\r\n  [defaultClass]=\"'website-detail-campus-info'\r\n  \">\r\n  <div class=\"container\">\r\n    <h2 *ngIf=\"module?.name\"\r\n        [ngClass]=\"module?.title_class || ''\">\r\n      {{module?.name}}\r\n    </h2>\r\n    <ng-container *ngIf=\"module?.texts?.length > 0\">\r\n      <div\r\n        *ngFor=\"let textContent of module?.texts\"\r\n        [ngClass]=\"textContent?.class || ''\"\r\n        [innerHTML]=\"textContent?.text || ''\"\r\n      ></div>\r\n    </ng-container>\r\n    <div class=\"info-detail-campus\">\r\n      <div class=\"content-info\">\r\n        <p *ngIf=\"detailLayout?.title\" class=\"title\">{{detailLayout?.title}}</p>\r\n        <p *ngIf=\"detailLayout?.street\">{{street}} {{detailLayout?.street}}</p>\r\n        <p *ngIf=\"detailLayout?.city || detailLayout?.country\">\r\n          {{city}} {{detailLayout?.city ? detailLayout?.city + ', ' : ''}}\r\n          {{detailLayout?.country ? detailLayout?.country + '. ' : ''}}\r\n        </p>\r\n        <p *ngIf=\"detailLayout?.phone\" class=\"icon-tel\">{{telephone}} <a\r\n          href=\"tel:{{detailLayout?.phone}}\">{{detailLayout?.phone}}</a></p>\r\n        <p *ngIf=\"detailLayout?.email\" class=\"icon-email\"><a\r\n          href=\"mailto:{{detailLayout?.email}}\">{{detailLayout?.email}}</a></p>\r\n        <ng-container *ngIf=\"detailLayout?.additional_information\">\r\n          <div [outerHTML]=\"detailLayout?.additional_information\"></div>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</dmmp-container>\r\n"
    })
], WebsiteDetailCampusInfoComponent);

let WebsiteDetailCampusInfoModule = class WebsiteDetailCampusInfoModule {
};
WebsiteDetailCampusInfoModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            BrowserModule,
            CommonModule,
            SharedModule,
            NgbNavModule,
            RouterModule,
            PipesModule
        ],
        declarations: [WebsiteDetailCampusInfoComponent],
        exports: [
            WebsiteDetailCampusInfoComponent
        ],
        providers: []
    })
], WebsiteDetailCampusInfoModule);

let SearchPaginatorComponent = class SearchPaginatorComponent {
    constructor() {
        this.selectedPage = new EventEmitter();
    }
};
__decorate([
    Input()
], SearchPaginatorComponent.prototype, "module", void 0);
__decorate([
    Input()
], SearchPaginatorComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], SearchPaginatorComponent.prototype, "defaultClass", void 0);
__decorate([
    Input()
], SearchPaginatorComponent.prototype, "currentPage", void 0);
__decorate([
    Input()
], SearchPaginatorComponent.prototype, "totalPages", void 0);
__decorate([
    Output()
], SearchPaginatorComponent.prototype, "selectedPage", void 0);
SearchPaginatorComponent = __decorate([
    Component({
        selector: 'dmmp-search-paginator',
        template: "<dmmp-container [data]=\"module\" [defaultClass]=\"defaultClass\" [identifier]=\"identifier\">\r\n  <div class=\"container\">\r\n    <ng-container *ngIf=\"module?.pager_type\" [ngSwitch]=\"module.pager_type\">\r\n      <ng-container *ngSwitchCase=\"'numbers'\">\r\n        <dmmp-numbers-paginator (selectedPage)=\"selectedPage.emit($event)\" [currentPage]=\"currentPage\"\r\n          [totalPages]=\"totalPages\">\r\n        </dmmp-numbers-paginator>\r\n      </ng-container>\r\n      <ng-container *ngSwitchCase=\"'pages'\">\r\n        <dmmp-go-to-paginator [currentIndex]=\"currentPage\" (selectedPage)=\"selectedPage.emit($event)\"\r\n          [totalPages]=\"totalPages\">\r\n        </dmmp-go-to-paginator>\r\n      </ng-container>\r\n      <ng-container *ngSwitchCase=\"'view_more'\">\r\n        <dmmp-see-more-paginator [currentPage]=\"currentPage\" [module]=\"module\" [totalPages]=\"totalPages\"\r\n          (selectedPage)=\"selectedPage.emit($event)\">\r\n        </dmmp-see-more-paginator>\r\n      </ng-container>\r\n    </ng-container>\r\n\r\n  </div>\r\n</dmmp-container>\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], SearchPaginatorComponent);

let NumbersPaginatorComponent = class NumbersPaginatorComponent {
    constructor() {
        this.selectedPage = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (changes.currentPage ? changes.currentPage.currentValue : false) {
            this.pagination(changes.currentPage.currentValue, this.totalPages);
        }
        if (changes.totalPages ? changes.totalPages.currentValue : false) {
            this.pagination(this.currentPage, changes.totalPages.currentValue);
        }
    }
    ngOnInit() {
        this.pagination(this.currentPage, this.totalPages);
    }
    getRange(start, end) {
        return Array(end - start + 1)
            .fill(end - start + 1)
            .map((v, i) => i + start);
    }
    pagination(current, length, delta = 3) {
        const range = {
            start: Math.round(current - delta / 2),
            end: Math.round(current + delta / 2),
        };
        if (range.start - 1 === 1 || range.end + 1 === length) {
            range.start += 1;
            range.end += 1;
        }
        let pages = current > delta
            ? this.getRange(Math.min(range.start, length - delta), Math.min(range.end, length))
            : this.getRange(1, Math.min(length, delta + 1));
        const withDots = (value, pair) => pages.length + 1 !== length ? pair : [value];
        if (pages[0] !== 1) {
            pages = withDots(1, [1, '...']).concat(pages);
        }
        if (pages[pages.length - 1] < length) {
            pages = pages.concat(withDots(length, ['...', length]));
        }
        this._array = pages;
    }
    nextPage() {
        this.selectedPage.emit(++this.currentPage);
    }
    backPage() {
        this.selectedPage.emit(--this.currentPage);
    }
    goToPage(item) {
        if (item !== '...') {
            this.selectedPage.emit(item - 1);
        }
    }
};
__decorate([
    Input()
], NumbersPaginatorComponent.prototype, "currentPage", void 0);
__decorate([
    Input()
], NumbersPaginatorComponent.prototype, "totalPages", void 0);
__decorate([
    Output()
], NumbersPaginatorComponent.prototype, "selectedPage", void 0);
NumbersPaginatorComponent = __decorate([
    Component({
        selector: 'dmmp-numbers-paginator',
        template: "<div class=\"row\">\r\n  <div class=\"col col-arrow first\">\r\n    <button (click)=\"backPage()\" [disabled]=\"(currentPage + 1) == _array[0]\">\r\n      <i class=\"fas fa-chevron-left\"></i>\r\n    </button>\r\n  </div>\r\n  <div class=\"col\" [ngClass]=\"{ 'active': item == currentPage + 1 }\" (click)=\"goToPage(item)\"\r\n    *ngFor=\"let item of _array\">\r\n    {{ item }}\r\n  </div>\r\n  <div class=\"col col-arrow last\">\r\n    <button (click)=\"nextPage()\" [disabled]=\"(currentPage + 1) == totalPages\">\r\n      <i class=\"fas fa-chevron-right\"></i>\r\n    </button>\r\n  </div>\r\n</div>\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        encapsulation: ViewEncapsulation.None
    })
], NumbersPaginatorComponent);

let GoToPaginatorComponent = class GoToPaginatorComponent {
    constructor() {
        this.currentIndex = 1;
        this.selectedPage = new EventEmitter();
        this.createForm();
    }
    ngOnInit() {
        this.listenInputChanges();
    }
    createForm() {
        this.control = new FormControl(this.currentIndex, [
            Validators.min(1)
        ]);
    }
    listenInputChanges() {
        this.control.valueChanges
            .pipe(tap(it => this.selectedPage.emit(it - 1)), untilDestroyed(this)).subscribe();
    }
    sendIndex(event) {
        if (this.control.value > this.totalPages) {
            this.control.setValue(this.totalPages);
        }
        if (this.control.value <= 0) {
            this.control.setValue(1);
        }
    }
    nextBtn() {
        if (this.control.value <= this.totalPages) {
            const next = Number(this.control.value) + 1;
            this.control.setValue(next);
        }
    }
    backBtn() {
        if (this.control.value !== 1) {
            const back = Number(this.control.value) - 1;
            this.control.setValue(back);
        }
    }
};
__decorate([
    Input()
], GoToPaginatorComponent.prototype, "totalPages", void 0);
__decorate([
    Input()
], GoToPaginatorComponent.prototype, "currentIndex", void 0);
__decorate([
    Output()
], GoToPaginatorComponent.prototype, "selectedPage", void 0);
GoToPaginatorComponent = __decorate([
    UntilDestroy(),
    Component({
        selector: 'dmmp-go-to-paginator',
        template: "<div class=\"col-button col-md-12 col-sm-12\">\r\n  <button class=\"button-green\" [disabled]=\"control.value == totalPages\" (click)=\"nextBtn()\">\r\n    Siguiente\r\n  </button>\r\n</div>\r\n<div class=\"col-goto col-md-3 col-sm-12\">\r\n  <button type=\"button\" [disabled]=\"control.value == 1\" (click)=\"backBtn()\">\r\n    <i class=\"fas fa-chevron-left\"></i>\r\n  </button>\r\n  <input (keyup.arrowUp)=\"sendIndex($event)\" (keyup.arrowDown)=\"sendIndex($event)\" (keyup.enter)=\"sendIndex($event)\"\r\n    type=\"number\" [formControl]=\"control\">\r\n  <button type=\"button\" [disabled]=\"control.value == totalPages\" (click)=\"nextBtn()\">\r\n    <i class=\"fas fa-chevron-right\"></i>\r\n  </button>\r\n  <p>de {{ totalPages }}</p>\r\n</div>\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        encapsulation: ViewEncapsulation.None
    })
], GoToPaginatorComponent);

let SeeMorePaginatorComponent = class SeeMorePaginatorComponent {
    constructor() {
        this.selectedPage = new EventEmitter();
    }
    nextPage() {
        this.selectedPage.emit(++this.currentPage);
    }
};
__decorate([
    Input()
], SeeMorePaginatorComponent.prototype, "currentPage", void 0);
__decorate([
    Input()
], SeeMorePaginatorComponent.prototype, "totalPages", void 0);
__decorate([
    Output()
], SeeMorePaginatorComponent.prototype, "selectedPage", void 0);
__decorate([
    Input()
], SeeMorePaginatorComponent.prototype, "module", void 0);
SeeMorePaginatorComponent = __decorate([
    Component({
        selector: 'dmmp-see-more-paginator',
        template: "<div class=\"row\" *ngIf=\"module?.see_more?.length > 0\">\r\n  <div class=\"col-12\">\r\n    <button [ngClass]=\"module?.see_more[0].class\"\r\n            class=\"button-green\"\r\n            [disabled]=\"(currentPage + 1) == totalPages || totalPages == 0\"\r\n      (click)=\"nextPage()\">{{module?.see_more[0]?.link[0]?.name}}</button>\r\n  </div>\r\n</div>\r\n",
        encapsulation: ViewEncapsulation.None,
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], SeeMorePaginatorComponent);

let SearchPaginatorModule = class SearchPaginatorModule {
};
SearchPaginatorModule = __decorate([
    NgModule({
        declarations: [SearchPaginatorComponent, NumbersPaginatorComponent, GoToPaginatorComponent, SeeMorePaginatorComponent],
        imports: [
            CommonModule,
            SharedModule,
            ReactiveFormsModule,
        ],
        exports: [SearchPaginatorComponent]
    })
], SearchPaginatorModule);

let ButtonFilterComponent = class ButtonFilterComponent {
    constructor() {
        this.defaultClass = 'button-filter';
        this.filtersState = new EventEmitter();
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], ButtonFilterComponent.prototype, "module", void 0);
__decorate([
    Input()
], ButtonFilterComponent.prototype, "identifier", void 0);
__decorate([
    Input()
], ButtonFilterComponent.prototype, "defaultClass", void 0);
__decorate([
    Output()
], ButtonFilterComponent.prototype, "filtersState", void 0);
ButtonFilterComponent = __decorate([
    Component({
        selector: 'dmmp-button-filter',
        template: "<dmmp-container [identifier]=\"identifier\" [data]=\"module\" [defaultClass]=\"defaultClass\">\r\n  <ng-container *ngIf=\"module?.see_more?.length > 0\">\r\n    <button [ngClass]=\"module?.see_more[0]?.class\" (click)=\"filtersState.emit()\">\r\n      {{ module?.see_more[0]?.link[0]?.name }}\r\n    </button>\r\n  </ng-container>\r\n</dmmp-container>\r\n"
    })
], ButtonFilterComponent);

let ButtonFilterModule = class ButtonFilterModule {
};
ButtonFilterModule = __decorate([
    NgModule({
        declarations: [ButtonFilterComponent],
        imports: [
            CommonModule,
            SharedModule
        ],
        exports: [ButtonFilterComponent]
    })
], ButtonFilterModule);

/*
 * Public API Surface of dmmp-components
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AccessFilterImageModule, ArticleTopicsModule, BannerFullModule, BannerGridModule, BannerModule, BannerVideoImageModule, BasicPageModule, BenefitsCarouselModule, BenefitsFiguresModule, BenefitsVideoModule, BreadcrumbModule, ButtonFilterModule, CampusLocationFilterModule, ContentSearchResultModule, ContentTableModule, DescriptionModule, DescriptiveEventTableModule, DirectAccessFilterModule, ErrorPageModule, EventInformationModule, EventLocationModule, EventSearchResultModule, EventsSectionModule, FaqSectionModule, FeaturedEventsModule, FeaturesCarouselModule, FiltersProgrammesModule, FloatObjectModule, FloatingMenuModule, FooterGridModule, FooterModule, FormModule, FourBenefitsModule, FreeTextModule, GeneralProgrammingModule, GeneralSearchResultModule, HeaderModule, IconsTextModule, ImagesEventCarouselModule, InformationCardsModule, LinkImageCampusModule, ListModule, LogosLinkModule, PipesModule, PressRoomModule, ProgramDescBulletsModule, ProgramDescGraficaModule, ProgramDescMixtaModule, ProgramDescSimplificadaModule, ProgramDescTablaModule, ProgrammesResultsModule, ReactiveSearchModule, RecentArticlesModule, SearchErrorModule, SearchHeadModule, SearchPaginatorModule, SharedModule, SvgIconsModule, TagsContentModule, TestimonyStoriesModule, ThanksYouPageModule, TitleModule, WebsiteArticleBannerModule, WebsiteArticleContentModule, WebsiteArticleListModule, WebsiteArticlesFeaturedModule, WebsiteBoxFloatProgramModule, WebsiteBoxFloatProgramV2Module, WebsiteCarouselArticlesFeaturedModule, WebsiteCookiesModule, WebsiteCourseCampusModule, WebsiteCourseDetailedTabsModule, WebsiteCourseDetailedTabsV2Module, WebsiteCourseFilterImageModule, WebsiteDetailCampusInfoModule, WebsiteDetailedBannerModule, WebsiteDetailedTabsModule, WebsiteDropDownFilterModule, WebsiteFeaturedLinkModule, WebsiteFooterModule, WebsiteHeaderModule, WebsiteHeaderV2Module, WebsiteNewsModule, WebsitePreviousOrNextContentModule, WebsiteRelatedContentModule, WebsiteRelatedContentTagsModule, WebsiteRelatedContentUrlModule, WebsiteRelatedProgramsModule, WebsiteSearchFilterModule, WebsiteShareSocialNetworksModule, WebsiteSocialNetworkCardsModule, WebsiteTenuredProfessorModule, WebsiteTrendingArticlesModule, WebsiteUpcomingEventsModule, DescriptionComponent as ɵa, ListComponent as ɵb, WebsiteCardTitleComponent as ɵba, WebsiteCardArticleFeaturedComponent as ɵbb, WebsiteArticleBannerFeaturedComponent as ɵbc, H1Component as ɵbd, VideoPlayerComponent as ɵbe, BackToTopComponent as ɵbf, LinkIconComponent as ɵbg, BannerItemComponent as ɵbh, TextComponent as ɵbi, AccordionComponent as ɵbj, CardHorizontalImageLinkComponent as ɵbk, PathLinkComponent as ɵbl, MapsComponent as ɵbm, CardNewComponent as ɵbn, BannerNewComponent as ɵbo, RelatedContentComponent as ɵbp, CardEventComponent as ɵbq, CardRelatedProgramComponent as ɵbr, VideoGalleryComponent as ɵbs, CardGeneralResultComponent as ɵbt, BannerItemDetailComponent as ɵbu, ShowItemOnUpScrollDirective as ɵbv, HeaderComponent as ɵbw, MobileMenuComponent as ɵbx, ToggleMenuComponent as ɵby, DesktopMenuComponent as ɵbz, IconsTextComponent as ɵc, MenuComponent as ɵca, BreadcrumbComponent as ɵcb, WebsiteHeaderComponent as ɵcc, FooterComponent as ɵcd, EventInformationComponent as ɵce, DesktopComponent as ɵcf, MobileComponent as ɵcg, GeneralProgrammingComponent as ɵch, ModalTemplateComponent as ɵci, SubEventComponent as ɵcj, FooterGridComponent as ɵck, ImageLinkComponent as ɵcl, CollapseItemComponent as ɵcm, ErrorPageComponent as ɵcn, TitleComponent as ɵco, BenefitsCarouselComponent as ɵcp, BannerComponent as ɵcq, BannerFullComponent as ɵcr, FloatObjectComponent as ɵcs, FloatObjectService as ɵct, ThanksYouPageComponent as ɵcu, FourBenefitsComponent as ɵcv, SvgIconsComponent as ɵcw, DetailProgramDescBulletsComponent as ɵcx, ModalProgramDescBulletsComponent as ɵcy, SearchProgramsDescBulletsComponent as ɵcz, FilterProgramsPipe as ɵd, DetailProgramDescGraficaComponent as ɵda, ModalProgramDescGraficaComponent as ɵdb, SearchProgramsDescGraficaComponent as ɵdc, DetailProgramDescMixtaComponent as ɵdd, ModalProgramDescMixtaComponent as ɵde, SearchProgramsDescMixtaComponent as ɵdf, DetailProgramDescSimplificadaComponent as ɵdg, ModalProgramDescSimplificadaComponent as ɵdh, SearchProgramsDescSimplificadaComponent as ɵdi, DetailProgramDescTablaComponent as ɵdj, ModalProgramDescTablaComponent as ɵdk, SearchProgramsDescTablaComponent as ɵdl, FeaturesCarouselComponent as ɵdm, ImagesEventCarouselComponent as ɵdn, BenefitsFiguresComponent as ɵdo, TestimonyStoriesComponent as ɵdp, TestimonyComponent as ɵdq, ButtonComponent$1 as ɵdr, CheckboxComponent as ɵds, SurveyComponent as ɵdt, TextLinkComponent as ɵdu, InputComponent as ɵdv, TextAreaComponent as ɵdw, InputInsideValidationsComponent as ɵdx, SelectComponent as ɵdy, SelectInsideValidationsComponent as ɵdz, SafePipe as ɵe, RadioComponent as ɵea, EventsComponent as ɵeb, StepNumberComponent as ɵec, StepDetailsComponent as ɵed, EventPipe as ɵee, CaptchaComponent as ɵef, FileComponent as ɵeg, FileListComponent as ɵeh, FaqSectionComponent as ɵei, InformationCardsComponent as ɵej, CardComponent as ɵek, MobileComponent$1 as ɵel, DesktopComponent$1 as ɵem, WebsiteFooterComponent as ɵen, DesktopSitemapMenuComponent as ɵeo, MobileSitemapMenuComponent as ɵep, WebsiteDetailedBannerComponent as ɵeq, WebsiteDetailedTabsComponent as ɵer, WebsiteCourseDetailedTabsComponent as ɵes, WebsiteTenuredProfessorComponent as ɵet, WebsiteBoxFloatProgramComponent as ɵeu, WebsiteRelatedProgramsComponent as ɵev, WebsiteArticleListComponent as ɵew, WebsiteArticleBannerComponent as ɵex, WebsiteArticleContentComponent as ɵey, WebsiteSearchFilterComponent as ɵez, EventsPipe as ɵf, WebsiteCarouselArticlesFeaturedComponent as ɵfa, WebsiteArticlesFeaturedComponent as ɵfb, FreeTextComponent as ɵfc, WebsiteDropDownFilterComponent as ɵfd, BannerGridComponent as ɵfe, BannerItemContentComponent as ɵff, BannerContentDesktopComponent as ɵfg, BannerContentMobileComponent as ɵfh, ItemContentComponent as ɵfi, BannerSlideComponent as ɵfj, LogosLinkComponent as ɵfk, LogosLinkIconComponent as ɵfl, HeaderLogoComponent as ɵfm, BenefitsVideoComponent as ɵfn, WebsiteHeaderV2Component as ɵfo, ToggleMenuComponent$1 as ɵfp, ContentRowsComponent as ɵfq, MobileMenuComponent$1 as ɵfr, ItemMenuComponent$1 as ɵfs, CollapseMobileMenuComponent as ɵft, HorizontalMobileMenuComponent as ɵfu, DynamicsModuleModule as ɵfv, DynamicsModuleComponent as ɵfw, DynamicsModuleDirective as ɵfx, ReactiveSearchComponent as ɵfy, ContentSearchComponent as ɵfz, ReplacePipe as ɵg, MultilevelMenuModule as ɵga, MultilevelMenuComponent as ɵgb, ItemMenuComponent as ɵgc, ItemContentComponent$1 as ɵgd, LinkImageCampusComponent as ɵge, CardImageCampusComponent as ɵgf, WebsiteCourseDetailedTabsV2Component as ɵgg, RecentArticlesComponent as ɵgh, WebsiteNewsComponent as ɵgi, FiltersProgrammesComponent as ɵgj, ProgrammesResultsComponent as ɵgk, ResultViewComponent as ɵgl, SearchHeadComponent as ɵgm, WebsiteBoxFloatProgramV2Component as ɵgn, EventLocationComponent as ɵgo, CampusLocationFilterComponent as ɵgp, EventSearchResultComponent as ɵgq, ContentSearchResultComponent as ɵgr, CardComponent$1 as ɵgs, ContentTableComponent as ɵgt, PathLinkTemplateComponent as ɵgu, WebsiteCourseCampusComponent as ɵgv, AccessFilterImageComponent as ɵgw, DirectAccessFilterComponent as ɵgx, EventsSectionComponent as ɵgy, WebsiteRelatedContentTagsComponent as ɵgz, RandomPipe as ɵh, FeaturedEventsComponent as ɵha, BannerVideoImageComponent as ɵhb, BlogViewComponent as ɵhc, NewViewComponent as ɵhd, EventViewComponent as ɵhe, SlideViewComponent as ɵhf, BasicViewComponent as ɵhg, WebsiteCourseFilterImageComponent as ɵhh, WebsiteRelatedContentUrlComponent as ɵhi, SearchErrorComponent as ɵhj, WebsiteTrendingArticlesComponent as ɵhk, WebsiteFeaturedLinkComponent as ɵhl, WebsiteRelatedContentComponent as ɵhm, WebsiteCookiesComponent as ɵhn, FloatingMenuComponent as ɵho, WebsiteShareSocialNetworksComponent as ɵhp, PressRoomComponent as ɵhq, GeneralSearchResultComponent as ɵhr, WebsitePreviousOrNextContentComponent as ɵhs, WebsiteUpcomingEventsComponent as ɵht, TagsContentComponent as ɵhu, ArticleTopicsComponent as ɵhv, ArticleTopicsDesktopComponent as ɵhw, ArticleTopicsMobileComponent as ɵhx, DescriptiveEventTableComponent as ɵhy, WebsiteSocialNetworkCardsComponent as ɵhz, TruncateTextPipe as ɵi, BasicPageComponent as ɵia, SubcontentBulletsComponent as ɵib, SubcontentComponent as ɵic, SubcontentLinksComponent as ɵid, SubcontentViewComponent as ɵie, BasicPageGalleryComponent as ɵif, BasicContentComponent as ɵig, WebsiteDetailCampusInfoComponent as ɵih, SearchPaginatorComponent as ɵii, NumbersPaginatorComponent as ɵij, GoToPaginatorComponent as ɵik, SeeMorePaginatorComponent as ɵil, ButtonFilterComponent as ɵim, ColorOpacityPipe as ɵj, BackgroundImagePipe as ɵk, RemoveHtmlPipe as ɵl, DeleteCharactersFilePipe as ɵm, HighligthSearchText as ɵn, ContentTypePipe as ɵo, ContainerComponent as ɵp, ImageComponent as ɵq, PdfViewerComponent as ɵr, EmbedComponent as ɵs, ModalComponent as ɵt, ButtonComponent as ɵu, PaginatorComponent as ɵv, ImageLogoComponent as ɵw, LinkComponent as ɵx, SimpleLinkComponent as ɵy, WebsiteCardProgramComponent as ɵz };
//# sourceMappingURL=dmmp-components.js.map
